@@ -82,16 +82,16 @@ class Parser(object):
         try:
             self.doc =  minidom.parse(XMLFileName)
         except:
-            print "No file of parameters or error in the name of the file or error in the syntax of the xml.\n"
+            print("No file of parameters or error in the name of the file or error in the syntax of the xml.\n")
             msg =  xmlChecker(self.filename)
             if msg:
-                print msg
+                print(msg)
             sys.exit(1)
 
         self.root = self.doc.firstChild
 
         if self.root.nodeName != "autovnv":
-            print XMLFileName + ": Wrong XML file. The Root markup is not autovnv.\n"
+            print(XMLFileName + ": Wrong XML file. The Root markup is not autovnv.\n")
             sys.exit(1)
 
 
@@ -113,7 +113,7 @@ class Parser(object):
             log.debug("__checkDirectory(): %s" % dir)
             return dir
         else:
-            print "Directory: %s does not exists." % dir
+            print("Directory: %s does not exist." % dir)
             sys.exit(1)
 
 
@@ -133,7 +133,7 @@ class Parser(object):
             current = l.item(0)
             data = current.firstChild.data
         else:
-            print "Error: in getDataFromNode several markup %s found." %  childName
+            print("Error: in getDataFromNode several markup %s found." %  childName)
             sys.exit(1)
 
         return data
@@ -169,7 +169,7 @@ class Parser(object):
         elif len(l) == 1:
             return l.item(0)
         else:
-            print "Error: in getChild several markup %s found." %  childname
+            print("Error: in getChild several markup %s found." %  childname)
             sys.exit(1)
 
 
@@ -221,7 +221,7 @@ class Parser(object):
                 if label not in labels:
                     labels.append(label)
                 else:
-                    print "Study: %s is repeted in the xml file of paramaters" % label
+                    print("Study: %s is repeted in the xml file of paramaters" % label)
                     sys.exit(1)
         return labels
 
@@ -285,7 +285,7 @@ class Parser(object):
         """
         Read N_PROCS and USER_INPUT_FILES in:
             <study label='STUDY' status='on'>
-                <case label='CASE1' status='on' compute="on" post="on"/>
+                <case label='CASE1' run_id ="Grid 1" status='on' compute="on" post="on"/>
                 <case label='CASE2' status='on' compute="on" post="on"/>
             </study>
         @type l: C{String}
@@ -298,10 +298,16 @@ class Parser(object):
         for node in self.getStudyNode(l).getElementsByTagName("case"):
             if str(node.attributes["status"].value) == 'on':
                 d = {}
-                d['node']  = node
-                d['label'] = str(node.attributes["label"].value)
+                d['node']    = node
+                d['label']   = str(node.attributes["label"].value)
                 d['compute'] = str(node.attributes["compute"].value)
-                d['post']    = str(node.attributes["post"].value)
+                d['post'] = str(node.attributes["post"].value)
+
+                try:
+                    d['run_id'] = str(node.attributes["run_id"].value)
+                except:
+                    d['run_id'] = ""
+
                 for n in node.childNodes:
                     if n.nodeType == minidom.Node.ELEMENT_NODE and n.childNodes:
                         if n.tagName not in ("compare", "prepro", "script", "data"):
@@ -538,6 +544,42 @@ class Parser(object):
         return nodes, files
 
 
+    def getPostPro(self, l):
+        """
+        Read:
+            <study label='STUDY' status='on'>
+                <case label='CASE1' status='on' compute="on" post="on"/>
+                <postpro label="script_post.py" args="" status="on">
+                    <data file="profile.dat">
+                        <plot fig="1" xcol="1" ycol="2" legend="Grid 1"/>
+                    </data>
+                </postpro>
+            </study>
+
+        Return the list of files of postpro.
+        @type l: C{String}
+        @param l: label of a study
+        @rtype: C{List}
+        @return: C{List} of list of nodes <postpro>
+        """
+        scripts, labels, nodes, args = [], [], [], []
+
+        for node in self.getStudyNode(l).getElementsByTagName("postpro"):
+            if str(node.attributes["status"].value) == 'on':
+                scripts.append(True)
+            else:
+                scripts.append(False)
+
+            labels.append(str(node.attributes["label"].value))
+            nodes.append(node)
+            try:
+                args.append(str(node.attributes["args"].value))
+            except:
+                args.append("")
+
+        return scripts, labels, nodes, args
+
+
     def getSubplots(self, studyLabel):
         return self.getStudyNode(studyLabel).getElementsByTagName("subplot")
 
