@@ -43,7 +43,7 @@ from autovnv.Parser import Parser
 from autovnv.TexMaker import Report1, Report2
 from autovnv.Drawing import Plotter
 from autovnv.PlotVTK import PlotVTK
-from autovnv.Command import run_command
+from autovnv.Command import run_autovnv_command
 
 #-------------------------------------------------------------------------------
 # log config.
@@ -61,39 +61,6 @@ def nodot(item):
 
 #-------------------------------------------------------------------------------
 
-class RunThread(threading.Thread):
-    """
-    Run an external script as a simple thread.
-    """
-
-    def __init__(self, cmd, rlog):
-
-        self.__cmd = cmd
-        self.__log = rlog
-        self.__retcode = -999
-        self.__time = 0.0
-        threading.Thread.__init__ (self, target=self.run)
-        self.__stopevent = threading.Event()
-
-    def run(self):
-        try:
-            if not self.__stopevent.isSet():
-                self.__retcode, self.__time = self.__runcommand()
-        except:
-            if not self.__stopevent.is_set():
-                self.__retcode, self.__time = self.__runcommand()
-
-    def stop(self):
-        self.__stopevent.set()
-        return self.__retcode, self.__time
-
-    def __runcommand(self):
-        retcode, t = run_command(self.__cmd, self.__log)
-        self.__stopevent.wait(1.0)
-        return retcode, t
-
-#-------------------------------------------------------------------------------
-
 class Case(object):
     def __init__(self, pkg, rlog, diff, study, data, repo, dest):
         """
@@ -111,6 +78,7 @@ class Case(object):
         self.label      = data['label']
         self.compute    = data['compute']
         self.plot       = data['post']
+        self.run_id     = data['run_id']
 
         self.is_compil  = "not done"
         self.is_run     = "not done"
@@ -119,6 +87,7 @@ class Case(object):
         self.is_compare = "not done"
         self.threshold  = "default"
         self.diff_value = []
+        self.run_dir    = ""
 
         self.exe, self.pkg = self.__get_exe()
 
@@ -135,7 +104,7 @@ class Case(object):
         try:
             f = file(run_ref, mode = 'r')
         except IOError:
-            print "Error: can not open %s\n" % run_ref
+            print("Error: can not open %s\n" % run_ref)
             sys.exit(1)
 
         lines = f.readlines()
@@ -148,7 +117,7 @@ class Case(object):
                     exe = name
 
         if not exe:
-            print "Error: name of the executable for the case %s not found. Stop." % self.label
+            print("Error: name of the executable for the case %s not found. Stop." % self.label)
             sys.exit(1)
 
         if exe == "code_saturne":
@@ -189,8 +158,8 @@ class Case(object):
                     try:
                         case = Case(package = self.pkg, file_name = fp)
                     except:
-                        print "File of parameters reading error.\n"
-                        print "This file is not in accordance with XML specifications."
+                        print("Parameters file reading error.\n")
+                        print("This file is not in accordance with XML specifications.")
                         sys.exit(1)
 
                     case['xmlfile'] = fp
@@ -209,7 +178,7 @@ class Case(object):
         try:
             f = file(ref, mode = 'r')
         except IOError:
-            print "Error: can not open %s\n" % ref
+            print("Error: can not open %s\n" % ref)
             sys.exit(1)
 
         lines = f.readlines()
@@ -229,7 +198,7 @@ class Case(object):
         try:
             f = file(ref, mode = 'r')
         except IOError:
-            print "Error: can not open %s\n" % ref
+            print("Error: can not open %s\n" % ref)
             sys.exit(1)
 
         lines = f.readlines()
@@ -295,7 +264,7 @@ class Case(object):
         try:
             f = file(run_ref, mode = 'r')
         except IOError:
-            print "Error: can not open %s\n" % run_ref
+            print("Error: can not open %s\n" % run_ref)
             sys.exit(1)
 
         for line in f.readlines():
@@ -308,7 +277,7 @@ class Case(object):
         try:
             f = file(run_new, mode = 'r')
         except IOError:
-            print "Error: can not open %s\n" % run_new
+            print("Error: can not open %s\n" % run_new)
             sys.exit(1)
 
         lines = f.readlines()
@@ -337,19 +306,38 @@ class Case(object):
         home = os.getcwd()
         os.chdir(os.path.join(self.__dest, self.label, 'SCRIPTS'))
 
-        run_id, run_dir = self.__suggest_run_id()
+        if self.run_id:
+            run_id = self.run_id
+            run_dir = os.path.join(self.__dest, self.label, "RESU", run_id)
 
-        while os.path.isdir(run_dir):
-            time.sleep(5)
+            if os.path.isdir(run_dir):
+                print("Warning: the directory %s already exists in the destination." % run_dir)
+
+                if os.path.isfile(os.path.join(run_dir, "error")):
+                    self.is_run = "KO"
+                    self.is_time = 0.
+                    error = 1
+                else:
+                    self.is_run = "OK"
+                    self.is_time = 0.
+                    error = 0
+                os.chdir(home)
+
+                return error
+
+        else:
             run_id, run_dir = self.__suggest_run_id()
 
+            while os.path.isdir(run_dir):
+                time.sleep(5)
+                run_id, run_dir = self.__suggest_run_id()
+
+        self.run_id  = run_id
+        self.run_dir = run_dir
+
         self.__updateRuncase(run_id)
 
-        error, self.is_time = run_command("./runcase", self.__log)
-        #t1 = RunThread("runcase", self.__log)
-        #t1.start()
-        #t1.join()
-        #error, self.is_time = t1.stop()
+        error, self.is_time = run_autovnv_command("./runcase", self.__log)
 
         if not error:
             self.is_run = "OK"
@@ -358,7 +346,7 @@ class Case(object):
 
         os.chdir(home)
 
-        return error, run_id
+        return error
 
 
     def compare(self, r, d, threshold, args):
@@ -386,11 +374,9 @@ class Case(object):
         if args != None:
             cmd += (" " + args)
             l = string.split(args)
-            try:
-                i = l.index('--threshold')
+            i = l.find('--threshold')
+            if i > -1:
                 self.threshold = l[i+1]
-            except:
-                pass
 
         l = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).stdout
         info = l.read().replace("\"", " ").replace(";", " ").replace(":", " ").split()
@@ -441,7 +427,7 @@ class Study(object):
         self.__dest = os.path.join(self.__parser.getDestination(), study)
 
         if not os.path.isdir(self.__repo):
-            print "Error: the directory %s does not exist" % self.__repo
+            print("Error: the directory %s does not exist" % self.__repo)
             sys.exit(1)
 
         self.Cases = []
@@ -451,7 +437,7 @@ class Study(object):
         # build the list of the cases
         self.cases = parser.getCasesLabel(study)
         if not self.cases:
-            print "\n\n\nWarning: no case defined in %s study\n\n\n" % study
+            print("\n\n\nWarning: no case defined in %s study\n\n\n" % study)
         else:
             for data in self.__parser.getCasesKeywords(self.__study):
                 c = Case(pkg,
@@ -482,7 +468,7 @@ class Study(object):
         # Create study if necessary
         if not os.path.isdir(self.__dest):
             cmd = self.__main_exe + " create --quiet --study " + self.__dest
-            retval, t = run_command(cmd, self.__log)
+            retval, t = run_autovnv_command(cmd, self.__log)
             shutil.rmtree(os.path.join(self.__dest, "CASE1"))
 
             # Link meshes and copy other files
@@ -527,12 +513,24 @@ class Study(object):
                 cmd = e + " create --case " + c.label  \
                       + " --quiet --noref --copy-from "    \
                       + os.path.join(self.__repo, c.label)
-                retval, t = run_command(cmd, self.__log)
+                retval, t = run_autovnv_command(cmd, self.__log)
             else:
-                print "Warning: the case %s already exists in the destination." % c.label
+                print("Warning: the case %s already exists in the destination." % c.label)
 
         os.chdir(repbase)
 
+
+    def getRunDirectories(self):
+        list_cases = []
+        list_dir   = []
+
+        for case in self.Cases:
+            if case.is_run != "KO":
+                list_cases.append(case.label)
+                list_dir.append(case.run_dir)
+
+        return string.join(list_cases), string.join(list_dir)
+
 #-------------------------------------------------------------------------------
 
 class Studies(object):
@@ -560,7 +558,7 @@ class Studies(object):
         @param dif: name of the diff executable: C{cs_io_dump -d}.
         """
 
-        # create a first xml parser only for 
+        # create a first xml parser only for
         #   the repository verification and
         #   the destination creation
 
@@ -718,26 +716,37 @@ class Studies(object):
             sys.exit(1)
 
 
-    def prepro(self):
+    def prepro(self, l, s, case):
         """
         Launch external additional scripts with arguments.
         """
-        for l, s in self.studies:
-            self.reporting('  o Script prepro study: ' + l)
-            for case in s.Cases:
-                pre, label, nodes, args = self.__parser.getPrepro(case.node)
-                for i in range(len(label)):
-                    if pre[i]:
-                        cmd = os.path.join(self.dest, l, "MESH", label[i])
-                        if os.path.isfile(cmd):
-                            cmd += " " + args[i]
-                            repbase = os.getcwd()
-                            os.chdir(os.path.join(self.dest, l, "MESH"))
-                            retcode, t = run_command(cmd, self.__log)
-                            os.chdir(repbase)
-                            self.reporting('    - script %s --> OK (%s s)' % (cmd, t))
-                        else:
-                            self.reporting('    - script %s not found' % cmd)
+        pre, label, nodes, args = self.__parser.getPrepro(case.node)
+        for i in range(len(label)):
+            if pre[i]:
+                # search if the script is the directoty MESH
+                # if not, the script is searched in the directories of the current case
+                cmd = os.path.join(self.dest, l, "MESH", label[i])
+                if not os.path.isfile(cmd):
+                    filePath = ""
+                    for root, dirs, fs in os.walk(os.path.join(self.dest, l, case.label)):
+                        if label[i] in fs:
+                            filePath = root
+                            break
+
+                    cmd = os.path.join(filePath, label[i])
+
+                if os.path.isfile(cmd):
+                    cmd += " " + args[i]
+                    cmd += " -c " + os.path.join(self.dest, l, case.label)
+                    repbase = os.getcwd()
+                    os.chdir(os.path.join(self.dest, l, "MESH"))
+                    # prepro external script might need the pythondir
+                    pdir = case.pkg.get_dir('pkgpythondir')
+                    retcode, t = run_autovnv_command(cmd, self.__log, pythondir = pdir)
+                    os.chdir(repbase)
+                    self.reporting('    - script %s --> OK (%s s)' % (cmd, t))
+                else:
+                    self.reporting('    - script %s not found' % cmd)
 
 
     def run(self):
@@ -746,18 +755,19 @@ class Studies(object):
         Warning, if the makup of the case is repeated in the xml file of parameters,
         the run of the case is also repeated.
         """
-        if self.__running:
-            for l, s in self.studies:
-                self.reporting('  o Run study: ' + l)
-                for case in s.Cases:
+        for l, s in self.studies:
+            self.reporting('  o Script prepro and run for study: ' + l)
+            for case in s.Cases:
+                self.prepro(l, s, case)
+                if self.__running:
                     if case.compute == 'on' and case.is_compil != "KO":
                         self.reporting('    - running %s ...' % case.label, True)
-                        error, run_id = case.run()
+                        error = case.run()
                         if not error:
-                            if not run_id:
+                            if not case.run_id:
                                 self.reporting('    - run %s --> Warning suffixe is not read' % case.label)
 
-                            self.reporting('    - run %s --> OK (%s s) in %s' % (case.label, case.is_time, run_id))
+                            self.reporting('    - run %s --> OK (%s s) in %s' % (case.label, case.is_time, case.run_id))
                             self.__parser.setAttribute(case.node, "compute", "off")
 
                             # update dest="" attribute
@@ -769,14 +779,14 @@ class Studies(object):
                             n6 = self.__parser.getChilds(case.node, "input")
                             for n in n1 + n2 + n3 + n4 + n5 + n6:
                                 if self.__parser.getAttribute(n, "dest") == "":
-                                    self.__parser.setAttribute(n, "dest", run_id)
+                                    self.__parser.setAttribute(n, "dest", case.run_id)
                         else:
                             self.reporting('    - run %s --> FAILED' % case.label)
 
                         self.__log.flush()
 
 
-    def __check_dir(self, study_label, case_label, node, result, rep, attr):
+    def __check_dir(self, study_label, case_label, run_id, node, result, rep, attr):
         """
         Check coherency between xml file of parameters and repository or destination.
         """
@@ -806,15 +816,27 @@ class Studies(object):
                 self.reporting(msg)
                 sys.exit(1)
 
-            if len(filter(nodot, os.listdir(result))) > 1:
+            # if no run_id is specified in the xml file
+            # only one result directory allowed in RESU
+            if len(filter(nodot, os.listdir(result))) > 1 and run_id == "":
                 msg = "Study %s case %s:\nthere are several directories in %s\nStop.\n" % \
                     (study_label, case_label, result)
                 self.reporting(msg)
                 sys.exit(1)
 
-            rep = filter(nodot, os.listdir(result))[0]
+            rep = run_id
+            # if no run_id is specified in the xml file
+            # the only result directory present in RESU is taken
+            if rep == "":
+                rep = filter(nodot, os.listdir(result))[0]
 
             rep_f = os.path.join(result, rep)
+            if not os.path.isdir(rep_f):
+                msg = "Study %s case %s:\nthe directory %s does not exist.\nStop.\n" % \
+                    (study_label, case_label, rep_f)
+                self.reporting(msg)
+                sys.exit(1)
+
             rep_e = os.path.join(result, rep, 'error')
             if os.path.isfile(rep_e):
                 msg = "Study %s case %s:\nthe directory %s contains an error file.\nStop.\n" % \
@@ -823,23 +845,26 @@ class Studies(object):
                 sys.exit(1)
 
         # 3. Update the file of parameters with the name of the result directory
-            self.__parser.setAttribute(node, attr, rep)
+            if node:
+                self.__parser.setAttribute(node, attr, rep)
+            return rep
+
         else:
             self.reporting('Error: check compare/script/plot/probe/resu/input failed.')
             sys.exit(1)
 
 
-    def __check_dirs(self, study_label, case_label, node, repo, dest):
+    def __check_dirs(self, study_label, case_label, run_id, node, repo, dest):
         """
         Check coherency between xml file of parameters and repository and destination.
         """
         if repo != None:
             result = os.path.join(self.repo, study_label, case_label, 'RESU')
-            self.__check_dir(study_label, case_label, node, result, repo, "repo")
+            self.__check_dir(study_label, case_label, run_id, node, result, repo, "repo")
 
         if dest != None:
             result = os.path.join(self.dest, study_label, case_label, 'RESU')
-            self.__check_dir(study_label, case_label, node, result, dest, "dest")
+            self.__check_dir(study_label, case_label, run_id, node, result, dest, "dest")
 
 
     def check_compare(self, destination=True):
@@ -854,7 +879,7 @@ class Studies(object):
                     if compare[i] and case.is_run != "KO":
                         if destination == False:
                             dest[i]= None
-                        self.__check_dirs(l, case.label, nodes[i], repo[i], dest[i])
+                        self.__check_dirs(l, case.label, case.run_id, nodes[i], repo[i], dest[i])
 
 
     def compare(self):
@@ -885,7 +910,7 @@ class Studies(object):
                     if script[i] and case.is_run != "KO":
                         if destination == False:
                             dest[i] = None
-                        self.__check_dirs(l, case.label, nodes[i], repo[i], dest[i])
+                        self.__check_dirs(l, case.label, case.run_id, nodes[i], repo[i], dest[i])
 
 
     def scripts(self):
@@ -907,16 +932,45 @@ class Studies(object):
                             if dest[i]:
                                 d = os.path.join(self.dest, l, case.label, "RESU", dest[i])
                                 cmd += " -d " + d
-                            retcode, t = run_command(cmd, self.__log)
+                            retcode, t = run_autovnv_command(cmd, self.__log)
                             self.reporting('    - script %s --> OK (%s s)' % (cmd, t))
                         else:
                             self.reporting('    - script %s not found' % cmd)
 
 
+    def postpro(self):
+        """
+        Launch external additional scripts with arguments.
+        """
+        for l, s in self.studies:
+            # fill results directories and ids for the cases of the current study
+            # that were not run by the current autovnv command
+            for case in s.Cases:
+                if case.is_run != "KO":
+                    if case.run_dir == "":
+                        resu = os.path.join(self.dest, l, case.label, 'RESU')
+                        rep = self.__check_dir(l, case.label, case.run_id, None, resu, "", "dest")
+                        case.run_id = rep
+                        case.run_dir = os.path.join(resu, rep)
+
+            self.reporting('  o Postprocessing cases of study: ' + l)
+            script, label, nodes, args = self.__parser.getPostPro(l)
+            for i in range(len(label)):
+                if script[i]:
+                    cmd = os.path.join(self.dest, l, "POST", label[i])
+                    if os.path.isfile(cmd):
+                        list_cases, list_dir = s.getRunDirectories()
+                        cmd += ' ' + args[i] + ' -c "' + list_cases + '" -d "' + list_dir + '" -s ' + l
+                        retcode, t = run_autovnv_command(cmd, self.__log)
+                        self.reporting('    - postpro %s --> OK (%s s)' % (cmd, t))
+                    else:
+                        self.reporting('    - postpro %s not found' % cmd)
+
+
     def check_plot(self, destination=True):
         """
         Check coherency between xml file of parameters and repository.
-        Stop if you try to make a plot of a file which does not exsist.
+        Stop if you try to make a plot of a file which does not exist.
         """
         for l, s in self.studies:
             for case in s.Cases:
@@ -925,26 +979,26 @@ class Studies(object):
                         plots, file, dest, repo = self.__parser.getResult(node)
                         if destination == False:
                             dest = None
-                        self.__check_dirs(l, case.label, node, repo, dest)
+                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
 
                     for node in self.__parser.getChilds(case.node, "probes"):
                         file, dest, fig = self.__parser.getProbes(node)
                         if destination == False:
                             dest = None
                         repo = None
-                        self.__check_dirs(l, case.label, node, repo, dest)
+                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
 
                     for node in self.__parser.getChilds(case.node, "resu"):
                         plots, file, dest, repo = self.__parser.getResult(node)
                         if destination == False:
                             dest = None
-                        self.__check_dirs(l, case.label, node, repo, dest)
+                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
 
                     for node in self.__parser.getChilds(case.node, "input"):
                         file, dest, repo = self.__parser.getInput(node)
                         if destination == False:
                             dest = None
-                        self.__check_dirs(l, case.label, node, repo, dest)
+                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
 
 
     def plot(self):
@@ -1016,6 +1070,7 @@ class Studies(object):
                         elif self.__compare:
                             doc2.appendLine("No difference between the repository and the destination.")
 
+                    # handle the input nodes that are inside case nodes
                     if case.plot == "on" and case.is_run != "KO":
                         nodes = self.__parser.getChilds(case.node, "input")
                         if nodes:
@@ -1037,7 +1092,35 @@ class Studies(object):
                                 ff = os.path.join(dd, l, case.label, "RESU", d, f)
 
                                 if not os.path.isfile(ff):
-                                    print "\n\nWarning: this file does not exist: %s\n\n" % ff
+                                    print("\n\nWarning: this file does not exist: %s\n\n" % ff)
+                                else:
+                                    doc2.addInput(ff)
+
+                # handle the input nodes that are inside postpro nodes
+                script, label, nodes, args = self.__parser.getPostPro(l)
+                doc2.appendLine("\\subsection{Results for post-processing cases}")
+                for i in range(len(label)):
+                    if script[i]:
+                        input_nodes = self.__parser.getChilds(nodes[i], "input")
+                        if input_nodes:
+                            for node in input_nodes:
+                                f, dest, repo = self.__parser.getInput(node)
+                                doc2.appendLine("\\subsubsection{%s}" % f)
+
+                                if dest:
+                                    d = dest
+                                    dd = self.dest
+                                elif repo:
+                                    d = repo
+                                    dd = self.repo
+                                else:
+                                    d = ""
+                                    dd = ""
+
+                                ff = os.path.join(dd, l, "POST", d, f)
+
+                                if not os.path.isfile(ff):
+                                    print("\n\nWarning: this file does not exist: %s\n\n" % ff)
                                 else:
                                     doc2.addInput(ff)
 
