@@ -52,7 +52,10 @@ except Exception: # email version 4.0 (Python2 from Python 2.5)
 # Application modules import
 #-------------------------------------------------------------------------------
 
-from autovnv.Study import Studies
+# Do not import Autovnv yet, as it pulls Python packages such as
+# matplotlib or vtk which may not be in the standard path, and may need
+# sourcing of a specific environment (which itself is delayed in case
+# the main and coputation packages are not the same).
 
 #-------------------------------------------------------------------------------
 # Processes the passed command line arguments
@@ -184,6 +187,15 @@ def runAutoverif(pkg, opt_f, opt_v, opt_u, opt_r, opt_c, opt_p, opt_to):
       8. reporting by mail
     """
 
+    # Source environment if required before importing Autovnv modules, as it
+    # pulls Python packages such as matplotlib or vtk which may not be in the
+    # standard path.
+    from cs_exec_environment import set_modules, source_rcfile
+    set_modules(pkg)
+    source_rcfile(pkg)
+
+    from autovnv.Study import Studies
+
     # Scripts
 
     exe = os.path.join(pkg.get_dir('bindir'), pkg.name)
@@ -246,15 +258,13 @@ def runAutoverif(pkg, opt_f, opt_v, opt_u, opt_r, opt_c, opt_p, opt_to):
 
     studies.compilation()
 
-    # Preprocessing
-
-    studies.prepro()
-
-    # Update and run all cases
+    # Preprocessing and run all cases
 
     if opt_r:
         studies.run()
 
+    # Compare checkpoint files
+
     if opt_c:
         studies.check_compare()
         studies.compare()
@@ -265,6 +275,7 @@ def runAutoverif(pkg, opt_f, opt_v, opt_u, opt_r, opt_c, opt_p, opt_to):
         studies.check_script()
         studies.scripts()
         studies.check_plot()
+        studies.postpro()
         studies.plot()
 
     studies.reporting("\n -----------------")
@@ -272,8 +283,6 @@ def runAutoverif(pkg, opt_f, opt_v, opt_u, opt_r, opt_c, opt_p, opt_to):
     studies.reporting(" -----------------")
 
     # Reporting
-    # TODO : *) inserer les images vtk dans le pdf
-    #        *) temps de calcul
 
     attached_file = studies.build_reports("report_global", "report_detailed")
     if opt_to:
