@@ -36,11 +36,11 @@ import sys
 import shutil
 import stat
 
-import cs_config
 import cs_compile
 import cs_xml_reader
 
 from cs_exec_environment import run_command, source_shell_script
+from cs_exec_environment import enquote_arg, separate_args
 
 #===============================================================================
 # Utility functions
@@ -284,7 +284,7 @@ class base_domain:
         executable path, and associated command-line arguments.
         """
 
-        return self.exec_dir, self.solver_path, ''
+        return enquote_arg(self.exec_dir), enquote_arg(self.solver_path), ''
 
     #---------------------------------------------------------------------------
 
@@ -509,17 +509,6 @@ class domain(base_domain):
 
     #---------------------------------------------------------------------------
 
-    def copy_user_script(self):
-        """
-        Copy the user script to the execution directory
-        """
-        user_scripts = os.path.join(self.data_dir, 'cs_user_scripts.py')
-        if os.path.isfile(user_scripts):
-            dest = os.path.join(self.result_dir, 'cs_user_scripts.py')
-            shutil.copy2(user_scripts, dest)
-
-    #---------------------------------------------------------------------------
-
     def compile_and_link(self):
         """
         Compile and link user subroutines if necessary
@@ -568,7 +557,7 @@ class domain(base_domain):
             log.close()
 
             if retval == 0:
-                self.solver_path = os.path.join(self.exec_dir,
+                self.solver_path = os.path.join('.',
                                                 self.package_compute.solver)
             else:
                 # In case of error, copy source to results directory now,
@@ -579,26 +568,18 @@ class domain(base_domain):
 
     #---------------------------------------------------------------------------
 
-    def copy_preprocessor_data(self):
+    def prepare_data(self):
         """
-        Copy preprocessor data to execution directory
+        Copy data to the execution directory
         """
 
-        # If we are using a prior preprocessing, simply link to it here
+        # If we are using a previous preprocessing, simply link to it here
         if self.mesh_input:
             mesh_input = os.path.expanduser(self.mesh_input)
             if not os.path.isabs(mesh_input):
                 mesh_input = os.path.join(self.case_dir, mesh_input)
             link_path = os.path.join(self.exec_dir, 'mesh_input')
             self.symlink(mesh_input, link_path)
-            return
-
-    #---------------------------------------------------------------------------
-
-    def copy_solver_data(self):
-        """
-        Copy solver data to the execution directory
-        """
 
         if not self.exec_solver:
             return
@@ -613,8 +594,9 @@ class domain(base_domain):
         for f in dir_files:
             src = os.path.join(self.data_dir, f)
             if os.path.isfile(src):
-                shutil.copy2(src,
-                             os.path.join(self.exec_dir, f))
+                shutil.copy2(src, os.path.join(self.exec_dir, f))
+                if f == 'cs_user_scripts.py':  # Copy user script to results now
+                    shutil.copy2(src,  os.path.join(self.result_dir, f))
 
         # Call user script if necessary
 
@@ -660,7 +642,7 @@ class domain(base_domain):
 
     #---------------------------------------------------------------------------
 
-    def run_preprocessor(self):
+    def preprocess(self):
         """
         Runs the preprocessor in the execution directory
         """
@@ -748,26 +730,26 @@ class domain(base_domain):
 
             # Build command
 
-            cmd = self.package.get_preprocessor()
+            cmd = [self.package.get_preprocessor()]
 
             if (type(m) == tuple):
                 for opt in m[1:]:
-                    cmd += ' ' + opt
+                    cmd.append(opt)
 
             if (mesh_id != None):
                 mesh_id += 1
-                cmd += ' --log preprocessor_%02d.log' % (mesh_id)
-                cmd += ' --out ' + os.path.join('mesh_input',
-                                                'mesh_%02d' % (mesh_id))
+                cmd = cmd + ['--log', 'preprocessor_%02d.log' % (mesh_id)]
+                cmd = cmd + ['--out', os.path.join('mesh_input',
+                                                   'mesh_%02d' % (mesh_id))]
             else:
-                cmd += ' --log'
-                cmd += ' --out mesh_input'
+                cmd = cmd + ['--log']
+                cmd = cmd + ['--out', 'mesh_input']
 
-            cmd += ' ' + mesh_path
+            cmd.append(mesh_path)
 
             # Run command
 
-            retcode = run_command(cmd)
+            retcode = run_command(cmd, pkg=self.package)
 
             if retcode != 0:
                 err_str = \
@@ -796,15 +778,15 @@ class domain(base_domain):
         executable path, and associated command-line arguments.
         """
 
-        wd = self.exec_dir              # Working directory
-        exec_path = self.solver_path    # Executable
+        wd = enquote_arg(self.exec_dir)              # Working directory
+        exec_path = enquote_arg(self.solver_path)    # Executable
 
         # Build kernel command-line arguments
 
         args = ''
 
         if self.param != None:
-            args += ' --param ' + self.param
+            args += ' --param ' + enquote_arg(self.param)
 
         if self.logging_args != None:
             args += ' ' + self.logging_args
@@ -813,74 +795,38 @@ class domain(base_domain):
             args += ' ' + self.solver_args
 
         if self.name != None:
-            args += ' --mpi --app-name ' + self.name
+            args += ' --mpi --app-name ' + enquote_arg(self.name)
         elif self.n_procs > 1:
             args += ' --mpi'
 
+        # Add FSI coupling (using SALOME YACS) if required
+
+        if hasattr(self, 'fsi_aster'):
+            if not sys.platform.startswith('linux'):
+                raise RunCaseError(' Coupling with Code_Aster only avalaible on Linux.')
+            salome_module = os.path.join(self.package_compute.get_dir('libdir'),
+                                         'salome',
+                                         'libFSI_SATURNEExelib.so')
+            if os.path.isfile(salome_module):
+                args += ' --yacs-module=' + enquote_arg(salome_module)
+
         # Adjust for Valgrind if used
 
         if self.valgrind != None:
-            args = self.solver_path + ' ' + args
-            exec_path = self.valgrind + ' '
+            args = enquote_arg(self.solver_path) + ' ' + args
+            exec_path = ''
+            for a in separate_args(self.valgrind):
+               exec_path += enquote_arg(a) + ' '
 
         return wd, exec_path, args
 
     #---------------------------------------------------------------------------
 
-    def copy_preprocessor_results(self):
-        """
-        Retrieve preprocessor results from the execution directory
-        and remove preprocessor input files if necessary.
-        """
-
-        if self.mesh_input:
-            return
-
-        # Determine if we should purge the execution directory
-
-        purge = True
-        if self.error == 'preprocess':
-            purge = False
-
-        # Copy log file(s) first
-
-        if len(self.meshes) == 1:
-            f = os.path.join(self.exec_dir, 'preprocessor.log')
-            if os.path.isfile(f):
-                self.copy_result(f, purge)
-        else:
-            mesh_id = 0
-            for m in self.meshes:
-                mesh_id += 1
-                f = os.path.join(self.exec_dir,
-                                 'preprocessor_%02d.log' % (mesh_id))
-                if os.path.isfile(f):
-                    self.copy_result(f, purge)
-
-        # Copy output if required (only purge if we have no further
-        # errors, as it may be necessary for future debugging).
-
-        if self.error != '':
-            purge = False
-
-        f = os.path.join(self.exec_dir, 'mesh_input')
-
-        if not self.exec_solver:
-            if os.path.isfile(f) or os.path.isdir(f):
-                self.copy_result(f, purge)
-        elif purge:
-            self.purge_result(f)
-
-    #---------------------------------------------------------------------------
-
-    def copy_solver_results(self):
+    def copy_results(self):
         """
         Retrieve solver results from the execution directory
         """
 
-        if not self.exec_solver:
-            return
-
         # Call user script
 
         if self.user_locals:
@@ -893,7 +839,7 @@ class domain(base_domain):
 
         dir_files = os.listdir(self.exec_dir)
 
-        # Determine if we should purge the execution directory
+        # Only purge if we have no errors, to allow for future debugging.
 
         valid_dir = False
         purge = True
@@ -905,17 +851,26 @@ class domain(base_domain):
 
         purge_list = []
 
-        for f in ['mesh_input', 'restart', 'partition_input']:
+        f = 'mesh_input'
+        if not self.mesh_input and self.exec_solver:
+            if f in dir_files:
+                purge_list.append(f)
+
+        for f in ['restart', 'partition_input']:
             if f in dir_files:
                 purge_list.append(f)
 
         # Determine files from this stage to ignore or to possibly remove
 
-        for f in [self.package.solver, 'run_solver.sh', 'run_solver.bat']:
+        for f in [self.package.solver, self.package.runsolver]:
             if f in dir_files:
                 purge_list.append(f)
         purge_list.extend(fnmatch.filter(dir_files, 'core*'))
 
+        f = 'scratch3.lag'
+        if f in dir_files:
+            purge_list.append(f)
+
         for f in purge_list:
             dir_files.remove(f)
             if purge:
@@ -1076,29 +1031,31 @@ class syrthes_domain(base_domain):
         executable path, and associated command-line arguments.
         """
 
-        wd = self.exec_dir              # Working directory
-        exec_path = self.solver_path    # Executable
+        wd = enquote_arg(self.exec_dir)              # Working directory
+        exec_path = enquote_arg(self.solver_path)    # Executable
 
         # Build kernel command-line arguments
 
         args = ''
 
-        args += ' -d ' + self.syrthes_case.data_file
+        args += ' -d ' + enquote_arg(self.syrthes_case.data_file)
         args += ' -n ' + str(self.syrthes_case.n_procs)
 
         if self.syrthes_case.n_procs_ray > 0:
             args += ' -r ' + str(self.n_procs_ray)
 
-        args += ' --name ' + self.name
+        args += ' --name ' + enquote_arg(self.name)
 
         # Output to a logfile
-        args += ' --log ' + self.logfile
+        args += ' --log ' + enquote_arg(self.logfile)
 
         # Adjust for Valgrind if used
 
         if self.valgrind != None:
-            args = self.solver_path + ' ' + args
-            exec_path = self.valgrind
+            args = enquote_arg(self.solver_path) + ' ' + args
+            exec_path = ''
+            for a in separate_args(self.valgrind):
+               exec_path += enquote_arg(a) + ' '
 
         return wd, exec_path, args
 
@@ -1186,7 +1143,7 @@ class syrthes_domain(base_domain):
 
         # Set executable
 
-        self.solver_path = os.path.join(self.exec_dir, 'syrthes')
+        self.solver_path = os.path.join('.', 'syrthes')
 
     #---------------------------------------------------------------------------
 
@@ -1250,6 +1207,196 @@ class syrthes_domain(base_domain):
         if self.solver_path:
             s.write('    SYRTHES      : ' + self.solver_path + '\n')
 
+#-------------------------------------------------------------------------------
+
+# Code_Aster coupling
+
+class aster_domain(base_domain):
+
+    def __init__(self,
+                 package,
+                 name = None,
+                 param = 'fsi.export'):
+
+        base_domain.__init__(self,
+                             package,
+                             name,
+                             n_procs_weight = None,
+                             n_procs_min = 1,
+                             n_procs_max = None)
+
+        # Get Code_Aster home
+
+        config = configparser.ConfigParser()
+        config.read([self.package.get_configfile(),
+                     os.path.expanduser('~/.' + self.package.configfile)])
+        self.aster_home = config.get('install', 'aster')
+
+        # Additional parameters for Code_Saturne/Code_Aster coupling
+        # Directories, and files in case structure
+
+        self.param = param
+
+        self.case_dir = None
+        self.result_dir = None
+
+        self.exec_solver = True
+
+        self.conf = 'fsi_config.txt'
+        self.comm = None
+        self.mesh = None
+
+        self.n_procs_max = 1
+
+    #---------------------------------------------------------------------------
+
+    def set_case_dir(self, case_dir):
+
+        base_domain.set_case_dir(self, case_dir)
+
+        e = []
+        p = os.path.join(self.case_dir, self.param)
+        if os.path.isfile(p):
+            f = open(p, 'r')
+            e = f.readlines()
+            f.close
+        else:
+            err_str = 'Code_Aster export file \'' + p + '\' is not present.\n'
+            raise RunCaseError(err_str)
+
+        for l in e:
+            k = l.split()
+            if len(k) >= 3:
+                if k[1] == 'mpi_nbcpu':
+                    self.n_procs_min = int(k[2])
+                    self.n_procs_max = self.n_procs_min
+                if k[1] == 'conf':
+                    self.conf = k[2]
+                if k[1] == 'comm':
+                    self.comm = k[2]
+                elif k[1] == 'mail':
+                    self.mesh = k[2]
+
+        if self.comm == None:
+            err_str = '\n  A Code_Aster ".comm" file must be specified.\n'
+            raise RunCaseError(err_str)
+
+        if self.mesh == None:
+            err_str = '\n  A Code_Aster mesh file must be specified.\n'
+            raise RunCaseError(err_str)
+
+    #---------------------------------------------------------------------------
+
+    def prepare_data(self):
+        """
+        Copy solver data to the execution directory
+        """
+
+        if not self.exec_solver:
+            return
+
+        # Copy data files
+
+        for f in [self.param, self.mesh, self.comm]:
+            p = os.path.join(self.case_dir, f)
+            if os.path.isfile(p):
+                shutil.copy2(p, os.path.join(self.exec_dir, f))
+            else:
+                err_str = \
+                    '\n  The Code_Aster input file: "' + f + '"\n' \
+                    '  is not present or readable.\n'
+                raise RunCaseError(err_str)
+
+        # Create FSI specific config.txt file
+
+        if os.path.isabs(self.conf):
+            s.path = self.conf
+        else:
+            s_path = os.path.join(self.aster_home, 'config.txt')
+        s = open(s_path, 'r')
+        template = s.read()
+        s.close()
+
+        import re
+
+        e_re = re.compile('profile.sh')
+        e_subst = os.path.join(self.aster_home, 'profile.sh')
+        template = re.sub(e_re, e_subst, template)
+
+        e_re = re.compile('Execution/E_SUPERV.py')
+        e_subst = os.path.join(self.package.get_dir('pythondir'),
+                               'salome',
+                               'FSI_ASTER_component.py')
+        template = re.sub(e_re, e_subst, template)
+
+        s_path = os.path.join(self.exec_dir, os.path.basename(self.conf))
+        s = open(s_path, 'w')
+        s.write(template)
+        s.close()
+
+    #---------------------------------------------------------------------------
+
+    def generate_script(self):
+        """
+        Generate Code_Aster run script
+        """
+
+        s_path = os.path.join(self.exec_dir, "aster_by_yacs")
+        s = open(s_path, 'w')
+
+        from cs_exec_environment import write_shell_shebang
+        write_shell_shebang(s)
+
+        s.write('cd ..\n')
+        s.write('export PATH=' + os.path.join(self.aster_home, 'bin') + ':$PATH\n')
+        s.write('as_run ' + self.param + '\n')
+
+        s.close()
+
+    #---------------------------------------------------------------------------
+
+    def copy_results(self):
+        """
+        Retrieve results from the execution directory
+        """
+
+        # Determine all files present in execution directory
+
+        dir_files = os.listdir(self.exec_dir)
+
+        # Determine if we should purge the execution directory
+
+        purge = True
+
+        if self.error != '':
+            purge = False
+
+        # Determine files from this stage to ignore or to possibly remove
+
+        purge_list = []
+
+        purge_list.extend(fnmatch.filter(dir_files, 'core*'))
+
+        for f in purge_list:
+            dir_files.remove(f)
+            if purge:
+                self.purge_result(f)
+
+        for f in dir_files:
+            self.copy_result(f, purge)
+
+    #---------------------------------------------------------------------------
+
+    def summary_info(self, s):
+        """
+        Output summary data into file s
+        """
+
+        base_domain.summary_info(self, s)
+
+        if self.param:
+            s.write('    Code_Aster   : ' + self.param + '\n')
+
 #-------------------------------------------------------------------------------
 # End
 #-------------------------------------------------------------------------------
