@@ -62,6 +62,79 @@ def abs_exec_path(path):
 
 #---------------------------------------------------------------------------
 
+def separate_args(s):
+    """
+    Separate arguments that may contain whitespace, depending on whether
+    whitespace is protected or not by ", ', and \ characters.
+    If quotes are found after the beginning of a string, such as in
+    --option="string 1", do not remove them.
+    """
+
+    l = []
+    if s:
+        a = ''
+        sep = False
+        protected = False
+        in_quotes = ''
+        for i in range(len(s)):
+            if protected:
+                a += s[i]
+                protected = False
+            else:
+                if s[i] == '\\':
+                    protected = True
+                elif s[i] == '"' or s[i] == "'":
+                    if in_quotes == s[i]:
+                        a += s[i]
+                        in_quotes = ''
+                    elif in_quotes != '':
+                            a += s[i]
+                    else:
+                        a += s[i]
+                        in_quotes = s[i]
+                elif in_quotes != '':
+                    a += s[i]
+                elif (s[i] == ' ' or s[i] == '\t'):
+                    if a != '':
+                        if (a[0] == a[-1:]) and (a[0] == '"' or a[0] == "'"):
+                            l.append(a[1:-1])
+                        else:
+                            l.append(a)
+                        a = ''
+                else:
+                    a += s[i]
+
+        if a != '':
+            l.append(a)
+
+    return l
+
+#---------------------------------------------------------------------------
+
+def enquote_arg(s):
+    """
+    Add quotes around argument if it contains whitespace, leave it
+    unchanged otherwise; if the argument already contains unprotected
+    quotes, do not add any more (so for example --option="string 1"
+    is unchanged).
+    """
+
+    if s:
+        if (s.find(' ') > -1):
+            protect = False
+            for i in range(len(s)):
+                if s[i] == '\\':
+                    protect = not protect
+                if not protect and s[i] == '"':
+                    return s
+            return '"' + s + '"'
+        else:
+            return s
+    else:
+        return s
+
+#---------------------------------------------------------------------------
+
 def get_shell_type():
     """
     Get name of current shell if available.
@@ -114,7 +187,7 @@ def write_export_env(fd, var, value):
     """
 
     if sys.platform.startswith('win'):
-        export_cmd = 'set ' + var + '="' + value
+        export_cmd = 'set ' + var + '=' + value
     else:
         if get_shell_type()[-3:] == 'csh': # handle C-type shells
             export_cmd = 'setenv ' + var + ' ' + value
@@ -130,8 +203,10 @@ def write_prepend_path(fd, var, user_path):
     Write the correct command so as to export PATH-type variables.
     """
 
+    # Caution: Windows PATH must NOT must double-quoted to account for blanks
+    # =======  in paths,contrary to UNIX systems
     if sys.platform.startswith('win'):
-        export_cmd = 'set ' + var + '="' + user_path + '";%' + var + '%'
+        export_cmd = 'set ' + var + '=' + user_path + ';%' + var + '%'
     else:
         if get_shell_type()[-3:] == 'csh': # handle C-type shells
             export_cmd = 'setenv ' + var + ' "' + user_path + '":$' + var
@@ -142,6 +217,50 @@ def write_prepend_path(fd, var, user_path):
 
 #-------------------------------------------------------------------------------
 
+def clean_path(path):
+    """
+    Remove duplicates from path.
+    """
+
+    # Case for a string
+
+    if type(path) == str:
+
+        if not path:
+            return ''
+
+        if sys.platform.startswith('win'):
+            s = ';'
+        else:
+            s = ':'
+
+        vals = path.split(s)
+
+        clean_path(vals)
+
+        value = ''
+        for v in vals:
+            if value:
+                value += s + v
+            else:
+                value = v
+
+        return value
+
+    # Case for a list
+
+    elif type(path) == list:
+
+        i = len(path) - 1
+        while i > -1:
+            if path.count(i) > 1 or not path[i]:
+                path.pop(i)
+            i -= 1
+
+    return path
+
+#-------------------------------------------------------------------------------
+
 def get_script_positional_args():
     """
     Write the positional arguments with a newline character.
@@ -168,12 +287,33 @@ def get_script_return_code():
 
 #-------------------------------------------------------------------------------
 
-def run_command(cmd, echo = False, stdout = sys.stdout, stderr = sys.stderr):
+def run_command(cmd, pkg = None, echo = False,
+                stdout = sys.stdout, stderr = sys.stderr, env = None):
     """
     Run a command.
     """
     if echo == True:
-        stdout.write(cmd + '\n')
+        if type(cmd) == str:
+            stdout.write(str(cmd) + '\n')
+        else:
+            l = ''
+            for s in cmd:
+                if (s.find(' ') > -1):
+                    l += ' ' + enquote_arg(s)
+                else:
+                    l += ' ' + s
+            stdout.write(l.strip() + '\n')
+
+    # Modify the PATH for relocatable installation: add Code_Saturne "bindir"
+
+    if pkg != None:
+        if pkg.config.features['relocatable'] == "yes":
+            if sys.platform.startswith("win"):
+                sep = ";"
+            else:
+                sep = ":"
+            saved_path = os.environ['PATH']
+            os.environ['PATH'] = pkg.get_dir('bindir') + sep + saved_path
 
     # As a workaround for a bug in which the standard output an error
     # are "lost" (observed in an apparently random manner, with Python 2.4),
@@ -185,13 +325,23 @@ def run_command(cmd, echo = False, stdout = sys.stdout, stderr = sys.stderr):
     if (stderr != sys.stderr):
         kwargs['stderr'] = stderr
 
-    p = subprocess.Popen(cmd,
-                         shell=True,
-                         executable=get_shell_type(),
-                         **kwargs)
+    if type(cmd) == str:
+        p = subprocess.Popen(cmd,
+                             shell=True,
+                             executable=get_shell_type(),
+                             env = env,
+                             **kwargs)
+    else:
+        p = subprocess.Popen(cmd, env = env, **kwargs)
 
     p.communicate()
 
+    # Reset the PATH to its previous value
+
+    if pkg != None:
+        if pkg.config.features['relocatable'] == "yes":
+            os.environ['PATH'] = saved_path
+
     return p.returncode
 
 #-------------------------------------------------------------------------------
@@ -232,13 +382,13 @@ def set_modules(pkg):
     Set environment modules if present.
     """
 
-    if pkg.env_modules == "no":
+    if pkg.config.env_modules == "no":
         return
 
-    cmd_prefix = pkg.env_modulecmd
+    cmd_prefix = pkg.config.env_modulecmd
 
     cmds = ['purge']
-    for m in pkg.env_modules.strip().split():
+    for m in pkg.config.env_modules.strip().split():
         cmds.append('load ' + m)
     for cmd in cmds:
         (output, error) = subprocess.Popen([cmd_prefix, 'python'] + cmd.split(),
@@ -275,9 +425,25 @@ def source_shell_script(path):
     output = p.communicate()[0]
 
     for line in output.splitlines():
+
         (key, _, value) = line.partition("=")
+
+        # For paths, cleanup (remove multiple values) first
+        if key[-4:] == 'PATH':
+            value = clean_path(value)
+
+        # Add key, value
         os.environ[key] = value
 
+        # additional handling for Python path
+        if key == 'PYTHONPATH':
+            vals = value.split(':')
+            vals.reverse()
+            for v in vals:
+                if v:
+                    sys.path.insert(0, v)
+            sys.path = clean_path(sys.path)
+
 #-------------------------------------------------------------------------------
 
 def source_rcfile(pkg):
@@ -751,7 +917,6 @@ MPI_MPMD_none       = 0
 MPI_MPMD_mpiexec    = (1<<0) # mpiexec colon-separated syntax
 MPI_MPMD_configfile = (1<<1) # mpiexec -configfile syntax
 MPI_MPMD_script     = (1<<2)
-MPI_MPMD_execve     = (1<<3)
 
 class mpi_environment:
 
@@ -765,8 +930,8 @@ class mpi_environment:
         # but in the case of srun, which uses a -n<n_procs> instead
         # of -n <n_procs> syntax, setting it to ' -n' will be enough.
 
-        self.type = pkg.mpi_type
-        self.bindir = pkg.mpi_bindir
+        self.type = pkg.config.libs['mpi'].variant
+        self.bindir = pkg.config.libs['mpi'].bindir
 
         self.gen_hostsfile = None
         self.del_hostsfile = None
@@ -788,14 +953,17 @@ class mpi_environment:
         init_method = self.__init_other__
 
         if len(self.type) > 0:
-            mpi_env_by_type = {'MPICH2':self.__init_mpich2__,
-                               'MPICH1':self.__init_mpich1__,
+            mpi_env_by_type = {'MPICH':self.__init_mpich2_3__,
+                               'MPICH2':self.__init_mpich2_3__,
+                               'Intel_MPI':self.__init_mpich2_3__,
+                               'MSMPI':self.__init_msmpi__,
                                'OpenMPI':self.__init_openmpi__,
+                               'BullxMPI':self.__init_openmpi__,
                                'LAM_MPI':self.__init_lam__,
-                               'BGL_MPI':self.__init_bgl__,
                                'BGP_MPI':self.__init_bgp__,
                                'BGQ_MPI':self.__init_bgq__,
                                'HP_MPI':self.__init_hp_mpi__,
+                               'MPICH1':self.__init_mpich1__,
                                'MPIBULL2':self.__init_mpibull2__}
             if self.type in mpi_env_by_type:
                 init_method = mpi_env_by_type[self.type]
@@ -808,22 +976,92 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
-    def __init_mpich2__(self, p, resource_info=None, wdir = None):
+    def __get_mpich2_3_default_pm__(self, mpiexec_path):
 
         """
-        Initialize for MPICH2 environment.
+        Try to determine the program manager for MPICH2 or MPICH-3.
+        """
 
-        MPICH2 allows for 4 different process managers, all or some
+        # Only smpd is supported on Windows, so that one is easy.
+
+        if sys.platform.startswith('win'):
+            return 'smpd'
+
+        # Check if we have a suffix which is self-explanatory
+
+        i = mpiexec_path.rfind('.')
+
+        if i > -1:
+            suffix = mpiexec_path[i+1:]
+
+        if suffix in ['hydra', 'smpd', 'mpd', 'gforker', 'remshell']:
+            return suffix
+
+        # Use mpichversion/mpich2version preferentially
+
+        infoname = os.path.join(os.path.split(mpiexec_path)[0],
+                                'mpichversion')
+        if not os.path.isfile(infoname):
+            infoname = os.path.join(os.path.split(mpiexec_path)[0],
+                                    'mpich2version')
+
+        if os.path.isfile(infoname):
+
+            # If program managers were specified at configure time,
+            # the first is the default
+
+            info = get_command_outputs(infoname + ' -configure')
+            i = info.find('-with-pm=')
+            if i > -1:
+                s = info[i + 8:]
+                for pm in ['hydra', 'smpd', 'mpd', 'gforker', 'remshell']:
+                    if s[0:len(pm)] == pm_c:
+                        return pm
+
+            # Otherwise, we know the default changed with MPICH2 1.3,
+            # from MPD to Hydra.
+
+            info = get_command_outputs(infoname + ' -version')
+            v = info.rstrip().split('\t')[1].split('.')
+            if int(v[0]) == 1 and int(v[1]) < 3:
+                return 'mpd'
+            else:
+                return 'hydra'
+
+        # If MPICH2 / MPICH-3 info is not available, try
+        # to determine this in another way
+
+        info = get_command_outputs(mpiexec_path + ' -help')
+        if info.find('Hydra') > -1:
+            return 'hydra'
+        elif info.find(' smpd ') > -1:
+            return 'smpd'
+        elif info.find('-usize') > -1:
+            return 'gforker' # might also be remshell
+
+        sys.stderr.write('Warning:\n'
+                         + '   Unable to determine MPICH program manager:'
+                         + ' assume "Hydra".\n\n')
+
+        return 'hydra'
+
+    #---------------------------------------------------------------------------
+
+    def __init_mpich2_3__(self, p, resource_info=None, wdir = None):
+
+        """
+        Initialize for MPICH-3 environment.
+
+        MPICH2 and MPICH-3 allow for 4 different process managers, all or some
         of which may be built depending on installation options:
 
-        - HYDRA is the default starting with MPICH2-1.3, and is available
-          in MPICH2-1.2. It natively uses existing daemons on the system
-          such as ssh, SLURM, PBS, etc.
+        - HYDRA is the default on Unix-type systems. It natively uses
+          existing daemons on the system such as ssh, SLURM, PBS, etc.
 
-        - MPD is the traditional process manager, which consists of a
-          ring of daemons. A hostsfile may be defined to start this
-          ring (a machinefile may still be used for mpiexec for
-          finer control, though we do not use it here).
+        - MPD was the traditional process manager, until it was deprecated
+          in MPICH2-1.3. It consists of a ring of daemons. A hostsfile may
+          be defined to start this ring (a machinefile may still be used for
+          mpiexec for finer control, though we do not use it here).
           We try to test if such a ring is already running, and
           start and stop it if this is not the case.
 
@@ -835,48 +1073,37 @@ class mpi_environment:
         - gforker is a simple manager that creates all processes on
           a single machine (the equivalent seem possible with HYDRA
           using "mpiexec -bootstrap fork")
+
+        - remsh is a very simple version of mpiexec which makes use of
+          the ssh command to start processes on a collection of
+          machines. It ignores the command line options which control
+          the environment variables given to MPI programs.
+          A hostsfile by name of machines should contain the list
+          of machines on which to run, one machine name per line
+          (machines may be listed multiple times if necessary).
         """
 
         # Determine base executable paths
 
-        # Also try to determine if mpiexec is that of MPD or of another
-        # process manager, using the knowledge that MPD's mpiexec
-        # is a Python script, while other MPICH2 mpiexec's are binary.
-        # We could have a false positive if another wrapper is used,
-        # but we still need to find mpdboot.
-        # In a similar fashion, we may determine if we are using the
-        # Hydra process manager, as the 'mpiexec --help' will contain
-        # a 'Hydra' string.
-
-        # Also, mpirun is a wrapper to mpdboot + mpiexec + mpiallexec,
+        # Using mpd,  mpirun is a wrapper to mpdboot + mpiexec + mpiallexec,
         # so it does not require running mpdboot and mpdallexit separately.
 
-        launcher_names = ['mpiexec.mpich2', 'mpiexec',
-                          'mpiexec.hydra', 'mpiexec.mpd', 'mpiexec.gforker',
-                          'mpirun.mpich2', 'mpirun']
-        pm = ''
+        # Executables suffixes 'mpich' or 'mpich2' may occur in case
+        # of Linux distribution packaging, while 'hydra', 'mpd', 'smpd',
+        # 'gforker', and 'remshell' are defined by the standard MPICH
+        # install and determine the associated launcher.
 
+        launcher_names = ['mpiexec.mpich', 'mpiexec.mpich2', 'mpiexec',
+                          'mpiexec.hydra', 'mpiexec.mpd', 'mpiexec.smpd',
+                          'mpiexec.gforker', 'mpiexec.remshell',
+                          'mpirun.mpich2', 'mpirun.mpich2', 'mpirun']
+
+        pm = ''
         for d in p:
             for name in launcher_names:
                 absname = os.path.join(d, name)
                 if os.path.isfile(absname):
-                    # Try to determine launcher type
-                    basename = os.path.basename(name)
-                    if basename in ['mpiexec.mpich2', 'mpiexec',
-                                    'mpirun.mpich2', 'mpirun']:
-                        info = get_command_outputs(absname)
-                        if info.find('Hydra') > -1:
-                            pm = 'hydra'
-                        elif info.find(' mpd ') > -1:
-                            pm = 'mpd'
-                        elif info.find('-usize') > -1:
-                            pm = 'gforker'
-                    elif basename == 'mpiexec.hydra':
-                        pm = 'hydra'
-                    elif basename == 'mpiexec.mpd':
-                        pm = 'mpd'
-                    elif basename == 'mpiexec.gforker':
-                        pm = 'gforker'
+                    pm = self.__get_mpich2_3_default_pm__(absname)
                     # Set launcher name
                     if d == self.bindir:
                         self.mpiexec = absname
@@ -890,6 +1117,21 @@ class mpi_environment:
             basename = 'mpiexec'
             self.mpiexec = 'mpiexec'
 
+        # Determine if SMPD should be handled
+
+        if pm == 'smpd':
+
+            smpdpath = 'smpd'
+            if os.path.isfile(os.path.join(d, 'smpd')):
+                if d == self.bindir:
+                    smpdpath = os.path.join(d, 'smpd')
+            if sys.platform.startswith('win'):
+                self.mpiboot = smpdpath + ' -start'
+                self.mpihalt = smpdpath + ' -stop'
+            else:
+                self.mpiboot = smpdpath + ' -s'
+                self.mpihalt = smpdpath + ' -shutdown'
+
         # Determine if MPD should be handled
         # (if we are using a root MPD, no need for setup)
 
@@ -933,7 +1175,23 @@ class mpi_environment:
         if resource_info != None:
             rm = resource_info.manager
 
-        if pm == 'mpd':
+        if pm == 'hydra':
+            # Nothing to do for resource managers directly handled by Hydra
+            if rm not in ['PBS', 'LOADL', 'LSF', 'SGE', 'SLURM']:
+                hostsfile = resource_info.get_hosts_file(wdir)
+                if hostsfile != None:
+                    self.mpiexec += ' -f ' + hostsfile
+
+            if (resource_info != None):
+                ppn = resource_info.n_procs_per_node()
+                if ppn != 1:
+                    self.mpiexec_n_per_node = ' -ppn ' + str(ppn)
+
+        elif pm == 'smpd':
+            hostsfile = resource_info.get_hosts_file(wdir)
+            if hostsfile != None:
+                self.mpiboot += ' --file=' + hostsfile
+        elif pm == 'mpd':
             if rm == 'SLURM':
                 # This requires linking with SLURM's implementation
                 # of the PMI library.
@@ -955,18 +1213,6 @@ class mpi_environment:
                 if hostsfile != None:
                     self.mpiboot += ' --file=' + hostsfile
 
-        elif pm == 'hydra':
-            # Nothing to do for resource managers directly handled by Hydra
-            if rm not in ['PBS', 'LOADL', 'LSF', 'SGE', 'SLURM']:
-                hostsfile = resource_info.get_hosts_file(wdir)
-                if hostsfile != None:
-                    self.mpiexec += ' -f ' + hostsfile
-
-            if (resource_info != None):
-                ppn = resource_info.n_procs_per_node()
-                if ppn != 1:
-                    self.mpiexec_n_per_node = ' -ppn ' + str(ppn)
-
         elif pm == 'gforker':
             hosts = False
             hostslist = resource_info.get_hosts_list()
@@ -979,15 +1225,15 @@ class mpi_environment:
             if hosts == True:
                 sys.stderr.write('Warning:\n'
                                  + '   Hosts list will be ignored by'
-                                 + ' MPICH2 gforker program manager.\n\n')
+                                 + ' MPICH gforker program manager.\n\n')
 
         # Finalize mpiboot and mpihalt commands.
-        # We use 'mpdtrace' to determine if a ring is already running,
+        # With MPD, we use 'mpdtrace' to determine if a ring is already running,
         # and mpdlistjobs to determine if other jobs are still running.
         # This means that a hostsfile will be ignored if an MPD ring
         # is already running, but will avoid killing other running jobs.
 
-        if self.mpiboot != None:
+        if self.mpiboot != None and pm == 'mpd':
             self.mpiboot = \
                 mpdtrace + ' > /dev/null 2>&1\n' \
                 + 'if test $? != 0 ; then ' + self.mpiboot + ' ; fi'
@@ -997,7 +1243,10 @@ class mpi_environment:
 
         # Info commands
 
-        self.info_cmds = ['mpich2version']
+        if self.type == 'MPICH':
+            self.info_cmds = ['mpichversion']
+        if self.type == 'MPICH2':
+            self.info_cmds = ['mpich2version']
 
     #---------------------------------------------------------------------------
 
@@ -1120,11 +1369,14 @@ class mpi_environment:
     def __init_lam__(self, p, resource_info=None, wdir = None):
         """
         Initialize for LAM/MPI environment.
+        We choose to use the mpiexec command, which wraps lamboot,
+        mpirun, and lamhalt, and provides for a basically standard
+        mpiexec syntax.
         """
 
         # Determine base executable paths
 
-        launcher_names = ['mpiexec.lam', 'mpirun.lam', 'mpiexec', 'mpirun']
+        launcher_names = ['mpiexec.lam', 'mpiexec']
 
         for d in p:
             for name in launcher_names:
@@ -1138,43 +1390,23 @@ class mpi_environment:
             if self.mpiexec != None:
                 break
 
-        if os.path.isfile(os.path.join(d, 'lamboot')):
-            if d == self.bindir:
-                self.mpiboot = os.path.join(d, 'lamboot')
-                self.mpihalt = os.path.join(d, 'lamhalt')
-            else:
-                self.mpiboot = 'lamboot'
-                self.mpihalt = 'lamhalt'
-
         # Determine processor count and MPMD handling
 
         launcher_base = os.path.basename(self.mpiexec)
 
-        if launcher_base[:7] == 'mpiexec':
-            self.mpiexec_n = ' -n '
-            self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_script
-        elif launcher_base[:7] == 'mpirun':
-            self.mpiexec_n = ' -np '
-            self.mpmd = MPI_MPMD_script
-
-        # Determine options to add
-
-        if self.mpiboot != None:
-            self.mpiboot += ' -v'
-            self.mpihalt += ' -v'
+        self.mpiexec_n = ' -n '
+        self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_script
 
         # Resource manager info
 
+        hostsfile = None
         if resource_info != None:
             hostsfile = resource_info.get_hosts_file(wdir)
-            if hostsfile != None and self.mpiboot != None:
-                self.mpiboot += ' ' + hostsfile
-                self.mpihalt += ' ' + hostsfile
 
-        # Finalize mpiboot and mpihalt commands
-
-        if self.mpiboot != None:
-            self.mpiboot += '|| exit $?'
+        if hostsfile != None:
+            self.mpiexec += ' --machinefile ' + hostsfile
+        else:
+            self.mpiexec += ' --boot'
 
         # Info commands
 
@@ -1182,30 +1414,6 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
-    def __init_bgl__(self, p, resource_info=None, wdir = None):
-
-        """
-        Initialize for Blue Gene/L environment.
-        """
-
-        # Set base executable path
-
-        self.mpiexec = '/bgl/BlueLight/ppcfloor/bglsys/mpi/mpirun'
-
-        # Determine processor count and MPMD handling
-
-        self.mpiexec_n = None
-        self.mpmd = MPI_MPMD_execve
-
-        # Other options to add
-
-        self.mpiexec_exe = '-exe'
-        self.mpiexec_args = '-args'
-
-        # Info commands
-
-    #---------------------------------------------------------------------------
-
     def __init_bgp__(self, p, resource_info=None, wdir = None):
 
         """
@@ -1309,6 +1517,37 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
+    def __init_msmpi__(self, p, resource_info=None, wdir = None):
+
+        """
+        Initialize for MS-MPI environment.
+
+        Microsoft MPI is based on standard MPICH2 distribution.
+
+        It allows only for the smpd process manager that consists
+        of independent daemons, so if a hostsfile is used, it must
+        be passed to mpiexec.
+        """
+
+        # On Windows, mpiexec.exe will be found through the PATH variable
+        # so, unset the MPI 'bindir' variable
+
+        self.bindir = ''
+
+        # Determine MS-MPI configuration
+
+        self.mpiexec = 'mpiexec.exe'
+        self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_configfile
+        self.mpiexec_n = ' -n '
+
+        # Other options to add
+
+        # Resource manager info
+
+        # Info commands
+
+    #---------------------------------------------------------------------------
+
     def __init_mpibull2__(self, p, resource_info=None, wdir = None):
         """
         Initialize for MPIBULL2 environment.
