@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -37,7 +37,7 @@ This module defines the following functions:
 #-------------------------------------------------------------------------------
 
 
-import os, sys, pwd, shutil, stat, fnmatch
+import os, sys, shutil, stat, fnmatch
 from optparse import OptionParser
 
 #-------------------------------------------------------------------------------
@@ -97,7 +97,7 @@ def print_version(pkg):
     Print Code_Saturne version.
     """
 
-    print(pkg.name + " version: " + pkg.version)
+    print(pkg.code_name + " version: " + pkg.version)
 
 
 #-------------------------------------------------------------------------------
@@ -109,8 +109,8 @@ def get_pdf(pkg):
     Return the list of available PDF manual for the command line.
     """
     l = []
-    if os.path.isdir(pkg.pdfdir):
-        for pdf in fnmatch.filter(os.listdir(pkg.pdfdir), '*.pdf'):
+    if os.path.isdir(pkg.get_dir('pdfdir')):
+        for pdf in fnmatch.filter(os.listdir(pkg.get_dir('pdfdir')), '*.pdf'):
             l.append(pdf[:-4])
     return l
 
@@ -128,26 +128,25 @@ def launch_manual(reader, m, pkg):
 
     readers = ["okular", "evince", "kpdf", "gpdf", "xpdf", "acroread"]
 
-    manual = os.path.join(pkg.pdfdir, m) + '.pdf'
+    manual = os.path.join(pkg.get_dir('pdfdir'), m) + '.pdf'
 
     if not os.path.isfile(manual):
         print("File %s not found." % manual)
         return
 
-    # First:  use the reader specified by the user, if any
-    # Second: try the different tool that open with the default system reader
-    # Last:   try some classical pdf viewers
-
-    if reader is not None:
-        cmd = reader + ' ' + manual + ' 2>/dev/null &'
-        os.system(cmd)
+    # On Windows platform, use the system standard launcher
+    if sys.platform.startswith('win'):
+        os.startfile(manual)
 
+    # On Linux and Unix-like platforms,
+    #  - first:  use the reader specified by the user, if any
+    #  - second: try the different tool that open with the default system reader
+    #  - last:   try some classical pdf viewers
     else:
-        if os.name == "nt":
-            os.filestart(manual)
-
-        elif os.name == "posix":
-
+        if reader is not None:
+            cmd = reader + ' ' + manual + ' 2>/dev/null &'
+            os.system(cmd)
+        else:
             for r in (sys_tools + readers):
                 cmd = r + ' ' + manual + ' 2>/dev/null &'
                 if os.system(cmd) == 0:
