@@ -38,9 +38,7 @@ import os, sys
 
 from optparse import OptionParser
 
-import cs_config
 import cs_exec_environment
-from cs_config import config
 
 #-------------------------------------------------------------------------------
 # Processes the passed command line arguments
@@ -69,23 +67,21 @@ def main(argv, pkg):
     """
 
     template = """\
-%(salomeenv)s;
-CFDSTUDY_ROOT_DIR=%(prefix)s;
-PYTHONPATH=%(pythondir)s/salome:%(pkgpythondir)s${PYTHONPATH:+:$PYTHONPATH};
-export CFDSTUDY_ROOT_DIR PYTHONPATH;
+%(salomeenv)s
+CFDSTUDY_ROOT_DIR=%(prefix)s
+PYTHONPATH=%(pythondir)s/salome:%(pkgpythondir)s${PYTHONPATH:+:$PYTHONPATH}
+export CFDSTUDY_ROOT_DIR PYTHONPATH
 %(runsalome)s --modules=%(modules)s
 """
 
-    cfg = config()
-
-    if cfg.have_salome == "no":
+    if pkg.config.have_salome == "no":
         sys.stderr.write("SALOME is not available in this installation.\n")
         sys.exit(1)
 
     # Skipped modules (version 6.3.0): YACS,JOBMANAGER,HOMARD,OPENTURNS
     default_modules = "GEOM,SMESH,MED,CFDSTUDY,PARAVIS,VISU"
 
-    run_cmd = cfg.salome_run
+    run_cmd = pkg.config.salome_run
     if not run_cmd:
         run_cmd = "${KERNEL_ROOT_DIR}/bin/salome/envSalome.py python ${KERNEL_ROOT_DIR}/bin/salome/runSalome.py"
 
@@ -97,9 +93,8 @@ export CFDSTUDY_ROOT_DIR PYTHONPATH;
         path = path+":"+cspath
 
         # Test if EOS modules could be imported
-        cfg = cs_config.config()
-        if cfg.libs['eos'].have == "yes":
-            eosprefix = cfg.libs['eos'].prefix
+        if pkg.config.libs['eos'].have == "yes":
+            eosprefix = pkg.config.libs['eos'].prefix
             try:
                 from distutils import sysconfig
                 eospath = os.path.join(sysconfig.get_python_lib(0, 0, prefix=eosprefix), 'eos')
@@ -109,7 +104,7 @@ export CFDSTUDY_ROOT_DIR PYTHONPATH;
                 if os.path.isdir(eospath) and not eospath in sys.path:
                     path = path+":"+eospath
 
-    cmd = template % {'salomeenv': cfg.salome_env,
+    cmd = template % {'salomeenv': pkg.config.salome_env,
                       'prefix': pkg.get_dir('prefix'),
                       'pythondir': pkg.get_dir('pythondir'),
                       'pkgpythondir': path,
