@@ -206,10 +206,6 @@ if test "x$cs_gcc" = "xgcc"; then
       esac
       ;;
 
-    *alphaev6|*alphaev67|*alphaev68|*alphaev7)
-      cflags_default_opt="-mcpu=ev6 -O"
-      ;;
-
   esac
 
   # Modify default flags depending on gcc version (as older versions
@@ -231,9 +227,6 @@ if test "x$cs_gcc" = "xgcc"; then
   esac
 
   case "$host_os" in
-    cygwin)
-    cflags_default="`echo $cflags_default | sed -e 's/c99/gnu99/g'`"
-    ;;
     mingw32)
     cflags_default="$cflags_default -Wno-format -Wno-pedantic-ms-format"
     ;;
@@ -390,19 +383,13 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
     if test "$?" = "0" ; then
       # Default compiler flags (we assume that MPI wrappers are used)
       cs_ibm_bg_type=`grep 'Blue Gene' $outfile | sed -e 's/.*Blue Gene\/\([A-Z]\).*/\1/'`
-      if test "x$cs_ibm_bg_type" = "xL" ; then
-        cppflags_default="-I/bgl/BlueLight/ppcfloor/bglsys/include"
-        cflags_default="-qlanglvl=stdc99"
-        cflags_default_opt="-O3"
-        cflags_default_hot="-O3 -qhot"
-        cflags_default_dbg="-g"
-      elif test "x$cs_ibm_bg_type" = "xP" ; then
+      if test "x$cs_ibm_bg_type" = "xP" ; then
         cppflags_default="-I/bgsys/drivers/ppcfloor/arch/include"
         cflags_default="-qlanglvl=extc99"
         cflags_default_opt="-O3"
         cflags_default_hot="-O3 -qhot"
         cflags_default_dbg="-g"
-      else
+      elif test -f /bgsys/drivers/ppcfloor/cnk/bin/bgq_kernel.elf ; then
         cs_ibm_bg_type="Q"
         cppflags_default=""
         cflags_default=""                    # "-qlanglvl=extc99" by default
@@ -661,10 +648,6 @@ if test "x$cs_gxx" = "xg++"; then
       esac
       ;;
 
-    *alphaev6|*alphaev67|*alphaev68|*alphaev7)
-      cxxflags_default_opt="-mcpu=ev6 -O"
-      ;;
-
   esac
 
   # Modify default flags depending on g++ version (as older versions
@@ -748,7 +731,7 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
     cs_cxx_compiler_known=yes
 
     # Default compiler flags
-    cxxflags_default="-q64"
+    cxxflags_default="-q64 -qlanglvl=redefmac"
     cxxflags_default_opt="-O3"
     cxxflags_default_hot="-O3"
     cxxflags_default_dbg="-g"
@@ -760,12 +743,7 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
     grep 'Blue Gene' $outfile > /dev/null
     if test "$?" = "0" ; then
       # Default compiler flags (we assume that MPI wrappers are used)
-      if test "x$cs_ibm_bg_type" = "xL" ; then
-        cxxflags_default=""
-        cxxflags_default_opt="-O3"
-        cxxflags_default_hot="-O3 -qhot"
-        cxxflags_default_dbg="-g"
-      elif test "x$cs_ibm_bg_type" = "xP" ; then
+      if test "x$cs_ibm_bg_type" = "xP" ; then
         cxxflags_default=""
         cxxflags_default_opt="-O3"
         cxxflags_default_hot="-O3 -qhot"
@@ -1037,12 +1015,17 @@ if test "$?" = "0" ; then
 
   # Default compiler flags
   fcflags_default="-x f95-cpp-input -Wall -Wno-unused"
-  fcflags_default_dbg="-g -fbounds-check"
+  fcflags_default_dbg="-g -fcheck=bounds"
   fcflags_default_opt="-O"
   fcflags_default_hot="-O2"
   fcflags_default_prf="-pg"
   fcflags_default_omp="-fopenmp"
 
+  case "$cs_fc_vendor-$cs_fc_version" in
+    gfortran-4.[234]*)
+    fcflags_default_dbg="`echo $fcflags_default_dbg | sed -e 's/-fcheck=bounds/-fbounds-check/g'`"
+  esac
+
 fi
 
 if test "x$cs_fc_compiler_known" != "xyes" ; then
@@ -1139,12 +1122,7 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     if test "$?" = "0" ; then
 
       # Default compiler flags (we assume that MPI wrappers are used)
-      if test "$cs_ibm_bg_type" = "L" ; then
-        fcflags_default="-qextname -qsuffix=cpp=f90"
-        fcflags_default_dbg="-g"
-        fcflags_default_opt="-O3"
-        fcflags_default_hot="-O3 -qhot"
-      elif test "$cs_ibm_bg_type" = "P" ; then
+      if test "$cs_ibm_bg_type" = "P" ; then
         fcflags_default="-qextname -qsuffix=cpp=f90"
         fcflags_default_dbg="-g"
         fcflags_default_opt="-O3"
