@@ -28,6 +28,7 @@ This GUI provides a simple way to display independante pages, in order to put
 informations in the XML document, which reflets the treated case.
 
 This module defines the following classes:
+- NewCaseDialogView
 - MainView
 
     @copyright: 1998-2013 EDF S.A., France
@@ -63,9 +64,11 @@ import cs_info
 
 try:
     from Base.MainForm import Ui_MainForm
+    from Base.NewCaseDialogForm import Ui_NewCaseDialogForm
 except:
     sys.path.insert(1, os.path.join(os.path.dirname(os.path.dirname(os.path.abspath(__file__))), "Base"))
     from Base.MainForm import Ui_MainForm
+    from Base.NewCaseDialogForm import Ui_NewCaseDialogForm
 
 from Base.IdView import IdView
 from Base.BrowserView import BrowserView
@@ -83,6 +86,7 @@ except:
 from Pages.WelcomeView import WelcomeView
 from Pages.IdentityAndPathesModel import IdentityAndPathesModel
 from Pages.XMLEditorView import XMLEditorView
+from Base.QtPage import setGreenColor
 
 
 #-------------------------------------------------------------------------------
@@ -93,6 +97,207 @@ logging.basicConfig()
 log = logging.getLogger("MainView")
 log.setLevel(GuiParam.DEBUG)
 
+#-------------------------------------------------------------------------------
+# New case dialog
+#-------------------------------------------------------------------------------
+
+class NewCaseDialogView(QDialog, Ui_NewCaseDialogForm):
+    """
+    Advanced dialog
+    """
+    def __init__(self, parent, pkg):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+
+        Ui_NewCaseDialogForm.__init__(self)
+        self.setupUi(self)
+
+        self.package = pkg
+
+        self.createMesh = False
+        self.createPost = False
+        self.copyFrom = False
+        self.copyFromName = None
+        self.caseName = None
+
+        self.currentPath = str(QDir.currentPath())
+        self.model = QFileSystemModel(self)
+        self.model.setRootPath(self.currentPath)
+        self.model.setFilter(QDir.Dirs)
+
+        self.listViewDirectory.setModel(self.model)
+        self.modelFolder = QStringListModel()
+        self.listViewFolder.setModel(self.modelFolder)
+
+        self.listViewDirectory.setRootIndex(self.model.index(self.currentPath))
+
+        self.lineEditCurrentPath.setText(QString(str(self.currentPath)))
+
+        self.connect(self.listViewDirectory,   SIGNAL("doubleClicked(QModelIndex)"),   self.slotParentDirectory)
+        self.connect(self.listViewFolder,      SIGNAL("clicked(QModelIndex)"),         self.slotSelectFolder)
+        self.connect(self.lineEditCurrentPath, SIGNAL("textChanged(const QString &)"), self.slotChangeDirectory)
+        self.connect(self.lineEditCaseName,    SIGNAL("textChanged(const QString &)"), self.slotChangeName)
+        self.connect(self.checkBoxPost,        SIGNAL("clicked()"),                    self.slotPostStatus)
+        self.connect(self.checkBoxMesh,        SIGNAL("clicked()"),                    self.slotMeshStatus)
+        self.connect(self.checkBoxCopyFrom,    SIGNAL("clicked()"),                    self.slotCopyFromStatus)
+        self.connect(self.pushButtonCopyFrom,  SIGNAL("clicked()"),                    self.slotCopyFromCase)
+
+
+    def slotParentDirectory(self, index):
+        if index.row() == 1 and index.column() == 0:
+            # ".." change directory
+            self.currentPath = os.path.abspath(os.path.join(self.currentPath, ".."))
+            self.model.setRootPath(self.currentPath)
+            self.listViewDirectory.setRootIndex(self.model.index(self.currentPath))
+        elif index.row() > 1:
+            self.currentPath = self.model.filePath(index)
+            self.model.setRootPath(self.currentPath)
+            self.listViewDirectory.setRootIndex(self.model.index(self.currentPath))
+        self.lineEditCurrentPath.setText(QString(str(self.currentPath)))
+
+        # construct list of study in current directory
+        cpath = QDir(str(self.currentPath))
+        cpath.setFilter(QDir.Dirs | QDir.NoSymLinks)
+        lst = []
+        self.modelFolder.setStringList(QStringList())
+        for name in cpath.entryList():
+            stud = True
+            base = os.path.abspath(os.path.join(self.currentPath, str(name)))
+            for rep in ['DATA',
+                        'RESU',
+                        'SRC',
+                        'SCRIPTS']:
+                directory = os.path.abspath(os.path.join(base, rep))
+                if not(os.path.isdir(directory)):
+                    stud = False
+            if stud:
+                lst.append(name)
+        self.modelFolder.setStringList(lst)
+
+
+    def slotSelectFolder(self, index):
+        if index.row() > 1:
+            self.lineEditCaseName.setText(QString(self.model.fileName(index)))
+
+
+    @pyqtSignature("const QString &")
+    def slotChangeDirectory(self, text):
+        """
+        change directory
+        """
+        if os.path.isdir(text):
+            self.currentPath = str(text)
+            self.model.setRootPath(self.currentPath)
+            self.listViewDirectory.setRootIndex(self.model.index(self.currentPath))
+
+
+    @pyqtSignature("const QString &")
+    def slotChangeName(self, text):
+        """
+        change case name
+        """
+        self.caseName = str(text)
+
+
+    @pyqtSignature("")
+    def slotPostStatus(self):
+        if self.checkBoxPost.isChecked():
+            self.createMesh = True
+        else:
+            self.createMesh = False
+
+
+    @pyqtSignature("")
+    def slotMeshStatus(self):
+        if self.checkBoxMesh.isChecked():
+            self.createPost = True
+        else:
+            self.createPost = False
+
+
+    @pyqtSignature("")
+    def slotCopyFromStatus(self):
+        if self.checkBoxCopyFrom.isChecked():
+            self.copyFrom = True
+            self.pushButtonCopyFrom.setEnabled(True)
+            setGreenColor(self.pushButtonCopyFrom, True)
+        else:
+            self.copyFrom = False
+            setGreenColor(self.pushButtonCopyFrom, False)
+            self.pushButtonCopyFrom.setEnabled(False)
+
+
+    @pyqtSignature("")
+    def slotCopyFromCase(self):
+        title = self.tr("Choose an existing case")
+
+        path = os.getcwd()
+        dataPath = os.path.join(path, "..", "DATA")
+        if os.path.isdir(dataPath): path = datapath
+
+        dirName = QFileDialog.getExistingDirectory(self, title,
+                                                   path,
+                                                   QFileDialog.ShowDirsOnly |
+                                                   QFileDialog.DontResolveSymlinks)
+        if dirName.isEmpty() or dirName.isNull():
+            self.copyFromName = None
+        else:
+            self.copyFromName = str(dirName)
+            setGreenColor(self.pushButtonCopyFrom, False)
+
+
+    @pyqtSignature("")
+    def accept(self):
+        """
+        Method called when user clicks 'OK'
+        """
+        if self.caseName == None or self.caseName == "":
+            msg = "name case not defined"
+            sys.stderr.write(msg + '\n')
+        elif self.copyFrom == True and self.copyFromName == None:
+            msg = "copy from case not defined"
+            sys.stderr.write(msg + '\n')
+        else:
+            cmd = [os.path.join(self.package.get_dir("bindir"), self.package.name),
+                   'create', '-c',
+                   os.path.join(self.currentPath, self.caseName)]
+            if self.copyFrom == True:
+                cmd += ['--copy-from=', self.copyFromName]
+
+            p = subprocess.Popen(cmd,
+                                 stdout=subprocess.PIPE,
+                                 stderr=subprocess.PIPE)
+            output = p.communicate()
+            if p.returncode != 0:
+                sys.stderr.write(output[1] + '\n')
+
+            if self.createMesh == True:
+                path = os.path.join(self.currentPath, "MESH")
+                os.mkdir(path)
+            if self.createPost == True:
+                path = os.path.join(self.currentPath, "POST")
+                os.mkdir(path)
+
+            self.currentPath = os.path.join(self.currentPath,
+                                            self.caseName,
+                                            "DATA")
+            self.model.setRootPath(self.currentPath)
+            self.listViewDirectory.setRootIndex(self.model.index(self.currentPath))
+            self.lineEditCurrentPath.setText(QString(str(self.currentPath)))
+
+            os.chdir(self.currentPath)
+            QDialog.accept(self)
+
+
+    def reject(self):
+        """
+        Method called when user clicks 'Cancel'
+        """
+        QDialog.reject(self)
+
+
 #-------------------------------------------------------------------------------
 # Base Main Window
 #-------------------------------------------------------------------------------
@@ -125,7 +330,6 @@ class MainView(object):
                 in MainView.Instances if isAlive(window)])
 
 
-
     def ui_initialize(self):
         self.setAttribute(Qt.WA_DeleteOnClose)
         MainView.Instances.add(self)
@@ -151,6 +355,7 @@ class MainView(object):
         # connections
 
         self.connect(self.fileOpenAction,   SIGNAL("triggered()"),   self.fileOpen)
+        self.connect(self.caseNewAction,    SIGNAL("triggered()"),   self.caseNew)
         self.connect(self.fileNewAction,    SIGNAL("triggered()"),   self.fileNew)
         self.connect(self.menuRecent,       SIGNAL("aboutToShow()"), self.updateRecentFileMenu)
         self.connect(self.fileSaveAction,   SIGNAL("triggered()"),   self.fileSave)
@@ -229,7 +434,7 @@ class MainView(object):
 
         if self.cmd_case == "new case":
             MainView.NextId += 1
-            self.fileNew()
+            self.caseNew()
             self.dockWidgetBrowserDisplay(True)
 
         # 2) existing case
@@ -426,6 +631,36 @@ class MainView(object):
             MainView(cmd_package=self.package, cmd_case="new case").show()
 
 
+    @pyqtSignature("")
+    def caseNew(self):
+        """
+        Public slot.
+
+        create new Code_Saturne case
+        """
+        if not hasattr(self, 'case'):
+            dialog = NewCaseDialogView(self, self.package)
+            if dialog.exec_():
+                self.case = XMLengine.Case(package=self.package)
+                self.case.root()['version'] = self.XML_DOC_VERSION
+                self.initCase()
+                title = self.tr("New parameters set") + \
+                         " - " + self.tr(self.package.code_name) + self.tr(" GUI") \
+                         + " - " + self.package.version
+                self.setWindowTitle(title)
+
+                self.Browser.configureTree(self.case)
+                self.dockWidgetBrowserDisplay(True)
+
+                self.case['salome'] = self.salome
+                self.scrollArea.setWidget(self.displayFisrtPage())
+                self.case['saved'] = "yes"
+
+                self.connect(self.case, SIGNAL("undo"), self.slotUndoRedoView)
+        else:
+            MainView(cmd_package=self.package, cmd_case="new case").show()
+
+
     def fileAlreadyLoaded(self, f):
         """
         private method
@@ -588,7 +823,8 @@ class MainView(object):
             path = self.case['data_path']
         else:
             path = os.getcwd()
-            if os.path.isdir(path + "/../DATA"): path = path + "/../DATA"
+            dataPath = os.path.join(path, "..", "DATA")
+            if os.path.isdir(dataPath): path = dataPath
 
         filetypes = self.tr(self.package.code_name) + self.tr(" GUI files (*.xml);;""All Files (*)")
 
@@ -716,9 +952,9 @@ class MainView(object):
         if hasattr(self,'case'):
             filetypes = self.tr(self.package.code_name) + self.tr(" GUI files (*.xml);;""All Files (*)")
             fname = QFileDialog.getSaveFileName(self,
-                                  self.tr("Save File As"),
-                                  self.case['data_path'],
-                                  filetypes)
+                                                self.tr("Save File As"),
+                                                self.case['data_path'],
+                                                filetypes)
 
             if not fname.isEmpty():
                 f = str(fname)
@@ -779,11 +1015,12 @@ class MainView(object):
                        ('resu_path',     'RESU'),
                        ('user_src_path', 'SRC'),
                        ('scripts_path',  'SCRIPTS')]:
-            self.IdPthMdl.setPathI(p,file_dir + '/' + rep)
+            self.IdPthMdl.setPathI(p, os.path.join(file_dir, rep))
         self.IdPthMdl.setRelevantSubdir("yes", "")
 
         self.IdPthMdl.setPathI('mesh_path',
-                               os.path.abspath(os.path.split(file_dir)[0] + '/' + 'MESH'))
+                               os.path.join(os.path.abspath(os.path.split(file_dir)[0],
+                                                            'MESH')))
         self.case['batch'] =  self.batch_file
         del IdentityAndPathesModel
 
@@ -855,7 +1092,7 @@ class MainView(object):
 
             self.batchFileUpdate()
 
-            batch = self.case['scripts_path'] + "/" + self.case['batch']
+            batch = os.path.join(self.case['scripts_path'], self.case['batch'])
             f = open(batch, 'w')
             f.writelines(self.batch_lines)
             f.close()
@@ -1045,7 +1282,7 @@ class MainViewSaturne(QMainWindow, Ui_MainForm, MainView):
         self.salome      = cmd_salome
         self.batch_type  = cs_batch_type
         self.batch       = None
-        self.batch_file  = 'runcase'
+        self.batch_file  = cmd_package.runcase
         self.batch_lines = []
         self.package     = cmd_package
 
