@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -77,7 +77,9 @@ class AtmosphericFlowsView(QWidget, Ui_AtmosphericFlowsForm):
         # create model
         model = AtmosphericFlowsModel(case)
         self.__model = model
-        self.__case = case
+        self.case = case
+
+        self.case.undoStopGlobal()
 
         # Define connection
         self.connect(self.checkBoxMeteoData,
@@ -94,6 +96,8 @@ class AtmosphericFlowsView(QWidget, Ui_AtmosphericFlowsForm):
         self.labelMeteoData.setEnabled(isMeteoDataChecked)
         self.labelMeteoFile.setEnabled(isMeteoDataChecked)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("bool")
     def __slotCheckBoxMeteoData(self, checked):
@@ -115,7 +119,7 @@ class AtmosphericFlowsView(QWidget, Ui_AtmosphericFlowsForm):
         """
         Select a meteorological file of data
         """
-        data = self.__case['data_path']
+        data = self.case['data_path']
         title = self.tr("Meteorological file of data.")
         filetypes = self.tr("Meteo data (*meteo*);;All Files (*)")
         file = QFileDialog.getOpenFileName(self, title, data, filetypes)
