@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -273,6 +273,8 @@ class BoundaryConditionsCoalInletView(QWidget, Ui_BoundaryConditionsCoalInletFor
         self.__case = case
         self.__boundary = None
 
+        self.__case.undoStopGlobal()
+
         # Connections
         self.connect(self.comboBoxTypeInlet,
                      SIGNAL("activated(const QString&)"),
@@ -377,6 +379,8 @@ class BoundaryConditionsCoalInletView(QWidget, Ui_BoundaryConditionsCoalInletFor
         for c in range(self.__modelCoalMass.columnCount()):
             self.tableViewCoalMass.setItemDelegateForColumn(c, delegateValueMass)
 
+        self.__case.undoStartGlobal()
+
 
     def showWidget(self, b):
         """
@@ -561,10 +565,12 @@ class BoundaryConditionsCoalInletView(QWidget, Ui_BoundaryConditionsCoalInletFor
                ('t', 'current time'),
                ('iter', 'number of iteration')]
 
-        dialog = QMeiEditorView(self, expression = exp,
-                                      required   = req,
-                                      symbols    = sym,
-                                      examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.__case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotFormulaVelocity -> %s" % str(result))
@@ -650,10 +656,12 @@ class BoundaryConditionsCoalInletView(QWidget, Ui_BoundaryConditionsCoalInletFor
                ('t', 'current time'),
                ('iter', 'number of iteration')]
 
-        dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.__case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotFormulaDirection -> %s" % str(result))
