@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -51,6 +51,7 @@ from Base.Toolbox import GuiParam
 from Base.QtPage import DoubleValidator, ComboModel
 from Pages.LocalizationModel import LocalizationModel, Zone
 from Pages.Boundary import Boundary
+from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -78,14 +79,21 @@ class BoundaryConditionsMeteoView(QWidget, Ui_BoundaryConditionsMeteoForm):
         self.setupUi(self)
 
 
-    def setup(self, case, velocityWidget, turbulenceWidget):
+    def setup(self, case, velocityWidget, turbulenceWidget, scalarsWidget):
         """
         Setup the widget.
         """
         self.__case = case
         self.velocityWidget = velocityWidget
         self.turbulenceWidget = turbulenceWidget
+        self.scalarsWidget = scalarsWidget
         self.__boundary = None
+
+        sca_mo  = DefineUserScalarsModel(self.__case)
+        self.species_list = sca_mo.getUserScalarLabelsList()
+
+        self.__case.undoStopGlobal()
+
         self.__model = AtmosphericFlowsModel(self.__case)
 
         self.connect(self.checkBoxReadData,
@@ -95,6 +103,8 @@ class BoundaryConditionsMeteoView(QWidget, Ui_BoundaryConditionsMeteoForm):
                      SIGNAL("clicked(bool)"),
                      self.__slotAutoNature)
 
+        self.__case.undoStartGlobal()
+
 
     def showWidget(self, b):
         """
@@ -149,6 +159,7 @@ class BoundaryConditionsMeteoView(QWidget, Ui_BoundaryConditionsMeteoForm):
             self.checkBoxAutoNature.setEnabled(True)
             self.velocityWidget.hideWidget()
             self.turbulenceWidget.hideWidget()
+            self.scalarsWidget.groupBoxMeteo.hide()
         else:
             self.__boundary.setMeteoDataStatus('off')
             self.checkBoxAutoNature.setChecked(False)
@@ -157,9 +168,11 @@ class BoundaryConditionsMeteoView(QWidget, Ui_BoundaryConditionsMeteoForm):
             if self.__boundary.getNature() == "meteo_inlet":
                 self.velocityWidget.showWidget(self.__b)
                 self.turbulenceWidget.showWidget(self.__b)
+                self.scalarsWidget.showWidget(self.__b)
             else:
                 self.velocityWidget.hideWidget()
                 self.turbulenceWidget.hideWidget()
+                self.scalarsWidget.showWidget(self.__b)
 
 
     def __slotAutoNature(self, bool):
