@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -79,9 +79,11 @@ class BoundaryConditionsRoughWallView(QWidget, Ui_BoundaryConditionsRoughWallFor
         """
         Setup the widget
         """
-        self.__case = case
+        self.case = case
         self.__boundary = None
 
+        self.case.undoStopGlobal()
+
         self.connect(self.radioButtonSmooth, SIGNAL("clicked()"), self.__slotRoughness)
         self.connect(self.radioButtonRough,  SIGNAL("clicked()"), self.__slotRoughness)
 
@@ -90,6 +92,8 @@ class BoundaryConditionsRoughWallView(QWidget, Ui_BoundaryConditionsRoughWallFor
         validatorRoughCoef = DoubleValidator(self.lineEditRoughCoef)
         self.lineEditRoughCoef.setValidator(validatorRoughCoef)
 
+        self.case.undoStartGlobal()
+
 
     def showWidget(self, boundary):
         """
