@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -52,6 +52,7 @@ from Pages.LocalizationModel import LocalizationModel, Zone
 from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 from Pages.ThermalScalarModel import ThermalScalarModel
 from Pages.QMeiEditorView import QMeiEditorView
+from Pages.Boundary import Boundary
 
 #-------------------------------------------------------------------------------
 # log config
@@ -82,9 +83,11 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         """
         Setup the widget
         """
-        self.case = case
+        self.__case = case
         self.__boundary = None
 
+        self.__case.undoStopGlobal()
+
         self.connect(self.lineEditValueThermal, SIGNAL("textChanged(const QString &)"), self.slotValueThermal)
         self.connect(self.lineEditValueSpecies, SIGNAL("textChanged(const QString &)"), self.slotValueSpecies)
         self.connect(self.lineEditValueMeteo,   SIGNAL("textChanged(const QString &)"), self.slotValueMeteo)
@@ -117,6 +120,8 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.lineEditExSpecies.setValidator(validatorExSpecies)
         self.lineEditExMeteo.setValidator(validatorExMeteo)
 
+        self.__case.undoStartGlobal()
+
 
     def __setBoundary(self, boundary):
         """
@@ -125,8 +130,8 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.__boundary = boundary
 
         self.nature  = boundary.getNature()
-        self.therm   = ThermalScalarModel(self.case)
-        self.sca_mo  = DefineUserScalarsModel(self.case)
+        self.therm   = ThermalScalarModel(self.__case)
+        self.sca_mo  = DefineUserScalarsModel(self.__case)
 
         self.modelTypeThermal = ComboModel(self.comboBoxTypeThermal, 1, 1)
         self.modelTypeSpecies = ComboModel(self.comboBoxTypeSpecies, 1, 1)
@@ -175,16 +180,23 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         else:
             self.groupBoxSpecies.hide()
 
+        self.meteo_list = ""
         self.meteo_list = self.sca_mo.getMeteoScalarsList()
-        if self.meteo_list != None:
-            self.groupBoxMeteo.show()
-            self.modelMeteo = ComboModel(self.comboBoxMeteo, 1, 1)
-            for m in self.meteo_list:
-                self.modelMeteo.addItem(self.tr(m), m)
-            self.meteo = self.meteo_list[0]
-            self.modelMeteo.setItem(str_model = self.meteo)
-        else:
-            self.groupBoxMeteo.hide()
+
+        self.groupBoxMeteo.hide()
+
+        if (self.meteo_list and (self.nature == 'inlet' or self.nature == 'outlet')):
+            label = self.__boundary.getLabel()
+            nature = "meteo_" + self.nature
+            bb = Boundary(nature, label, self.__case)
+
+            if bb.getMeteoDataStatus() == 'off':
+                self.groupBoxMeteo.show()
+                self.modelMeteo = ComboModel(self.comboBoxMeteo, 1, 1)
+                for m in self.meteo_list:
+                    self.modelMeteo.addItem(self.tr(m), m)
+                self.meteo = self.meteo_list[0]
+                self.modelMeteo.setItem(str_model = self.meteo)
 
         self.model_th = self.therm.getThermalScalarModel()
         if self.model_th != 'off':
@@ -289,42 +301,47 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.pushButtonMeteo.setEnabled(False)
         setGreenColor(self.pushButtonMeteo, False)
 
-        if self.meteo_list != None:
-            self.meteo_type = self.__boundary.getScalarChoice(self.meteo)
-            self.modelTypeMeteo.setItem(str_model = self.meteo_type)
-            self.labelValueMeteo.setText('Value')
-            self.groupBoxMeteo.setTitle('Meteo')
+        if (self.meteo_list and (self.nature == 'inlet' or self.nature == 'outlet')):
+            label = self.__boundary.getLabel()
+            nature = "meteo_" + self.nature
+            bb = Boundary(nature, label, self.__case)
 
-            if self.meteo_type in ('dirichlet', 'exchange_coefficient', 'neumann'):
-                self.labelValueMeteo.show()
-                self.lineEditValueMeteo.show()
+            if bb.getMeteoDataStatus() == 'off':
+                self.meteo_type = self.__boundary.getScalarChoice(self.meteo)
+                self.modelTypeMeteo.setItem(str_model = self.meteo_type)
+                self.labelValueMeteo.setText('Value')
+                self.groupBoxMeteo.setTitle('Meteo')
 
-                if self.meteo_type == 'exchange_coefficient':
-                    self.lineEditExMeteo.show()
-                    self.labelExMeteo.show()
-                    v = self.__boundary.getScalarValue(self.meteo, 'dirichlet')
-                    w = self.__boundary.getScalarValue(self.meteo, 'exchange_coefficient')
-                    self.lineEditValueMeteo.setText(QString(str(v)))
-                    self.lineEditExMeteo.setText(QString(str(w)))
-                else:
-                    v = self.__boundary.getScalarValue(self.meteo, self.meteo_type)
-                    self.lineEditValueMeteo.setText(QString(str(v)))
+                if self.meteo_type in ('dirichlet', 'exchange_coefficient', 'neumann'):
+                    self.labelValueMeteo.show()
+                    self.lineEditValueMeteo.show()
 
-            if self.meteo_type == 'neumann':
-                self.labelValueMeteo.setText('Flux')
-                if self.nature == 'outlet':
-                    self.groupBoxMeteo.setTitle('Meteo for backflow')
+                    if self.meteo_type == 'exchange_coefficient':
+                        self.lineEditExMeteo.show()
+                        self.labelExMeteo.show()
+                        v = self.__boundary.getScalarValue(self.meteo, 'dirichlet')
+                        w = self.__boundary.getScalarValue(self.meteo, 'exchange_coefficient')
+                        self.lineEditValueMeteo.setText(QString(str(v)))
+                        self.lineEditExMeteo.setText(QString(str(w)))
+                    else:
+                        v = self.__boundary.getScalarValue(self.meteo, self.meteo_type)
+                        self.lineEditValueMeteo.setText(QString(str(v)))
 
-            if self.meteo_type in ('exchange_coefficient_formula', 'dirichlet_formula', 'neumann_formula'):
-                self.pushButtonMeteo.setEnabled(True)
-                setGreenColor(self.pushButtonMeteo, True)
+                if self.meteo_type == 'neumann':
+                    self.labelValueMeteo.setText('Flux')
+                    if self.nature == 'outlet':
+                        self.groupBoxMeteo.setTitle('Meteo for backflow')
+
+                if self.meteo_type in ('exchange_coefficient_formula', 'dirichlet_formula', 'neumann_formula'):
+                    self.pushButtonMeteo.setEnabled(True)
+                    setGreenColor(self.pushButtonMeteo, True)
 
 
     def showWidget(self, boundary):
         """
         Show the widget
         """
-        if DefineUserScalarsModel(self.case).getScalarLabelsList():
+        if DefineUserScalarsModel(self.__case).getScalarLabelsList() or DefineUserScalarsModel(self.__case).getMeteoScalarsList():
             self.__setBoundary(boundary)
             self.show()
         else:
@@ -410,10 +427,12 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.__case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotThermalFormula -> %s" % str(result))
@@ -436,10 +455,12 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.__case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotSpeciesFormula -> %s" % str(result))
@@ -462,10 +483,12 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.__case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotMeteoFormula -> %s" % str(result))
