@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -84,6 +84,8 @@ class BoundaryConditionsTurbulenceInletView(QWidget, Ui_BoundaryConditionsTurbul
         self.__case = case
         self.__boundary = None
 
+        self.__case.undoStopGlobal()
+
         self.connect(self.comboBoxTurbulence, SIGNAL("activated(const QString&)"), self.__slotChoiceTurbulence)
 
         self.__modelTurbulence = ComboModel(self.comboBoxTurbulence, 2, 1)
@@ -104,6 +106,8 @@ class BoundaryConditionsTurbulenceInletView(QWidget, Ui_BoundaryConditionsTurbul
         self.lineEditDiameterIntens.setValidator(validatorDiam)
         self.lineEditIntensity.setValidator(validatorIntensity)
 
+        self.__case.undoStartGlobal()
+
 
     def showWidget(self, boundary):
         """
@@ -239,10 +243,12 @@ eps = ustar2^1.5/(kappa*dh*0.1);"""
                    ('t','time'),
                    ('dt','time step'),
                    ('iter','number of time step')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.__case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -300,10 +306,12 @@ R23 = 0;
                    ('t','time'),
                    ('dt','time step'),
                    ('iter','number of time step')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.__case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -363,17 +371,19 @@ alpha =  1.;
                    ('t','time'),
                    ('dt','time step'),
                    ('iter','number of time step')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.__case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
                 self.__boundary.setTurbFormula(result)
                 setGreenColor(self.pushButtonTurb, False)
 
-        elif turb_model == 'v2f-phi':
+        elif turb_model == 'v2f-BL-v2/k':
 
             exp = self.__boundary.getTurbFormula()
             if not exp:
@@ -405,21 +415,23 @@ d2s3 = 2/3;
 k   = ustar2/sqrt(cmu);
 eps = ustar2^1.5/(kappa*dh*0.1);
 phi = d2s3;
-fb = 0;"""
+alpha = 0;"""
             req = [('k', "turbulent energy"),
             ('eps', "turbulent dissipation"),
             ('phi', "variable phi in v2f model"),
-            ('fb', "variable f in v2f model")]
+            ('alpha', "variable alpha in v2f model")]
             sym = [('x','cell center coordinate'),
                    ('y','cell center coordinate'),
                    ('z','cell center coordinate'),
                    ('t','time'),
                    ('dt','time step'),
                    ('iter','number of time step')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.__case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -465,10 +477,12 @@ omega = eps/(cmu * k);"""
                    ('t','time'),
                    ('dt','time step'),
                    ('iter','number of time step')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.__case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -513,10 +527,12 @@ nusa = eps/(cmu * k);"""
                    ('t','time'),
                    ('dt','time step'),
                    ('iter','number of time step')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.__case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
