@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -130,6 +130,8 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.setupUi(self)
         self.__case = case
 
+        self.__case.undoStopGlobal()
+
         # Model and QTreeView for Boundaries
 
         self.__modelBoundaries = StandardItemModelBoundaries()
@@ -162,13 +164,16 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.turbulenceWidget.setup(self.__case)
         self.compressibleOutletWidget.setup(self.__case)
         self.coalWidget.setup(self.__case)
-        self.meteoWidget.setup(self.__case, self.velocityWidget, self.turbulenceWidget)
         self.scalarsWidget.setup(self.__case)
+        self.meteoWidget.setup(self.__case, self.velocityWidget, self.turbulenceWidget, self.scalarsWidget)
         self.mobileMeshWidget.setup(self.__case)
         self.radiativeWidget.setup(self.__case)
+        self.electricalwidget.setup(self.__case)
 
         self.__hideAllWidgets()
 
+        self.__case.undoStartGlobal()
+
 
     @pyqtSignature("const QModelIndex&")
     def __slotSelectBoundary(self, index):
@@ -206,6 +211,7 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.meteoWidget.showWidget(boundary)
         self.scalarsWidget.showWidget(boundary)
         self.mobileMeshWidget.showWidget(boundary)
+        self.electricalwidget.showWidget(boundary)
 
 
     def __selectWallBoundary(self, boundary):
@@ -217,6 +223,7 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.scalarsWidget.showWidget(boundary)
         self.mobileMeshWidget.showWidget(boundary)
         self.radiativeWidget.showWidget(boundary)
+        self.electricalwidget.showWidget(boundary)
 
 
     def __selectOutletBoundary(self, boundary):
@@ -230,6 +237,7 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
             self.compressibleOutletWidget.showWidget(boundary)
         else:
             self.compressibleOutletWidget.hideWidget()
+        self.electricalwidget.showWidget(boundary)
         #self.pressureWidget.showWidget(boundary)
 
 
@@ -254,6 +262,7 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.scalarsWidget.hideWidget()
         self.mobileMeshWidget.hideWidget()
         self.radiativeWidget.hideWidget()
+        self.electricalwidget.hideWidget()
         #self.pressureWidget.hideWidget()
 
 
