@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -269,8 +269,11 @@ class ConjugateHeatTransferView(QWidget, Ui_ConjugateHeatTransferForm):
         Ui_ConjugateHeatTransferForm.__init__(self)
         self.setupUi(self)
 
-        self.__case = case
-        self.__model = ConjugateHeatTransferModel(self.__case)
+        self.case = case
+
+        self.case.undoStopGlobal()
+
+        self.__model = ConjugateHeatTransferModel(self.case)
 
         # Models
         self.modelSyrthes = StandardItemModelSyrthes(self.__model)
@@ -301,6 +304,8 @@ class ConjugateHeatTransferView(QWidget, Ui_ConjugateHeatTransferForm):
         if len(self.__model.getSyrthesCouplingList()) < 2:
             self.tableViewSyrthes.hideColumn(0)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("")
     def slotAddSyrthes(self):
