@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -470,6 +470,9 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         self.setupUi(self)
 
         self.case = case
+
+        self.case.undoStopGlobal()
+
         self.mdl = DefineUserScalarsModel(self.case)
 
         # tableView
@@ -512,6 +515,8 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         for label in self.mdl.getScalarsVarianceList():
             self.modelVariance.newItem(label)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("")
     def slotAddScalar(self):
@@ -528,15 +533,15 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         Just delete the current selected entries from the table and
         of course from the XML file.
         """
-        list = []
+        lst = []
         for index in self.tableScalars.selectionModel().selectedRows():
             row = index.row()
-            list.append(row)
+            lst.append(row)
 
-        list.sort()
-        list.reverse()
+        lst.sort()
+        lst.reverse()
 
-        for row in list:
+        for row in lst:
             label = self.modelScalars.getItem(row)
             if self.mdl.getScalarType(label) == 'user':
                 self.mdl.deleteScalar(label)
@@ -573,15 +578,15 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         Just delete the current selected entries from the table and
         of course from the XML file.
         """
-        list = []
+        lst = []
         for index in self.tableVariance.selectionModel().selectedRows():
             row = index.row()
-            list.append(row)
+            lst.append(row)
 
-        list.sort()
-        list.reverse()
+        lst.sort()
+        lst.reverse()
 
-        for row in list:
+        for row in lst:
             label = self.modelVariance.getItem(row)[0]
             self.mdl.deleteScalar(label)
             self.modelVariance.deleteItem(row)
