@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -45,7 +45,6 @@ from Base.Common import *
 import Base.Toolbox as Tool
 from Base.XMLvariables import Variables, Model
 from Base.XMLmodel import XMLmodel, ModelTest
-from Pages.CompressibleModel import CompressibleModel
 
 #-------------------------------------------------------------------------------
 # Model class
@@ -61,26 +60,41 @@ class FluidCharacteristicsModel(Variables, Model):
         self.node_models = self.case.xmlGetNode('thermophysical_models')
         self.node_prop   = self.case.xmlGetNode('physical_properties')
         self.node_fluid  = self.node_prop.xmlInitNode('fluid_properties')
-        self.node_comp = self.node_models.xmlInitNode('compressible_model')
+        self.node_comp   = self.node_models.xmlInitNode('compressible_model', 'model')
+        self.node_gas    = self.node_models.xmlInitNode('gas_combustion',     'model')
+        self.node_coal   = self.node_models.xmlInitNode('solid_fuels',        'model')
 
         self.node_density   = self.setNewFluidProperty(self.node_fluid, 'density')
         self.node_viscosity = self.setNewFluidProperty(self.node_fluid, 'molecular_viscosity')
         self.node_heat      = self.setNewFluidProperty(self.node_fluid, 'specific_heat')
         self.node_cond      = self.setNewFluidProperty(self.node_fluid, 'thermal_conductivity')
-        self.node_dyn       = self.setNewFluidProperty(self.node_fluid, 'dynamic_diffusion')
-        self.nodeList = (self.node_density, self.node_viscosity,
-                         self.node_heat, self.node_cond, self.node_dyn)
-        if CompressibleModel(self.case).getCompressibleModel() != 'off':
-            self.node_vol_visc  = self.setNewFluidProperty(self.node_fluid, 'volumic_viscosity')
-            self.nodeList = (self.node_density, self.node_viscosity,
-                             self.node_heat, self.node_cond,
-                             self.node_vol_visc, self.node_dyn)
 
 
     def __nodeFromTag(self, name):
         """
         Private method : return node with attibute name 'name'
         """
+        if self.node_coal['model'] != None and self.node_coal['model'] != 'off':
+            self.node_dyn = self.setNewFluidProperty(self.node_fluid, 'dynamic_diffusion')
+            self.nodeList = (self.node_density, self.node_viscosity,
+                             self.node_heat, self.node_dyn)
+
+        elif self.node_gas['model'] != None and self.node_gas['model'] != 'off':
+            self.node_dyn = self.setNewFluidProperty(self.node_fluid, 'dynamic_diffusion')
+            self.nodeList = (self.node_density, self.node_viscosity,
+                             self.node_heat, self.node_dyn)
+
+        elif self.node_comp['model'] != None and self.node_comp['model'] != 'off':
+            self.node_vol_visc  = self.setNewFluidProperty(self.node_fluid, 'volumic_viscosity')
+            self.node_dyn = self.setNewFluidProperty(self.node_fluid, 'dynamic_diffusion')
+            self.node_cond      = self.setNewFluidProperty(self.node_fluid, 'thermal_conductivity')
+            self.nodeList = (self.node_density, self.node_viscosity,
+                             self.node_heat, self.node_vol_visc, self.node_dyn, self.node_cond)
+        else:
+            self.node_cond      = self.setNewFluidProperty(self.node_fluid, 'thermal_conductivity')
+            self.nodeList = (self.node_density, self.node_viscosity,
+                             self.node_heat, self.node_cond)
+
         for node in self.nodeList:
             if node['name'] == name:
                 return node
@@ -100,11 +114,12 @@ class FluidCharacteristicsModel(Variables, Model):
         default['specific_heat']        = 1017.24
         default['thermal_conductivity'] = 0.02495
         default['dynamic_diffusion']    = 0.01
-        default['volumic_viscosity']    = 1.83e-05
+        default['volumic_viscosity']    = 0.
 
         return default
 
 
+    @Variables.noUndo
     def getThermalModel(self):
         """
         Return node and model of choosen thermophysical model
@@ -115,8 +130,9 @@ class FluidCharacteristicsModel(Variables, Model):
         node3 = self.node_models.xmlGetNode('joule_effect',      'model')
         node4 = self.node_models.xmlGetNode('thermal_scalar',    'model')
         node5 = self.node_models.xmlGetNode('atmospheric_flows', 'model')
+        node6 = self.node_models.xmlGetNode('compressible_model', 'model')
 
-        for node in (node1, node2, node3, node4, node5):
+        for node in (node1, node2, node3, node4, node5, node6):
             if node:
                 if node['model'] == "":
                     node['model'] = "off"
@@ -133,17 +149,19 @@ class FluidCharacteristicsModel(Variables, Model):
         return nodeThermal, modelList[0]
 
 
+    @Variables.noUndo
     def getThermoPhysicalModel(self):
         """
         Return values of attribute "model" of all thermophysical model nodes.
         (also called by NumericalParamGlobalView and TimeStepView)
         """
         d = {}
-        d['joule_effect']      = 'off'
-        d['gas_combustion']    = 'off'
-        d['solid_fuels']       = 'off'
-        d['thermal_scalar']    = 'off'
-        d['atmospheric_flows'] = 'off'
+        d['joule_effect']       = 'off'
+        d['gas_combustion']     = 'off'
+        d['solid_fuels']        = 'off'
+        d['thermal_scalar']     = 'off'
+        d['atmospheric_flows']  = 'off'
+        d['compressible_model'] = 'off'
 
         node, model = self.getThermalModel()
         if node:
@@ -153,9 +171,11 @@ class FluidCharacteristicsModel(Variables, Model):
                d['joule_effect'],      \
                d['thermal_scalar'],    \
                d['gas_combustion'],    \
-               d['solid_fuels']
+               d['solid_fuels'],    \
+               d['compressible_model']
 
 
+    @Variables.noUndo
     def getInitialValue(self, tag):
         """
         Return initial value of the markup tag : 'density', or
@@ -172,6 +192,7 @@ class FluidCharacteristicsModel(Variables, Model):
         return pp
 
 
+    @Variables.undoLocal
     def setInitialValue(self, tag, val):
         """
         Put initial value for the markup tag : 'density', or
@@ -180,71 +201,87 @@ class FluidCharacteristicsModel(Variables, Model):
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
                             'volumic_viscosity', 'dynamic_diffusion'))
-        self.isGreater(val, 0.)
+        if tag != 'volumic_viscosity':
+            self.isGreater(val, 0.)
+        else:
+            self.isPositiveFloat(val)
         node = self.node_fluid.xmlGetNode('property', name=tag)
         node.xmlSetData('initial_value', val)
 
 
+    @Variables.noUndo
     def getInitialValueDensity(self):
         """Return initial value of density"""
         return self.getInitialValue('density')
 
 
+    @Variables.undoLocal
     def setInitialValueDensity(self, val):
         """Put initial value for density"""
         self.setInitialValue('density', val)
 
 
+    @Variables.noUndo
     def getInitialValueViscosity(self):
         """Return initial value of viscosity"""
         return self.getInitialValue('molecular_viscosity')
 
 
+    @Variables.undoLocal
     def setInitialValueViscosity(self, val):
         """Put initial value for viscosity"""
         self.setInitialValue('molecular_viscosity', val)
 
 
+    @Variables.noUndo
     def getInitialValueVolumicViscosity(self):
         """Return initial value of volumic viscosity"""
         return self.getInitialValue('volumic_viscosity')
 
 
+    @Variables.undoLocal
     def setInitialValueVolumicViscosity(self, val):
         """Put initial value for volumic viscosity"""
         self.setInitialValue('volumic_viscosity', val)
 
 
+    @Variables.noUndo
     def getInitialValueHeat(self):
         """Return initial value of specific heat"""
         return self.getInitialValue('specific_heat')
 
 
+    @Variables.undoLocal
     def setInitialValueHeat(self, val):
         """Put initial value for specific heat"""
         self.setInitialValue('specific_heat', val)
 
 
+    @Variables.noUndo
     def getInitialValueCond(self):
         """Return initial value of conductivity"""
         return self.getInitialValue('thermal_conductivity')
 
 
+    @Variables.undoLocal
     def setInitialValueCond(self, val):
         """Put initial value for conductivity"""
         self.setInitialValue('thermal_conductivity', val)
 
 
+    @Variables.noUndo
     def getInitialValueDyn(self):
         """Return initial value of conductivity"""
         return self.getInitialValue('dynamic_diffusion')
 
 
+    @Variables.undoLocal
     def setInitialValueDyn(self, val):
         """Put initial value for conductivity"""
         self.setInitialValue('dynamic_diffusion', val)
 
 
+    @Variables.noUndo
     def getFormula(self, tag):
         """
         Return a formula for I{tag} 'density', 'molecular_viscosity',
@@ -261,6 +298,7 @@ class FluidCharacteristicsModel(Variables, Model):
         return formula
 
 
+    @Variables.noUndo
     def getDefaultFormula(self, tag):
         """
         Return default formula
@@ -282,6 +320,7 @@ class FluidCharacteristicsModel(Variables, Model):
         return formula
 
 
+    @Variables.undoLocal
     def setFormula(self, tag, str):
         """
         Gives a formula for 'density', 'molecular_viscosity',
@@ -294,6 +333,7 @@ class FluidCharacteristicsModel(Variables, Model):
         node.xmlSetData('formula', str)
 
 
+    @Variables.noUndo
     def getPropertyMode(self, tag):
         """Return choice of node I{tag}. Choice is constant or variable"""
         self.isInList(tag, ('density', 'molecular_viscosity',
@@ -305,6 +345,7 @@ class FluidCharacteristicsModel(Variables, Model):
         return c
 
 
+    @Variables.undoGlobal
     def setPropertyMode(self, tag, choice):
         """Put choice in xml file's node I{tag}"""
         self.isInList(tag, ('density', 'molecular_viscosity',
@@ -356,7 +397,7 @@ class FluidCharacteristicsModelTestCase(ModelTest):
         from Pages.ThermalScalarModel import ThermalScalarModel
         ThermalScalarModel(self.case).setThermalModel('temperature_celsius')
         del ThermalScalarModel
-        assert mdl.getThermoPhysicalModel() == ('off', 'off', 'temperature_celsius', 'off', 'off'),\
+        assert mdl.getThermoPhysicalModel() == ('off', 'off', 'temperature_celsius', 'off', 'off', 'off'),\
         'Could not get thermophysical models in FluidCaracteristicsModel'
 
     def checkSetandGetInitialValue(self):
