@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -91,7 +91,7 @@ class FluidStructureInteractionAdvancedOptionsView(QDialog,
     """
     Advanced dialog
     """
-    def __init__(self, parent, default):
+    def __init__(self, parent, case, default):
         """
         Constructor
         """
@@ -100,6 +100,9 @@ class FluidStructureInteractionAdvancedOptionsView(QDialog,
         Ui_FluidStructureInteractionAdvancedOptionsDialogForm.__init__(self)
         self.setupUi(self)
 
+        self.case = case
+        self.case.undoStopGlobal()
+
         title = self.tr("Displacements prediction:")
         self.setWindowTitle(title)
 
@@ -108,6 +111,8 @@ class FluidStructureInteractionAdvancedOptionsView(QDialog,
         self.__setValidator()
         self.__setInitialValues()
 
+        self.case.undoStartGlobal()
+
 
     def __setValidator(self):
         """
@@ -425,6 +430,7 @@ class FormulaCoupling(Coupling):
 
         # run the editor
         dialog = QMeiEditorView(self.getWidget(),
+                                check_syntax = None,
                                 expression = exp,
                                 required   = self.__required,
                                 symbols    = self.__symbols,
@@ -488,7 +494,8 @@ class CouplingManager:
         """
         Constructor
         """
-        self.__case               = case
+        self.case               = case
+        self.case.undoStopGlobal()
         self.__internalTableModel = internalTableModel
         self.__externalTableModel = externalTableModel
         self.__internalCouplings = []
@@ -498,6 +505,7 @@ class CouplingManager:
         self.__initLineEditCouplings(mainView)
         self.__initFormulaCouplings (mainView)
         self.__initCheckBoxCouplings(mainView)
+        self.case.undoStartGlobal()
 
 
     def __initLineEditCouplings(self, mainView):
@@ -656,7 +664,7 @@ fx = fluid_fx;\nfy = 0;\nfz = fluid_fz;"""
         # Get Boundary
         label = tableModel.getLabel(selected)
 
-        boundary = Boundary("coupling_mobile_boundary", label, self.__case)
+        boundary = Boundary("coupling_mobile_boundary", label, self.case)
 
         # Set boundary for coupling
         for coupling in couplings:
@@ -680,7 +688,8 @@ class FluidStructureInteractionView(QWidget, Ui_FluidStructureInteractionForm):
         Ui_FluidStructureInteractionForm.__init__(self)
         self.setupUi(self)
 
-        self.__case = case
+        self.case = case
+        self.case.undoStopGlobal()
         self.__model = FluidStructureInteractionModel(case)
 
         self.__defineConnection()
@@ -713,6 +722,7 @@ class FluidStructureInteractionView(QWidget, Ui_FluidStructureInteractionForm):
         self.__initTableView(self.tableExternalCoupling,
                             self.__externalTableModel,
                             couplingManager.slotExternalSelectionChanged)
+        self.case.undoStartGlobal()
 
 
     def __defineConnection(self):
@@ -763,7 +773,7 @@ class FluidStructureInteractionView(QWidget, Ui_FluidStructureInteractionForm):
 
         # Populate QTableView model
         for zone in modelLocalization.getZones():
-            boundary = Boundary("mobile_boundary", zone.getLabel(), self.__case)
+            boundary = Boundary("mobile_boundary", zone.getLabel(), self.case)
             if boundary.getALEChoice() == filterALE:
                 tableViewItemModel.addItem(zone)
         return tableViewItemModel
@@ -839,7 +849,7 @@ class FluidStructureInteractionView(QWidget, Ui_FluidStructureInteractionForm):
         log.debug("slotAdvancedOptions -> %s" % str(default))
 
         # run the dialog
-        dialog = FluidStructureInteractionAdvancedOptionsView(self, default)
+        dialog = FluidStructureInteractionAdvancedOptionsView(self, self.case, default)
         if dialog.exec_():
             # Set the model with the dialog results
             result = dialog.get_result()
