@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -152,6 +152,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
 
         # Create the Page layout.
 
@@ -159,7 +160,6 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
         self.modelHeadLosses = StandardItemModelHeadLosses()
         self.treeView.setModel(self.modelHeadLosses)
 
-
         # Connections
         self.connect(self.treeView, SIGNAL("clicked(const QModelIndex &)"), self.slotSelectHeadLossesZones)
         self.connect(self.groupBox_3, SIGNAL("clicked(bool)"), self.slotTransfoMatrix)
@@ -215,7 +215,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
         self.entriesNumber = 0
         d = HeadLossesModel(self.case).getNameAndLocalizationZone()
         liste=[]
-        liste=d.items()
+        liste=list(d.items())
         t=[]
         for t in liste :
             NamLoc=t[1]
@@ -223,6 +223,8 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             self.modelHeadLosses.insertItem(Lab, NamLoc[0],NamLoc[1])
         self.forgetStandardWindows()
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("const QModelIndex&")
     def slotSelectHeadLossesZones(self, index):
