@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -44,14 +44,12 @@ from math import pow
 from Base.Common import *
 import Base.Toolbox as Tool
 from Base.XMLmodel import XMLmodel, ModelTest
-from Base.XMLvariables import Model
+from Base.XMLvariables import Model, Variables
 from Pages.TurbulenceModel import TurbulenceModel
-from Pages.GasCombustionModel import GasCombustionModel
-from Pages.CoalCombustionModel import CoalCombustionModel
-from Pages.ElectricalModelsModel import ElectricalModel
 from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 from Pages.LocalizationModel import LocalizationModel
 from Pages.CompressibleModel import CompressibleModel
+from Pages.ElectricalModel import ElectricalModel
 
 #-------------------------------------------------------------------------------
 # Variables and Scalar model initialization modelling class
@@ -79,12 +77,15 @@ class InitializationModel(Model):
         self.Turb_var_List = ('turb_k', 'turb_eps',
                               'component_R11', 'component_R22', 'component_R33',
                               'component_R12', 'component_R13', 'component_R23',
-                              'turb_phi', 'turb_fb', 'turb_omega', 'turb_nusa',
+                              'turb_phi', 'turb_al', 'turb_omega', 'turb_nusa',
                               'turb_alpha')
 
         self.turb = TurbulenceModel(self.case)
         self.turbulenceModes = ('formula',
                                 'reference_value')
+        self.node_scalartherm = self.node_userscalar
+        if ElectricalModel(self.case).getElectricalModel() != "off":
+            self.node_scalartherm = self.models.xmlGetNode("joule_effect")
 
 
     def __defaultValues(self):
@@ -108,6 +109,7 @@ class InitializationModel(Model):
         self.isInList(zone, LocalizationModel('VolumicZone', self.case).getCodeNumbersList())
 
 
+    @Variables.noUndo
     def getDefaultTurbFormula(self, turb_model):
         self.isInList(turb_model,self.turb.turbulenceModels())
         if turb_model in ('k-epsilon', 'k-epsilon-PL'):
@@ -137,12 +139,12 @@ r23 = 0.;
 k = 0.5*(r11+r22+r33);
 eps = k^1.5*cmu/almax;
 alpha = 1.;"""
-        elif turb_model == 'v2f-phi':
+        elif turb_model == 'v2f-BL-v2/k':
             formula = """cmu = 0.22;
 k = 1.5*(0.02*uref)^2;
 eps = k^1.5*cmu/almax;
 phi = 2./3.;
-fb = 0.;"""
+al = 0.;"""
         elif turb_model == 'k-omega-SST':
             formula = """k = 1.5*(0.02*uref)^2;
 omega = k^0.5/almax;"""
@@ -151,6 +153,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.noUndo
     def getInitialTurbulenceChoice(self, zone):
         """
         Public method.
@@ -168,6 +171,7 @@ omega = k^0.5/almax;"""
         return choice
 
 
+    @Variables.undoLocal
     def setInitialTurbulenceChoice(self, zone, init_mode):
         """
         Public method.
@@ -180,6 +184,7 @@ omega = k^0.5/almax;"""
         node_init['choice'] = init_mode
 
 
+    @Variables.noUndo
     def getTurbFormula(self, zone, turb_model):
         """
         Public method.
@@ -195,6 +200,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.undoLocal
     def setTurbFormula(self, zone, formula):
         """
         Public method.
@@ -209,6 +215,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.undoLocal
     def setVelocityFormula(self, zone, formula):
         """
         Public method.
@@ -220,6 +227,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getVelocityFormula(self, zone):
         """
         Public method.
@@ -232,6 +240,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.undoLocal
     def setThermalFormula(self, zone, scalar, formula):
         """
         Public method.
@@ -239,7 +248,7 @@ omega = k^0.5/almax;"""
         """
         self.__verifyZone(zone)
         self.isInList(scalar, ['TempC', 'TempK', 'Enthalpy'])
-        node = self.node_userscalar.xmlGetNode('scalar', label = str(scalar))
+        node = self.node_scalartherm.xmlGetNode('scalar', label = str(scalar))
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -247,6 +256,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getThermalFormula(self, zone, scalar):
         """
         Public method.
@@ -254,7 +264,7 @@ omega = k^0.5/almax;"""
         """
         self.__verifyZone(zone)
         self.isInList(scalar, ['TempC', 'TempK', 'Enthalpy'])
-        node = self.node_userscalar.xmlGetNode('scalar', label = str(scalar))
+        node = self.node_scalartherm.xmlGetNode('scalar', label = str(scalar))
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -263,6 +273,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.noUndo
     def getDensityStatus(self, zone):
         """
         Return status of Density for the initialisation
@@ -276,6 +287,7 @@ omega = k^0.5/almax;"""
         return status
 
 
+    @Variables.undoLocal
     def setDensityStatus(self, zone, status):
         """
         Put status of Density for the initialisation
@@ -286,6 +298,7 @@ omega = k^0.5/almax;"""
         n['status'] = status
 
 
+    @Variables.noUndo
     def getTemperatureStatus(self, zone):
         """
         Return status of Temperature for the initialisation
@@ -299,6 +312,7 @@ omega = k^0.5/almax;"""
         return status
 
 
+    @Variables.undoLocal
     def setTemperatureStatus(self, zone, status):
         """
         Put status of Temperature for the initialisation
@@ -309,6 +323,7 @@ omega = k^0.5/almax;"""
         n['status'] = status
 
 
+    @Variables.noUndo
     def getEnergyStatus(self, zone):
         """
         Return status of total energy for the initialisation
@@ -322,6 +337,7 @@ omega = k^0.5/almax;"""
         return status
 
 
+    @Variables.undoLocal
     def setEnergyStatus(self, zone, status):
         """
         Put status of Energy for the initialisation
@@ -332,6 +348,7 @@ omega = k^0.5/almax;"""
         n['status'] = status
 
 
+    @Variables.noUndo
     def getPressureStatus(self, zone):
         """
         Return status of pressure for the initialisation
@@ -345,6 +362,7 @@ omega = k^0.5/almax;"""
         return status
 
 
+    @Variables.undoLocal
     def setPressureStatus(self, zone, status):
         """
         Put status of pressure for the initialisation
@@ -355,6 +373,7 @@ omega = k^0.5/almax;"""
         n['status'] = status
 
 
+    @Variables.undoLocal
     def setPressureFormula(self, zone, formula):
         """
         Public method.
@@ -370,6 +389,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getPressureFormula(self, zone):
         """
         Public method.
@@ -386,6 +406,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.undoLocal
     def setDensityFormula(self, zone, formula):
         """
         Public method.
@@ -400,6 +421,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getDensityFormula(self, zone):
         """
         Public method.
@@ -415,6 +437,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.undoLocal
     def setTemperatureFormula(self, zone, formula):
         """
         Public method.
@@ -431,6 +454,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getTemperatureFormula(self, zone):
         """
         Public method.
@@ -448,8 +472,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
-
-
+    @Variables.undoLocal
     def setEnergyFormula(self, zone, formula):
         """
         Public method.
@@ -464,6 +487,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getEnergyFormula(self, zone):
         """
         Public method.
@@ -479,6 +503,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.noUndo
     def getCheckedBoxList(self,zone):
         """
         Public method.
@@ -500,6 +525,7 @@ omega = k^0.5/almax;"""
         return box_list
 
 
+    @Variables.undoLocal
     def setSpeciesFormula(self, zone, species, formula):
         """
         Public method.
@@ -515,6 +541,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getSpeciesFormula(self, zone, species):
         """
         Public method.
@@ -535,6 +562,7 @@ omega = k^0.5/almax;"""
         return formula
 
 
+    @Variables.undoLocal
     def setMeteoFormula(self, zone, scalar, formula):
         """
         Public method.
@@ -551,6 +579,7 @@ omega = k^0.5/almax;"""
         n.xmlSetTextNode(formula)
 
 
+    @Variables.noUndo
     def getMeteoFormula(self, zone, scalar):
         """
         Public method.
