@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -55,6 +55,7 @@ from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 from Pages.LocalizationModel import VolumicLocalizationModel, LocalizationModel
 from Pages.InitializationModel import InitializationModel
 from Pages.CompressibleModel import CompressibleModel
+from Pages.ElectricalModel import ElectricalModel
 from Pages.QMeiEditorView import QMeiEditorView
 
 #-------------------------------------------------------------------------------
@@ -83,12 +84,14 @@ class InitializationView(QWidget, Ui_InitializationForm):
 
         self.case = case
         self.parent = parent
+        self.case.undoStopGlobal()
 
         self.init    = InitializationModel(self.case)
         self.turb    = TurbulenceModel(self.case)
         self.therm   = ThermalScalarModel(self.case)
         self.th_sca  = DefineUserScalarsModel(self.case)
         self.comp    = CompressibleModel(self.case)
+        self.elec    = ElectricalModel(self.case)
         self.volzone = LocalizationModel('VolumicZone', self.case)
 
         # create group to control hide/show options
@@ -168,7 +171,7 @@ class InitializationView(QWidget, Ui_InitializationForm):
             for item in self.species_group:
                 item.show()
             for scalar in scalar_list:
-                self.modelSpecies.addItem(self.tr(scalar),self.scalar)
+                self.modelSpecies.addItem(self.tr(scalar), scalar)
             self.modelSpecies.setItem(str_model = self.scalar)
             setGreenColor(self.pushButtonSpecies, True)
         else:
@@ -194,6 +197,8 @@ class InitializationView(QWidget, Ui_InitializationForm):
         # Initialize widget
         self.initializeVariables(self.zone)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("const QString&")
     def slotZone(self, text):
@@ -251,10 +256,12 @@ class InitializationView(QWidget, Ui_InitializationForm):
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')] #quel symbol
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotFormulaVelocity -> %s" % str(result))
@@ -288,10 +295,12 @@ eps = k^1.5*cmu/almax;
                    ('z','cell center coordinate'),
                    ('uref','reference velocity'),
                    ('almax','reference length')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -329,10 +338,12 @@ eps = k^1.5*cmu/almax;"""
                    ('z','cell center coordinate'),
                    ('uref','reference velocity'),
                    ('almax','reference length')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -372,17 +383,19 @@ alpha = 1.;"""
                    ('z','cell center coordinate'),
                    ('uref','reference velocity'),
                    ('almax','reference length')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
                 self.init.setTurbFormula(self.zone, result)
                 setGreenColor(self.sender(), False)
 
-        elif turb_model == 'v2f-phi':
+        elif turb_model == 'v2f-BL-v2/k':
             exp = self.init.getTurbFormula(self.zone, turb_model)
             exa = """#example
 
@@ -391,12 +404,12 @@ k = 1.5*(0.02*uref)^2;
 eps = k^1.5*cmu/almax;
 
 phi = 2./3.;
-fb = 0.;
+al = 0.;
 """
             req = [('k', "turbulent energy"),
             ('eps', "turbulent dissipation"),
             ('phi', "variable phi in v2f model"),
-            ('fb', "variable f in v2f model")]
+            ('alpha', "variable alpha in v2f model")]
             sym = [('rho0', 'density (reference value)'),
                    ('mu0', 'viscosity (reference value)'),
                    ('cp0', 'specific heat (reference value)'),
@@ -406,10 +419,12 @@ fb = 0.;
                    ('z','cell center coordinate'),
                    ('uref','reference velocity'),
                    ('almax','reference length')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -432,10 +447,12 @@ omega = k^0.5/almax;"""
                    ('z','cell center coordinate'),
                    ('uref','reference velocity'),
                    ('almax','reference length')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -456,10 +473,12 @@ nusa = (cmu * k)/eps;;"""
                    ('z','cell center coordinate'),
                    ('uref','reference velocity'),
                    ('almax','reference length')]
-            dialog = QMeiEditorView(self,expression = exp,
-                                     required   = req,
-                                     symbols    = sym,
-                                     examples   = exa)
+            dialog = QMeiEditorView(self,
+                                    check_syntax = self.case['package'].get_check_syntax(),
+                                    expression = exp,
+                                    required   = req,
+                                    symbols    = sym,
+                                    examples   = exa)
             if dialog.exec_():
                 result = dialog.get_result()
                 log.debug("slotFormulaTurb -> %s" % str(result))
@@ -480,10 +499,12 @@ nusa = (cmu * k)/eps;;"""
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotFormulaThermal -> %s" % str(result))
@@ -504,10 +525,12 @@ nusa = (cmu * k)/eps;;"""
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotFormulaSpecies -> %s" % str(result))
@@ -527,10 +550,12 @@ nusa = (cmu * k)/eps;;"""
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotFormulaMeteo -> %s" % str(result))
@@ -679,10 +704,12 @@ nusa = (cmu * k)/eps;;"""
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotPressureFormula -> %s" % str(result))
@@ -704,10 +731,12 @@ nusa = (cmu * k)/eps;;"""
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotDensityFormula -> %s" % str(result))
@@ -729,10 +758,12 @@ nusa = (cmu * k)/eps;;"""
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotTemperatureFormula -> %s" % str(result))
@@ -754,10 +785,12 @@ nusa = (cmu * k)/eps;;"""
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
-        dialog = QMeiEditorView(self,expression = exp,
-                                 required   = req,
-                                 symbols    = sym,
-                                 examples   = exa)
+        dialog = QMeiEditorView(self,
+                                check_syntax = self.case['package'].get_check_syntax(),
+                                expression = exp,
+                                required   = req,
+                                symbols    = sym,
+                                examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotEnergyFormula -> %s" % str(result))
@@ -778,7 +811,7 @@ nusa = (cmu * k)/eps;;"""
                               'Rij-epsilon',
                               'Rij-SSG',
                               'Rij-EBRSM',
-                              'v2f-phi',
+                              'v2f-BL-v2/k',
                               'k-omega-SST',
                               'Spalart-Allmaras'):
             for item in self.turb_group:
@@ -809,14 +842,17 @@ nusa = (cmu * k)/eps;;"""
         setGreenColor(self.pushButtonVelocity, True)
 
         # Initialisation of Model Variables if thermal model is selectionned
-        model = self.therm.getThermalScalarModel()
+        for item in self.thermal_group:
+            item.hide()
 
-        if model == "off":
-            for item in self.thermal_group:
-                item.hide()
-        else:
+        model = self.therm.getThermalScalarModel()
+        modelElec = self.elec.getElectricalModel()
+
+        if model != "off" or modelElec != "off":
             for item in self.thermal_group:
                 item.show()
+            if modelElec != "off":
+                self.th_sca_label = 'Enthalpy'
             th_formula = self.init.getThermalFormula(zone, self.th_sca_label)
             if not th_formula:
                 th_formula = self.th_sca_label+""" = 0;\n"""
