@@ -120,7 +120,7 @@ class LagrangianBoundariesModel(Model):
         elif nature == "outlet":
             self.isInList(value, ["outlet"])
         elif nature == "symmetry":
-            self.isInList(value, ["bounce"])
+            self.isInList(value, ["part_symmetry"])
         elif nature == "wall":
             l = [ "inlet", "bounce", "deposit1", "deposit2"]
             #if iscoal: l.append("encra")
@@ -137,7 +137,7 @@ class LagrangianBoundariesModel(Model):
         Return value for the boundary condition.
         """
         default = { "wall" : "deposit1", "inlet" : "inlet",
-                    "outlet" : "outlet", "symmetry" : "bounce"}
+                    "outlet" : "outlet", "symmetry" : "part_symmetry"}
         self.setCurrentBoundaryNode(nature, labelbc)
         if self.node_particles:
             val = self.node_particles['choice']
