@@ -44,6 +44,7 @@ from Base.Common import *
 import Base.Toolbox as Tool
 from Base.XMLvariables import Model, Variables
 from Base.XMLmodel import ModelTest
+from Pages.CoalCombustionModel import CoalCombustionModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -84,6 +85,7 @@ class LagrangianModel(Model):
         default['carrier_field_stationary']            = "off"
         default['particles_max_number']                = 1000000
         default['continuous_injection']                = "off"
+        default['deposition_submodel']                 = "off"
         default['particles_models']                    = "off"
         default['thermal']                             = "off"
         default['evaporation']                         = "off"
@@ -146,7 +148,13 @@ class LagrangianModel(Model):
         Update the lagrangian module status markup.
         """
         self.isOnOff(status)
+        old_status = self.node_lagr['model']
         self.node_lagr['model'] = status
+        from Pages.OutputControlModel import OutputControlModel
+        if status != 'off':
+            OutputControlModel(self.case).addDefaultLagrangianWriter()
+            OutputControlModel(self.case).addDefaultLagrangianMesh()
+        del OutputControlModel
 
 
     @Variables.noUndo
@@ -282,6 +290,29 @@ class LagrangianModel(Model):
         return status
 
 
+    @Variables.undoLocal
+    def setDepositionSubmodel(self, status):
+        """
+        Update the status for the particle deposition submodel.
+        """
+        self.isOnOff(status)
+        node_deposition = self.node_lagr.xmlInitChildNode('deposition_submodel', 'status')
+        node_deposition['status'] = status
+
+
+    @Variables.noUndo
+    def getDepositionSubmodel(self):
+        """
+        Return status for the particle deposition submodel.
+        """
+        node_deposition = self.node_lagr.xmlInitChildNode('deposition_submodel', 'status')
+        status = node_deposition['status']
+        if not status:
+            status = self.defaultParticlesValues()['deposition_submodel']
+            self.setDepositionSubmodel(status)
+        return status
+
+
     @Variables.undoGlobal
     def setParticlesModel(self, model):
         """
@@ -869,6 +900,22 @@ class LagrangianTestCase(ModelTest):
         assert mdl.node_lagr == self.xmlNodeFromString(doc), \
             'Could not set values for continuous injection status'
 
+    def checkDepositionSubmodel(self):
+        """Check whether the particle deposition model could be set and get."""
+        mdl = LagrangianModel(self.case)
+        status = mdl.getDepositionSubmodel()
+
+        assert status == mdl.defaultParticlesValues()['deposition_submodel'], \
+            'Could not get default values for particle deposition model status'
+
+        mdl.setDepositionSubmodel('on')
+        doc = """<lagrangian model="off">
+                      <deposition_submodel status="on"/>
+                 </lagrangian>"""
+
+        assert mdl.node_lagr == self.xmlNodeFromString(doc), \
+            'Could not set values for particle deposition model status'
+
 
     def checkParticlesModel(self):
         """Check whether the particles models could be set and get."""
