@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -292,6 +292,7 @@ class LagrangianStatisticsView(QWidget, Ui_LagrangianStatisticsForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
         self.model = LagrangianStatisticsModel(self.case)
 
         self.connect(self.checkBoxISUIST, SIGNAL("clicked()"), self.slotISUIST)
@@ -359,6 +360,8 @@ class LagrangianStatisticsView(QWidget, Ui_LagrangianStatisticsForm):
             self.groupBoxIENSI3.setChecked(False)
         self.slotIENSI3()
 
+        self.case.undoStartGlobal()
+
 
     def _initVolumicNames(self):
         """
