@@ -374,7 +374,7 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
         self.modelIPHYLA = ComboModel(self.comboBoxIPHYLA,2,1)
         self.modelIPHYLA.addItem(self.tr("No model"), 'off')
         self.modelIPHYLA.addItem(self.tr("Heat transfer and evaporation"), 'thermal')
-        # self.modelIPHYLA.addItem(self.tr("Pulverised coal model"), 'coal')
+        self.modelIPHYLA.addItem(self.tr("Pulverised coal model"), 'coal')
 
         # Connections
         self.connect(self.comboBoxIILAGR, SIGNAL("activated(const QString&)"), self.slotIILAGR)
@@ -382,6 +382,7 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
         self.connect(self.checkBoxISTTIO, SIGNAL("clicked()"), self.slotISTTIO)
         self.connect(self.lineEditNBPMAX, SIGNAL("textChanged(const QString &)"), self.slotNBPMAX)
         self.connect(self.checkBoxINJCON, SIGNAL("clicked()"), self.slotINJCON)
+        self.connect(self.checkBoxIDEPST, SIGNAL("clicked()"), self.slotIDEPST)
         self.connect(self.comboBoxIPHYLA, SIGNAL("activated(const QString&)"), self.slotIPHYLA)
         self.connect(self.checkBoxITPVAR, SIGNAL("clicked()"), self.slotITPVAR)
         #self.connect(self.lineEditTPPART, SIGNAL("textChanged(const QString &)"), self.slotTPPART)
@@ -445,6 +446,12 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
         else:
             self.checkBoxINJCON.setChecked(False)
 
+        status = self.model.getDepositionSubmodel()
+        if status == "on":
+            self.checkBoxIDEPST.setChecked(True)
+        else:
+            self.checkBoxIDEPST.setChecked(False)
+
         if ( model == "frozen" ):
             self.labelISTTIO.setDisabled(True)
             self.checkBoxISTTIO.setChecked(True)
@@ -547,6 +554,17 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
             self.model.setContinuousInjection("off")
 
 
+    @pyqtSignature("")
+    def slotIDEPST(self):
+        """
+        Input IDEPST.
+        """
+        if self.checkBoxIDEPST.isChecked():
+            self.model.setDepositionSubmodel("on")
+        else:
+            self.model.setDepositionSubmodel("off")
+
+
     @pyqtSignature("const QString&")
     def slotNBPMAX(self, text):
         """
