@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -175,13 +175,13 @@ class BoundaryNatureDelegate(QItemDelegate):
         self.dicoM2V = dicoM2V
 
         self.dicoV2M = {}
-        for k, v in self.dicoM2V.items():
+        for k, v in list(self.dicoM2V.items()):
             self.dicoV2M[v] = k
 
 
     def createEditor(self, parent, option, index):
         editor = QComboBox(parent)
-        for k in self.dicoV2M.keys():
+        for k in list(self.dicoV2M.keys()):
             editor.addItem(k)
         editor.installEventFilter(self)
         #editor.setSizeAdjustPolicy(QComboBox.AdjustToContents)
@@ -193,7 +193,7 @@ class BoundaryNatureDelegate(QItemDelegate):
         row = index.row()
         col = index.column()
         str_model = index.model().getData(row, col)
-        idx = self.dicoM2V.keys().index(str_model)
+        idx = list(self.dicoM2V.keys()).index(str_model)
         #str_view  = self.dicoM2V[str_model]
         #comboBox.setItem(str_view)
         comboBox.setCurrentIndex(idx)
@@ -303,7 +303,7 @@ class StandardItemVolumeNature(QStandardItemModel):
 
     def getChecked(self):
         s = []
-        for k, v in self.dicoNature.items():
+        for k, v in list(self.dicoNature.items()):
             if v == "on":
                 s.append(k)
         return string.join(s, ";")
@@ -453,7 +453,7 @@ class StandardItemModelLocalization(QStandardItemModel):
             elif col == 2:
                 if self.zoneType == "VolumicZone":
                     data = self._data[row][col]
-                    item = string.join([self.dicoM2V[key] for key in self.dicoM2V.keys() if data[key] == "on"], "\n")
+                    item = string.join([self.dicoM2V[key] for key in list(self.dicoM2V.keys()) if data[key] == "on"], "\n")
 #                    item = ""
 #                    for key in dico.keys():
 #                        print(key)
@@ -513,9 +513,9 @@ class StandardItemModelLocalization(QStandardItemModel):
             if self.zoneType == "VolumicZone":
 
                 # We modify the dictionary here
-                nature_list = string.split(str(value.toString()), ";")
+                nature_list = str(value.toString()).split(";")
 
-                for key in self._data[row][col].keys():
+                for key in list(self._data[row][col].keys()):
                     if key in nature_list:
                         self._data[row][col][key] = "on"
                     else:
@@ -566,7 +566,8 @@ class StandardItemModelLocalization(QStandardItemModel):
             if zone.getLabel() == "all_cells":
                 for c in range(self.columnCount()):
                     self._disable.append((row, c))
-            self._disable.append((row, 1))
+        self._disable.append((row, 1))
+        self.browser.configureTree(self.case)
 
 
     def getItem(self, row):
@@ -575,8 +576,8 @@ class StandardItemModelLocalization(QStandardItemModel):
 
     def updateItem(self):
         # update zone Id
-        for id in self.mdl.getCodeNumbersList():
-            self._data[int(id)-1][1] = id
+        for id in range(0, len(self.mdl.getCodeNumbersList())):
+            self._data[id][1] = id + 1
 
 
     def deleteItem(self, irow):
@@ -586,6 +587,12 @@ class StandardItemModelLocalization(QStandardItemModel):
         self.updateItem()
 
 
+    def deleteItems(self):
+        for row in range(self.rowCount()):
+            del self._data[0]
+        self.setRowCount(0)
+
+
     def getData(self, row, column):
         return self._data[row][column]
 
@@ -606,6 +613,9 @@ class LocalizationView(QWidget, Ui_LocalizationForm):
         Ui_LocalizationForm.__init__(self)
         self.setupUi(self)
 
+        self.case = case
+        self.case.undoStopGlobal()
+
         self.zoneType = zoneType
         self.mdl = LocalizationModel(zoneType, case)
         self.browser = tree
@@ -647,6 +657,8 @@ class LocalizationView(QWidget, Ui_LocalizationForm):
         self.tableView.setContextMenuPolicy(Qt.CustomContextMenu)
         self.connect(self.tableView, SIGNAL("customContextMenuRequested(QPoint)"), self.slotContextMenu)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("")
     def slotAddZone(self):
@@ -662,15 +674,15 @@ class LocalizationView(QWidget, Ui_LocalizationForm):
         Private Slot.
         Warning: the Volume region 'all_cells' is mandatory, therefore it can not be deleted.
         """
-        list = []
+        lst = []
         for index in self.tableView.selectionModel().selectedRows():
             row = index.row()
-            list.append(row)
+            lst.append(row)
 
-        list.sort()
-        list.reverse()
+        lst.sort()
+        lst.reverse()
 
-        for row in list:
+        for row in lst:
             [label, codeNumber, nature, localization] = self.modelLocalization.getItem(row)
             if not (label == "all_cells" and self.zoneType == 'VolumicZone'):
                 self.mdl.deleteZone(label)
@@ -738,30 +750,27 @@ class LocalizationView(QWidget, Ui_LocalizationForm):
         """
         public slot
         """
-        list = []
+        lst = []
         for index in self.tableView.selectionModel().selectedRows():
-            list.append(index.row())
+            lst.append(index.row())
 
-        row = list.pop(0)
+        row = lst.pop(0)
         [label, code, nature, new_localization] = self.modelLocalization.getItem(row)
+        ll = label
 
-        new_zone = Zone(self.zoneType,
-                        label        = label,
-                        codeNumber   = code,
-                        localization = new_localization,
-                        nature       = nature)
-
-        for row in list:
+        for row in lst:
             [label, code, nature, localization] = self.modelLocalization.getItem(row)
-            if "all[]" not in string.split(new_localization, " "):
+            if "all[]" not in new_localization.split(" "):
                 new_localization += " or " + localization
             if localization == "all[]":
                 new_localization = "all[]"
 
-        new_zone.setLocalization(new_localization)
-        self.slotDeleteZone()
-        self.mdl.addZone(new_zone)
-        self.modelLocalization.addItem(new_zone)
+        self.modelLocalization.deleteItems()
+        self.mdl.mergeZones(ll, new_localization, lst)
+
+        # Populate QTableView model
+        for zone in self.mdl.getZones():
+            self.modelLocalization.addItem(zone)
 
 
     @pyqtSignature("")
