@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -102,7 +102,7 @@ class NumericalParamEquatModel(Model):
         self.default['flux_reconstruction'] = 'on'
 
         self.default['solver_choice_pressure'] = 'multigrid'
-        self.default['solver_choice'] = 'jacobi'
+        self.default['solver_choice'] = 'automatic'
 
         if label not in self.var:
             self.default['order_scheme'] = 'upwind'
@@ -110,6 +110,11 @@ class NumericalParamEquatModel(Model):
         else:
             self.default['order_scheme'] = 'centered'
             self.default['blending_factor'] = 1.
+        from Pages.CompressibleModel import CompressibleModel
+        if CompressibleModel(self.case).getCompressibleModel() != 'off':
+            self.default['order_scheme'] = 'upwind'
+            self.default['blending_factor'] = 0.
+        del CompressibleModel
 
         if TurbulenceModel(self.case).getTurbulenceModel() in \
             ('LES_Smagorinsky', 'LES_dynamique', 'LES_WALE'):
@@ -138,8 +143,8 @@ class NumericalParamEquatModel(Model):
                         self.default['min_value'] = 0
                         self.default['max_value'] = 1e+12
         else:
-            self.default['min_value'] = 0
-            self.default['max_value'] = 1
+            self.default['min_value'] = -1e+12
+            self.default['max_value'] = 1e+12
 
         return self.default
 
@@ -182,6 +187,28 @@ class NumericalParamEquatModel(Model):
         return nodList
 
 
+    def _getElectricalScalarsNodes(self):
+        """ Private method: return list of electric scalar's nodes """
+        nodList = []
+        node = self.node_models.xmlGetNode('joule_effect', 'model')
+        if not node: return []
+        model = node['model']
+        if model != 'off':
+            nodList = node.xmlGetNodeList('scalar')
+        return nodList
+
+
+    def _getCompressibleScalarsNodes(self):
+        """ Private method: return list of compressible scalar's nodes """
+        nodList = []
+        node = self.node_models.xmlGetNode('compressible_model', 'model')
+        if not node: return []
+        model = node['model']
+        if model != 'off':
+            nodList = node.xmlGetNodeList('scalar')
+        return nodList
+
+
     def _getAdditionalScalarNodes(self):
         """ Private method: return list of additional scalar's nodes """
         n = self.case.xmlGetNode('additional_scalars')
@@ -205,6 +232,8 @@ class NumericalParamEquatModel(Model):
                      self._getPuCoalScalarsNodes(),
                      self._getGasScalarsNodes(),
                      self._getMeteoScalarsNodes(),
+                     self._getElectricalScalarsNodes(),
+                     self._getCompressibleScalarsNodes(),
                      self._getAdditionalScalarNodes()):
             self.var_clip.append(part)
         return self.var_clip
@@ -220,6 +249,8 @@ class NumericalParamEquatModel(Model):
                      self._getPuCoalScalarsNodes(),
                      self._getGasScalarsNodes(),
                      self._getMeteoScalarsNodes(),
+                     self._getElectricalScalarsNodes(),
+                     self._getCompressibleScalarsNodes(),
                      self._getAdditionalScalarNodes()):
             self.var_shem.append(part)
         return self.var_shem
@@ -234,7 +265,9 @@ class NumericalParamEquatModel(Model):
                      self._getPuCoalScalarsNodes(),
                      self._getGasScalarsNodes(),
                      self._getMeteoScalarsNodes(),
+                     self._getElectricalScalarsNodes(),
                      self._getAdditionalScalarNodes(),
+                     self._getCompressibleScalarsNodes(),
                      self._getAleVariablesNodes()):
             self.var_solv.append(part)
         return self.var_solv
@@ -254,10 +287,7 @@ class NumericalParamEquatModel(Model):
         for node in self._getSchemeNodesList():
             for n in node:
                 if n['label'] == label:
-                    if n['name'] == 'pressure':
-                        raise ValueError("This method does not run with pressure")
-                    else:
-                        return n
+                    return n
         raise ValueError("This label does not exist: " + label)
 
 
@@ -277,7 +307,7 @@ class NumericalParamEquatModel(Model):
         else:
             return 0
 
-
+    @Variables.undoGlobal
     def setSchemeDefaultValues(self):
         """Usefull for TurbulenceModel in case of LES"""
         for label in self.var:
@@ -291,6 +321,7 @@ class NumericalParamEquatModel(Model):
                 pass
 
 
+    @Variables.noUndo
     def getClippingList(self):
         """ Return the variables label list for clipping parameters """
         list = []
@@ -301,22 +332,32 @@ class NumericalParamEquatModel(Model):
         return list
 
 
+    @Variables.noUndo
     def getSchemeList(self):
         """ Return the variables label list for scheme parameters """
         list = []
         for node in self._getSchemeNodesList():
             for n in node:
-                if not self._isPressure(n):
-                    list.append(n['label'])
+                list.append(n['label'])
         return list
 
 
+    @Variables.noUndo
     def getSolverList(self):
         """ Return the variables label list for solver parameters """
         list = []
+        from Pages.CompressibleModel import CompressibleModel
+        comp_model = CompressibleModel(self.case).getCompressibleModel()
+        del CompressibleModel
+
         for node in self._getSolverNodesList():
             for n in node:
-                list.append(n['label'])
+                if self._isPressure(n):
+                    if comp_model == 'off':
+                        list.append(n['label'])
+                else:
+                    list.append(n['label'])
+
         return list
 
 
@@ -335,9 +376,12 @@ class NumericalParamEquatModel(Model):
 
 # Following methods for dependances of scheme:
 
+    @Variables.noUndo
     def getScheme(self, label):
         """ Return value of order scheme for variable labelled label """
         node = self._getSchemeLabelNode(label)
+        if self._isPressure(node):
+            return None
         value = self._defaultValues(label)['order_scheme']
         n = node.xmlGetNode('order_scheme')
         if n:
@@ -345,18 +389,24 @@ class NumericalParamEquatModel(Model):
         return value
 
 
+    @Variables.noUndo
     def getBlendingFactor(self, label):
         """ Return value of blending factor for variable labelled label """
         node = self._getSchemeLabelNode(label)
+        if self._isPressure(node):
+            return None
         value = node.xmlGetDouble('blending_factor')
         if value == None:
             value = self._defaultValues(label)['blending_factor']
         return value
 
 
+    @Variables.noUndo
     def getSlopeTest(self, label):
         """ Return value of slope test for variable labelled label """
         node = self._getSchemeLabelNode(label)
+        if self._isPressure(node):
+            return None
         value = self._defaultValues(label)['slope_test']
         n = node.xmlGetNode('slope_test')
         if n:
@@ -364,32 +414,42 @@ class NumericalParamEquatModel(Model):
         return value
 
 
+    @Variables.noUndo
     def getFluxReconstruction(self, label):
         """ Return value of flux reconstruction for variable labelled label """
         node = self._getSchemeLabelNode(label)
+        if self._isPressure(node):
+            return None
         value = self._defaultValues()['flux_reconstruction']
         if node.xmlGetNode('flux_reconstruction'):
             value = node.xmlGetNode('flux_reconstruction')['status']
         return value
 
 
+    @Variables.noUndo
     def getRhsReconstruction(self, label):
         """ Return value of blending factor for variable labelled label """
         node = self._getSchemeLabelNode(label)
         value = node.xmlGetDouble('rhs_reconstruction')
         if value == None:
-            value = self._defaultValues(label)['rhs_reconstruction']
+            if self._isPressure(node): # temporary fix for probable mix between label and name
+                value = self._defaultValues('Pressure')['rhs_reconstruction']
+            else:
+                value = self._defaultValues(label)['rhs_reconstruction']
         return value
 
 
+    @Variables.undoGlobal
     def setBlendingFactor(self, label, value):
         """
         Put value of blending factor for variable labelled label
         only if it 's different of default value
         """
+        node = self._getSchemeLabelNode(label)
+        if self._isPressure(node):
+            return
         self.isGreaterOrEqual(value, 0.)
         self.isLowerOrEqual(value, 1.)
-        node = self._getSchemeLabelNode(label)
         scheme = self.getScheme(label)
         if scheme == self._defaultValues(label)['order_scheme']:
             if scheme == 'upwind':
@@ -404,6 +464,7 @@ class NumericalParamEquatModel(Model):
 #                node.xmlRemoveChild('blending_factor')
 
 
+    @Variables.undoGlobal
     def setScheme(self, label, value):
         """
         Put value of order scheme for variable or scalar labelled label
@@ -422,6 +483,7 @@ class NumericalParamEquatModel(Model):
             n['choice'] = value
 
 
+    @Variables.undoLocal
     def setSlopeTest(self, label, status):
         """ Put status of slope test for variable labelled label """
         self.isOnOff(status)
@@ -433,6 +495,7 @@ class NumericalParamEquatModel(Model):
             n['status'] = status
 
 
+    @Variables.undoLocal
     def setFluxReconstruction(self, label, value):
         """ Put status of flux reconstruction for variable labelled label """
         self.isOnOff(value)
@@ -444,6 +507,7 @@ class NumericalParamEquatModel(Model):
             n['status']=value
 
 
+    @Variables.undoLocal
     def setRhsReconstruction(self, label, value):
         """
         Put value of blending factor for variable labelled label
@@ -456,6 +520,7 @@ class NumericalParamEquatModel(Model):
 
 # Following methods for dependances of solver:
 
+    @Variables.undoLocal
     def setMaxIterNumber(self, label, value):
         """ Put number of maximum iterations for variable labelled label """
         self.isInt(value)
@@ -466,6 +531,7 @@ class NumericalParamEquatModel(Model):
             node.xmlRemoveChild('max_iter_number')
 
 
+    @Variables.undoLocal
     def setSolverPrecision(self, label, value):
         """ Put value of solver precision for variable labelled label """
         # for pressure default value always equal to 1e-8
@@ -482,9 +548,10 @@ class NumericalParamEquatModel(Model):
             node.xmlRemoveChild('solver_precision')
 
 
+    @Variables.undoLocal
     def setSolverChoice(self, label, value):
         """ Put choice of solver for variable labelled label """
-        self.isInList(value, ('multigrid', 'conjugate_gradient', 'jacobi', 'bi_cgstab', 'gmres'))
+        self.isInList(value, ('multigrid', 'conjugate_gradient', 'jacobi', 'bi_cgstab', 'gmres', 'automatic'))
         node = self._getSolverLabelNode(label)
         if self._isPressure(node):
             default = self._defaultValues()['solver_choice_pressure']
@@ -498,6 +565,7 @@ class NumericalParamEquatModel(Model):
             node.xmlRemoveChild('solver_choice')
 
 
+    @Variables.noUndo
     def getMaxIterNumber(self, label):
         """ Return number of maximum iterations for variable labelled label """
         node = self._getSolverLabelNode(label)
@@ -507,6 +575,7 @@ class NumericalParamEquatModel(Model):
         return value
 
 
+    @Variables.noUndo
     def getSolverPrecision(self, label):
         """ Return value of solver precision for variable labelled label """
         node = self._getSolverLabelNode(label)
@@ -522,6 +591,7 @@ class NumericalParamEquatModel(Model):
         return value
 
 
+    @Variables.noUndo
     def getSolverChoice(self, label):
         """ Return choice of solver for variable labelled label """
         node = self._getSolverLabelNode(label)
@@ -538,6 +608,7 @@ class NumericalParamEquatModel(Model):
         return value
 
 
+    @Variables.noUndo
     def getScalarTimeStepFactor(self, label):
         """ Return value of time_step_factor for variable labelled label """
         if self.isScalar(label):
@@ -550,6 +621,7 @@ class NumericalParamEquatModel(Model):
             raise ValueError("This method runs only with scalar label")
 
 
+    @Variables.undoLocal
     def setScalarTimeStepFactor(self, label, value):
         """ Put value of time_step_factor for variable labelled label """
         self.isStrictPositiveFloat(value)
@@ -563,6 +635,7 @@ class NumericalParamEquatModel(Model):
             raise ValueError("This method runs only with scalar label")
 
 
+    @Variables.noUndo
     def getMinValue(self, label):
         """Get minimal value from an additional_scalar with label scalar_label"""
         self.isInList(label, self.getClippingList())
@@ -575,6 +648,7 @@ class NumericalParamEquatModel(Model):
         return min_val
 
 
+    @Variables.undoLocal
     def setMinValue(self, label, min_value):
         """
         Put minimal value for an additional_scalar with label scalar_label.
@@ -586,6 +660,7 @@ class NumericalParamEquatModel(Model):
         node.xmlSetData('min_value', min_value)
 
 
+    @Variables.noUndo
     def getMaxValue(self, label):
         """Get maximal value from an additional_scalar with label scalar_label"""
         self.isInList(label, self.getClippingList())
@@ -597,6 +672,7 @@ class NumericalParamEquatModel(Model):
         return max_val
 
 
+    @Variables.undoLocal
     def setMaxValue(self, label, max_value):
         """
         Put maximal value for an additional_scalar with label scalar_label.
@@ -640,7 +716,6 @@ class NumericalParamEquatTestCase(ModelTest):
                         <property label="total_pressure" name="total_pressure"/>
                         <property label="Yplus" name="yplus" support="boundary"/>
                         <property label="Efforts" name="effort" support="boundary"/>
-                        <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set scheme in NumericalParamEquationModel'
@@ -664,7 +739,6 @@ class NumericalParamEquatTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set blending factor in NumericalParamEquationModel'
@@ -687,7 +761,6 @@ class NumericalParamEquatTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set status of slope test in NumericalParamEquationModel'
@@ -710,7 +783,6 @@ class NumericalParamEquatTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set status of flux reconstruction in NumericalParamEquationModel'
@@ -728,7 +800,6 @@ class NumericalParamEquatTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                   </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc2),\
                 'Could not set status of flux reconstruction in NumericalParamEquationModel'
@@ -751,7 +822,6 @@ class NumericalParamEquatTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set max of number of iterations in NumericalParamEquationModel'
@@ -782,7 +852,6 @@ class NumericalParamEquatTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set solver precision in NumericalParamEquationModel'
@@ -811,7 +880,6 @@ class NumericalParamEquatTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>"""
         sca = """<additional_scalars>
                     <scalar label="TempC" name="temperature_celsius" type="thermal">
