@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -115,6 +115,7 @@ class SolverChoiceDelegate(QItemDelegate):
 
     def createEditor(self, parent, option, index):
         editor = QComboBox(parent)
+        editor.addItem(QString("Automatic"))
         editor.addItem(QString("Conjugate gradient"))
         editor.addItem(QString("Jacobi"))
         editor.addItem(QString("BI-CGSTAB"))
@@ -127,7 +128,7 @@ class SolverChoiceDelegate(QItemDelegate):
 
 
     def setEditorData(self, comboBox, index):
-        dico = {"conjugate_gradient": 0, "jacobi": 1, "bi_cgstab": 2, "gmres": 3, "multigrid":4}
+        dico = {"automatic": 0, "conjugate_gradient": 1, "jacobi": 2, "bi_cgstab": 3, "gmres": 4, "multigrid": 5}
         row = index.row()
         string = index.model().dataSolver[row]['iresol']
         idx = dico[string]
@@ -267,6 +268,7 @@ class StandardItemModelScheme(QStandardItemModel):
                         self.tr("Slope\nTest"),
                         self.tr("Flux\nReconstruction"),
                         self.tr("RHS Sweep\nReconstruction")]
+        self.keys = ['label', 'ischcv', 'blencv', 'isstpc', 'ircflu', 'nswrsm']
         self.setColumnCount(len(self.headers))
 
         # Initialize the flags
@@ -307,43 +309,31 @@ class StandardItemModelScheme(QStandardItemModel):
             return QVariant()
 
         row = index.row()
+        column = index.column()
         dico = self.dataScheme[row]
+        key = self.keys[column]
+
+        if dico[key] == None:
+            return QVariant()
 
         if role == Qt.ToolTipRole:
-            if index.column() == 1:
-                return QVariant(self.tr("Code_Saturne keyword: ISCHCV"))
-            elif index.column() == 2:
-                return QVariant(self.tr("Code_Saturne keyword: BLENCV"))
-            elif index.column() == 3:
-                return QVariant(self.tr("Code_Saturne keyword: ISSTPC"))
-            elif index.column() == 4:
-                return QVariant(self.tr("Code_Saturne keyword: IRCFLU"))
-            elif index.column() == 5:
-                return QVariant(self.tr("Code_Saturne keyword: NSWRSM"))
+            if index.column() > 0:
+                return QVariant(self.tr("Code_Saturne keyword: " + key.upper()))
 
-        elif role == Qt.DisplayRole:
-            if index.column() == 0:
-                return QVariant(dico['label'])
-            elif index.column() == 1:
-                return QVariant(self.dicoM2V[dico['ischcv']])
-            elif index.column() == 2:
-                return QVariant(dico['blencv'])
-            elif index.column() == 5:
-                return QVariant(dico['nswrsm'])
+        elif role == Qt.DisplayRole and not column in [3, 4]:
+            if key == 'ischcv':
+                return QVariant(self.dicoM2V[dico[key]])
             else:
-                return QVariant()
+                return QVariant(dico[key])
 
-        elif role == Qt.CheckStateRole:
-            if index.column() == 3:
-                if dico['isstpc'] == 'on':
-                    return QVariant(Qt.Checked)
-                else:
-                    return QVariant(Qt.Unchecked)
-            elif index.column() == 4:
-                if dico['ircflu'] == 'on':
-                    return QVariant(Qt.Checked)
-                else:
-                    return QVariant(Qt.Unchecked)
+        elif role == Qt.CheckStateRole and column in [3, 4]:
+            st = None
+            if key in ['isstpc', 'ircflu']:
+                st = dico[key]
+            if st == 'on':
+                return QVariant(Qt.Checked)
+            else:
+                return QVariant(Qt.Unchecked)
 
         elif role == Qt.TextAlignmentRole:
             return QVariant(Qt.AlignCenter)
@@ -353,11 +343,11 @@ class StandardItemModelScheme(QStandardItemModel):
 
     def flags(self, index):
         if not index.isValid():
-            return Qt.ItemIsEnabled
+            return Qt.NoItemFlags
 
         # disable item
         if (index.row(), index.column()) in self.disabledItem:
-            return Qt.ItemIsSelectable
+            return Qt.NoItemFlags
 
         if index.column() == 0:
             return Qt.ItemIsEnabled | Qt.ItemIsSelectable
@@ -377,12 +367,18 @@ class StandardItemModelScheme(QStandardItemModel):
 
     def setData(self, index, value, role=None):
         row = index.row()
+        column = index.column()
         label = self.dataScheme[row]['label']
 
-        # set ISCHCV
-        if index.column() == 1:
-            self.dataScheme[row]['ischcv'] = self.dicoV2M[str(value.toString())]
+        # for Pressure, most fields are empty
+        if column > 0 and str(value.toString()) in ['', 'None']:
+            if (row, column) not in self.disabledItem:
+                self.disabledItem.append((row, column))
+            return False
 
+        # set ISCHCV
+        if column == 1:
+            self.dataScheme[row]['ischcv'] = self.dicoV2M[str(value.toString())]
             if self.dataScheme[row]['ischcv'] == "upwind":
                 if (row, 2) not in self.disabledItem:
                     self.disabledItem.append((row, 2))
@@ -402,13 +398,13 @@ class StandardItemModelScheme(QStandardItemModel):
             self.NPE.setBlendingFactor(label, self.dataScheme[row]['blencv'])
 
         # set BLENCV
-        elif index.column() == 2:
+        elif column == 2:
             if self.dataScheme[row]['ischcv'] != "upwind":
                 self.dataScheme[row]['blencv'], ok = value.toDouble()
                 self.NPE.setBlendingFactor(label, self.dataScheme[row]['blencv'])
 
         # set ISSTPC
-        elif index.column() == 3:
+        elif column == 3:
             if self.dataScheme[row]['ischcv'] != "upwind":
                 v, ok = value.toInt()
                 if v == Qt.Unchecked:
@@ -418,7 +414,7 @@ class StandardItemModelScheme(QStandardItemModel):
                 self.NPE.setSlopeTest(label, self.dataScheme[row]['isstpc'])
 
         # set IRCFLU
-        elif index.column() == 4:
+        elif column == 4:
             v, ok = value.toInt()
             if v == Qt.Unchecked:
                 self.dataScheme[row]['ircflu'] = "off"
@@ -426,8 +422,8 @@ class StandardItemModelScheme(QStandardItemModel):
                 self.dataScheme[row]['ircflu'] = "on"
             self.NPE.setFluxReconstruction(label, self.dataScheme[row]['ircflu'])
 
-        # set BLENCV
-        elif index.column() == 5:
+        # set NSWRSM
+        elif column == 5:
             self.dataScheme[row]['nswrsm'], ok = value.toInt()
             self.NPE.setRhsReconstruction(label, self.dataScheme[row]['nswrsm'])
 
@@ -457,9 +453,11 @@ class StandardItemModelSolver(QStandardItemModel):
 
     def populateModel(self):
         self.dicoV2M= {"Multigrid": 'multigrid',"Conjugate gradient" : 'conjugate_gradient',
-                       "Jacobi": 'jacobi', "BI-CGSTAB": 'bi_cgstab', "GMRES": 'gmres'}
+                       "Jacobi": 'jacobi', "BI-CGSTAB": 'bi_cgstab', "GMRES": 'gmres',
+                       "Automatic": "automatic"}
         self.dicoM2V= {"multigrid" : 'Multigrid',"conjugate_gradient" : 'Conjugate gradient',
-                       "jacobi": 'Jacobi', "bi_cgstab": 'BI-CGSTAB', 'gmres': "GMRES"}
+                       "jacobi": 'Jacobi', "bi_cgstab": 'BI-CGSTAB', 'gmres': "GMRES",
+                       "automatic": "Automatic"}
         for label in self.NPE.getSolverList():
             row = self.rowCount()
             self.setRowCount(row + 1)
@@ -780,6 +778,7 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
         self.NPE = NumericalParamEquatModel(self.case)
         self.SM  = SteadyManagementModel(self.case)
         self.turb = TurbulenceModel(self.case)
@@ -844,6 +843,20 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         if len(self.NPE.getClippingList()) == 0:
             self.tab_clipping.setEnabled(False)
 
+        self.tabWidgetScheme.setCurrentIndex(self.case['current_tab'])
+
+        self.connect(self.tabWidgetScheme, SIGNAL("currentChanged(int)"), self.slotchanged)
+
+        self.case.undoStartGlobal()
+
+
+    @pyqtSignature("int")
+    def slotchanged(self, index):
+        """
+        Changed tab
+        """
+        self.case['current_tab'] = index
+
 
     def tr(self, text):
         """
