@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -49,7 +49,6 @@ from Pages.NumericalParamGlobalForm import Ui_NumericalParamGlobalForm
 import Base.QtPage as QtPage
 from Pages.NumericalParamGlobalModel import NumericalParamGlobalModel
 from Pages.SteadyManagementModel import SteadyManagementModel
-from Pages.CompressibleModel import CompressibleModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -77,6 +76,7 @@ class NumericalParamGlobalView(QWidget, Ui_NumericalParamGlobalForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
         self.model = NumericalParamGlobalModel(self.case)
         self.browser = tree
 
@@ -135,19 +135,9 @@ class NumericalParamGlobalView(QWidget, Ui_NumericalParamGlobalForm):
         else:
             self.checkBoxIPUCOU.setChecked(False)
 
-        status_compressible = CompressibleModel(self.case).getCompressibleModel()
-        if status_compressible != 'off':
-            self.labelICFGRP.show()
-            self.checkBoxICFGRP.show()
-            self.line_4.show()
-            if self.model.getHydrostaticEquilibrium() == 'on':
-                self.checkBoxICFGRP.setChecked(True)
-            else:
-                self.checkBoxICFGRP.setChecked(False)
-        else:
-            self.labelICFGRP.hide()
-            self.checkBoxICFGRP.hide()
-            self.line_4.hide()
+        import Pages.FluidCharacteristicsModel as FluidCharacteristics
+        fluid = FluidCharacteristics.FluidCharacteristicsModel(self.case)
+        modl_atmo, modl_joul, modl_thermo, modl_gas, modl_coal, modl_comp = fluid.getThermoPhysicalModel()
 
         if self.model.getHydrostaticPressure() == 'on':
             self.checkBoxImprovedPressure.setChecked(True)
@@ -158,9 +148,6 @@ class NumericalParamGlobalView(QWidget, Ui_NumericalParamGlobalForm):
         self.modelEXTRAG.setItem(str_model=self.model.getWallPressureExtrapolation())
         self.modelIMRGRA.setItem(str_model=self.model.getGradientReconstruction())
 
-        import Pages.FluidCharacteristicsModel as FluidCharacteristics
-        fluid = FluidCharacteristics.FluidCharacteristicsModel(self.case)
-        modl_atmo, modl_joul, modl_thermo, modl_gas, modl_coal = fluid.getThermoPhysicalModel()
         if modl_joul != 'off' or modl_gas != 'off' or modl_coal != 'off':
             self.labelSRROM.show()
             self.lineEditSRROM.show()
@@ -171,8 +158,10 @@ class NumericalParamGlobalView(QWidget, Ui_NumericalParamGlobalForm):
         status = SteadyManagementModel(self.case).getSteadyFlowManagement()
         if status == 'on':
             self.modelNTERUP.enableItem(str_model = 'simple')
+            self.modelNTERUP.disableItem(str_model = 'piso')
         else:
             self.modelNTERUP.disableItem(str_model = 'simple')
+            self.modelNTERUP.enableItem(str_model = 'piso')
 
         self.modelNTERUP.setItem(str_model=algo)
 
@@ -181,12 +170,50 @@ class NumericalParamGlobalView(QWidget, Ui_NumericalParamGlobalForm):
         else:
             self.spinBoxNTERUP.hide()
 
+        if modl_comp != 'off':
+            self.labelICFGRP.show()
+            self.checkBoxICFGRP.show()
+            self.line_4.show()
+            if self.model.getHydrostaticEquilibrium() == 'on':
+                self.checkBoxICFGRP.setChecked(True)
+            else:
+                self.checkBoxICFGRP.setChecked(False)
+            self.checkBoxIPUCOU.hide()
+            self.labelIPUCOU.hide()
+            self.lineEditRELAXP.hide()
+            self.labelRELAXP.hide()
+            self.checkBoxImprovedPressure.hide()
+            self.labelImprovedPressure.hide()
+            self.line_2.hide()
+            self.line_5.hide()
+            self.line_7.hide()
+            self.line_8.hide()
+            self.labelNTERUP.setText(QString("Velocity-Pressure algorithm\nsub-iterations on Navier-Stokes"))
+            self.comboBoxNTERUP.hide()
+            self.spinBoxNTERUP.show()
+        else:
+            self.labelICFGRP.hide()
+            self.checkBoxICFGRP.hide()
+            self.line_4.hide()
+            self.checkBoxIPUCOU.show()
+            self.labelIPUCOU.show()
+            self.lineEditRELAXP.show()
+            self.labelRELAXP.show()
+            self.checkBoxImprovedPressure.show()
+            self.labelImprovedPressure.show()
+            self.line_2.show()
+            self.line_5.show()
+            self.line_7.show()
+            self.line_8.show()
+
         value = self.model.getPisoSweepNumber()
         self.spinBoxNTERUP.setValue(value)
 
         # Update the Tree files and folders
         self.browser.configureTree(self.case)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("")
     def slotIVISSE(self):
