@@ -427,8 +427,10 @@ class OutputVolumicVariablesModel(Model):
         self._updateBoundariesNodes(old_label, new_label)
 
         for node in self.case.xmlGetNodeList('formula'):
-            f = node.xmlGetTextNode().replace(old_label, new_label)
-            node.xmlSetTextNode(f)
+            f = node.xmlGetTextNode()
+            if f:
+                f.replace(old_label, new_label)
+                node.xmlSetTextNode(f)
 
 
     def _updateBoundariesNodes(self, old_label, new_label):
@@ -555,7 +557,6 @@ class OutputVolumicVariablesModelTestCase(ModelTest):
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
-                    <property label="all_variables" name="all_variables" support="boundary"/>
                  </velocity_pressure>'''
         assert node == self.xmlNodeFromString(doc),\
             'Could not set label of property in output volumic variables model'
