@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -424,6 +424,7 @@ class OutputVolumicVariablesView(QWidget, Ui_OutputVolumicVariablesForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
         self.info_turb_name = []
         self.mdl = OutputVolumicVariablesModel(self.case)
 
@@ -443,6 +444,8 @@ class OutputVolumicVariablesView(QWidget, Ui_OutputVolumicVariablesForm):
         probesDelegate = ProbesDelegate(self.tableViewOutput, self.mdl)
         self.tableViewOutput.setItemDelegateForColumn(3, probesDelegate)
 
+        self.case.undoStartGlobal()
+
 
     def tr(self, text):
         """
