@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -201,8 +201,8 @@ class Informations:
 
 
     def getLocalizations(self):
-        list = self.refList + self.groupList
-        return map(str, list)
+        lst = self.refList + self.groupList
+        return list(map(str, lst))
 
 
 #-------------------------------------------------------------------------------
