@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -35,6 +35,7 @@ This module contains the following classes and function:
 # Library modules import
 #-------------------------------------------------------------------------------
 
+import os
 import sys, string
 import logging
 import subprocess
@@ -53,8 +54,6 @@ from PyQt4.QtGui  import *
 from Base.Toolbox import GuiParam
 from Pages.QMeiEditorForm import Ui_QMeiDialog
 
-from Base.Common import cs_check_syntax
-
 #-------------------------------------------------------------------------------
 # log config
 #-------------------------------------------------------------------------------
@@ -149,7 +148,7 @@ class QMeiHighlighter(QSyntaxHighlighter):
 class QMeiEditorView(QDialog, Ui_QMeiDialog):
     """
     """
-    def __init__(self, parent, expression = "", symbols = [], required = [], examples = ""):
+    def __init__(self, parent, check_syntax = None, expression = "", symbols = [], required = [], examples = ""):
         """
         Constructor.
         """
@@ -158,6 +157,12 @@ class QMeiEditorView(QDialog, Ui_QMeiDialog):
         Ui_QMeiDialog.__init__(self)
         self.setupUi(self)
 
+        if check_syntax is not None:
+            if not os.path.isfile(check_syntax):
+                check_syntax = None
+
+        self.check_syntax = check_syntax
+
         self.required = required
         self.symbols  = symbols
 
@@ -195,7 +200,7 @@ class QMeiEditorView(QDialog, Ui_QMeiDialog):
         predif += self.tr("<br>"\
                   "<big><u>Useful functions:</u></big><br>"\
                   "<b>cos</b>: cosine<br>"\
-                  "<b>sin</b>: sinus<br>"\
+                  "<b>sin</b>: sine<br>"\
                   "<b>tan</b>: tangent<br>"\
                   "<b>exp</b>: exponential<br>"\
                   "<b>sqrt</b>: square root<br>"\
@@ -255,7 +260,7 @@ class QMeiEditorView(QDialog, Ui_QMeiDialog):
         What to do when user clicks on 'OK'.
         """
 
-        if cs_check_syntax == None:
+        if self.check_syntax == None:
             QDialog.accept(self)
             return
 
@@ -265,7 +270,7 @@ class QMeiEditorView(QDialog, Ui_QMeiDialog):
 
         log.debug("check.string: %s" % str(self.textEditExpression.toPlainText()))
 
-        check = subprocess.Popen([cs_check_syntax],
+        check = subprocess.Popen([self.check_syntax],
                                  stdin=subprocess.PIPE,
                                  stdout=subprocess.PIPE,
                                  stderr=subprocess.PIPE)
