@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -79,6 +79,7 @@ class ReferenceValuesView(QWidget, Ui_ReferenceValuesForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
         self.mdl = ReferenceValuesModel(self.case)
 
         # Combo models
@@ -146,7 +147,6 @@ class ReferenceValuesView(QWidget, Ui_ReferenceValuesForm):
         gas_comb = GasCombustionModel(self.case).getGasCombustionModel()
         if gas_comb == 'd3p':
             self.groupBoxTempd3p.show()
-            self.groupBoxTemperature.hide()
             t_oxy  = self.mdl.getTempOxydant()
             t_fuel = self.mdl.getTempFuel()
             self.lineEditOxydant.setText(QString(str(t_oxy)))
@@ -182,6 +182,8 @@ class ReferenceValuesView(QWidget, Ui_ReferenceValuesForm):
             m = self.mdl.getMassemol()
             self.lineEditMassMolar.setText(QString(str(m)))
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("const QString&")
     def slotPressure(self,  text):
