@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -78,6 +78,7 @@ class SteadyManagementView(QWidget, Ui_SteadyManagementForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
         self.mdl = SteadyManagementModel(self.case)
 
         # Connections
@@ -108,6 +109,8 @@ class SteadyManagementView(QWidget, Ui_SteadyManagementForm):
         else:
             self.checkBoxINPDT0.setChecked(False)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("const QString&")
     def slotRelaxCoef(self, text):
