@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -78,6 +78,7 @@ class ThermalScalarView(QWidget, Ui_ThermalScalarForm):
 
         self.browser = tree
         self.case = case
+        self.case.undoStopGlobal()
         self.thermal = ThermalScalarModel(self.case)
 
         # combo Model
@@ -101,6 +102,8 @@ class ThermalScalarView(QWidget, Ui_ThermalScalarForm):
         model = self.thermal.getThermalScalarModel()
         self.modelThermal.setItem(str_model=model)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("const QString &")
     def slotThermalScalar(self, text):
