@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2012 EDF S.A.
+# Copyright (C) 1998-2013 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -75,6 +75,7 @@ class TimeStepView(QWidget, Ui_TimeStepForm):
         self.setupUi(self)
 
         self.case = case
+        self.case.undoStopGlobal()
         self.mdl = TimeStepModel(self.case)
 
        # Combo model
@@ -181,6 +182,8 @@ class TimeStepView(QWidget, Ui_TimeStepForm):
         else:
             self.checkBoxINPDT0.setChecked(False)
 
+        self.case.undoStartGlobal()
+
 
     @pyqtSignature("")
     def slotTimePassing(self, text):
