@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -281,6 +281,7 @@ _matrix_vector_test(double                 t_measure,
   cs_matrix_set_coefficients(m,
                              sym_coeffs,
                              NULL,
+                             NULL,
                              da,
                              xa);
 
@@ -766,6 +767,16 @@ cs_benchmark(int  mpi_trace_mode)
   size_t n_cells_ext = mesh->n_cells_with_ghosts;
   size_t n_faces = mesh->n_i_faces;
 
+  int                    n_fill_types_nsym = 3;
+  int                    n_fill_types_sym = 2;
+  cs_matrix_fill_type_t  fill_types_nsym[] = {CS_MATRIX_SCALAR,
+                                              CS_MATRIX_33_BLOCK_D,
+                                              CS_MATRIX_33_BLOCK};
+  cs_matrix_fill_type_t  fill_types_sym[] = {CS_MATRIX_SCALAR_SYM,
+                                             CS_MATRIX_33_BLOCK_D_SYM};
+  double                 fill_weights_nsym[] = {0.5, 0.4, 0.1};
+  double                 fill_weights_sym[] = {0.8, 0.2};
+
   /* Allocate and initialize  working arrays */
   /*-----------------------------------------*/
 
@@ -819,8 +830,9 @@ cs_benchmark(int  mpi_trace_mode)
                   "=====================================\n"));
 
   mv = cs_matrix_variant_tuned(t_measure,
-                               0.000001, /* sym_weight */
-                               0.000001, /* block_weight */
+                               n_fill_types_nsym,
+                               fill_types_nsym,
+                               fill_weights_nsym,
                                10,       /* min expected SpMV products */
                                n_cells,
                                n_cells_ext,
@@ -844,8 +856,9 @@ cs_benchmark(int  mpi_trace_mode)
                   "=============================\n"));
 
   mv = cs_matrix_variant_tuned(t_measure,
-                               1.0, /* sym_weight */
-                               0.0, /* block_weight */
+                               n_fill_types_sym,
+                               fill_types_sym,
+                               fill_weights_sym,
                                10,  /* min expected SpMV products */
                                n_cells,
                                n_cells_ext,
