@@ -3100,10 +3100,9 @@ cs_sles_post_error_output_var(const char  *var_name,
                       true, /* interlace */
                       true, /* use parents */
                       CS_POST_TYPE_cs_real_t,
-                      -1,
-                      0.0,
                       var,
                       NULL,
+                      NULL,
                       NULL);
 
     if (n_non_norm > 0) {
@@ -3127,10 +3126,9 @@ cs_sles_post_error_output_var(const char  *var_name,
                         true, /* interlace */
                         true, /* use parents */
                         CS_POST_TYPE_int,
-                        -1,
-                        0.0,
                         val_type,
                         NULL,
+                        NULL,
                         NULL);
 
     }
