@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -107,10 +107,9 @@ implicit none
 ! Arguments
 
 integer          ivar   , imrgra , inc    , iccocg , nswrgp
-integer          imligp ,iwarnp  , iphydp , nfecra
+integer          imligp , iwarnp , iphydp , nfecra
 double precision epsrgp , climgp , extrap
 
-
 double precision ppond(ncelet)
 double precision fextx(ncelet),fexty(ncelet),fextz(ncelet)
 double precision pvar(ncelet), coefap(nfabor), coefbp(nfabor)
@@ -118,13 +117,15 @@ double precision grad(ncelet,3)
 
 ! Local variables
 
-integer          idimtr
+integer          imrgrp
+integer          idimtr, ipond
 integer          iiu,iiv,iiw
 integer          iitytu
 integer          iir11,iir22,iir33
 integer          iir12,iir13,iir23
 integer          imlini
 
+double precision rvoid(1)
 double precision climin
 
 !===============================================================================
@@ -133,9 +134,15 @@ double precision climin
 ! 0. Initialization
 !===============================================================================
 
+! Use iterative gradient
+
+imrgrp = 0
+if (imrgra.lt.0) imrgrp = -imrgra
+
 ! The gradient of a potential (pressure, ...) is a vector
 
 idimtr = 0
+ipond = 0
 
 !===============================================================================
 ! 1. Compute gradient
@@ -143,10 +150,10 @@ idimtr = 0
 
 call cgdcel                                                       &
 !==========
- ( ivar   , imrgra , inc    , iccocg , imobil , iale   , nswrgp , &
-   idimtr , iphydp , iwarnp , imligp , epsrgp , extrap , climgp , &
-   isympa , fextx  , fexty  , fextz  , coefap , coefbp , pvar   , &
-   grad   )
+ ( ivar   , imrgrp , inc    , iccocg , imobil , iale   , nswrgp , &
+   idimtr , iphydp , ipond  , iwarnp , imligp , epsrgp , extrap , &
+   climgp , isympa , fextx  , fexty  , fextz  , coefap , coefbp , &
+   pvar   , rvoid  , grad   )
 
 return
 end subroutine
