@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -23,7 +23,7 @@
 subroutine invers &
 !================
 
- ( cnom   , isym   , ibsize , ipol   , ireslp , nitmap ,          &
+ ( cnom   , isym   , ibsize , iesize , ipol   , ireslp , nitmap , &
    imgrp  , ncymxp , nitmfp ,                                     &
    iwarnp , nfecra , niterf , icycle , iinvpe ,                   &
    epsilp , rnorm  , residu ,                                     &
@@ -47,6 +47,10 @@ subroutine invers &
 ! cnom             ! a  ! <-- ! variable name                                  !
 ! isym             ! e  ! <-- ! flag = 1: symmetric matrix                     !
 !                  !    !     !        2: non-symmetric matrix                 !
+! ibsize           !    ! <-- ! flag = 1: diag block size 1                    !
+!                  !    !     !      = 3: diag block size 3                    !
+! iesize           !    ! <-- ! flag = 1: extra diag block size                !
+!                  !    !     !      = 3: diag block size 3                    !
 ! ipol             ! e  ! <-- ! polynomial degree for preconditioning          !
 !                  !    !     !   (0 <-- diagonal)                             !
 ! ireslp           ! e  ! <-- ! solver type: 0 conjugate gradient              !
@@ -92,7 +96,7 @@ implicit none
 ! Arguments
 
 character*16     cnom
-integer          isym   , ipol   , ireslp , nitmap , ibsize
+integer          isym   , ipol   , ireslp , nitmap , ibsize , iesize
 integer          imgrp  , ncymxp , nitmfp
 integer          iwarnp , nfecra
 integer          niterf , icycle , iinvpe
@@ -132,7 +136,7 @@ if (imgrp.eq.1) then
 
   call resmgr                                                     &
   !==========
- ( cnom   , lnom   , ncelet , ncel   , nfac   ,                   &
+ ( cnom   , lnom   ,                                              &
    iresds , iresas , ireslp , ipol   ,                            &
    ncymxp , nitmds , nitmas , nitmap , iinvpe ,                   &
    iwarnp , icycle , niterf , epsilp , rnorm  , residu ,          &
@@ -140,35 +144,17 @@ if (imgrp.eq.1) then
 
 elseif(imgrp.eq.0) then
 
-  if (ireslp.ge.0 .and. ireslp.le. 3) then
-
-    call reslin                                                   &
-    !==========
- ( cnom   , lnom   , ncelet , ncel   , nfac   ,                   &
-   isym   , ilved  , ibsize , ireslp , ipol   , nitmap , iinvpe , &
-   iwarnp , niterf , epsilp , rnorm  , residu ,                   &
+  call reslin &
+  !==========
+ ( cnom   , lnom   , ncelet , ncel   , nfac   ,                            &
+   isym   , ilved  , ibsize , iesize , ireslp , ipol   , nitmap , iinvpe , &
+   iwarnp , niterf , epsilp , rnorm  , residu ,                            &
    !        ------                     ------
    ifacel , dam    , xam    , smbrp  , vx     )
    !                          -----
 
-  else
-    write(nfecra,1000) cnom, ireslp
-    call csexit (1)
-  endif
-
 endif
 
-
-#if defined(_CS_LANG_FR)
-
- 1000 format('invers appele pour ', a16, ' avec iresol = ', i10)
-
-#else
-
- 1000 format('invers called for ', a16, ' with iresol = ', i10)
-
-#endif
-
 !----
 ! End
 !----
