@@ -33,10 +33,10 @@
    _GNU_SOURCE must be defined before including any headers, to ensure
    the correct feature macros are defined first. */
 
-#if (   (defined(__linux__) || defined(__linux) || defined(linux)) \
-     && !defined(__bg__))
-#if    (!defined(__ia64__) && !defined(__blrts__)) \
+#if defined(__linux__) || defined(__linux) || defined(linux)
+#if    (!defined(__ia64__) && !defined(__blrts__) && !defined(__bg__)) \
     || defined(DEBUG)
+#define CS_FPE_TRAP
 #define _GNU_SOURCE
 #endif
 #endif
@@ -53,7 +53,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if defined(_GNU_SOURCE)
+#if defined(CS_FPE_TRAP)
 #include <fenv.h>
 #endif
 
@@ -90,6 +90,7 @@
 #include "cs_gui_particles.h"
 #include "cs_io.h"
 #include "cs_join.h"
+#include "cs_lagr_tracking.h"
 #include "cs_log.h"
 #include "cs_mesh.h"
 #include "cs_mesh_coherency.h"
@@ -152,7 +153,7 @@ cs_run(void);
 
 static cs_opts_t  opts;
 
-#if defined(_GNU_SOURCE)
+#if defined(CS_FPE_TRAP)
 static int _fenv_set = 0;    /* Indicates if behavior modified */
 static fenv_t _fenv_old;     /* Old exception mask */
 #endif
@@ -360,8 +361,7 @@ cs_run(void)
 
   }
 
-  /* Now that mesh modification is finished, save mesh if modified
-     (do this before building colors, which adds internal groups) */
+  /* Now that mesh modification is finished, save mesh if modified */
 
   cs_user_mesh_save(cs_glob_mesh); /* Disable or force */
 
@@ -394,9 +394,8 @@ cs_run(void)
   cs_renumber_mesh(cs_glob_mesh,
                    cs_glob_mesh_quantities);
 
-  /* Initialize group classes and insert colors if possible */
+  /* Initialize group classes */
 
-  cs_mesh_build_colors(cs_glob_mesh);
   cs_mesh_init_group_classes(cs_glob_mesh);
 
   /* Print info on mesh */
@@ -513,6 +512,7 @@ cs_run(void)
                                   &n_g_i_faces,
                                   &n_g_b_faces,
                                   &n_g_vertices,
+                                  &(cs_glob_mesh->n_families),
                                   &nthrdi,
                                   &nthrdb,
                                   &ngrpi,
@@ -523,7 +523,6 @@ cs_run(void)
                                   cs_glob_mesh->b_face_cells,
                                   cs_glob_mesh->b_face_family,
                                   cs_glob_mesh->cell_family,
-                                  cs_glob_mesh->family_item,
                                   cs_glob_mesh->i_face_vtx_idx,
                                   cs_glob_mesh->i_face_vtx_lst,
                                   cs_glob_mesh->b_face_vtx_idx,
@@ -628,6 +627,10 @@ cs_run(void)
   cs_field_destroy_all();
   cs_field_destroy_all_keys();
 
+  /* Free Lagrangian related structures */
+
+  cs_lagr_destroy();
+
   /* Free main mesh after printing some statistics */
 
   cs_mesh_location_finalize();
@@ -685,7 +688,7 @@ main(int    argc,
 
   /* Trap floating-point exceptions */
 
-#if defined(_GNU_SOURCE)
+#if defined(CS_FPE_TRAP)
   if (_fenv_set == 0) {
     if (fegetenv(&_fenv_old) == 0) {
       feenableexcept(FE_DIVBYZERO | FE_INVALID | FE_OVERFLOW);
