@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -284,7 +284,7 @@ syear = 1994
 squant = 1
 shour = 1
 smin = 0
-ssec = 0.
+ssec = 0
 xlon = 0.d0
 xlat = 45.d0
 
@@ -295,7 +295,7 @@ xlat = 45.d0
 !       = 1 : top to bottom Laplace integration based on P computed for
 !            the standard atmosphere at z(nbmaxt)
 
-ihpm = 1
+ihpm = 0
 
 ! 1d radiative transfer model:
 ! ----------------------------
@@ -365,7 +365,7 @@ endif
 
 if (iihmpr.eq.1) then
 
-  call uiati1 (imeteo)
+  call uiati1 (imeteo, ficmet, len(ficmet))
   !==========
 
 endif
