@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -79,7 +79,7 @@ integer ih2o
 
 double precision second
 double precision sjday, jday
-double precision rap,rscp,tmoy, rhmoy, psol
+double precision rap,rscp,tmoy, rhmoy
 double precision ztop, zzmax, tlkelv, pptop, dum
 double precision rhum,q0,q1
 
@@ -107,12 +107,12 @@ open (unit=impmet, file=ficmet,                                  &
 rewind(unit=impmet, err=99)
 
 itp=0
+ih2o = 0
 
 if (imode.eq.1) then
   rscp=rair/cp0
 
   !--> flag to take into account the humidity
-  ih2o = 0
   if (ippmod(iatmos).eq.2) ih2o=1
 
 endif
@@ -324,7 +324,6 @@ endif
 if (imode.eq.1) then
 
   phmet(1, itp) = pmer(itp)
-  psol = p0
   rscp = rair/cp0
 
   if (ihpm.eq.0) then
