@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -37,7 +37,7 @@ subroutine atmcls &
 ! --------
 ! Compute u*, q0, e0, (momentum, sensible heat and latent heat fluxes)
 !   for a non neutral atmospheric surface layer using the explicit formula
-!   developped for the ECMWF by Louis (1982)
+!   developed for the ECMWF by Louis (1982)
 
 !-------------------------------------------------------------------------------
 ! Arguments
@@ -122,7 +122,7 @@ implicit none
 integer          nvar   , nscal
 integer          ifac   , iel
 
-integer          icodcl(nfabor,nvar)
+integer          icodcl(nfabor,nvarcl)
 
 double precision uk, utau, yplus, uet
 double precision gredu, rib, lmo, q0, e0
@@ -131,7 +131,7 @@ double precision cfnnu, cfnns, cfnnk,cfnne
 double precision dt(ncelet), rtp(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
-double precision rcodcl(nfabor,nvar,3)
+double precision rcodcl(nfabor,nvarcl,3)
 
 ! Local variables
 
