@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -108,19 +108,17 @@
 !>                               de bord apres amortisst de v driest
 !> \param[out]    hbord         coefficients d'echange aux bords
 !>
-!> \param[out]    thbord        boundary temperature in \f$ \centip \f$
+!> \param[out]    theipb        boundary temperature in \f$ \centip \f$
 !>                               (more exaclty the energetic variable)
 !_______________________________________________________________________________
 
 subroutine clptrg &
-!================
-
  ( nvar   , nscal  ,                                              &
    isvhb  ,                                                       &
    icodcl ,                                                       &
    dt     , rtp    , rtpa   , propce , propfa , propfb , rcodcl , &
    velipb , rijipb , coefa  , coefb  , visvdr ,                   &
-   hbord  , thbord )
+   hbord  , theipb )
 
 !===============================================================================
 
@@ -143,6 +141,7 @@ use ppincl
 use radiat
 use cplsat
 use mesh
+use field
 use lagran
 
 !===============================================================================
@@ -154,20 +153,20 @@ implicit none
 integer          nvar   , nscal
 integer          isvhb
 
-integer          icodcl(nfabor,nvar)
+integer          icodcl(nfabor,nvarcl)
 
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
-double precision rcodcl(nfabor,nvar,3)
+double precision rcodcl(nfabor,nvarcl,3)
 double precision velipb(nfabor,ndim), rijipb(nfabor,6)
 double precision coefa(nfabor,*), coefb(nfabor,*)
 double precision visvdr(ncelet)
-double precision hbord(nfabor),thbord(nfabor)
+double precision hbord(nfabor),theipb(nfabor)
 
 ! Local variables
 
-integer          ifac, iel, ivar, isou, ii, jj, kk, isvhbl
+integer          ifac, iel, ivar, isou, jsou, ii, jj, kk, isvhbl
 integer          ihcp, iscal
 integer          modntl
 integer          iuntur, iuiptn
@@ -183,13 +182,16 @@ integer          icl11f, icl22f, icl33f, icl12f, icl13f, icl23f
 integer          iclphf, iclfbf, iclalf, iclomf
 integer          iclvaf
 integer          ipcrom, ipcvis, ipcvst, ipccp , ipccv
-integer          ipcvsl
+integer          ipcvsl, itplus, itstar
+integer          f_id
+
 double precision rnx, rny, rnz, rxnn
 double precision tx, ty, tz, txn, txn0, t2x, t2y, t2z
 double precision utau, upx, upy, upz, usn
 double precision uiptn, uiptnf, uiptmn, uiptmx
 double precision uetmax, uetmin, ukmax, ukmin, yplumx, yplumn
-double precision uk, uet, tet, yplus, uplus
+double precision tetmax, tetmin, tplumx, tplumn
+double precision uk, uet, tet, yplus, uplus, phit, tplus
 double precision gredu, rib, lmo, q0, e0
 double precision cfnnu, cfnns, cfnnk, cfnne
 double precision sqrcmu, clsyme, ek
@@ -204,6 +206,14 @@ double precision visclc, visctc, romc  , distbf, srfbnf, cpscv
 double precision cofimp
 double precision distb0, rugd  , rugt  , ydep  , act
 double precision dsa0
+double precision pfac
+double precision visci(3,3), fikis, viscis, distfi
+
+character*80     fname
+
+double precision, dimension(:), pointer :: tplusp, tstarp
+double precision, dimension(:,:), pointer :: coefaut, cofafut, cofarut
+double precision, dimension(:,:,:), pointer :: coefbut, cofbfut, cofbrut
 
 !===============================================================================
 
@@ -227,7 +237,28 @@ icl23 = 0
 iclvar = 0
 ipccv = 0
 
+icl11r = 0
+icl12r = 0
+icl13r = 0
+icl22r = 0
+icl23r = 0
+icl33r = 0
+iclal = 0
+iclalf = 0
+iclepf = 0
+iclfbf = 0
+iclkf = 0
+iclomf = 0
+iclphf = 0
+iuntur = 0
+
+cofimp = 0.d0
 ek = 0.d0
+hflui = 0.d0
+phit = 0.d0
+rugt = 0.d0
+uiptn = 0.d0
+uiptnf = 0.d0
 
 ! --- Constants
 uet = 1.d0
@@ -347,6 +378,14 @@ ukmin  =  grand
 yplumx = -grand
 yplumn =  grand
 
+! min. and max. of wall friction of the thermal scalar
+tetmax = -grand
+tetmin =  grand
+
+! min. and max. of T+
+tplumx = -grand
+tplumn =  grand
+
 ! Counter (reversal)
 iuiptn = 0
 
@@ -358,6 +397,21 @@ if (itytur.eq.5) then
   uiptmn = 0.d0
 endif
 
+! pointers to T+ and T* if saved
+
+tplusp => null()
+tstarp => null()
+
+call field_get_id('tplus', itplus)
+if (itplus.ge.0) then
+  call field_get_val_s (itplus, tplusp)
+endif
+
+call field_get_id('tstar', itstar)
+if (itstar.ge.0) then
+  call field_get_val_s (itstar, tstarp)
+endif
+
 ! --- Loop on boundary faces
 do ifac = 1, nfabor
 
@@ -618,7 +672,7 @@ do ifac = 1, nfabor
 
 
     ! Save yplus is post-processed
-    if (mod(ipstdv,ipstyp).eq.0) then
+    if (ipstdv(ipstyp).ne.0) then
       yplbr(ifac) = yplus
     endif
 
@@ -1216,8 +1270,8 @@ do ifac = 1, nfabor
             endif
           endif
 
-          ! Turbulent
-          if (iturb.ne.0) then
+          ! Scalar diffusivity
+          if (idften(ivar).eq.1) then
             ! En compressible, pour l'energie LAMBDA/CV+CP/CV*(MUT/SIGMAS)
             if (ippmod(icompf) .ge. 0) then
               if (ipccp.gt.0) then
@@ -1230,24 +1284,92 @@ do ifac = 1, nfabor
               else
                 cpscv = cpscv/cv0
               endif
-              hint = (rkl+cpp*cpscv*visctc/sigmas(iscal))/distbf
+              hint = (rkl+idifft(ivar)*cpp*cpscv*visctc/sigmas(iscal))/distbf
             else
-              hint = (rkl+cpp*visctc/sigmas(iscal))/distbf
+              hint = (rkl+idifft(ivar)*cpp*visctc/sigmas(iscal))/distbf
             endif
 
-          ! Laminar
-          else
-            hint  = rkl/distbf
+          ! Symmetric tensor diffusivity (GGDH or AFM)
+          elseif (idften(ivar).eq.6) then
+            ! En compressible, pour l'energie LAMBDA/CV+CP/CV*(MUT/SIGMAS)
+            if (ippmod(icompf) .ge. 0) then
+              if (ipccp.gt.0) then
+                cpscv = propce(iel,ipproc(icp))
+              else
+                cpscv = cp0
+              endif
+              if (ipccv.gt.0) then
+                cpscv = cpscv/propce(iel,ipproc(icv))
+              else
+                cpscv = cpscv/cv0
+              endif
+              visci(1,1) = rkl + idifft(ivar)*cpp*cpscv*visten(1,iel)*ctheta(iscal)
+              visci(2,2) = rkl + idifft(ivar)*cpp*cpscv*visten(2,iel)*ctheta(iscal)
+              visci(3,3) = rkl + idifft(ivar)*cpp*cpscv*visten(3,iel)*ctheta(iscal)
+              visci(1,2) =       idifft(ivar)*cpp*cpscv*visten(4,iel)*ctheta(iscal)
+              visci(2,1) =       idifft(ivar)*cpp*cpscv*visten(4,iel)*ctheta(iscal)
+              visci(2,3) =       idifft(ivar)*cpp*cpscv*visten(5,iel)*ctheta(iscal)
+              visci(3,2) =       idifft(ivar)*cpp*cpscv*visten(5,iel)*ctheta(iscal)
+              visci(1,3) =       idifft(ivar)*cpp*cpscv*visten(6,iel)*ctheta(iscal)
+              visci(3,1) =       idifft(ivar)*cpp*cpscv*visten(6,iel)*ctheta(iscal)
+            else
+              visci(1,1) = rkl + idifft(ivar)*cpp*visten(1,iel)*ctheta(iscal)
+              visci(2,2) = rkl + idifft(ivar)*cpp*visten(2,iel)*ctheta(iscal)
+              visci(3,3) = rkl + idifft(ivar)*cpp*visten(3,iel)*ctheta(iscal)
+              visci(1,2) =       idifft(ivar)*cpp*visten(4,iel)*ctheta(iscal)
+              visci(2,1) =       idifft(ivar)*cpp*visten(4,iel)*ctheta(iscal)
+              visci(2,3) =       idifft(ivar)*cpp*visten(5,iel)*ctheta(iscal)
+              visci(3,2) =       idifft(ivar)*cpp*visten(5,iel)*ctheta(iscal)
+              visci(1,3) =       idifft(ivar)*cpp*visten(6,iel)*ctheta(iscal)
+              visci(3,1) =       idifft(ivar)*cpp*visten(6,iel)*ctheta(iscal)
+            endif
+
+            ! ||Ki.S||^2
+            viscis = ( visci(1,1)*surfbo(1,ifac)       &
+                     + visci(1,2)*surfbo(2,ifac)       &
+                     + visci(1,3)*surfbo(3,ifac))**2   &
+                   + ( visci(2,1)*surfbo(1,ifac)       &
+                     + visci(2,2)*surfbo(2,ifac)       &
+                     + visci(2,3)*surfbo(3,ifac))**2   &
+                   + ( visci(3,1)*surfbo(1,ifac)       &
+                     + visci(3,2)*surfbo(2,ifac)       &
+                     + visci(3,3)*surfbo(3,ifac))**2
+
+            ! IF.Ki.S
+            fikis = ( (cdgfbo(1,ifac)-xyzcen(1,iel))*visci(1,1)   &
+                    + (cdgfbo(2,ifac)-xyzcen(2,iel))*visci(2,1)   &
+                    + (cdgfbo(3,ifac)-xyzcen(3,iel))*visci(3,1)   &
+                    )*surfbo(1,ifac)                              &
+                  + ( (cdgfbo(1,ifac)-xyzcen(1,iel))*visci(1,2)   &
+                    + (cdgfbo(2,ifac)-xyzcen(2,iel))*visci(2,2)   &
+                    + (cdgfbo(3,ifac)-xyzcen(3,iel))*visci(3,2)   &
+                    )*surfbo(2,ifac)                              &
+                  + ( (cdgfbo(1,ifac)-xyzcen(1,iel))*visci(1,3)   &
+                    + (cdgfbo(2,ifac)-xyzcen(2,iel))*visci(2,3)   &
+                    + (cdgfbo(3,ifac)-xyzcen(3,iel))*visci(3,3)   &
+                    )*surfbo(3,ifac)
+
+            distfi = distb(ifac)
+
+            ! Take I" so that I"F= eps*||FI||*Ki.n when J" is in cell rji
+            ! NB: eps =1.d-1 must be consistent with vitens.f90
+            fikis = max(fikis, 1.d-1*sqrt(viscis)*distfi)
+
+            hint = viscis/surfbn(ifac)/fikis
           endif
 
-          ! Loi rugueuse, on recalcule le coefficient d'echange fluide - paroi
-          if (iturb.ne.0.and.icodcl(ifac,ivar).eq.6)then
-
+          ! Dirichlet on the scalar, with wall function
+          if (iturb.ne.0.and.icodcl(ifac,ivar).eq.6) then
             rugt = rcodcl(ifac,iv,3)
             act = xkappa/log((distbf+rugt)/rugt)
+            ! T+ = (T_I - T_w) / Tet
+            tplus = log((distbf+rugt)/rugt)/xkappa
             hflui = romc*cpp*uet*act*cfnns
+          ! Neumann on the scalar, with wall function (for post-processing)
           else
             hflui = hint
+            ! T+ = (T_I - T_w) / Tet, we assume here rugt = rugd
+            tplus = uplus
           endif
 
           if (isvhbl.gt.0) hbord(ifac) = hflui
@@ -1270,9 +1392,8 @@ do ifac = 1, nfabor
             if (abs(hext).gt.rinfin*0.5d0) then
 
               ! Gradient BCs
-              hredui = hint/hflui
-              coefa(ifac,iclvar) = pimp/hredui
-              coefb(ifac,iclvar) = (hredui-1.d0)/hredui
+              coefa(ifac,iclvar) = pimp*hflui/hint
+              coefb(ifac,iclvar) = 1.d0 - hflui/hint
 
               ! Flux BCs
               coefa(ifac,iclvaf) = -hflui*pimp
@@ -1280,16 +1401,89 @@ do ifac = 1, nfabor
 
             else
 
+              heq = hflui*hext/(hflui+hext)
               ! Gradient BCs
-              hredui = hint/hflui
-              coefa(ifac,iclvar) = hext*pimp/(hint+hext*hredui)
-              coefb(ifac,iclvar) = (hint-(1.d0-hredui)*hext)/       &
-                                 (hint+hext*hredui)
+              coefa(ifac,iclvar) = pimp*heq/hint
+              coefb(ifac,iclvar) = 1.d0 - heq/hint
 
               ! Flux BCs
-              heq = hflui*hext/(hflui+hext)
               coefa(ifac,iclvaf) = -heq*pimp
               coefb(ifac,iclvaf) =  heq
+            endif
+
+            !--> Turbulent heat flux
+            if (ityturt(iscal).eq.3) then
+
+              ! Name of the scalar ivar !TODO move outside of the loop
+              call field_get_name(ivarfl(ivar), fname)
+
+              ! Index of the corresponding turbulent flux
+              call field_get_id(trim(fname)//'_turbulent_flux', f_id)
+
+              call field_get_coefa_v(f_id,coefaut)
+              call field_get_coefb_v(f_id,coefbut)
+              call field_get_coefaf_v(f_id,cofafut)
+              call field_get_coefbf_v(f_id,cofbfut)
+              call field_get_coefad_v(f_id,cofarut)
+              call field_get_coefbd_v(f_id,cofbrut)
+
+              hint = 0.5d0*(visclc+rkl)/distbf !FIXME with the GGDH component
+
+              ! Gradient boundary conditions
+              !-----------------------------
+
+              coefaut(1,ifac) = 0.d0
+              coefaut(2,ifac) = 0.d0
+              coefaut(3,ifac) = 0.d0
+              ! Projection in order to have the velocity parallel to the wall
+              ! B = cofimp * ( IDENTITY - n x n )
+
+              coefbut(1,1,ifac) = 0.d0
+              coefbut(2,2,ifac) = 0.d0
+              coefbut(3,3,ifac) = 0.d0
+              coefbut(1,2,ifac) = 0.d0
+              coefbut(1,3,ifac) = 0.d0
+              coefbut(2,1,ifac) = 0.d0
+              coefbut(2,3,ifac) = 0.d0
+              coefbut(3,1,ifac) = 0.d0
+              coefbut(3,2,ifac) = 0.d0
+
+              ! Boundary conditions used in the temperature equation
+              do isou = 1, 3
+                cofarut(isou,ifac) = coefaut(isou,ifac)
+                do jsou = 1, 3
+                  cofbrut(isou,jsou,ifac) = coefbut(isou,jsou,ifac)
+                enddo
+              enddo
+
+              ! Add uk*Tet to the turbulent flux T'v' in High Reynolds
+              do isou = 1, 3
+                coefaut(isou,ifac) = coefaut(isou,ifac)                    &
+                                   + surfbo(isou,ifac)/surfbn(ifac)*phit
+              enddo
+
+              ! Translate coefa into cofaf and coefb into cofbf
+
+              ! Flux boundary conditions
+              !-------------------------
+
+              cofafut(1,ifac) = -hint*coefaut(1,ifac)
+              cofafut(2,ifac) = -hint*coefaut(2,ifac)
+              cofafut(3,ifac) = -hint*coefaut(3,ifac)
+
+              ! Projection in order to have the shear stress parallel to the wall
+              !  B = hflui*( IDENTITY - n x n )
+
+              cofbfut(1,1,ifac) = hint*(1.d0-rnx**2)
+              cofbfut(2,2,ifac) = hint*(1.d0-rny**2)
+              cofbfut(3,3,ifac) = hint*(1.d0-rnz**2)
+
+              cofbfut(1,2,ifac) = - hint*rnx*rny
+              cofbfut(1,3,ifac) = - hint*rnx*rnz
+              cofbfut(2,1,ifac) = - hint*rny*rnx
+              cofbfut(2,3,ifac) = - hint*rny*rnz
+              cofbfut(3,1,ifac) = - hint*rnz*rnx
+              cofbfut(3,2,ifac) = - hint*rnz*rny
 
             endif
 
@@ -1362,9 +1556,32 @@ do ifac = 1, nfabor
               ! The outgoing flux is stored (Q = h(Ti'-Tp): negative if
               !  gain for the fluid) in W/m2
               propfb(ifac,ipprob(ifconv)) = coefa(ifac,iclvaf)              &
-                                          + coefb(ifac,iclvaf)*thbord(ifac)
+                                          + coefb(ifac,iclvaf)*theipb(ifac)
             endif
 
+          endif ! End if icodcl=6
+
+          ! Save the value of T^star and T^+
+          if (iscal.eq.iscalt) then
+            ! Rough wall function
+            if (icodcl(ifac,ivar).eq.6) then
+              phit = coefa(ifac,iclvaf)+coefb(ifac,iclvaf)*theipb(ifac)
+            ! Imposed flux with wall function for post-processing
+            elseif (icodcl(ifac,ivar).eq.3) then
+              phit = rcodcl(ifac,ivar,3)
+            else
+              phit = 0.d0
+            endif
+
+            tet = phit/(max(sqrt(uk*uet),epzero))
+
+            if (itplus .ge. 0) tplusp(ifac) = tplus
+            if (itstar .ge. 0) tstarp(ifac) = tet
+
+            tetmax = max(tet, tetmax)
+            tetmin = min(tet, tetmin)
+            tplumx = max(tplus,tplumx)
+            tplumn = min(tplus,tplumn)
           endif
 
         endif
@@ -1382,23 +1599,20 @@ enddo
 
 if (irangp.ge.0) then
   call parmin (uiptmn)
-  !==========
   call parmax (uiptmx)
-  !==========
   call parmin (uetmin)
-  !==========
   call parmax (uetmax)
-  !==========
   call parmin (ukmin)
-  !==========
   call parmax (ukmax)
-  !==========
   call parmin (yplumn)
-  !==========
   call parmax (yplumx)
-  !==========
   call parcpt (iuiptn)
-  !==========
+  if (iscalt.gt.0) then
+    call parmin (tetmin)
+    call parmax (tetmax)
+    call parmin (tplumn)
+    call parmax (tplumx)
+  endif
 endif
 
 !===============================================================================
@@ -1421,7 +1635,11 @@ if (iwarni(iu).ge.0) then
     modntl = 1
   endif
 
-  if (modntl.eq.0 .or. iwarni(iu).ge.2) then
+  if ((modntl.eq.0 .or. iwarni(iu).ge.2).and.iscalt.gt.0) then
+    write(nfecra,2011) &
+         uiptmn,uiptmx,uetmin,uetmax,ukmin,ukmax,yplumn,yplumx,   &
+         tetmin, tetmax, tplumn, tplumx, iuiptn
+  elseif (modntl.eq.0 .or. iwarni(iu).ge.2) then
     write(nfecra,2010) &
          uiptmn,uiptmx,uetmin,uetmax,ukmin,ukmax,yplumn,yplumx,   &
          iuiptn
@@ -1453,6 +1671,23 @@ endif
  '------------------------------------------------------------',  &
  /,/)
 
+ 2011 format(/,                                                   &
+ 3X,'** CONDITIONS AUX LIMITES EN PAROI RUGUEUSE',/,        &
+ '   -------------------------------------------',/,        &
+ '------------------------------------------------------------',/,&
+ '                                         Minimum     Maximum',/,&
+ '------------------------------------------------------------',/,&
+ '   Vitesse rel. en paroi    uiptn : ',2E12.5                 ,/,&
+ '   Vitesse de frottement    uet   : ',2E12.5                 ,/,&
+ '   Vitesse de frottement    uk    : ',2E12.5                 ,/,&
+ '   Distance adim. rugueuse  yplus : ',2E12.5                 ,/,&
+ '   Sca. thermal de frott.   tstar : ',2E12.5                 ,/,&
+ '   Sca. thermal adim. rug.  tplus : ',2E12.5                 ,/,&
+ '   ------------------------------------------------------'   ,/,&
+ '   Nbre de retournements de la vitesse en paroi : ',I10      ,/,&
+ '------------------------------------------------------------',  &
+ /,/)
+
 
 #else
 
@@ -1474,6 +1709,23 @@ endif
  '------------------------------------------------------------',  &
  /,/)
 
+ 2011 format(/,                                                   &
+ 3X,'** BOUNDARY CONDITIONS FOR ROUGH WALLS',/,             &
+ '   --------------------------------------',/,             &
+ '------------------------------------------------------------',/,&
+ '                                         Minimum     Maximum',/,&
+ '------------------------------------------------------------',/,&
+ '   Rel velocity at the wall uiptn : ',2E12.5                 ,/,&
+ '   Friction velocity        uet   : ',2E12.5                 ,/,&
+ '   Friction velocity        uk    : ',2E12.5                 ,/,&
+ '   Rough dimensionless dist yplus : ',2E12.5                 ,/,&
+ '   Friction thermal sca.    tstar : ',2E12.5                 ,/,&
+ '   Rough dim-less th. sca.  tplus : ',2E12.5                 ,/,&
+ '   ------------------------------------------------------   ',/,&
+ '   Nb of reversal of the velocity at the wall   : ',I10      ,/,&
+ '------------------------------------------------------------',  &
+ /,/)
+
 
 #endif
 
