@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -79,8 +79,6 @@
 
 
 subroutine clsyvt &
-!================
-
  ( nvar   , nscal  ,                                              &
    icodcl ,                                                       &
    dt     , rtp    , rtpa   , propce , propfa , propfb , rcodcl , &
@@ -100,6 +98,7 @@ use cstnum
 use pointe
 use entsor
 use albase
+use field
 use mesh
 
 !===============================================================================
@@ -110,12 +109,12 @@ implicit none
 
 integer          nvar   , nscal
 
-integer          icodcl(nfabor,nvar)
+integer          icodcl(nfabor,nvarcl)
 
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
-double precision rcodcl(nfabor,nvar,3)
+double precision rcodcl(nfabor,nvarcl,3)
 double precision velipb(nfabor,ndim), rijipb(nfabor,6)
 double precision coefa(nfabor,*), coefb(nfabor,*)
 
@@ -129,14 +128,25 @@ integer          icl11r, icl22r, icl33r, icl12r, icl13r, icl23r
 integer          icluf , iclvf , iclwf
 integer          iclumf, iclvmf, iclwmf
 integer          icl11f, icl22f, icl33f, icl12f, icl13f, icl23f
-integer          iclvar, iel, iclvrr
+integer          iclvar, iel   , iclvrr
+integer          iscal , ipccp , ivar
+integer          niturt, iiturt
+integer          f_id
+
 double precision rnx, rny, rnz, rxnn
 double precision upx, upy, upz, usn
 double precision tx, ty, tz, txn, t2x, t2y, t2z
 double precision clsyme
 double precision eloglo(3,3), alpha(6,6)
 double precision srfbnf, rcodcn, hint, visclc, visctc, distbf
+double precision cpp,rkl
 double precision vismsh(3), hintv(3)
+double precision hintt(6)
+
+character*80     fname
+
+double precision, dimension(:,:), pointer :: coefaut, cofafut, cofarut
+double precision, dimension(:,:,:), pointer :: coefbut, cofbfut, cofbrut
 
 !===============================================================================
 
@@ -152,8 +162,16 @@ icl33 = 0
 icl12 = 0
 icl13 = 0
 icl23 = 0
+icl11r = 0
+icl12r = 0
+icl13r = 0
+icl22r = 0
+icl23r = 0
+icl33r = 0
 iclvar = 0
 
+cpp = 0.d0
+
 ! --- Gradient Boundary Conditions
 iclu   = iclrtp(iu ,icoef)
 iclv   = iclrtp(iv ,icoef)
@@ -330,7 +348,7 @@ do ifac = 1, nfabor
     !                     a homogenous Neumann on the other components
     !===========================================================================
 
-    coefa(ifac,iclu) = rcodcn*rnx - rnx*(rny*upy+rnz*upz) !FIXME with the new formulation
+    coefa(ifac,iclu) = rcodcn*rnx - rnx*(rny*upy+rnz*upz)
     coefb(ifac,iclu) = 1.d0-rnx**2
     coefa(ifac,iclv) = rcodcn*rny - rny*(rnz*upz+rnx*upx)
     coefb(ifac,iclv) = 1.d0-rny**2
@@ -472,6 +490,106 @@ do ifac = 1, nfabor
 
     endif
 
+    !===========================================================================
+    ! 3.bis Boundary conditions on u'T'
+    !===========================================================================
+
+    do iscal = 1, nscal
+
+      if (ityturt(iscal).eq.3) then
+        ivar = isca(iscal)
+        ! Name of the scalar ivar !TODO move outside of the loop
+        call field_get_name(ivarfl(ivar), fname)
+
+        ! Index of the corresponding turbulent flux
+        call field_get_id(trim(fname)//'_turbulent_flux', f_id)
+
+        call field_get_coefa_v(f_id,coefaut)
+        call field_get_coefb_v(f_id,coefbut)
+        call field_get_coefaf_v(f_id,cofafut)
+        call field_get_coefbf_v(f_id,cofbfut)
+        call field_get_coefad_v(f_id,cofarut)
+        call field_get_coefbd_v(f_id,cofbrut)
+
+        iel = ifabor(ifac)
+        ! --- Physical Propreties
+        visclc = propce(iel,ipproc(iviscl))
+        if (icp.gt.0) then
+          ipccp  = ipproc(icp)
+        else
+          ipccp = 0
+        endif
+        if (iscsth(iscal).eq.0.or.iscsth(iscal).eq.2.or.iscsth(iscal).eq.3) then
+          cpp = 1.d0
+        elseif (abs(iscsth(iscal)).eq.1.and.(ipccp.gt.0)) then
+          cpp = propce(iel,ipccp)
+        elseif (abs(iscsth(iscal)).eq.1) then
+          cpp = cp0
+        endif
+
+        ! --- Geometrical quantities
+        distbf = distb(ifac)
+
+        if (ivisls(iscal).le.0) then
+          rkl = visls0(iscal)/cpp
+        else
+          rkl = propce(iel,ipproc(ivisls(iscal)))/cpp
+        endif
+
+        hintt(1) = 0.5d0*(visclc+rkl)/distbf                        &
+                 + visten(1,iel)*ctheta(iscal)/distbf
+        hintt(2) = 0.5d0*(visclc+rkl)/distbf                        &
+                 + visten(2,iel)*ctheta(iscal)/distbf
+        hintt(3) = 0.5d0*(visclc+rkl)/distbf                        &
+                 + visten(3,iel)*ctheta(iscal)/distbf
+        hintt(4) = visten(4,iel)*ctheta(iscal)/distbf
+        hintt(5) = visten(5,iel)*ctheta(iscal)/distbf
+        hintt(6) = visten(6,iel)*ctheta(iscal)/distbf
+
+        ! Gradient BCs
+        coefaut(1,ifac) = 0.d0
+        coefaut(2,ifac) = 0.d0
+        coefaut(3,ifac) = 0.d0
+
+        coefbut(1,1,ifac) = 1.d0-rnx**2
+        coefbut(2,2,ifac) = 1.d0-rny**2
+        coefbut(3,3,ifac) = 1.d0-rnz**2
+
+        coefbut(1,2,ifac) = -rnx*rny
+        coefbut(1,3,ifac) = -rnx*rnz
+        coefbut(2,1,ifac) = -rny*rnx
+        coefbut(2,3,ifac) = -rny*rnz
+        coefbut(3,1,ifac) = -rnz*rnx
+        coefbut(3,2,ifac) = -rnz*rny
+
+        ! Flux BCs
+        cofafut(1,ifac) = 0.d0
+        cofafut(2,ifac) = 0.d0
+        cofafut(3,ifac) = 0.d0
+
+        cofbfut(1,1,ifac) = hintt(1)*rnx**2  + hintt(4)*rnx*rny + hintt(6)*rnx*rnz
+        cofbfut(2,2,ifac) = hintt(4)*rnx*rny + hintt(2)*rny**2  + hintt(5)*rny*rnz
+        cofbfut(3,3,ifac) = hintt(6)*rnx*rnz + hintt(5)*rny*rnz + hintt(3)*rnz**2
+
+        cofbfut(1,2,ifac) = hintt(1)*rnx*rny + hintt(4)*rny**2  + hintt(6)*rny*rnz
+        cofbfut(2,1,ifac) = hintt(1)*rnx*rny + hintt(4)*rny**2  + hintt(6)*rny*rnz
+        cofbfut(1,3,ifac) = hintt(1)*rnx*rnz + hintt(4)*rny*rnz + hintt(6)*rnz**2
+        cofbfut(3,1,ifac) = hintt(1)*rnx*rnz + hintt(4)*rny*rnz + hintt(6)*rnz**2
+        cofbfut(2,3,ifac) = hintt(4)*rnx*rnz + hintt(2)*rny*rnz + hintt(5)*rnz**2
+        cofbfut(3,2,ifac) = hintt(4)*rnx*rnz + hintt(2)*rny*rnz + hintt(5)*rnz**2
+
+        ! Boundary conditions for thermal transport equation
+        do isou = 1, 3
+          cofarut(isou,ifac) = coefaut(isou,ifac)
+          do jsou =1, 3
+            cofbrut(isou,jsou,ifac) = coefbut(isou,jsou,ifac)
+          enddo
+        enddo
+
+      endif
+
+    enddo
+
   endif
 ! --- Test sur la presence d'une condition de symetrie vitesse : fin
 
@@ -526,6 +644,8 @@ if (iale.eq.1) then
   do ifac = 1, nfabor
     if (icodcl(ifac,iuma).eq.4) then
 
+      iel = ifabor(ifac)
+
       ! For a sliding boundary, the normal velocity is enforced to zero
       ! whereas the other components have an Homogenous Neumann
       ! NB: no recontruction in I' here
