@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -33,7 +33,7 @@
 !>
 !> \f[
 !> f_s^{imp}(a^{n+1}-a^n)
-!> + \divs \left( a^{n+1} \rho \vect {u} - \mu \grad a^{n+1} \right)
+!> + \divs \left( a^{n+1} \rho \vect{u} - \mu \grad a^{n+1} \right)
 !> = Rhs
 !> \f]
 !>
@@ -63,7 +63,6 @@
 !> Be careful, it is forbidden to modify \f$ f_s^{imp} \f$ here!
 !-------------------------------------------------------------------------------
 
-!-------------------------------------------------------------------------------
 !-------------------------------------------------------------------------------
 ! Arguments
 !______________________________________________________________________________.
@@ -110,13 +109,27 @@
 !> \param[in]     imucpp        indicator
 !>                               - 0 do not multiply the convectiv term by Cp
 !>                               - 1 do multiply the convectiv term by Cp
+!> \param[in]     idftnp        indicator
+!>                               - 0 the diffusivity is scalar
+!>                               - 1 the diffusivity is a diagonal tensor
+!>                               - 2 the diffusivity is a symmetric tensor
+!> \param[in]     iswdyp        indicator
+!>                               - 0 no dynamic relaxation
+!>                               - 1 dynamic relaxation depending on
+!>                                 \f$ \delta \varia^k \f$
+!>                               - 2 dynamic relaxation depending on
+!>                                 \f$ \delta \varia^k \f$  and
+!>                                 \f$ \delta \varia^{k-1} \f$
 !> \param[in]     imgrp         indicator
 !>                               - 0 no multi-grid
 !>                               - 1 otherwise
+!> \param[in]     ncymxp        max. number of multigrid cycles
+!> \param[in]     nitmfp        number of equivalent iterations on fine mesh
 !> \param[in]     ipp           index of the variable for post-processing
 !> \param[in]     iwarnp        verbosity
 !> \param[in]     blencp        fraction of upwinding
 !> \param[in]     epsilp        precision pour resol iter
+!> \param[in]     epsrsp        relative precision for the iterative process
 !> \param[in]     epsrgp        relative precision for the gradient
 !>                               reconstruction
 !> \param[in]     climgp        clipping coeffecient for the computation of
@@ -150,10 +163,16 @@
 !>                               at interior faces for the matrix
 !> \param[in]     viscbm        \f$ \mu_\fib \dfrac{S_\fib}{\ipf \centf} \f$
 !>                               at border faces for the matrix
+!> \param[in]     visccm        symmetric cell tensor \f$ \tens{\mu}_\celli \f$
 !> \param[in]     viscfs        \f$ \mu_\fij \dfrac{S_\fij}{\ipf \jpf} \f$
 !>                               at interior faces for the r.h.s.
 !> \param[in]     viscbs        \f$ \mu_\fib \dfrac{S_\fib}{\ipf \centf} \f$
 !>                               at border faces for the r.h.s.
+!> \param[in]     visccs        symmetric cell tensor \f$ \tens{\mu}_\celli \f$
+!> \param[in]     weighf        internal face weight between cells i j in case
+!>                               of tensor diffusion
+!> \param[in]     weighb        boundary face weight for cells i in case
+!>                               of tensor diffusion
 !> \param[in]     rovsdt        \f$ f_s^{imp} \f$
 !> \param[in]     smbrp         Right hand side \f$ Rhs^k \f$
 !> \param[in,out] pvar          current variable
@@ -164,18 +183,17 @@
 !_______________________________________________________________________________
 
 subroutine codits &
-!================
-
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
    pvara  , pvark  ,                                              &
    coefap , coefbp , cofafp , cofbfp , flumas , flumab ,          &
-   viscfm , viscbm , viscfs , viscbs ,                            &
+   viscfm , viscbm , visccm , viscfs , viscbs , visccs ,          &
+   weighf , weighb ,                                              &
    rovsdt , smbrp  , pvar   , dpvar  ,                            &
    xcpp   , eswork )
 
@@ -208,7 +226,7 @@ integer          imrgra , nswrsp , nswrgp , imligp , ircflp
 integer          ischcp , isstpp , iescap , imgrp
 integer          ncymxp , nitmfp
 integer          ipp    , iwarnp
-integer          imucpp
+integer          imucpp , idftnp , iswdyp
 double precision blencp , epsilp , epsrgp , climgp , extrap
 double precision relaxp , thetap , epsrsp
 
@@ -217,7 +235,10 @@ double precision coefap(nfabor), coefbp(nfabor)
 double precision cofafp(nfabor), cofbfp(nfabor)
 double precision flumas(nfac), flumab(nfabor)
 double precision viscfm(nfac), viscbm(nfabor)
+double precision visccm(ncelet)
 double precision viscfs(nfac), viscbs(nfabor)
+double precision visccs(ncelet)
+double precision weighf(2,nfac), weighb(nfabor)
 double precision rovsdt(ncelet), smbrp(ncelet)
 double precision pvar(ncelet)
 double precision dpvar(ncelet)
@@ -234,14 +255,16 @@ integer          inc,isweep,niterf,iccocg,iel,icycle,nswmod
 integer          idimte,itenso,iinvpe, iinvpp
 integer          idtva0
 integer          nagmax, npstmg
-integer          ibsize
+integer          ibsize, iesize
+integer          incp, insqrt
 
-double precision residu, rnorm, ressol, res
-double precision thetex
+double precision residu, rnorm, ressol, rnorm2
+double precision thetex, nadxkm1, nadxk, paxm1ax, paxm1rk, paxkrk, alph, beta
 
 double precision, allocatable, dimension(:) :: dam
 double precision, allocatable, dimension(:,:) :: xam
-double precision, allocatable, dimension(:) :: smbini, w1
+double precision, allocatable, dimension(:) :: smbini, w1, adxk, adxkm1, dpvarm1
+double precision, allocatable, dimension(:) :: rhs0
 
 !===============================================================================
 
@@ -252,6 +275,10 @@ double precision, allocatable, dimension(:) :: smbini, w1
 ! Allocate temporary arrays
 allocate(dam(ncelet), xam(nfac,2))
 allocate(smbini(ncelet))
+if (iswdyp.ge.1) then
+  allocate(adxk(ncelet), adxkm1(ncelet), dpvarm1(ncelet))
+  allocate(rhs0(ncelet))
+endif
 
 ! Names
 chaine = nomvar(ipp)
@@ -263,6 +290,7 @@ if (iconvp.gt.0) isym  = 2
 
 ! Matrix block size
 ibsize = 1
+iesize = 1
 
 ! METHODE DE RESOLUTION ET DEGRE DU PRECOND DE NEUMANN
 !     0 SI CHOIX AUTOMATIQUE GRADCO OU BICGSTAB
@@ -356,7 +384,7 @@ if (imgrp.gt.0) then
   call clmlga &
   !==========
  ( chaine(1:16) ,    lchain ,                                     &
-   isym   , ibsize , nagmax , npstmg , iwarnp ,                   &
+   isym   , ibsize , iesize , nagmax , npstmg , iwarnp ,          &
    ngrmax , ncegrm ,                                              &
    rlxp1  ,                                                       &
    dam    , xam    )
@@ -379,15 +407,16 @@ if (abs(thetex).gt.epzero) then
   inc    = 1
   iccocg = 1
 
-  call bilsc2 &
+  call bilsca &
   !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp ,                                     &
+   ipp    , iwarnp , imucpp , idftnp ,                            &
    blencp , epsrgp , climgp , extrap , relaxp , thetex ,          &
    pvara  , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
-   flumas , flumab , viscfs , viscbs , xcpp    ,                  &
+   flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
+   weighf , weighb ,                                              &
    smbrp  )
 endif
 
@@ -405,7 +434,7 @@ do iel = 1, ncelet
   pvar(iel) = pvark(iel)
 enddo
 
-! In the following, bilsc2 is called with inc=1,
+! In the following, bilsca is called with inc=1,
 ! except for Weight Matrix (nswrsp=-1)
 inc = 1
 if (nswrsp.eq.-1) then
@@ -413,8 +442,6 @@ if (nswrsp.eq.-1) then
   inc = 0
 endif
 
-isweep = 1
-
 ! ---> INCREMENTATION ET RECONSTRUCTION DU SECOND MEMBRE
 
 !  On est entre avec un smb explicite base sur PVARA.
@@ -423,28 +450,50 @@ isweep = 1
 
 !$omp parallel do
 do iel = 1, ncel
-  smbini(iel) = smbini(iel) - rovsdt(iel)*(pvar(iel) - pvara(iel))
-  smbrp(iel)  = smbini(iel)
+  smbrp(iel)  = 0.d0
 enddo
 
 iccocg = 1
 
-call bilsc2 &
+call bilsca &
 !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp ,                                     &
+   ipp    , iwarnp , imucpp , idftnp ,                            &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
-   flumas , flumab , viscfs , viscbs , xcpp   ,                   &
+   flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
+   weighf , weighb ,                                              &
    smbrp  )
 
+if (iswdyp.ge.1) then
+  !$omp parallel do
+  do iel = 1, ncel
+    rhs0(iel) = smbrp(iel)
+    smbini(iel) = smbini(iel) - rovsdt(iel)*(pvar(iel) - pvara(iel))
+    smbrp(iel)  = smbrp(iel) + smbini(iel)
+
+    adxkm1(iel) = 0.d0
+    adxk(iel) = 0.d0
+    dpvar(iel) = 0.d0
+  enddo
+
+  ! ||A.dx^0||^2 = 0
+  nadxk = 0.d0
+
+else
+
+  !$omp parallel do
+  do iel = 1, ncel
+    smbini(iel) = smbini(iel) - rovsdt(iel)*(pvar(iel) - pvara(iel))
+    smbrp(iel)  = smbrp(iel) + smbini(iel)
+  enddo
+endif
+
 ! --- Right hand side residual
 call prodsc(ncel,isqrt,smbrp,smbrp,residu)
 
-res = residu
-
 ! ---> RESIDU DE NORMALISATION
 !    (NORME C.L +TERMES SOURCES+ TERMES DE NON ORTHOGONALITE)
 
@@ -467,14 +516,16 @@ else
   iinvpp = iinvpe
 endif
 
-call promav(isym,ibsize,iinvpp,dam,xam,pvar,w1)
+call promav(isym,ibsize,iesize,iinvpp,dam,xam,pvar,w1)
 
 !$omp parallel do
 do iel = 1, ncel
   w1(iel) = w1(iel) + smbrp(iel)
 enddo
+
 call prodsc(ncel,isqrt,w1,w1,rnorm)
 rnsmbr(ipp) = rnorm
+rnorm2 = rnorm**2
 
 ! Free memory
 deallocate(w1)
@@ -484,47 +535,133 @@ nswmod = max(nswrsp, 1)
 
 ! Reconstruction loop (beginning)
 !--------------------------------
+nbivar(ipp) = 0
+isweep = 1
 
-do while (isweep.le.nswmod.and.res.gt.epsrsp*rnorm)
+do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
 
   ! --- Solving on the increment dpvar
 
-  !$omp parallel do
-  do iel = 1, ncel
-    dpvar(iel) = 0.d0
-  enddo
+  if (iswdyp.ge.1) then
+    !$omp parallel do
+    do iel = 1, ncel
+      dpvarm1(iel) = dpvar(iel)
+      dpvar(iel) = 0.d0
+    enddo
+  else
+    !$omp parallel do
+    do iel = 1, ncel
+      dpvar(iel) = 0.d0
+    enddo
+  endif
 
-  ! Solver reisudal
+  ! Solver residual
   ressol = residu
 
   call invers &
   !==========
- ( cnom   , isym   , ibsize ,                                     &
+ ( cnom   , isym   , ibsize , iesize ,                            &
    ipol   , ireslq , nitmap , imgrp  ,                            &
    ncymxp , nitmfp ,                                              &
    iwarnp , nfecra , niterf , icycle , iinvpe ,                   &
    epsilp , rnorm  , ressol ,                                     &
    dam    , xam    , smbrp  , dpvar  )
 
-  ! Writing
-  nbivar(ipp) = niterf
-  if (abs(rnorm).gt.epzero) then
-    resvar(ipp) = ressol/rnorm
-  else
-    resvar(ipp) = 0.d0
-  endif
+  ! Dynamic relaxation of the system
+  if (iswdyp.ge.1) then
+
+    ! Computation of the variable ralaxation coefficient
+
+    !$omp parallel do
+    do iel = 1, ncelet
+      adxkm1(iel) = adxk(iel)
+      adxk(iel) = - rhs0(iel)
+    enddo
+
+    call bilsca &
+    !==========
+   ( nvar   , nscal  ,                                              &
+     idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
+     ischcp , isstpp , inc    , imrgra , iccocg ,                   &
+     ipp    , iwarnp , imucpp , idftnp ,                            &
+     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
+     dpvar  , dpvar  , coefap , coefbp , cofafp , cofbfp ,          &
+     flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
+     weighf , weighb ,                                              &
+     adxk   )
+
+    insqrt = 0
+
+    ! ||E.dx^(k-1)-E.0||^2
+    nadxkm1 = nadxk
+
+    ! ||E.dx^k-E.0||^2
+    call prodsc(ncel , insqrt , adxk , adxk , nadxk)
+
+    ! < E.dx^k-E.0; r^k >
+    call prodsc(ncel , insqrt , smbrp , adxk , paxkrk)
+
+    ! Relaxation with respect to dx^k and dx^(k-1)
+    if (iswdyp.ge.2) then
+
+      ! < E.dx^(k-1)-E.0; r^k >
+      call prodsc(ncel , insqrt , smbrp , adxkm1 , paxm1rk)
+
+      ! < E.dx^(k-1)-E.0; E.dx^k-E.0 >
+      call prodsc(ncel , insqrt , adxk, adxkm1 , paxm1ax)
+
+      if (nadxkm1.gt.1.d-30*rnorm2.and.                     &
+          (nadxk*nadxkm1-paxm1ax**2).gt.1.d-30*rnorm2) then
+        beta = (paxkrk*paxm1ax - nadxk*paxm1rk)/(nadxk*nadxkm1-paxm1ax**2)
+      else
+        beta = 0.d0
+      endif
+
+    else
+      beta = 0.d0
+      paxm1ax =1.d0
+      paxm1rk = 0.d0
+      paxm1ax = 0.d0
+    endif
+
+    ! The first sweep is not relaxed
+    if (isweep.eq.1) then
+      alph = 1.d0
+      beta = 0.d0
+    elseif (isweep.eq.2) then
+      beta = 0.d0
+      alph = -paxkrk/max(nadxk, 1.d-30*rnorm2)
+    else
+      alph = -(paxkrk + beta*paxm1ax)/max(nadxk, 1.d-30*rnorm2)
+    endif
+
+    ! Writing
+    if (iwarnp.ge.3) then
+      write(nfecra,1200) cnom, isweep, alph, beta, &
+                         paxkrk, nadxk, paxm1rk, nadxkm1, paxm1ax
+    endif
 
-  ! Writing
-  if (iwarnp.ge.3) then
-    write(nfecra,1000) cnom, isweep, residu, rnorm
   endif
 
   ! --- Update the solution with the increment
 
-  !$omp parallel do
-  do iel = 1, ncel
-    pvar(iel) = pvar(iel) + dpvar(iel)
-  enddo
+  if (iswdyp.eq.0) then
+    !$omp parallel do
+    do iel = 1, ncel
+      pvar(iel) = pvar(iel) + dpvar(iel)
+    enddo
+  elseif (iswdyp.eq.1) then
+    if (alph.lt.0.d0) goto 100
+    !$omp parallel do
+    do iel = 1, ncel
+      pvar(iel) = pvar(iel) + alph*dpvar(iel)
+    enddo
+  elseif (iswdyp.ge.2) then
+    !$omp parallel do
+    do iel = 1, ncel
+      pvar(iel) = pvar(iel) + alph*dpvar(iel) + beta*dpvarm1(iel)
+    enddo
+  endif
 
   ! ---> Handle parallelism and periodicity
   !      (periodicity of rotation is not ensured here)
@@ -536,15 +673,11 @@ do while (isweep.le.nswmod.and.res.gt.epsrsp*rnorm)
     endif
   endif
 
-  isweep = isweep + 1
+  ! --- Update the right hand side And compute the new residual
 
-  res = residu
-
-  ! --- Update the right hand side if needed:
-  if (isweep.le.nswmod.and.res.gt.epsrsp*rnorm) then
-
-    iccocg = 0
+  iccocg = 0
 
+  if (iswdyp.eq.0) then
     !$omp parallel do
     do iel = 1, ncel
       ! smbini already contains instationnary terms and mass source terms
@@ -552,27 +685,63 @@ do while (isweep.le.nswmod.and.res.gt.epsrsp*rnorm)
       smbini(iel) = smbini(iel) - rovsdt(iel)*dpvar(iel)
       smbrp(iel)  = smbini(iel)
     enddo
-
-    call bilsc2 &
-    !==========
-   ( nvar   , nscal  ,                                              &
-     idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-     ipp    , iwarnp , imucpp ,                                     &
-     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
-     pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
-     flumas , flumab , viscfs , viscbs , xcpp   ,                   &
-     smbrp  )
-
-    ! --- Convergence test
-    call prodsc(ncel , isqrt , smbrp , smbrp , residu)
-
+  elseif (iswdyp.eq.1) then
+    !$omp parallel do
+    do iel = 1, ncel
+      ! smbini already contains instationnary terms and mass source terms
+      ! of the RHS updated at each sweep
+      smbini(iel) = smbini(iel) - rovsdt(iel)*alph*dpvar(iel)
+      smbrp(iel)  = smbini(iel)
+    enddo
+  elseif (iswdyp.ge.2) then
+    !$omp parallel do
+    do iel = 1, ncel
+      ! smbini already contains instationnary terms and mass source terms
+      ! of the RHS updated at each sweep
+      smbini(iel) = smbini(iel)                                     &
+                  - rovsdt(iel)*(alph*dpvar(iel)+beta*dpvarm1(iel))
+      smbrp(iel)  = smbini(iel)
+    enddo
   endif
 
+  call bilsca &
+  !==========
+ ( nvar   , nscal  ,                                              &
+   idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
+   ischcp , isstpp , inc    , imrgra , iccocg ,                   &
+   ipp    , iwarnp , imucpp , idftnp ,                            &
+   blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
+   pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
+   flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
+   weighf , weighb ,                                              &
+   smbrp  )
+
+  ! --- Convergence test
+  call prodsc(ncel , isqrt , smbrp , smbrp , residu)
+
+  ! Writing
+  nbivar(ipp) = nbivar(ipp) + niterf
+
+  ! Writing
+  if (iwarnp.ge.3) then
+    write(nfecra,1000) cnom, isweep, residu, rnorm
+    write(nfecra,1010) cnom, isweep, niterf
+  endif
+
+  isweep = isweep + 1
+
 enddo
 ! --- Reconstruction loop (end)
 
+100 continue
+
 ! Writing: convergence
+if (abs(rnorm).gt.epzero) then
+  resvar(ipp) = residu/rnorm
+else
+  resvar(ipp) = 0.d0
+endif
+
 if (iwarnp.ge.1) then
   if (residu.le.epsrsp*rnorm) then
     write(nfecra,1000) cnom,isweep-1,residu,rnorm
@@ -580,7 +749,7 @@ if (iwarnp.ge.1) then
 endif
 
 ! Writing: non-convergence
-if (iwarnp.ge.2) then
+if (iwarnp.ge.1) then
   if (isweep.gt.nswmod) then
     write(nfecra,1100) cnom, nswmod
   endif
@@ -608,15 +777,16 @@ if (iescap.gt.0) then
   ! Without relaxation even for a statonnary computation
   idtva0 = 0
 
-  call bilsc2 &
+  call bilsca &
   !==========
  ( nvar   , nscal  ,                                              &
    idtva0 , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp ,                                     &
+   ipp    , iwarnp , imucpp , idftnp ,                            &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
-   flumas , flumab , viscfs , viscbs , xcpp   ,                   &
+   flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
+   weighf , weighb ,                                              &
    smbrp  )
 
   ! Contribution of the current component to the L2 norm stored in eswork
@@ -641,32 +811,46 @@ endif
 ! Free memory
 deallocate(dam, xam)
 deallocate(smbini)
-
+if (iswdyp.ge.1) deallocate(adxk, adxkm1, dpvarm1,rhs0)
 !--------
 ! Formats
 !--------
 
 #if defined(_CS_LANG_FR)
 
- 1000 format (                                                          &
+ 1000 format ( &
  1X,A16,' : CV-DIF-TS',I5,' IT - RES= ',E12.5,' NORME= ', E12.5)
- 1100 format (                                                          &
-'@                                                            ',/,&
-'@ @@ ATTENTION : ',A8 ,' CONVECTION-DIFFUSION-TERMES SOURCES ',/,&
-'@    =========                                               ',/,&
-'@  Nombre d''iterations maximal ',I10   ,' atteint           ',/,&
-'@                                                            '  )
+ 1010 format ( &
+ 1X,A16,' : Current reconstruction sweep = ',I5,' - Sweeps for solver = ',I5)
+ 1100 format ( &
+'@'                                                                 ,/,&
+'@ @@ ATTENTION : ',A8 ,' CONVECTION-DIFFUSION-TERMES SOURCES'      ,/,&
+'@    ========='                                                    ,/,&
+'@  Nombre d''iterations maximal ',I10   ,' atteint'                ,/,&
+'@' )
+1200 format ( &
+ 1X,A16,' Sweep: ',I5,' Dynamic relaxation: alpha = ',E12.5,' beta = ',E12.5,/,&
+'    < dI^k  ; R^k > = ',E12.5,' ||dI^k  ||^2 = ',E12.5                     ,/,&
+'    < dI^k-1; R^k > = ',E12.5,' ||dI^k-1||^2 = ',E12.5                     ,/,&
+'   < dI^k-1; dI^k > = ',E12.5)
 
 #else
 
- 1000 format (                                                          &
+ 1000 format ( &
  1X,A16,' : CV-DIF-TS',I5,' IT - RES= ',E12.5,' NORM= ', E12.5)
- 1100 format (                                                          &
-'@                                                            ',/,&
-'@ @@ WARNING: ',A8 ,' CONVECTION-DIFFUSION-SOURCE TERMS      ',/,&
-'@    ========                                                ',/,&
-'@  Maximum number of iterations ',I10   ,' reached           ',/,&
-'@                                                            '  )
+ 1010 format ( &
+ 1X,A16,' : Current reconstruction sweep = ',I5,' - Sweeps for solver = ',I5)
+ 1100 format ( &
+'@'                                                                 ,/,&
+'@ @@ WARNING: ',A8 ,' CONVECTION-DIFFUSION-SOURCE TERMS'           ,/,&
+'@    ========'                                                     ,/,&
+'@  Maximum number of iterations ',I10   ,' reached'                ,/,&
+'@' )
+1200 format ( &
+ 1X,A16,' Sweep: ',I5,' Dynamic relaxation: alpha = ',E12.5,' beta = ',E12.5,/,&
+'    < dI^k  ; R^k > = ',E12.5,' ||dI^k  ||^2 = ',E12.5                     ,/,&
+'    < dI^k-1; R^k > = ',E12.5,' ||dI^k-1||^2 = ',E12.5                     ,/,&
+'   < dI^k-1; dI^k > = ',E12.5)
 
 #endif
 
