@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -118,13 +118,28 @@
 !>                               - 1 without slope test
 !>                               - 0 with slope test
 !> \param[in]     iescap        compute the predictor indicator if 1
+!> \param[in]     idftnp        indicator
+!>                               - 1 the diffusivity is scalar
+!>                               - 6 the diffusivity is a symmetric tensor
+!> \param[in]     iswdyp        indicator
+!>                               - 0 no dynamic relaxation
+!>                               - 1 dynamic relaxation depending on
+!>                                 \f$ \delta \vect{\varia}^k \f$
+!>                               - 2 dynamic relaxation depending on
+!>                                 \f$ \delta \vect{\varia}^k \f$  and
+!>                                 \f$ \delta \vect{\varia}^{k-1} \f$
 !> \param[in]     imgrp         indicator
 !>                               - 0 no multi-grid
 !>                               - 1 otherwise
-!> \param[in]     ipp*          index of the variable for post-processing
+!> \param[in]     ncymxp        max. number of multigrid cycles
+!> \param[in]     nitmfp        number of equivalent iterations on fine mesh
+!> \param[in]     ippu          index of the variable for post-processing
+!> \param[in]     ippv          index of the variable for post-processing
+!> \param[in]     ippw          index of the variable for post-processing
 !> \param[in]     iwarnp        verbosity
 !> \param[in]     blencp        fraction of upwinding
 !> \param[in]     epsilp        precision pour resol iter
+!> \param[in]     epsrsp        relative precision for the iterative process
 !> \param[in]     epsrgp        relative precision for the gradient
 !>                               reconstruction
 !> \param[in]     climgp        clipping coeffecient for the computation of
@@ -144,13 +159,13 @@
 !>                               If you sub-iter on Navier-Stokes, then
 !>                               it allows to initialize by something else than
 !>                               pvara (usually pvar=pvara)
-!> \param[in]     coefap        boundary condition array for the variable
+!> \param[in]     coefav        boundary condition array for the variable
 !>                               (Explicit part)
-!> \param[in]     coefbp        boundary condition array for the variable
+!> \param[in]     coefbv        boundary condition array for the variable
 !>                               (Impplicit part)
-!> \param[in]     cofafp        boundary condition array for the diffusion
+!> \param[in]     cofafv        boundary condition array for the diffusion
 !>                               of the variable (Explicit part)
-!> \param[in]     cofbfp        boundary condition array for the diffusion
+!> \param[in]     cofbfv        boundary condition array for the diffusion
 !>                               of the variable (Implicit part)
 !> \param[in]     flumas        mass flux at interior faces
 !> \param[in]     flumab        mass flux at boundary faces
@@ -170,12 +185,10 @@
 !_______________________________________________________________________________
 
 subroutine coditv &
-!================
-
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp , ivisep ,          &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , idftnp , iswdyp ,                   &
    imgrp  , ncymxp , nitmfp , ippu   , ippv   , ippw   , iwarnp , &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
@@ -184,7 +197,7 @@ subroutine coditv &
    flumas , flumab ,                                              &
    viscfm , viscbm , viscfs , viscbs , secvif , secvib ,          &
    fimp   ,                                                       &
-   smbr   ,                                                       &
+   smbrp  ,                                                       &
    pvar   ,                                                       &
    eswork )
 
@@ -214,6 +227,7 @@ integer          idtvar , ivar   , iconvp , idiffp , ndircp
 integer          nitmap
 integer          imrgra , nswrsp , nswrgp , imligp , ircflp
 integer          ischcp , isstpp , iescap , imgrp
+integer          idftnp , iswdyp
 integer          ncymxp , nitmfp
 integer          iwarnp
 integer          ippu   , ippv   , ippw   , ivisep
@@ -228,11 +242,11 @@ double precision cofafv(3,ndimfb)
 double precision coefbv(3,3,ndimfb)
 double precision cofbfv(3,3,ndimfb)
 double precision flumas(nfac), flumab(nfabor)
-double precision viscfm(nfac), viscbm(nfabor)
-double precision viscfs(nfac), viscbs(nfabor)
+double precision viscfm(*), viscbm(nfabor)
+double precision viscfs(*), viscbs(nfabor)
 double precision secvif(nfac), secvib(nfabor)
 double precision fimp(3,3,ncelet)
-double precision smbr(3,ncelet)
+double precision smbrp(3,ncelet)
 double precision eswork(3,ncelet)
 
 ! Local variables
@@ -245,15 +259,19 @@ integer          inc,isweep,niterf,iel,icycle,nswmod
 integer          iinvpe
 integer          idtva0
 integer          nagmax, npstmg
-double precision thetex
-
 integer          isou , jsou, ifac
-integer          ibsize
-double precision residu, rnorm, ressol, res
+integer          ibsize, iesize
+integer          incp, insqrt
+
+double precision residu, rnorm, ressol, rnorm2
+double precision thetex
+double precision alph, beta
+double precision paxkrk, nadxk, paxm1rk, nadxkm1, paxm1ax
 
 double precision, allocatable, dimension(:,:,:) :: dam
 double precision, allocatable, dimension(:,:) :: xam
 double precision, allocatable, dimension(:,:) :: dpvar, smbini, w1
+double precision, allocatable, dimension(:,:) :: adxk, adxkm1, dpvarm1, rhs0
 
 !===============================================================================
 
@@ -261,10 +279,21 @@ double precision, allocatable, dimension(:,:) :: dpvar, smbini, w1
 ! 0.  Initialization
 !===============================================================================
 
+! Matrix block size
+ibsize = 3
+if (idftnp.eq.1) iesize = 1
+if (idftnp.eq.6) iesize = 3
+
 ! Allocate temporary arrays
+allocate(dam(3,3,ncelet))
 ! be carefull here, xam is interleaved
-allocate(dam(3,3,ncelet), xam(2,nfac))
+if (iesize.eq.1) allocate(xam(2,nfac))
+if (iesize.eq.3) allocate(xam(3*3*2,nfac))
 allocate(dpvar(3,ncelet), smbini(3,ncelet))
+if (iswdyp.ge.1) then
+  allocate(adxk(3,ncelet), adxkm1(3,ncelet), dpvarm1(3,ncelet))
+  allocate(rhs0(3,ncelet))
+endif
 
 ! Names
 chaine = nomvar(ippu)
@@ -278,9 +307,6 @@ cnom(3)= chaine(1:16)
 isym  = 1
 if (iconvp.gt.0) isym  = 2
 
-! Matrix block size
-ibsize = 3
-
 ! METHODE DE RESOLUTION ET DEGRE DU PRECOND DE NEUMANN
 !     0 SI CHOIX AUTOMATIQUE GRADCO OU BICGSTAB
 !     0 SI CHOIX AUTOMATIQUE JACOBI
@@ -307,20 +333,35 @@ iinvpe = 0
 ! 1.  Building of the "simplified" matrix
 !===============================================================================
 
-! xam is the same for the 3 components
+if (iesize.eq.1) then
 
-call matrxv &
-!==========
- ( ncelet , ncel   , nfac   , nfabor ,                            &
-   iconvp , idiffp , ndircp , isym   , nfecra ,                   &
-   thetap ,                                                       &
-   ifacel , ifabor ,                                              &
-   coefbv , cofbfv , fimp   ,                                     &
-   flumas , flumab , viscfm , viscbm ,                            &
-   dam    , xam    )
+  call matrxv &
+  !==========
+   ( ncelet , ncel   , nfac   , nfabor ,                            &
+     iconvp , idiffp , ndircp , isym   , nfecra ,                   &
+     thetap ,                                                       &
+     ifacel , ifabor ,                                              &
+     coefbv , cofbfv , fimp   ,                                     &
+     flumas , flumab , viscfm , viscbm ,                            &
+     dam    , xam    )
+
+elseif (iesize.eq.3) then
+
+  call matrvv &
+  !==========
+   ( ncelet , ncel   , nfac   , nfabor ,                            &
+     iconvp , idiffp , ndircp , isym   , nfecra ,                   &
+     thetap ,                                                       &
+     ifacel , ifabor ,                                              &
+     coefbv , cofbfv , fimp   ,                                     &
+     flumas , flumab , viscfm , viscbm ,                            &
+     dam    , xam    )
+
+endif
 
 ! For stationary computations, the diagonal is relaxed
 if (idtvar.lt.0) then
+  !$omp parallel do private(isou, jsou)
   do iel = 1, ncel
     do isou = 1, 3
       do jsou = 1, 3
@@ -347,7 +388,7 @@ if (imgrp.gt.0) then
   call clmlga &
   !==========
  ( chaine(1:16) ,    lchain ,                                     &
-   isym   , ibsize , nagmax , npstmg , iwarnp ,                   &
+   isym   , ibsize , iesize , nagmax , npstmg , iwarnp ,          &
    ngrmax , ncegrm ,                                              &
    rlxp1  ,                                                       &
    dam    , xam    )
@@ -369,35 +410,38 @@ thetex = 1.d0 - thetap
 if (abs(thetex).gt.epzero) then
   inc    = 1
 
-  call bilsc4 &
+  call bilscv &
   !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , ivisep ,                   &
-   ippu   , ippv   , ippw   , iwarnp ,                            &
+   ippu   , ippv   , ippw   , iwarnp , idftnp ,                   &
    blencp , epsrgp , climgp , extrap , relaxp , thetex ,          &
    pvar   , pvara  ,                                              &
    coefav , coefbv , cofafv , cofbfv ,                            &
    flumas , flumab , viscfs , viscbs , secvif , secvib ,          &
-   smbr   )
+   smbrp  )
 endif
 
 ! Before looping, the RHS without reconstruction is stored in smbini
 
+!$omp parallel do private(isou)
 do iel = 1, ncel
   do isou = 1, 3
-    smbini(isou,iel) = smbr(isou,iel)
+    smbini(isou,iel) = smbrp(isou,iel)
   enddo
 enddo
 
 ! pvar is initialized on ncelet to avoid a synchronization
+
+!$omp parallel do private(isou)
 do iel = 1, ncelet
   do isou = 1, 3
     pvar(isou,iel) = pvark(isou,iel)
   enddo
 enddo
 
-! In the following, bilsc4 is called with inc=1,
+! In the following, bilscv is called with inc=1,
 ! except for Weight Matrix (nswrsp=-1)
 inc = 1
 if (nswrsp.eq.-1) then
@@ -410,43 +454,76 @@ endif
 !  On est entre avec un smb explicite base sur PVARA.
 !     si on initialise avec PVAR avec autre chose que PVARA
 !     on doit donc corriger SMBR (c'est le cas lorsqu'on itere sur navsto)
+
+!$omp parallel do private(isou)
 do iel = 1, ncel
   do isou = 1, 3
-    smbini(isou,iel) = smbini(isou,iel)                        &
-               -fimp(isou,1,iel)*(pvar(1,iel) - pvara(1,iel))  &
-               -fimp(isou,2,iel)*(pvar(2,iel) - pvara(2,iel))  &
-               -fimp(isou,3,iel)*(pvar(3,iel) - pvara(3,iel))
-    smbr(isou,iel) = smbini(isou,iel)
+    smbrp(isou,iel) = 0.d0
   enddo
 enddo
 
-call bilsc4 &
+call bilscv &
 !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , ivisep ,                   &
-   ippu   , ippv   , ippw   , iwarnp ,                            &
+   ippu   , ippv   , ippw   , iwarnp , idftnp ,                   &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  ,                                              &
    coefav , coefbv , cofafv , cofbfv ,                            &
    flumas , flumab , viscfs , viscbs , secvif , secvib ,          &
-   smbr   )
+   smbrp  )
+
+! Dynamic relaxation
+if (iswdyp.ge.1) then
+
+  !$omp parallel do private(isou)
+  do iel = 1, ncel
+    do isou = 1, 3
+      rhs0(isou,iel) = smbrp(isou,iel)
+      smbini(isou,iel) = smbini(isou,iel)                        &
+                 -fimp(isou,1,iel)*(pvar(1,iel) - pvara(1,iel))  &
+                 -fimp(isou,2,iel)*(pvar(2,iel) - pvara(2,iel))  &
+                 -fimp(isou,3,iel)*(pvar(3,iel) - pvara(3,iel))
+      smbrp(isou,iel) = smbrp(isou,iel) + smbini(isou,iel)
+
+      adxkm1(isou,iel) = 0.d0
+      adxk(isou,iel) = 0.d0
+      dpvar(isou,iel) = 0.d0
+    enddo
+  enddo
+
+  ! ||A.dx^0||^2 = 0
+  nadxk = 0.d0
+
+else
+
+  !$omp parallel do private(isou)
+  do iel = 1, ncel
+    do isou = 1, 3
+      smbini(isou,iel) = smbini(isou,iel)                        &
+                 -fimp(isou,1,iel)*(pvar(1,iel) - pvara(1,iel))  &
+                 -fimp(isou,2,iel)*(pvar(2,iel) - pvara(2,iel))  &
+                 -fimp(isou,3,iel)*(pvar(3,iel) - pvara(3,iel))
+      smbrp(isou,iel) = smbrp(isou,iel) + smbini(isou,iel)
+    enddo
+  enddo
+endif
 
 ! --- Convergence test
-call prodsc(3*ncel, isqrt, smbr, smbr, residu)
-
-res = residu
+call prodsc(3*ncel, isqrt, smbrp, smbrp, residu)
 
 ! ---> RESIDU DE NORMALISATION
 !    (NORME C.L +TERMES SOURCES+ TERMES DE NON ORTHOGONALITE)
 
 allocate(w1(3, ncelet))  ! Allocate a temporary array
 
-call promav(isym, ibsize, iinvpe, dam, xam, pvar, w1)
+call promav(isym, ibsize, iesize, iinvpe, dam, xam, pvar, w1)
 
+!$omp parallel do private(isou)
 do iel = 1, ncel
    do isou = 1, 3
-      w1(isou,iel) = w1(isou,iel) + smbr(isou,iel)
+      w1(isou,iel) = w1(isou,iel) + smbrp(isou,iel)
    enddo
 enddo
 
@@ -455,6 +532,7 @@ call prodsc(3*ncel, isqrt, w1, w1, rnorm)
 rnsmbr(ippu) = rnorm
 rnsmbr(ippv) = rnorm
 rnsmbr(ippw) = rnorm
+rnorm2 = rnorm**2
 
 deallocate(w1)  ! Free memory
 
@@ -465,16 +543,33 @@ isweep = 1
 
 ! Reconstruction loop (beginning)
 !--------------------------------
+nbivar(ippu) = 0
+nbivar(ippv) = 0
+nbivar(ippw) = 0
 
-do while (isweep.le.nswmod.and.res.gt.epsrsp*rnorm)
+do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
 
   ! --- Solving on the increment dpvar
 
-  do iel = 1, ncelet
-    do isou =1,3
-      dpvar(isou,iel) = 0.d0
+  ! Dynamic relaxation of the system
+  if (iswdyp.ge.1) then
+
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      do isou =1,3
+        dpvarm1(isou,iel) = dpvar(isou,iel)
+        dpvar(isou,iel) = 0.d0
+      enddo
     enddo
-  enddo
+  else
+
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      do isou =1,3
+        dpvar(isou,iel) = 0.d0
+      enddo
+    enddo
+  endif
 
   ! iinvpe is useless in the vectorial framework
   iinvpe = 0
@@ -482,43 +577,124 @@ do while (isweep.le.nswmod.and.res.gt.epsrsp*rnorm)
   ! Matrix block size
   ibsize = 3
 
+  ! Solver residual
+  ressol = residu
+
   call invers &
   !==========
- ( cnom(1), isym   , ibsize , ipol   , ireslq , nitmap , imgrp  , &
+ ( cnom(1), isym   , ibsize , iesize ,                            &
+   ipol   , ireslq , nitmap , imgrp  ,                            &
    ncymxp , nitmfp ,                                              &
    iwarnp , nfecra , niterf , icycle , iinvpe ,                   &
-   epsilp , rnorm  , residu          ,                            &
-   dam    , xam    , smbr   , dpvar  )
+   epsilp , rnorm  , ressol ,                                     &
+   dam    , xam    , smbrp  , dpvar  )
 
-  nbivar(ippu) = niterf
-  nbivar(ippv) = niterf
-  nbivar(ippw) = niterf
+  ! Dynamic relaxation of the system
+  if (iswdyp.ge.1) then
 
-  ! Writing
-  if (abs(rnorm)/sqrt(3.d0).gt.epzero) then
-    resvar(ippu) = residu/rnorm
-    resvar(ippv) = residu/rnorm
-    resvar(ippw) = residu/rnorm
-  else
-    resvar(ippu) = 0.d0
-    resvar(ippv) = 0.d0
-    resvar(ippw) = 0.d0
-  endif
+    ! Computation of the variable ralaxation coefficient
+
+    !$omp parallel do private(isou)
+    do iel = 1, ncelet
+      do isou = 1, 3
+        adxkm1(isou,iel) = adxk(isou,iel)
+        adxk(isou,iel) = - rhs0(isou,iel)
+      enddo
+    enddo
+
+    call bilscv &
+    !==========
+   ( nvar   , nscal  ,                                              &
+     idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
+     ischcp , isstpp , incp   , imrgra , ivisep ,                   &
+     ippu   , ippv   , ippw   , iwarnp , idftnp ,                   &
+     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
+     dpvar  , dpvar  ,                                              &
+     coefav , coefbv , cofafv , cofbfv ,                            &
+     flumas , flumab , viscfs , viscbs , secvif , secvib ,          &
+     adxk   )
+
+    insqrt = 0
+
+    ! ||E.dx^(k-1)-E.0||^2
+    nadxkm1 = nadxk
+
+    ! ||E.dx^k-E.0||^2
+    call prodsc(3*ncel , insqrt , adxk , adxk , nadxk)
+
+    ! < E.dx^k-E.0; r^k >
+    call prodsc(3*ncel , insqrt , smbrp , adxk , paxkrk)
+
+    ! Relaxation with respect to dx^k and dx^(k-1)
+    if (iswdyp.ge.2) then
+
+      ! < E.dx^(k-1)-E.0; r^k >
+      call prodsc(3*ncel , insqrt , smbrp , adxkm1 , paxm1rk)
+
+      ! < E.dx^(k-1)-E.0; E.dx^k-E.0 >
+      call prodsc(3*ncel , insqrt , adxk, adxkm1 , paxm1ax)
+
+      if (nadxkm1.gt.1.d-30*rnorm2.and.                     &
+          (nadxk*nadxkm1-paxm1ax**2).gt.1.d-30*rnorm2) then
+        beta = (paxkrk*paxm1ax - nadxk*paxm1rk)/(nadxk*nadxkm1-paxm1ax**2)
+      else
+        beta = 0.d0
+      endif
+
+    else
+      beta = 0.d0
+      paxm1ax =1.d0
+      paxm1rk = 0.d0
+      paxm1ax = 0.d0
+    endif
+
+    ! The first sweep is not relaxed
+    if (isweep.eq.1) then
+      alph = 1.d0
+      beta = 0.d0
+    elseif (isweep.eq.2) then
+      beta = 0.d0
+      alph = -paxkrk/max(nadxk, 1.d-30*rnorm2)
+    else
+      alph = -(paxkrk + beta*paxm1ax)/max(nadxk, 1.d-30*rnorm2)
+    endif
+
+    ! Writing
+    if (iwarnp.ge.3) then
+      write(nfecra,1200) cnom, isweep, alph, beta, &
+                         paxkrk, nadxk, paxm1rk, nadxkm1, paxm1ax
+    endif
 
-  ! Writing
-  if (iwarnp.ge.3) then
-     write(nfecra,1000) cnom(1), isweep, residu, rnorm
-     write(nfecra,1000) cnom(2), isweep, residu, rnorm
-     write(nfecra,1000) cnom(3), isweep, residu, rnorm
   endif
 
   ! --- Update the solution with the increment
 
-  do iel = 1, ncelet
-    do isou = 1, 3
-       pvar(isou,iel) = pvar(isou,iel) + dpvar(isou,iel)
+  if (iswdyp.eq.0) then
+
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      do isou = 1, 3
+         pvar(isou,iel) = pvar(isou,iel) + dpvar(isou,iel)
+      enddo
     enddo
-  enddo
+  elseif (iswdyp.eq.1) then
+
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      do isou = 1, 3
+         pvar(isou,iel) = pvar(isou,iel) + alph*dpvar(isou,iel)
+      enddo
+    enddo
+  elseif (iswdyp.ge.2) then
+
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      do isou = 1, 3
+         pvar(isou,iel) = pvar(isou,iel) + alph*dpvar(isou,iel)  &
+                        + beta*dpvarm1(isou,iel)
+      enddo
+    enddo
+  endif
 
   ! ---> Handle parallelism and periodicity
 
@@ -526,46 +702,96 @@ do while (isweep.le.nswmod.and.res.gt.epsrsp*rnorm)
     call synvin(pvar)
   endif
 
-  isweep = isweep + 1
+  ! --- Update the right hand and compute the new residual
 
-  res = residu
-
-  ! --- Update the right hand side if needed:
-  if (isweep.le.nswmod.and.res.gt.epsrsp*rnorm) then
+  if (iswdyp.eq.0) then
 
+    !$omp parallel do private(isou)
     do iel = 1, ncel
       ! smbini already contains instationnary terms and mass source terms
       ! of the RHS updated at each sweep
-      do isou=1,3
+      do isou = 1, 3
         smbini(isou,iel) = smbini(isou,iel)                 &
                   - fimp(isou,1,iel)*dpvar(1,iel)           &
                   - fimp(isou,2,iel)*dpvar(2,iel)           &
                   - fimp(isou,3,iel)*dpvar(3,iel)
-        smbr(isou,iel) = smbini(isou,iel)
+        smbrp(isou,iel) = smbini(isou,iel)
       enddo
     enddo
 
-    call bilsc4 &
-    !==========
-   ( nvar   , nscal  ,                                              &
-     idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , inc    , imrgra , ivisep ,                   &
-     ippu   , ippv   , ippw   , iwarnp ,                            &
-     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
-     pvar   , pvara  ,                                              &
-     coefav , coefbv , cofafv , cofbfv ,                            &
-     flumas , flumab , viscfs , viscbs , secvif , secvib ,          &
-     smbr   )
+  elseif (iswdyp.eq.1) then
 
-    ! --- Convergence test
-    call prodsc(3*ncel, isqrt, smbr, smbr, residu)
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      ! smbini already contains instationnary terms and mass source terms
+      ! of the RHS updated at each sweep
+      do isou = 1, 3
+        smbini(isou,iel) = smbini(isou,iel)                 &
+                  - fimp(isou,1,iel)*alph*dpvar(1,iel)      &
+                  - fimp(isou,2,iel)*alph*dpvar(2,iel)      &
+                  - fimp(isou,3,iel)*alph*dpvar(3,iel)
+        smbrp(isou,iel) = smbini(isou,iel)
+      enddo
+    enddo
 
+  elseif (iswdyp.eq.2) then
+
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      ! smbini already contains instationnary terms and mass source terms
+      ! of the RHS updated at each sweep
+      do isou = 1, 3
+        smbini(isou,iel) = smbini(isou,iel)                                  &
+                  - fimp(isou,1,iel)*(alph*dpvar(1,iel)+beta*dpvarm1(1,iel)) &
+                  - fimp(isou,2,iel)*(alph*dpvar(2,iel)+beta*dpvarm1(2,iel)) &
+                  - fimp(isou,3,iel)*(alph*dpvar(3,iel)+beta*dpvarm1(3,iel))
+        smbrp(isou,iel) = smbini(isou,iel)
+      enddo
+    enddo
   endif
 
+  call bilscv &
+  !==========
+ ( nvar   , nscal  ,                                              &
+   idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
+   ischcp , isstpp , inc    , imrgra , ivisep ,                   &
+   ippu   , ippv   , ippw   , iwarnp , idftnp ,                   &
+   blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
+   pvar   , pvara  ,                                              &
+   coefav , coefbv , cofafv , cofbfv ,                            &
+   flumas , flumab , viscfs , viscbs , secvif , secvib ,          &
+   smbrp  )
+
+  ! --- Convergence test
+  call prodsc(3*ncel, isqrt, smbrp, smbrp, residu)
+
+  ! Writing
+  nbivar(ippu) = nbivar(ippu) + niterf
+  nbivar(ippv) = nbivar(ippv) + niterf
+  nbivar(ippw) = nbivar(ippw) + niterf
+  ! Writing
+  if (iwarnp.ge.3) then
+     write(nfecra,1000) cnom(1), isweep, residu, rnorm
+     write(nfecra,1000) cnom(2), isweep, residu, rnorm
+     write(nfecra,1000) cnom(3), isweep, residu, rnorm
+  endif
+
+  isweep = isweep + 1
+
 enddo
 ! --- Reconstruction loop (end)
 
 ! Writing: convergence
+if (abs(rnorm)/sqrt(3.d0).gt.epzero) then
+  resvar(ippu) = residu/rnorm
+  resvar(ippv) = residu/rnorm
+  resvar(ippw) = residu/rnorm
+else
+  resvar(ippu) = 0.d0
+  resvar(ippv) = 0.d0
+  resvar(ippw) = 0.d0
+endif
+
 if (iwarnp.ge.1) then
   if (residu.le.epsrsp*rnorm) then
     write(nfecra,1000) cnom(1),isweep-1,residu,rnorm
@@ -575,7 +801,7 @@ if (iwarnp.ge.1) then
 endif
 
 ! Writing: non-convergence
-if (iwarnp.ge.2) then
+if (iwarnp.ge.1) then
   if (isweep.gt.nswmod) then
     write(nfecra,1100) cnom(1), nswmod
     write(nfecra,1100) cnom(2), nswmod
@@ -595,11 +821,12 @@ if (iescap.gt.0) then
   ! smbini already contains instationnary terms and mass source terms
   ! of the RHS updated at each sweep
 
+  !$omp parallel do private(isou)
   do iel = 1, ncel
     do isou = 1, 3
-      smbr(isou,iel) = smbini(isou,iel) - fimp(isou,1,iel)*dpvar(1,iel) &
-                                        - fimp(isou,2,iel)*dpvar(2,iel) &
-                                        - fimp(isou,3,iel)*dpvar(3,iel)
+      smbrp(isou,iel) = smbini(isou,iel) - fimp(isou,1,iel)*dpvar(1,iel) &
+                                         - fimp(isou,2,iel)*dpvar(2,iel) &
+                                         - fimp(isou,3,iel)*dpvar(3,iel)
     enddo
   enddo
 
@@ -607,23 +834,24 @@ if (iescap.gt.0) then
   ! Without relaxation even for a statonnary computation
   idtva0 = 0
 
-  call bilsc4 &
+  call bilscv &
   !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , ivisep ,                   &
-   ippu   , ippv   , ippw   , iwarnp ,                            &
+   ippu   , ippv   , ippw   , iwarnp , idftnp ,                   &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  ,                                              &
    coefav , coefbv , cofafv , cofbfv ,                            &
    flumas , flumab , viscfs , viscbs , secvif , secvib ,          &
-   smbr   )
+   smbrp   )
 
   ! Contribution of the current component to the L2 norm stored in eswork
 
+  !$omp parallel do private(isou)
   do iel = 1, ncel
     do isou = 1, 3
-      eswork(isou,iel) = (smbr(isou,iel)/ volume(iel))**2
+      eswork(isou,iel) = (smbrp(isou,iel)/ volume(iel))**2
     enddo
   enddo
 
@@ -639,31 +867,46 @@ if (imgrp.gt.0) then
   call dsmlga(chaine(1:16), lchain)
 endif
 
+! Free memory
+deallocate(dam, xam)
+deallocate(dpvar, smbini)
+if (iswdyp.ge.1) deallocate(adxk, adxkm1, dpvarm1, rhs0)
+
 !--------
 ! Formats
 !--------
 
 #if defined(_CS_LANG_FR)
 
- 1000 format (                                                          &
+ 1000 format ( &
  1X,A16,' : CV-DIF-TS',I5,' IT - RES= ',E12.5,' NORME= ', E12.5)
- 1100 format (                                                          &
-'@                                                            ',/,&
-'@ @@ ATTENTION : ',A8 ,' CONVECTION-DIFFUSION-TERMES SOURCES ',/,&
-'@    =========                                               ',/,&
-'@  Nombre d''iterations maximal ',I10   ,' atteint           ',/,&
-'@                                                            '  )
+ 1100 format ( &
+'@'                                                                 ,/,&
+'@ @@ ATTENTION : ',A8 ,' CONVECTION-DIFFUSION-TERMES SOURCES'      ,/,&
+'@    ========='                                                    ,/,&
+'@  Nombre d''iterations maximal ',I10   ,' atteint'                ,/,&
+'@' )
+ 1200 format ( &
+ 1X,A16,' Sweep: ',I5,' Dynamic relaxation: alpha = ',E12.5,' beta = ',E12.5,/,&
+'    < dI^k  ; R^k > = ',E12.5,' ||dI^k  ||^2 = ',E12.5                     ,/,&
+'    < dI^k-1; R^k > = ',E12.5,' ||dI^k-1||^2 = ',E12.5                     ,/,&
+'   < dI^k-1; dI^k > = ',E12.5)
 
 #else
 
- 1000 format (                                                          &
+ 1000 format ( &
  1X,A16,' : CV-DIF-TS',I5,' IT - RES= ',E12.5,' NORM= ', E12.5)
- 1100 format (                                                          &
-'@                                                            ',/,&
-'@ @@ WARNING: ',A8 ,' CONVECTION-DIFFUSION-SOURCE TERMS      ',/,&
-'@    ========                                                ',/,&
-'@  Maximum number of iterations ',I10   ,' reached           ',/,&
-'@                                                            '  )
+ 1100 format ( &
+'@'                                                                 ,/,&
+'@ @@ WARNING: ',A8 ,' CONVECTION-DIFFUSION-SOURCE TERMS'           ,/,&
+'@    ========'                                                     ,/,&
+'@  Maximum number of iterations ',I10   ,' reached'                ,/,&
+'@' )
+ 1200 format ( &
+ 1X,A16,' Sweep: ',I5,' Dynamic relaxation: alpha = ',E12.5,' beta = ',E12.5,/,&
+'    < dI^k  ; R^k > = ',E12.5,' ||dI^k  ||^2 = ',E12.5                     ,/,&
+'    < dI^k-1; R^k > = ',E12.5,' ||dI^k-1||^2 = ',E12.5                     ,/,&
+'   < dI^k-1; dI^k > = ',E12.5)
 
 #endif
 
