@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -93,8 +93,8 @@ implicit none
 
 integer          nfabor
 integer          nvar , nscal
-integer          isvtb  , icodcl(nfabor,nvar)
-double precision rcodcl(nfabor,nvar,3)
+integer          isvtb  , icodcl(nfabor,nvarcl)
+double precision rcodcl(nfabor,nvarcl,3)
 
 ! Local variables
 
