@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -223,12 +223,11 @@ do inbcou = 1, nbccou
       iccfth = 7
       imodif = 0
 
-      call uscfth                                                   &
+      call cfther                                                   &
       !==========
     ( nvar   , nscal  ,                                              &
       iccfth , imodif ,                                              &
       dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-      coefa  , coefb  ,                                              &
       wa(iepsel) , wa(iepsfa) , wa(igamag) , wa(ixmasm) )
       !---------   ---------
 
