@@ -149,8 +149,10 @@ static _cs_base_sighandler_t cs_glob_base_sigcpu_save = SIG_DFL;
 
 static const char _cs_base_build_localedir[] = LOCALEDIR;
 static const char _cs_base_build_pkgdatadir[] = PKGDATADIR;
+static const char _cs_base_build_pkglibdir[] = PKGLIBDIR;
 static char *_cs_base_env_localedir = NULL;
 static char *_cs_base_env_pkgdatadir = NULL;
+static char *_cs_base_env_pkglibdir = NULL;
 
 /* Log file */
 
@@ -306,6 +308,15 @@ _cs_base_exit(int status)
 
     MPI_Initialized(&mpi_flag);
 
+#if (MPI_VERSION >= 2)
+    if (mpi_flag != 0) {
+      int finalized_flag;
+      MPI_Finalized(&finalized_flag);
+      if (finalized_flag != 0)
+        mpi_flag = 0;
+    }
+#endif
+
     if (mpi_flag != 0) {
 
       if (status != EXIT_SUCCESS)
@@ -567,9 +578,9 @@ _cs_base_sig_fatal(int  signum)
  *----------------------------------------------------------------------------*/
 
 static const char *
-_get_path(const char  *dir_path,
-          const char  *build_path,
-          char        *env_path)
+_get_path(const char   *dir_path,
+          const char   *build_path,
+          char        **env_path)
 {
 #if defined(HAVE_RELOCATABLE)
   {
@@ -578,8 +589,8 @@ _get_path(const char  *dir_path,
 
     /* Allow for displacable install */
 
-    if (env_path != NULL)
-      return env_path;
+    if (*env_path != NULL)
+      return *env_path;
 
     /* First try with an environment variable CS_ROOT_DIR */
 
@@ -588,12 +599,18 @@ _get_path(const char  *dir_path,
       rel_path = "/";
     }
 
+    /* Second try with an environment variable CFDSTUDY_ROOT_DIR */
+
+    else if (getenv("CFDSTUDY_ROOT_DIR") != NULL) {
+      cs_root_dir = getenv("CFDSTUDY_ROOT_DIR");
+      rel_path = "/";
+    }
+
 #if defined(HAVE_GETCWD)
 
     /*
-      Then, try to guess a relative path, knowing that executables can be:
-      - in libexecdir/code_saturne [default]
-      - in bin [windows]
+      Then, try to guess a relative path, knowing that executables are
+      located in libexecdir/code_saturne
     */
 
     else {
@@ -610,23 +627,19 @@ _get_path(const char  *dir_path,
                     _("Error querying working directory.\n"));
       }
 
-#if defined(WIN32) || defined(_WIN32)
-      rel_path = "/../";
-#else
       rel_path = "/../../";
-#endif
 
     }
 #endif /* defined(HAVE_GETCWD) */
 
-    BFT_MALLOC(env_path,
+    BFT_MALLOC(*env_path,
                strlen(cs_root_dir) + strlen(rel_path) + strlen(dir_path) + 1,
                char);
-    strcpy(env_path, cs_root_dir);
-    strcat(env_path, rel_path);
-    strcat(env_path, dir_path);
+    strcpy(*env_path, cs_root_dir);
+    strcat(*env_path, rel_path);
+    strcat(*env_path, dir_path);
 
-    return env_path;
+    return *env_path;
   }
 #endif /* defined(HAVE_RELOCATABLE) */
 
@@ -929,32 +942,69 @@ cs_base_logfile_head(int    argc,
   /* Define MPI Information */
 
 #if defined(MPI_SUBVERSION)
-#if defined(OPEN_MPI)
+
+  char mpi_vendor_lib[32] = "";
+  char mpi_lib[32] = "";
+
+  /* Base MPI library information */
+
+#if defined(MPI_VENDOR_NAME)
+
 #if defined(OMPI_MAJOR_VERSION)
-  char mpi_lib[32];
-  snprintf(mpi_lib, 31, "Open MPI %d.%d.%d",
-          OMPI_MAJOR_VERSION, OMPI_MINOR_VERSION, OMPI_RELEASE_VERSION);
-  mpi_lib[31] = '\0';
+  snprintf(mpi_lib, 31, "%s %d.%d.%d",
+           MPI_VENDOR_NAME,
+           OMPI_MAJOR_VERSION, OMPI_MINOR_VERSION, OMPI_RELEASE_VERSION);
+#elif defined(MPICH2_VERSION)
+  snprintf(mpi_lib, 31, "%s %s", MPI_VENDOR_NAME, MPICH2_VERSION);
+#elif defined(MPICH_VERSION)
+  snprintf(mpi_lib, 31, "%s %s", MPI_VENDOR_NAME, MPICH_VERSION);
 #else
-  const char mpi_lib[] = "Open MPI";
+  snprintf(mpi_lib, 31, "%s", MPI_VENDOR_NAME);
 #endif
+
+#elif defined(OPEN_MPI)
+#if defined(OMPI_MAJOR_VERSION)
+  snprintf(mpi_lib, 31, "Open MPI %d.%d.%d",
+           OMPI_MAJOR_VERSION, OMPI_MINOR_VERSION, OMPI_RELEASE_VERSION);
+#else
+  snprintf(mpi_lib, 31, "Open MPI");
+#endif
+
 #elif defined(MPICH2)
 #if defined(MPICH2_VERSION)
-  char mpi_lib[32];
   snprintf(mpi_lib, 31, "MPICH2 %s", MPICH2_VERSION);
-  mpi_lib[31] = '\0';
 #else
-  const char mpi_lib[] = "MPICH2";
+  snprintf(mpi_lib, 31, "MPICH2");
 #endif
-#elif defined(LAM_MPI)
-  const char mpi_lib[] = "LAM/MPI";
 #elif defined(MPICH_NAME)
-  const char mpi_lib[] = "MPICH";
-#elif defined(HP_MPI)
-  const char mpi_lib[] = "HP-MPI";
-#elif defined(MPI_SUBVERSION)
-  const char *mpi_lib = NULL;
+#if defined(MPICH_VERSION)
+  snprintf(mpi_lib, 31, "MPICH %s", MPICH_VERSION);
+#else
+  snprintf(mpi_lib, 31, "MPICH");
 #endif
+
+#elif defined(LAM_MPI)
+#if defined(LAM_VERSION)
+  snprintf(mpi_lib, 31, "LAM/MPI %s", LAM_VERSION);
+#else
+  snprintf(mpi_lib, 31, "LAM/MPI");
+#endif
+#endif
+
+  mpi_lib[31] = '\0';
+
+  /* Possible additional MPI vendor information */
+
+#if defined(MVAPICH2_VERSION)
+  snprintf(mpi_vendor_lib, 31, "MVAPICH2 %s", MVAPICH2_VERSION);
+#elif defined(MSMPI_VER)
+  snprintf(mpi_vendor_lib, 31, "MS-MPI");
+#elif defined(HP_MPI)
+  snprintf(mpi_vendor_lib, 31, "HP-MPI");
+#endif
+
+  mpi_vendor_lib[31] = '\0';
+
 #endif /* defined(MPI_SUBVERSION) */
 
   /* Determine compilation date */
@@ -1002,12 +1052,22 @@ cs_base_logfile_head(int    argc,
   bft_printf(_("  build %s\n"), str);
 
 #if defined(MPI_SUBVERSION)
-  if (mpi_lib != NULL)
-    bft_printf(_("  MPI version %d.%d (%s)\n\n"),
-               MPI_VERSION, MPI_SUBVERSION, mpi_lib);
-  else
-    bft_printf(_("  MPI version %d.%d\n\n"),
-               MPI_VERSION, MPI_SUBVERSION);
+  if (mpi_vendor_lib[0] != '\0') {
+    if (mpi_lib[0] != '\0')
+      bft_printf(_("  MPI version %d.%d (%s, based on %s)\n\n"),
+                 MPI_VERSION, MPI_SUBVERSION, mpi_vendor_lib, mpi_lib);
+    else
+      bft_printf(_("  MPI version %d.%d (%s)\n\n"),
+                 MPI_VERSION, MPI_SUBVERSION, mpi_vendor_lib);
+  }
+  else {
+    if (mpi_lib[0] != '\0')
+      bft_printf(_("  MPI version %d.%d (%s)\n\n"),
+                 MPI_VERSION, MPI_SUBVERSION, mpi_lib);
+    else
+      bft_printf(_("  MPI version %d.%d\n\n"),
+                 MPI_VERSION, MPI_SUBVERSION);
+  }
 #endif
 
   bft_printf("\n");
@@ -1059,11 +1119,18 @@ cs_base_mpi_init(int    *argc,
 
   use_mpi = true;
 
-#elif defined(MPICH2)
+#elif defined(MPICH) || defined(MPICH2) || defined(MSMPI_VER)
+
+  /* Notes: Microsoft MPI is based on standard MPICH2 */
+
   if (getenv("PMI_RANK") != NULL)
     use_mpi = true;
 
-#elif defined(MPICH_NAME)
+  else if (getenv("PCMPI") != NULL) /* Platform MPI */
+    use_mpi = true;
+
+#if defined(MPICH_NAME)
+#if (MPICH_NAME == 1)
 
   /*
     Using standard MPICH1 1.2.x with the p4 (default) mechanism,
@@ -1086,6 +1153,9 @@ cs_base_mpi_init(int    *argc,
   if (getenv("GMPI_ID") != NULL) /* In case we are using MPICH-GM */
     use_mpi = true;
 
+#endif /* End for MPICH-1 or variants */
+#endif
+
 #elif defined(LAM_MPI)
   if (getenv("LAMRANK") != NULL)
     use_mpi = true;
@@ -1420,6 +1490,7 @@ cs_base_mem_finalize(void)
 
     BFT_FREE(_cs_base_env_localedir);
     BFT_FREE(_cs_base_env_pkgdatadir);
+    BFT_FREE(_cs_base_env_pkglibdir);
     BFT_FREE(_bft_printf_file_name);
 
     bft_mem_end();
@@ -1805,7 +1876,7 @@ cs_base_get_localedir(void)
 {
   return _get_path("share/locale",
                    _cs_base_build_localedir,
-                   _cs_base_env_localedir);
+                   &_cs_base_env_localedir);
 }
 
 /*----------------------------------------------------------------------------
@@ -1820,7 +1891,25 @@ cs_base_get_pkgdatadir(void)
 {
   return _get_path("share/" PACKAGE_NAME,
                    _cs_base_build_pkgdatadir,
-                   _cs_base_env_pkgdatadir);
+                   &_cs_base_env_pkgdatadir);
+}
+
+/*----------------------------------------------------------------------------
+ * Return a string providing loadable library path information.
+ *
+ * This is normally the path determined upon configuration, but may be
+ * adapted for movable installs using the CS_ROOT_DIR environment variable.
+ *
+ * returns:
+ *   package loadable library (plugin) path
+ *----------------------------------------------------------------------------*/
+
+const char *
+cs_base_get_pkglibdir(void)
+{
+  return _get_path("lib/" PACKAGE_NAME,
+                   _cs_base_build_pkglibdir,
+                   &_cs_base_env_pkglibdir);
 }
 
 /*----------------------------------------------------------------------------*/
