@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -441,6 +441,21 @@ cs_halo_perio_sync_var_tens(const cs_halo_t *halo,
                             cs_halo_type_t   sync_mode,
                             cs_real_t        var[]);
 
+/*----------------------------------------------------------------------------
+ * Synchronize values for a real tensor (symmetric interleaved) between
+ * periodic cells.
+ *
+ * parameters:
+ *   halo      <-> halo associated with variable to synchronize
+ *   sync_mode --> kind of halo treatment (standard or extended)
+ *   var       <-> symmetric tensor to update (6 values)
+ *----------------------------------------------------------------------------*/
+
+void
+cs_halo_perio_sync_var_sym_tens(const cs_halo_t  *halo,
+                                cs_halo_type_t    sync_mode,
+                                cs_real_t         var[]);
+
 /*----------------------------------------------------------------------------
  * Synchronize values for a real diagonal tensor between periodic cells.
  *
