@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -36,6 +36,10 @@
 #include <string.h>
 #include <time.h>
 
+#if defined(__bgq__)
+#include <unistd.h>
+#endif
+
 #if defined(HAVE_MPI)
 #include <mpi.h>
 #endif
@@ -120,12 +124,6 @@ _arg_env_help(const char  *name)
     (e, _(" --mpi             force use of MPI for parallelism or coupling\n"
           "                   (usually automatic, only required for\n"
           "                   undetermined MPI libraries)\n"));
-  fprintf
-    (e, _(" --mpi-io          <mode> set parallel I/O behavior\n"
-          "                     off: do not use MPI-IO\n"
-          "                     eo:  MPI-IO with explicit offsets\n"
-          "                          (default if available)\n"
-          "                     ip:  MPI-IO with individual file pointers\n"));
   fprintf
     (e, _(" --log             output redirection for rank -1 or 0:\n"
           "                     0: standard output\n"
@@ -147,6 +145,11 @@ _arg_env_help(const char  *name)
 
   fprintf
     (e, _(" --version         print version number\n"));
+
+#if defined(__bgq__)
+  fprintf
+    (e, _(" -wdir, --wdir     <path> working directory\n"));
+#endif
 }
 
 /*----------------------------------------------------------------------------
@@ -226,6 +229,7 @@ cs_opts_define(int         argc,
   /* Local variables */
 
   const char *s;
+  const char *s_param = NULL;
   int arg_id = 0, argerr = 0;
 
   const char moduleoptbase[] = "--yacs-module=";
@@ -237,8 +241,6 @@ cs_opts_define(int         argc,
   opts->ilisr0 = 1;
   opts->ilisrp = 2;
 
-  opts->mpi_io_mode = -1;
-
   opts->preprocess = false;
   opts->verif = false;
   opts->benchmark = 0;
@@ -269,6 +271,24 @@ cs_opts_define(int         argc,
       }
     }
 
+#if defined(__bgq__)
+
+    else if (strcmp(s, "-wdir") == 0 || strcmp(s, "--wdir") == 0) {
+      if (arg_id + 1 < argc) {
+        s = argv[++arg_id];
+        if (chdir(s) != 0) {
+          fprintf(stderr, _("Error switching to directory \"%s\":\n\n"
+                            "%s\n"),
+                  s, strerror(errno));
+          cs_exit(EXIT_FAILURE);
+        }
+      }
+      else
+        argerr = 1;
+    }
+
+#endif
+
     else if (strcmp(s, "--log") == 0) {
       int n1 = 0;
       n1 = _arg_to_int(++arg_id, argc, argv, &argerr);
@@ -299,27 +319,9 @@ cs_opts_define(int         argc,
       /* Handled in pre-reading stage */
     }
 
-    else if (strcmp(s, "--mpi-io") == 0) {
-      if (arg_id + 1 < argc) {
-        const char *s_n = argv[arg_id + 1];
-        if (strcmp(s_n, "off") == 0)
-          opts->mpi_io_mode = 0;
-        else if (strcmp(s_n, "eo") == 0)
-          opts->mpi_io_mode = 1;
-        else if (strcmp(s_n, "ip") == 0)
-          opts->mpi_io_mode = 2;
-        else
-          argerr = 1;
-        if (argerr == 0)
-          arg_id++;
-      }
-      else
-        argerr = 1;
-    }
-
 #else /* !defined(HAVE_MPI) */
 
-    else if ((strcmp(s, "--mpi") == 0) || (strcmp(s, "--mpi-io") == 0)) {
+    else if (strcmp(s, "--mpi") == 0) {
       fprintf(stderr, _("%s was built without MPI support,\n"
                         "so option \"%s\" may not be used.\n"),
               argv[0], s);
@@ -330,15 +332,13 @@ cs_opts_define(int         argc,
 
     else if (strcmp(s, "-p") == 0 || strcmp(s, "--param") == 0) {
       if (arg_id + 1 < argc) {
-        s = argv[++arg_id];
-#if defined(HAVE_LIBXML2)
-        argerr = cs_gui_load_file(s);
-#else
+        s_param = argv[++arg_id];
+#if !defined(HAVE_LIBXML2)
         fprintf(stderr, _("%s was built without XML support,\n"
                           "so parameter file \"%s\" may not be loaded.\n"),
-                argv[0], s);
+                argv[0], s_param);
         cs_exit(EXIT_FAILURE);
-#endif /* defined(HAVE_LIBXML2) */
+#endif /* !defined(HAVE_LIBXML2) */
       }
       else
         argerr = 1;
@@ -402,6 +402,16 @@ cs_opts_define(int         argc,
       cs_exit(EXIT_SUCCESS);
   }
 
+#if defined(HAVE_LIBXML2)
+  if (s_param != NULL) {
+    if (cs_gui_load_file(s_param) != 0) {
+      fprintf(stderr, _("Error loading parameter file \"%s\".\n"),
+              s_param);
+      cs_exit(EXIT_FAILURE);
+    }
+  }
+#endif
+
   /* If application name has not been defined, use working directory
      base name as default. */
 
