@@ -31,6 +31,7 @@
  *----------------------------------------------------------------------------*/
 
 #include <assert.h>
+#include <ctype.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,12 +46,14 @@
 
 #include "cs_base.h"
 #include "cs_field.h"
+#include "cs_lagr_tracking.h"
 #include "cs_log.h"
 #include "cs_mesh.h"
 #include "cs_mesh_connect.h"
 #include "cs_mesh_location.h"
 #include "cs_prototypes.h"
 #include "cs_selector.h"
+#include "cs_time_step.h"
 
 #include "cs_post.h"
 
@@ -78,6 +81,14 @@ typedef struct {
   const cs_int_t   *nvlsta;
   const cs_int_t   *nvisbr;
 
+  const cs_int_t   *nbpmax;
+  const cs_int_t   *nvp;
+  const cs_int_t   *nvp1;
+  const cs_int_t   *nvep;
+  const cs_int_t   *nivep;
+
+  const cs_int_t   *itepa;
+
   const cs_real_t  *dt;
   const cs_real_t  *rtpa;
   const cs_real_t  *rtp;
@@ -90,6 +101,10 @@ typedef struct {
   const cs_real_t  *stativ;
   const cs_real_t  *statfb;
 
+  /* Lagrangian variables */
+
+  bool  particle_attr[CS_LAGR_N_ATTRIBUTES];
+
 } cs_post_default_input_t;
 
 /*============================================================================
@@ -105,6 +120,56 @@ static bool                     _default_input_is_set = false;
  * Private function definitions
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Default additional particle output of mesh and time-dependent variables
+ * for the call to pstvar / cs_post_write_vars.
+ *
+ * Note: if the input pointer is non-NULL, it must point to valid data
+ * when the output function is called, so either:
+ * - that value or structure should not be temporary (i.e. local);
+ * - post-processing output must be ensured using cs_post_write_var()
+ *   or similar before the data pointed to goes out of scope.
+ *
+ * parameters:
+ *   input       <-> pointer to optional (untyped) value or structure;
+ *                   here, we should point to _default_input.
+ *   mesh_id     <-- id of the output mesh for the current call
+ *   cat_id      <-- category id of the output mesh for the current call
+ *   ts          <-- time step status structure
+ *----------------------------------------------------------------------------*/
+
+static void
+_write_particle_vars(cs_post_default_input_t  *input,
+                     int                       mesh_id,
+                     const cs_time_step_t     *ts)
+{
+  cs_lagr_attribute_t attr_id;
+
+  char var_name[64];
+
+  for (attr_id = 0; attr_id < CS_LAGR_N_ATTRIBUTES; attr_id++)
+
+    if (input->particle_attr[attr_id]) {
+
+      /* build name */
+
+      int i;
+      int l = snprintf(var_name,
+                       63,
+                       "particle_%s",
+                       cs_lagr_attribute_name[attr_id] + strlen("cs_lagr_"));
+      var_name[63] = '\0';
+      for (i = 0; i < l; i++)
+        var_name[i] = tolower(var_name[i]);
+
+      /* Output values */
+
+      cs_post_write_particle_values(mesh_id, attr_id, var_name, ts);
+
+    }
+
+}
+
 /*----------------------------------------------------------------------------
  * Default additional output of mesh and time-dependent variables for the
  * call to pstvar / cs_post_write_vars.
@@ -121,39 +186,36 @@ static bool                     _default_input_is_set = false;
  *   mesh_id     <-- id of the output mesh for the current call
  *   cat_id      <-- category id of the output mesh for the current call
  *   ent_flag    <-- indicate global presence of cells (ent_flag[0]), interior
- *                   faces (ent_flag[1]), or boundary faces (ent_flag[2])
+ *                   faces (ent_flag[1]), boundary faces (ent_flag[2]),
+ *                   or particles (ent_flag[3])
  *   n_cells     <-- local number of cells of post_mesh
  *   n_i_faces   <-- local number of interior faces of post_mesh
  *   n_b_faces   <-- local number of boundary faces of post_mesh
  *   cell_list   <-- list of cells (1 to n) of post-processing mesh
  *   i_face_list <-- list of interior faces (1 to n) of post-processing mesh
  *   b_face_list <-- list of boundary faces (1 to n) of post-processing mesh
- *   nt_cur_abs  <-- current time step number
- *   t_cur_abs   <-- current physical time
- *   nt_cur_abs  <-- current time step number
- *   t_cur_abs   <-- absolute time at the current time step
+ *   ts          <-- time step status structure
  *----------------------------------------------------------------------------*/
 
 static void
-_write_additional_vars(void             *input,
-                       int               mesh_id,
-                       int               cat_id,
-                       int               ent_flag[3],
-                       cs_lnum_t         n_cells,
-                       cs_lnum_t         n_i_faces,
-                       cs_lnum_t         n_b_faces,
-                       const cs_lnum_t   cell_list[],
-                       const cs_lnum_t   i_face_list[],
-                       const cs_lnum_t   b_face_list[],
-                       int               nt_cur_abs,
-                       cs_real_t         t_cur_abs)
+_write_additional_vars(void                  *input,
+                       int                    mesh_id,
+                       int                    cat_id,
+                       int                    ent_flag[4],
+                       cs_lnum_t              n_cells,
+                       cs_lnum_t              n_i_faces,
+                       cs_lnum_t              n_b_faces,
+                       const cs_lnum_t        cell_list[],
+                       const cs_lnum_t        i_face_list[],
+                       const cs_lnum_t        b_face_list[],
+                       const cs_time_step_t  *ts)
 {
   /* Local variables */
 
   cs_post_default_input_t  *_input = input;
 
   int i;
-  cs_int_t   itypps[3];
+  cs_int_t   itypps[4];
   cs_int_t   nummai = mesh_id;
   cs_int_t   numtyp = cat_id;
 
@@ -161,9 +223,16 @@ _write_additional_vars(void             *input,
   cs_real_t  *cel_vals = NULL;
   cs_real_t  *b_face_vals = NULL;
 
+  /* Specific handling for particle meshes */
+
+  if (cat_id == -3) {
+    _write_particle_vars(_input, mesh_id, ts);
+    return;
+  }
+
   /* Basic initialization */
 
-  for (i = 0; i < 3; i++)
+  for (i = 0; i < 4; i++)
     itypps[i] = ent_flag[i];
 
  /* Allocate work array to build variables */
@@ -230,17 +299,27 @@ _write_additional_vars(void             *input,
  * *****************
  *                  ( ntcabs,
  *                    nvar,   nscal,  nvlsta, nvisbr,
+ *                    nbpmax, nvp, nvp1, nvep, nivep,
  *                    ttcabs,
+ *                    itepa,
  *                    dt,     rtpa,   rtp,    propce, propfa, propfb,
  *                    coefa,  coefb,
- *                    statce, stativ, statfb )
+ *                    statce, stativ, statfb,
+ *                    ettp, ettpa, tepa )
  *
  * integer          ntcabs      : --> : current time step number
  * integer          nvar        : <-- : number of variables
  * integer          nscal       : <-- : number of scalars
  * integer          nvlsta      : <-- : number of statistical variables (lagr)
  * integer          nvisbr      : <-- : number of boundary stat. variables (lagr)
+ * integer          nbpmax      : <-- : maximum number of particles allowed
+ * integer          nvp         : <-- : number of particle variables
+ * integer          nvp1        : <-- : nvp less position, fluid and
+ *                              :     : particle velocity
+ * integer          nvep        : <-- : number of real particle attributes
+ * integer          nivep       : <-- : number of interger particle attributes
  * double precision ttcabs      : <-- : current physical time
+ * integer          itepa       : <-- : integer particle attributes
  * double precision dt          : <-- : local time step
  * double precision rtpa        : <-- : cell variables at previous time step
  * double precision rtp         : <-- : cell variables
@@ -261,7 +340,13 @@ void CS_PROCF (pstvar, PSTVAR)
  const cs_int_t   *nscal,
  const cs_int_t   *nvlsta,
  const cs_int_t   *nvisbr,
+ const cs_int_t   *nbpmax,
+ const cs_int_t   *nvp,
+ const cs_int_t   *nvp1,
+ const cs_int_t   *nvep,
+ const cs_int_t   *nivep,
  const cs_real_t  *ttcabs,
+ const cs_int_t    itepa[],
  const cs_real_t   dt[],
  const cs_real_t   rtpa[],
  const cs_real_t   rtp[],
@@ -275,6 +360,8 @@ void CS_PROCF (pstvar, PSTVAR)
  const cs_real_t   statfb[]
 )
 {
+  cs_lagr_attribute_t p_attr;
+
   /* Define or update map of variables */
 
   _default_input.nvar = nvar;
@@ -283,6 +370,14 @@ void CS_PROCF (pstvar, PSTVAR)
   _default_input.nvlsta = nvlsta;
   _default_input.nvisbr = nvisbr;
 
+  _default_input.nbpmax = nbpmax;
+  _default_input.nvp = nvp;
+  _default_input.nvp1 = nvp1;
+  _default_input.nvep = nvep;
+  _default_input.nivep = nivep;
+
+  _default_input.itepa = itepa;
+
   _default_input.dt = dt;
   _default_input.rtpa = rtpa;
   _default_input.rtp = rtp;
@@ -307,7 +402,78 @@ void CS_PROCF (pstvar, PSTVAR)
 
   /* Call main post-processing function */
 
-  cs_post_write_vars(*ntcabs, *ttcabs);
+  if (*ntcabs > -1)
+    cs_post_write_vars(cs_glob_time_step);
+  else
+    cs_post_write_vars(NULL);
+}
+
+/*----------------------------------------------------------------------------
+ * Define which Lagragian variables should be postprocessed
+ *
+ * Fortran interface:
+ *
+ * subroutine lagpvr
+ * *****************
+ *                  ( ivisv1, ivisv2, ivistp, ivisdm, iviste,
+ *                    ivismp, ivisdk, ivisch, ivisck )
+ *
+ * integer          ivisv1      : <-- : display of variable 'fluid velocity'
+ * integer          ivisv2      : <-- : display of variable 'particles velocity'
+ * integer          ivistp      : <-- : display of variable 'resident time'
+ * integer          ivisdm      : <-- : display of variable 'particle diameter'
+ * integer          iviste      : <-- : display of variable 'particle temperature'
+ * integer          ivismp      : <-- : display of variable 'particle mass'
+ * integer          ivisdk      : <-- : display of variable 'core diameter of part.'
+ * integer          ivisch      : <-- : display of variable 'mass of reactive coal'
+ * integer          ivisck      : <-- : display of variable 'mass of char'
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (lagpvr, LAGPVR)
+(
+ const cs_int_t  *ivisv1,
+ const cs_int_t  *ivisv2,
+ const cs_int_t  *ivistp,
+ const cs_int_t  *ivisdm,
+ const cs_int_t  *iviste,
+ const cs_int_t  *ivismp,
+ const cs_int_t  *ivisdk,
+ const cs_int_t  *ivisch,
+ const cs_int_t  *ivisck
+)
+{
+  cs_lagr_attribute_t attr_id;
+
+  for (attr_id = 0; attr_id < CS_LAGR_N_ATTRIBUTES; attr_id++)
+    _default_input.particle_attr[attr_id] = false;
+
+  if (*ivisv1)
+    _default_input.particle_attr[CS_LAGR_VELOCITY] = true;
+
+  if (*ivisv2)
+    _default_input.particle_attr[CS_LAGR_VELOCITY_SEEN] = true;
+
+  if (*ivistp)
+    _default_input.particle_attr[CS_LAGR_RESIDENCE_TIME] = true;
+
+  if (*ivisdm)
+    _default_input.particle_attr[CS_LAGR_DIAMETER] = true;
+
+  if (*iviste)
+    _default_input.particle_attr[CS_LAGR_TEMPERATURE] = true;
+
+  if (*ivismp)
+    _default_input.particle_attr[CS_LAGR_MASS] = true;
+
+  if (*ivisdk)
+    _default_input.particle_attr[CS_LAGR_SHRINKING_DIAMETER] = true;
+
+  if (*ivisch)
+    _default_input.particle_attr[CS_LAGR_COAL_MASS] = true;
+
+  if (*ivisck)
+    _default_input.particle_attr[CS_LAGR_COKE_MASS] = true;
+
 }
 
 /*============================================================================
