@@ -53,7 +53,6 @@
  *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "fvm_io_num.h"
 #include "fvm_periodicity.h"
 
 #include "cs_base.h"
@@ -1937,28 +1936,21 @@ _clean_groups(cs_mesh_t  *mesh)
  *
  * Fortran Interface:
  *
- * subroutine ledevi(nfml, nprfml, iperio, iperot)
+ * subroutine ledevi(iperio, iperot)
  * *****************
  *
- * integer          nfml        : <-- : Number of families
- * integer          nprfml      : <-- : Number of properties per family
  * integer          iperio      : <-- : Periodicity indicator
  * integer          iperot      : <-- : Number of rotation periodicities
  *----------------------------------------------------------------------------*/
 
 void
-CS_PROCF(ledevi, LEDEVI)(cs_int_t   *nfml,
-                         cs_int_t   *nprfml,
-                         cs_int_t   *iperio,
+CS_PROCF(ledevi, LEDEVI)(cs_int_t   *iperio,
                          cs_int_t   *iperot)
 {
   cs_mesh_t  *mesh = cs_glob_mesh;
 
   /* Initialize parameter values */
 
-  *nfml = mesh->n_families;
-  *nprfml = mesh->n_max_family_items;
-
   if (mesh->n_init_perio > 0)
     *iperio = 1;
   if (mesh->have_rotation_perio > 0)
