@@ -794,6 +794,134 @@ _sort_local(cs_lnum_t  number[],
   }
 }
 
+/*----------------------------------------------------------------------------
+ * Create a CSR graph structure from a native face-based connectivity.
+ *
+ * parameters:
+ *   n_cells_ext <-- Local number of cells + ghost cells sharing a face
+ *   n_faces     <-- Local number of faces
+ *   face_cell   <-- Face -> cells connectivity (1 to n)
+ *
+ * returns:
+ *   pointer to allocated CSR graph structure.
+ *----------------------------------------------------------------------------*/
+
+static _csr_graph_t *
+_csr_graph_create(cs_lnum_t         n_cells_ext,
+                  cs_lnum_t         n_faces,
+                  const cs_lnum_t  *face_cell)
+{
+  int n_cols_max;
+  cs_lnum_t ii, jj, f_id;
+
+  cs_lnum_t  *ccount = NULL;
+  bool unique_faces = true;
+
+  _csr_graph_t  *g;
+
+  /* Allocate and map */
+
+  BFT_MALLOC(g, 1, _csr_graph_t);
+
+  g->n_rows = n_cells_ext;
+
+  BFT_MALLOC(g->row_index, g->n_rows + 1, cs_lnum_t);
+
+  /* Count number of nonzero elements per row */
+
+  BFT_MALLOC(ccount, g->n_rows, cs_lnum_t);
+
+  for (ii = 0; ii < g->n_rows; ii++)
+    ccount[ii] = 0;
+
+  for (f_id = 0; f_id < n_faces; f_id++) {
+    ii = face_cell[f_id*2] - 1;
+    jj = face_cell[f_id*2 + 1] - 1;
+    ccount[ii] += 1;
+    ccount[jj] += 1;
+  }
+
+  n_cols_max = 0;
+
+  g->row_index[0] = 0;
+  for (ii = 0; ii < g->n_rows; ii++) {
+    g->row_index[ii+1] = g->row_index[ii] + ccount[ii];
+    if (ccount[ii] > n_cols_max)
+      n_cols_max = ccount[ii];
+    ccount[ii] = 0;
+  }
+
+  g->n_cols_max = n_cols_max;
+
+  /* Build structure */
+
+  BFT_MALLOC(g->col_id, (g->row_index[g->n_rows]), cs_lnum_t);
+
+  for (f_id = 0; f_id < n_faces; f_id++) {
+    ii = face_cell[f_id*2] - 1;
+    jj = face_cell[f_id*2 + 1] - 1;
+    g->col_id[g->row_index[ii] + ccount[ii]] = jj;
+    ccount[ii] += 1;
+    g->col_id[g->row_index[jj] + ccount[jj]] = ii;
+    ccount[jj] += 1;
+  }
+
+  BFT_FREE(ccount);
+
+  /* Sort line elements by column id (for better access patterns) */
+
+  if (n_cols_max > 1) {
+
+    for (ii = 0; ii < g->n_rows; ii++) {
+      cs_lnum_t *col_id = g->col_id + g->row_index[ii];
+      cs_lnum_t n_cols = g->row_index[ii+1] - g->row_index[ii];
+      cs_lnum_t col_id_prev = -1;
+      _sort_local(col_id, g->row_index[ii+1] - g->row_index[ii]);
+      for (jj = 0; jj < n_cols; jj++) {
+        if (col_id[jj] == col_id_prev)
+          unique_faces = false;
+        col_id_prev = col_id[jj];
+      }
+    }
+
+  }
+
+  /* Compact elements if necessary */
+
+  if (unique_faces == false) {
+
+    cs_lnum_t *tmp_row_index = NULL;
+    cs_lnum_t  kk = 0;
+
+    BFT_MALLOC(tmp_row_index, g->n_rows+1, cs_lnum_t);
+    memcpy(tmp_row_index, g->row_index, (g->n_rows+1)*sizeof(cs_lnum_t));
+
+    kk = 0;
+
+    for (ii = 0; ii < g->n_rows; ii++) {
+      cs_lnum_t *col_id = g->col_id + g->row_index[ii];
+      cs_lnum_t n_cols = g->row_index[ii+1] - g->row_index[ii];
+      cs_lnum_t col_id_prev = -1;
+      g->row_index[ii] = kk;
+      for (jj = 0; jj < n_cols; jj++) {
+        if (col_id_prev != col_id[jj]) {
+          g->col_id[kk++] = col_id[jj];
+          col_id_prev = col_id[jj];
+        }
+      }
+    }
+    g->row_index[g->n_rows] = kk;
+
+    assert(g->row_index[g->n_rows] < tmp_row_index[g->n_rows]);
+
+    BFT_FREE(tmp_row_index);
+    BFT_REALLOC(g->col_id, (g->row_index[g->n_rows]), cs_lnum_t);
+
+  }
+
+  return g;
+}
+
 /*----------------------------------------------------------------------------
  * Create a CSR graph structure from a native face-based conectivity.
  *
@@ -1859,10 +1987,12 @@ _renum_b_faces_no_share_cell_across_thread(cs_mesh_t   *mesh,
       cs_lnum_t f_id = renum_b[end_id - 1] - 1;
       cs_lnum_t c_num = mesh->b_face_cells[f_id];
       f_id = renum_b[end_id] - 1;
-      while (   end_id < mesh->n_b_faces
-             && mesh->b_face_cells[f_id] == c_num) {
+      while (mesh->b_face_cells[f_id] == c_num) {
         end_id += 1;
-        f_id = renum_b[end_id] - 1;
+        if (end_id < mesh->n_b_faces)
+          f_id = renum_b[end_id] - 1;
+        else
+          break;
       }
     }
 
