@@ -69,6 +69,7 @@
 #include "cs_parall.h"
 #include "cs_post.h"
 #include "cs_selector.h"
+#include "cs_time_step.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -309,14 +310,12 @@ _exchange_sync(cs_syr4_coupling_t  *syr_coupling,
  *
  * parameters:
  *   coupling        <--  Void pointer to SYRTHES coupling structure
- *   nt_cur_abs      <--  Current time step
- *   t_cur_abs       <--  Current time value
+ *   ts              <--  time step status structure, or NULL
  *----------------------------------------------------------------------------*/
 
 static void
-_cs_syr4_coupling_post_function(void       *coupling,
-                                cs_int_t    nt_cur_abs,
-                                cs_real_t   t_cur_abs)
+_cs_syr4_coupling_post_function(void                  *coupling,
+                                const cs_time_step_t  *ts)
 {
   int type_id, var_id;
 
@@ -354,11 +353,10 @@ _cs_syr4_coupling_post_function(void       *coupling,
                             false,
                             false,
                             CS_POST_TYPE_float,
-                            nt_cur_abs,
-                            t_cur_abs,
                             cell_var[var_id],
                             NULL,
-                            face_var[var_id]);
+                            face_var[var_id],
+                            ts);
 
       }
     }
@@ -557,6 +555,8 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
 
   }
 
+  BFT_FREE(coupled_mesh_name);
+
   if (syr_coupling->verbosity > 0) {
     bft_printf(" [ok]\n");
     bft_printf_flush();
@@ -677,13 +677,16 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
     bft_printf_flush();
   }
 
+  if (location_elts != coupling_ent->elts)
+    fvm_nodal_destroy(location_elts);
+
   if (elt_centers != NULL)
     BFT_FREE(elt_centers);
 
   if (syr_coupling->visualization != 0 && locate_on_closest != NULL) {
 
     cs_post_activate_writer(0, 1);
-    cs_post_write_meshes(-1, 0.0);
+    cs_post_write_meshes(cs_glob_time_step);
 
     cs_post_write_var(coupling_ent->post_mesh_id,
                       _("distance_to_solid"),
@@ -691,11 +694,10 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                       false,
                       false, /* use_parent, */
                       CS_POST_TYPE_float,
-                      -1, /* time-independent variable */
-                      0.0,
                       NULL,
                       NULL,
-                      cs_to_syr_dist);
+                      cs_to_syr_dist,
+                      NULL);  /* time-independent variable */
   }
 
   BFT_FREE(cs_to_syr_dist);
@@ -754,7 +756,7 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                                    writer_ids);
 
       cs_post_activate_writer(0, 1);
-      cs_post_write_meshes(-1, 0.0);
+      cs_post_write_meshes(NULL);
 
       cs_post_write_vertex_var(mesh_id,
                                _("distance_to_fluid"),
@@ -762,9 +764,8 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                                false,
                                false, /* use parent */
                                CS_POST_TYPE_float,
-                               -1, /* time-independent variable */
-                               0.0,
-                               syr_to_cs_dist);
+                               syr_to_cs_dist,
+                               NULL); /* time-independent variable */
 
       cs_post_free_mesh(mesh_id);
 
@@ -842,7 +843,7 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                                  writer_ids);
 
     cs_post_activate_writer(0, 1);
-    cs_post_write_meshes(-1, 0.0);
+    cs_post_write_meshes(NULL);
     cs_post_free_mesh(mesh_id);
 
     if (cs_glob_n_ranks > 1)
@@ -855,7 +856,7 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
     bft_printf(_("Coupling with SYRTHES impossible:\n"
                  "%llu element centers from mesh \"%s\"\n"
                  "not located on SYRTHES mesh."),
-               (unsigned long long)n_ext, coupled_mesh_name);
+               (unsigned long long)n_ext, fvm_nodal_get_name(coupling_ent->elts));
 
     /* Ensure clean stop */
 
@@ -863,11 +864,6 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
 
   }
 
-  if (location_elts != coupling_ent->elts)
-    fvm_nodal_destroy(location_elts);
-
-  BFT_FREE(coupled_mesh_name);
-
   return coupling_ent;
 }
 
@@ -1423,7 +1419,19 @@ cs_syr4_coupling_init_mesh(cs_syr4_coupling_t  *syr_coupling)
 
   _exchange_sync(syr_coupling, op_name_send, op_name_recv);
 
-  if (strcmp(op_name_recv, "coupling:start"))
+  if (!strcmp(op_name_recv, "coupling:error:location")) {
+
+    cs_coupling_set_sync_flag(PLE_COUPLING_STOP);
+
+    cs_base_warn(__FILE__, __LINE__);
+
+    bft_printf(_(" Message received from SYRTHES: \"%s\"\n"
+                 " indicates meshes have not been matched correctly.\n\n"
+                 " The calculation will not run.\n\n"),
+               op_name_recv);
+
+  }
+  else if (strcmp(op_name_recv, "coupling:start"))
     bft_error(__FILE__, __LINE__, 0,
               _(" Message received from SYRTHES: \"%s\"\n"
                 " indicates an error or is unexpected."),
