@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -70,7 +70,6 @@ use optcal
 use cstphy
 use cstnum
 use ppppar
-!use coincl !FIXME usefull?
 use parall
 use period
 use mltgrd
@@ -97,8 +96,8 @@ integer          iinvpe
 integer          isqrt , iel   , ifac
 integer          inc   , iccocg, ivar
 integer          isweep, nittot, idtva0
-integer          ibsize, mmprpl, nswrsl
-integer          imucpp
+integer          ibsize, iesize, mmprpl, nswrsl
+integer          imucpp, idftnp
 double precision relaxp, thetap, rnorm, residu, rnoini
 double precision dismax, dismin, hint, pimp, qimp
 
@@ -239,6 +238,7 @@ iinvpe = 0
 if(iperio.eq.1) iinvpe = 1
 isqrt = 1
 ibsize = 1
+iesize = 1
 nswrsl = nswrsy
 110 continue
 
@@ -272,9 +272,9 @@ do isweep = 0, nswrsl
     rtpdp(iel) = 0.d0
   enddo
 
-  call invers                                                     &
+  call invers &
   !==========
- ( nomvar(ipp)     , isym   , ibsize ,                            &
+ ( nomvar(ipp)     , isym   , ibsize , iesize ,                   &
    ipol   , ireslp , nitmay , imgrpy ,                            &
    ncymxp , nitmfp ,                                              &
    iwarny , nfecra , niterf , icycle , iinvpe ,                   &
@@ -297,19 +297,21 @@ do isweep = 0, nswrsl
     inc    = 0
     iccocg = 1
     imucpp = 0
+    idftnp = 1 ! no tensorial diffusivity
     ivar = 0
     idtva0 = 0
     relaxp = 1.d0
 
-    call bilsc2                                                   &
+    call bilsca &
     !==========
  ( nvar   , nscal  ,                                              &
    idtva0 , ivar   , iconvp , idiffp , nswrgy , imligy , ircfly , &
    ischcy , isstpy , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarny , imucpp ,                                     &
+   ipp    , iwarny , imucpp , idftnp ,                            &
    blency , epsrgy , climgy , extray , relaxp , thetap ,          &
    rtpdp  , rtpdp  , coefad , coefbd , coefad , cofbfd ,          &
-   viscf  , viscb  , viscf  , viscb  , rvoid  ,                   &
+   viscf  , viscb  , viscf  , viscb  , rvoid  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    smbdp  )
 
   endif
