@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -70,8 +70,6 @@
 !_______________________________________________________________________________
 
 subroutine distyp &
-!================
-
  ( nvar   , nscal  ,                                              &
    itypfb ,                                                       &
    distpa , propce , disty  )
@@ -116,7 +114,7 @@ integer          iescap, iflmb0, imaspe, itypfl
 integer          ncymxp, nitmfp, ipp
 integer          ifac  , iel   , ipcvis, init  , ipcrom
 integer          inc   , iccocg, isym  , isweep, infpar
-integer          imucpp
+integer          imucpp, idftnp, iswdyp
 
 double precision xnorme, dtminy, dtmaxy, relaxp, thetap, timey
 double precision xusnmx, xusnmn, xnorm0
@@ -522,6 +520,8 @@ do isweep = 1, ntcmxy
   ! Pas d'estimateurs, ni de multigrille (100 et 10 sont arbitraires)
   iescap = 0
   imucpp = 0
+  idftnp = 1
+  iswdyp = 0
   ncymxp = 100
   nitmfp = 10
   ! La case 1 est une poubelle
@@ -540,13 +540,14 @@ do isweep = 1, ntcmxy
  ( nvar   , nscal  ,                                              &
    idtva0 , ivar   , iconvp , idiffp , ireslp , ndircp , nitmay , &
    imrgra , nswrsy , nswrgy , imligy , ircfly ,                   &
-   ischcy , isstpy , iescap , imucpp ,                            &
+   ischcy , isstpy , iescap , imucpp , idftnp , iswdyp ,          &
    imgrpy , ncymxp , nitmfp , ipp    , iwarny ,                   &
    blency , epsily , epsrsy , epsrgy , climgy , extray ,          &
    relaxp , thetap ,                                              &
    rtpdp  , rtpdp  ,                                              &
    coefax , coefbx , coefax , coefbx , flumas , flumab ,          &
-   flumas , flumab , flumas , flumab ,                            &
+   flumas , flumab , rvoid  , flumas , flumab , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    rovsdp , smbdp  , rtpdp  , dpvar  ,                            &
    rvoid  , rvoid  )
 
