@@ -2068,12 +2068,10 @@ if (iecaux.eq.1) then
 
 ! ---> Grandeurs complementaires pour la combustion CP
 
-  if (ippmod(icp3pl).ge.0 .or.                                    &
-      ippmod(icpl3c).ge.0 .or.                                    &
+  if (ippmod(icpl3c).ge.0 .or.                                    &
       ippmod(iccoal).ge.0) then
     nberro = 0
 
-
 !     Charbon PuLVerise : masse vol des charbons
 
     itysup = 0
@@ -2115,7 +2113,7 @@ if (iecaux.eq.1) then
     nberro = nberro + ierror
 
 !       ientat, inmoxy et x20 ne servent pas pour le CP couple Lagrangien (cplphy)
-    if (ippmod(icp3pl).ge.0 .or. ippmod(iccoal).ge.0) then
+    if (ippmod(iccoal).ge.0) then
 
       itysup = 0
       nbval  = nozppm
