@@ -96,7 +96,7 @@ integer          ipuvw
 integer          icmin, icmax
 integer          nbrval
 integer          idivdt, ixmsdt, iel
-double precision petit,xyzmin(3),xyzmax(3)
+double precision petit,xyzmin(3),xyzmax(3), varmin(nvppmx), varmax(nvppmx)
 character*200    chain, chainc
 
 double precision, dimension(:), allocatable, target :: momtmp
@@ -106,7 +106,6 @@ double precision, dimension(:), pointer :: varptr => null()
 ! 0. INITIALISATIONS LOCALES
 !===============================================================================
 
-
 petit  =-grand
 
 !================================================
@@ -114,7 +113,7 @@ petit  =-grand
 !================================================
 
 do ipp = 2, nvppmx
-  if(ilisvr(ipp).eq.1) then
+  if (ilisvr(ipp).eq.1) then
     varmin(ipp) = grand
     varmax(ipp) = petit
     ira = abs(ipp2ra(ipp))
@@ -138,8 +137,8 @@ do ipp = 2, nvppmx
     endif
 
     do icel = 1, ncel
-      if(varptr(icel).lt.varmin(ipp)) varmin(ipp) = varptr(icel)
-      if(varptr(icel).gt.varmax(ipp)) varmax(ipp) = varptr(icel)
+      if (varptr(icel).lt.varmin(ipp)) varmin(ipp) = varptr(icel)
+      if (varptr(icel).gt.varmax(ipp)) varmax(ipp) = varptr(icel)
     enddo
 
     if (idivdt.ne.0) then
@@ -342,8 +341,6 @@ do ipp = 2, nvppmx
     endif
 
     write(nfecra,'(A)') chainc(1:ic)
-!MO          ICLPMN(IPP) = 0
-!MO          ICLPMX(IPP) = 0
   endif
 enddo
 
@@ -351,9 +348,6 @@ write(nfecra,1110)
 write(nfecra,*) ' '
 write(nfecra,*) ' '
 
-
-
-
 write(nfecra,1150)
 write(nfecra,1160)
 write(nfecra,1161)
@@ -361,10 +355,10 @@ write(nfecra,1160)
 
 do ipp = 2, nvppmx
   ipuvw = 0
-  if(ipp.eq.ipprtp(ipr) .or.                             &
-       ipp.eq.ipprtp(iu ) .or.                             &
-       ipp.eq.ipprtp(iv ) .or.                             &
-       ipp.eq.ipprtp(iw ) ) then
+  if (ipp.eq.ipprtp(ipr) .or.       &
+      ipp.eq.ipprtp(iu ) .or.       &
+      ipp.eq.ipprtp(iv ) .or.       &
+      ipp.eq.ipprtp(iw )) then
     ipuvw = 1
   endif
   !   En v2f on ne clippe jamais f_barrre, on ne l'affiche donc pas
@@ -374,8 +368,8 @@ do ipp = 2, nvppmx
   !   En ALE on ne clippe pas la vitesse de maillage
   if (iale.eq.1) then
     if (ipp.eq.ipprtp(iuma) .or.                                &
-         ipp.eq.ipprtp(ivma) .or.                                &
-         ipp.eq.ipprtp(iwma)) ipuvw = 1
+        ipp.eq.ipprtp(ivma) .or.                                &
+        ipp.eq.ipprtp(iwma)) ipuvw = 1
   endif
   !   Compressible
   if(ippmod(icompf).ge.0) then
