@@ -287,6 +287,26 @@ do iprop = 1, nproce
   call field_map_values(iprpfl(iprop), propce(1, iprop), propce(1, iprop))
 enddo
 
+! Map inner mass flux (the same for all variables, additional mass fluxes
+! might be defined in addfld.f90)
+call field_get_id("inner_mass_flux", f_id)
+
+if (ifluaa(ipr).eq.-1) then
+  call field_map_values(f_id, propfa(1, ipprof(ifluma(ipr))), propfa(1, ipprof(ifluma(ipr))))
+else
+  call field_map_values(f_id, propfa(1, ipprof(ifluma(ipr))), propfa(1, ipprof(ifluaa(ipr))))
+endif
+
+! Map boundary mass flux (the same for all variables, additional mass fluxes
+! might be defined in addfld.f90)
+call field_get_id("boundary_mass_flux", f_id)
+
+if (ifluaa(ipr).eq.-1) then
+  call field_map_values(f_id, propfb(1, ipprob(ifluma(ipr))), propfb(1, ipprob(ifluma(ipr))))
+else
+  call field_map_values(f_id, propfb(1, ipprob(ifluma(ipr))), propfb(1, ipprob(ifluaa(ipr))))
+endif
+
 ! Reserved fields whose ids are not saved (may be queried by name)
 !-----------------------------------------------------------------
 
