@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -62,13 +62,16 @@ implicit none
 
 ! Arguments
 
-integer          ii, ivoset
+integer          ii, ivoset, imrgrl
 
 !===============================================================================
 
 ivoset = 0
 
-if (imrgra.eq.2 .or. imrgra.eq.3) ivoset = 1
+imrgrl = imrgra
+if (imrgrl.lt.0) imrgrl = - imrgra
+
+if (imrgrl.eq.2 .or. imrgrl.eq.3 .or. imrgrl.eq.5 .or. imrgrl.eq.6) ivoset = 1
 
 if (iturb.eq.41) ivoset = 1
 
