@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -57,43 +57,53 @@
 !______________________________________________________________________________.
 !  mode           name          role                                           !
 !______________________________________________________________________________!
-!> \param[in]     yplus         dimensionless distance to the wall
-!> \param[in]     ckarm         Von Karman constant
-!> \param[in]     prt           turbulent Prandtl number
 !> \param[in]     prl           laminar Prandtl number
+!> \param[in]     prt           turbulent Prandtl number
+!> \param[in]     ckarm         Von Karman constant
+!> \param[in]     yplus         dimensionless distance to the wall
+!> \param[in]     dplus         dimensionless distance for scalable
+!>                              wall functions
 !> \param[out]    htur          corrected exchange coefficient
+!> \param[out]    yp1
 !_______________________________________________________________________________
 
 subroutine hturbp &
-!================
+ ( prl    , prt    , ckarm  , yplus  , dplus, htur , yp1 )
 
- ( prl    , prt    , ckarm  , yplus  , htur   )
+!===============================================================================
+
+!===============================================================================
+! Module files
+!===============================================================================
+
+use optcal, only: iwallt
+use cstnum
 
 !===============================================================================
 
 implicit none
 
-!===============================================================================
-
 ! Arguments
 
 double precision htur
-double precision prl,ckarm,prt,yplus
+double precision prl,ckarm,prt,yplus, dplus, yp1
 
 ! Local variables
 
 double precision tplus
 double precision beta2,a2
-double precision yp0,yp1,yp2
+double precision yp0,yp2
 double precision prlm1
 
-!============================================================================
+!===============================================================================
 
 !===============================================================================
 ! 1. Initializations
 !===============================================================================
 
-htur = 1.d0
+!===============================================================================
+
+htur = max(yplus-dplus, epzero)/max(yplus, epzero)
 
 prlm1 = 0.1d0
 
@@ -109,7 +119,7 @@ yp1   = (1000.d0/prl)**(1.d0/3.d0)
 if (prl.le.prlm1) then
   if (yplus .gt. yp0) then
     tplus = prl*yp0 + prt/ckarm * log(yplus/yp0)
-    htur = prl*yplus/tplus
+    htur = prl*(yplus-dplus)/tplus
   endif
 endif
 
@@ -124,12 +134,12 @@ if (prl.gt.prlm1) then
 
   if ((yplus.ge.yp1).and.(yplus.lt.yp2)) then
     tplus = a2 - 500.d0/(yplus*yplus)
-    htur = prl*yplus/tplus
+    htur = prl*(yplus-dplus)/tplus
   endif
 
   if ((yplus.ge.yp2)) then
     tplus = beta2 + prt/ckarm*log(yplus/yp2)
-    htur = prl*yplus/tplus
+    htur = prl*(yplus-dplus)/tplus
   endif
 
 endif
