@@ -332,8 +332,6 @@ do ii = 1, nvppmx
 enddo
 
 do ii = 1, nvppmx
-  varmin(ii) = 0.d0
-  varmax(ii) = 0.d0
   varmna(ii) = 0.d0
   varmxa(ii) = 0.d0
 enddo
@@ -387,7 +385,6 @@ ncelet = 0
 nfac   = 0
 nfabor = 0
 nfml   = 0
-nprfml = 0
 nnod   = 0
 lndfac = 0
 lndfbr = 0
@@ -404,7 +401,7 @@ iperot = 0
 
 ! Get mesh metadata.
 
-call ledevi(nfml, nprfml, iperio, iperot)
+call ledevi(iperio, iperot)
 !==========
 
 call tstjpe(iperio, iperot)
