@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -25,7 +25,7 @@ subroutine iniva0 &
 
  ( nvar   , nscal  , ncofab ,                                     &
    dt     , tpucou , rtp    , propce , propfa , propfb ,          &
-   coefa  , coefb  , frcxt  )
+   coefa  , coefb  , frcxt  , prhyd)
 
 !===============================================================================
 ! FONCTION :
@@ -54,6 +54,7 @@ subroutine iniva0 &
 !  (nfabor,*)      !    !     !    faces de bord                               !
 ! frcxt(ncelet,3)  ! tr ! <-- ! force exterieure generant la pression          !
 !                  !    !     !  hydrostatique                                 !
+! prhyd(ncelet)    ! ra ! <-- ! hydrostatic pressure predicted                 !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -80,6 +81,7 @@ use ppppar
 use ppthch
 use ppincl
 use cplsat
+use field
 use mesh
 
 !===============================================================================
@@ -94,7 +96,7 @@ integer          nvar   , nscal  , ncofab
 double precision dt(ncelet), tpucou(ncelet,3), rtp(ncelet,*), propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
 double precision coefa(nfabor,ncofab), coefb(nfabor,ncofab)
-double precision frcxt(ncelet,3)
+double precision frcxt(ncelet,3), prhyd(ncelet)
 
 ! Local variables
 
@@ -108,11 +110,16 @@ integer          iicp  , iicpa
 integer          iiviss, iiptot
 integer          iptsna, iptsta, iptsca
 integer          nn
+integer          f_id
 
 double precision xxk, xcmu, trii
 
+character*80     fname
+
 double precision rvoid(1)
 
+double precision, dimension(:,:), pointer :: xut
+
 !===============================================================================
 
 !===============================================================================
@@ -223,21 +230,27 @@ if (ippmod(icompf).lt.0) then
   enddo
 endif
 
-!     Diffusivite des scalaires
+! Diffusivite des scalaires
 do iscal = 1, nscal
-  if(ivisls(iscal).gt.0) then
+  if (ivisls(iscal).gt.0) then
     iiviss = ipproc(ivisls(iscal))
-!     Diffusivite aux cellules (et au pdt precedent si ordre2)
+    ! Diffusivite aux cellules (et au pdt precedent si ordre2)
     do iel = 1, ncel
       propce(iel,iiviss) = visls0(iscal)
     enddo
-    if(ivsext(iscal).gt.0) then
+    if (ivsext(iscal).gt.0) then
       iivisa = ipproc(ivissa(iscal))
       do iel = 1, ncel
         propce(iel,iivisa) = propce(iel,iiviss)
       enddo
     endif
   endif
+
+  if (iscal.eq.iscalt.and.iturt(iscal).gt.0.and.irovar.eq.1) then
+    do iel = 1, ncelet
+      propce(iel,ipproc(ibeta)) = 0.d0
+    enddo
+  endif
 enddo
 
 ! Initialisation of source terms for weakly compressible algorithm
@@ -642,7 +655,17 @@ if(iphydr.eq.1) then
 endif
 
 !===============================================================================
-! 13.  INITIALISATIONS EN ALE OU MAILLAGE MOBILE
+! 13.  INITIALISATION DE LA PRESSION HYDROSTATIQUE QUAND IPHYDR=2
+!===============================================================================
+
+if(iphydr.eq.2) then
+  do iel = 1, ncel
+    prhyd(iel) = 0.d0
+  enddo
+endif
+
+!===============================================================================
+! 14.  INITIALISATIONS EN ALE OU MAILLAGE MOBILE
 !===============================================================================
 
 if (iale.eq.1) then
