@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -50,6 +50,7 @@ subroutine lecamp &
 ! jphas            ! e  ! <-- ! nombre de phases du calcul precedent           !
 ! ljtu             ! e  ! <-- ! longueur de jturb                              !
 ! jturb            ! te ! <-- ! modeles de turb calcul precedent               !
+! jturbt           ! te ! <-- ! modeles de flux turb calcul precedent          !
 ! rtp              ! tr ! --> ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules (instant courant        )          !
 !__________________!____!_____!________________________________________________!
@@ -73,6 +74,8 @@ use pointe
 use numvar
 use albase
 use parall
+use cplsat
+use field
 
 !===============================================================================
 
@@ -92,6 +95,7 @@ character        rubriq*64,rubrik*64,car4*4
 character        cindfp*2
 character        cphase*2
 character        ficsui*32
+character*80     fname
 
 integer          iel
 integer          ivar  , iscal , ii    ,  ivers
@@ -101,9 +105,14 @@ integer          ierror, irtyp,  itysup, nbval
 integer          nberro, ilecec
 integer          iturph, jturph, itytph, jtytph
 integer          nfmtsc, nfmtru
-integer          jturb, jtytur, jale
+integer          jturb, jtytur, jale, jturbt
 integer          impamo
+integer          ival
+integer          f_id
 double precision d2s3, d2s3xk
+double precision rval
+
+double precision, dimension(:,:), pointer :: xut
 
 !===============================================================================
 
@@ -346,16 +355,16 @@ rubriq = 'nbre_pas_de_temps'
 itysup = 0
 nbval  = 1
 irtyp  = 1
-call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,ntpabs,  &
-            ierror)
+call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,ival,ierror)
+ntpabs = ival ! no direct read to avoid pointer issue
 nberro=nberro+ierror
 
 rubriq = 'instant_precedent'
 itysup = 0
 nbval  = 1
 irtyp  = 2
-call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,ttpabs,  &
-            ierror)
+call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,rval,ierror)
+ttpabs = rval ! no direct read to avoid pointer issue
 nberro=nberro+ierror
 
 
@@ -418,6 +427,28 @@ if (iale.eq.1 .and. jale.eq.1) then
   endif
 endif
 
+!     Instant de maillage mobile precedent (rotor/stator)
+
+nberro = 0
+
+rubriq = 'instant_mobile_precedent'
+itysup = 0
+nbval  = 1
+irtyp  = 2
+call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,rval,ierror)
+ttpmob = rval ! no direct read to avoid pointer issue
+nberro=nberro+ierror
+
+! --->  Message si erreur (pas de stop pour compatibilite avec les fichiers anterieurs)
+!       -> on n'affiche le message que si imobil=1 (sinon RAS)
+if (nberro.ne.0) then
+  if (imobil.eq.1) write(nfecra,9403) ttpabs
+  ttpmob = ttpabs
+endif
+
+! --->  Information (uniquement si imobil=1 et pas d affichage precedent)
+if (imobil.eq.1 .and. nberro.eq.0)  write(nfecra,2412) ttpmob
+
 ! --->  Fin de la lecture des options
 write(nfecra,1499)
 
@@ -934,21 +965,33 @@ write(nfecra,1598)
 
 nberro = 0
 
-if(nscal.gt.0) then
+if (nscal.gt.0) then
   do iscal = 1, nscal
     ivar = isca(iscal)
-!         Si le scalaire existait precedemment on le lit
-!         sinon on ne fait rien (init par defaut dans INIVA0)
+    ! Si le scalaire existait precedemment on le lit
+    ! sinon on ne fait rien (init par defaut dans INIVA0)
     if (iscold(iscal).gt.0) then
       if(iscold(iscal).le.nfmtsc) then
-        WRITE(CAR4,'(I4.4)')ISCOLD(ISCAL)
-        rubriq = 'scalaire_ce_'//CAR4
+        write(car4,'(i4.4)')iscold(iscal)
+        rubriq = 'scalaire_ce_'//car4
         itysup = 1
         nbval  = 1
         irtyp  = 2
         call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp, &
                     rtp(1,ivar),ierror)
         nberro=nberro+ierror
+        rubriq = 'turbulent_flux_model'//car4
+        itysup = 0
+        nbval  = 1
+        irtyp  = 1
+        call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,jturbt,    &
+                    ierror)
+        ! If the old calculation has no turbulent flux model, set it to 0
+        if (ierror.ne.0) jturbt = 0
+
+        ! ---> Modified data
+        if (iturt(iscal) .ne. jturbt) write(nfecra,8411) iturt(iscal), jturbt
+
       else
         ierror= -1
         nberro=nberro+ierror
@@ -964,6 +1007,24 @@ if(nscal.gt.0) then
         write(nfecra,9511)rubrik
       endif
     endif
+    if (ityturt(iscal).eq.2 .or. ityturt(iscal).eq.3) then
+
+      ! Name of the previous scalar ivar
+      call field_get_name(ivarfl(iscold(iscal)), fname)
+      rubriq = trim(fname)//'_turbulent_flux_ce'
+
+      ! Index of the corresponding turbulent flux
+      call field_get_name(ivarfl(ivar), fname)
+      call field_get_id(trim(fname)//'_turbulent_flux_ce', f_id)
+      call field_get_val_v(f_id, xut)
+
+      itysup = 1
+      nbval  = 3
+      irtyp  = 2
+      call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,xut,ierror)
+      nberro=nberro+ierror
+
+    endif
   enddo
 endif
 
@@ -1083,6 +1144,9 @@ return
  2411 format                                                            &
  ('   Lecture du pas de temps precedent (suite) ',                &
                                                 'TTPABS = ',E12.4)
+ 2412 format                                                            &
+ ('   Lecture du temps de maillage mobile precedent (suite) ',    &
+                                                'TTPMOB = ',E12.4)
 
 #else
 
@@ -1092,6 +1156,9 @@ return
  2411 format                                                            &
  ('   Reading the previous time step number ',                    &
                       '(restarting computation)  TTPABS = ',E12.4)
+ 2412 format                                                            &
+ ('   Reading the previous moving mesh moment ',                  &
+                      '(restarting computation)  TTPMOB = ',E12.4)
 
 #endif
 
@@ -1150,8 +1217,8 @@ return
 '@      les dimensions suivantes :                            ',/,&
 '@                                                            ',/,&
 '@                NVAR     NSCAL    NSCAUS    NSCAPP          ',/,&
-'@  AMONT : ',5I10                                             ,/,&
-'@  ACTUEL: ',5I10                                             ,/,&
+'@  AMONT : ',4I10                                             ,/,&
+'@  ACTUEL: ',4I10                                             ,/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
@@ -1172,6 +1239,24 @@ return
 '@      verifier la valeur de ITURB(',I2,')                   ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 8411 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ ATTENTION : LECTURE DU FICHIER SUITE PRINCIPAL          ',/,&
+'@    =========                                               ',/,&
+'@                                                            ',/,&
+'@      REPRISE  DE CALCUL           AVEC ITURB = ',I4         ,/,&
+'@      A PARTIR D''UN CALCUL REALISE AVEC ITURB = ',I4        ,/,&
+'@                                                            ',/,&
+'@    Le modele de flux turbulent a ete modifie.              ',/,&
+'@    Le calcul peut etre execute.                            ',/,&
+'@                                                            ',/,&
+'@    Il est conseille cependant de                           ',/,&
+'@      verifier la valeur de ITURB(',I2,')                   ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
  8711 format(                                                     &
 '@                                                            ',/,&
@@ -1238,8 +1323,8 @@ return
 '@      the following dimensions:                             ',/,&
 '@                                                            ',/,&
 '@                NVAR     NSCAL    NSCAUS    NSCAPP          ',/,&
-'@ PREVIOUS:',5I10                                             ,/,&
-'@ CURRENT :',5I10                                             ,/,&
+'@ PREVIOUS:',4I10                                             ,/,&
+'@ CURRENT :',4I10                                             ,/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
@@ -1260,6 +1345,24 @@ return
 '@      the value of the variable ITURB(',I2,')               ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 8411 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : WHEN READING THE MAIN RESTART FILE            ',/,&
+'@    =========                                               ',/,&
+'@                                                            ',/,&
+'@    THE CURRENT CALCULATION USES ITURB = ',I4                ,/,&
+'@    BUT RESTARTS FROM ANOTHER ONE USING ITURB = ',I4         ,/,&
+'@                                                            ',/,&
+'@    The turbulent flux model has changed.                   ',/,&
+'@    The computation can be executed.                        ',/,&
+'@                                                            ',/,&
+'@    However, it is strongly advised to check                ',/,&
+'@      the value of the variable ITURB(',I2,')               ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
  8711 format(                                                     &
 '@                                                            ',/,&
@@ -1478,6 +1581,26 @@ return
 '@    Verifier ILEAUX.                                        ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 9403 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ ATTENTION : ERREUR A LA LECTURE DU FICHIER SUITE        ',/,&
+'@    =========                                      PRINCIPAL',/,&
+'@                                                            ',/,&
+'@      ERREUR A LA LECTURE DE L INSTANT DE MAILLAGE MOBILE  ',/,&
+'@                                                   PRECEDENT',/,&
+'@    Il se peut que le fichier suite relu corresponde a une  ',/,&
+'@      version anterieure de Code_Saturne, sans couplage     ',/,&
+'@      rotor/stator instationnaire.                          ',/,&
+'@    Le calcul sera execute en initialisant l instant de     ',/,&
+'@      maillage mobile precedent a TTCMOB = ',E12.4           ,/,&
+'@    Verifier neanmoins que le fichier suite utilise n''a    ',/,&
+'@        pas ete endommage.                                  ',/,&
+'@                                                            ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
  9410 format(                                                     &
 '@                                                            ',/,&
@@ -1753,6 +1876,26 @@ return
 '@    Please check the value of ILEAUX.                       ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 9403 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : ERROR AT THE MAIN RESTART FILE READING        ',/,&
+'@    =========                                               ',/,&
+'@                                                            ',/,&
+'@      ERROR AT READING THE PREVIOUS MOVING MESH MOMENT      ',/,&
+'@                                                            ',/,&
+'@    The read restart file might come from a previous        ',/,&
+'@      version of Code Saturne, without unsteady             ',/,&
+'@      rotor/stator coupling method.                         ',/,&
+'@    The calculation will be executed with the previous      ',/,&
+'@      moving mesh moment initialized to TTCMOB = ',E12.4     ,/,&
+'@    Please check the integrity of the file used as          ',/,&
+'@        restart file, however.                              ',/,&
+'@                                                            ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
  9410 format(                                                     &
 '@                                                            ',/,&
