@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -57,6 +57,7 @@ use albase
 use radiat, only: iirayo
 use alstru
 use cplsat
+use post
 use ppincl
 
 !===============================================================================
@@ -72,7 +73,7 @@ integer          ii, jj, ivar, iok, iest, imom, ikw
 integer          icompt, ipp, nbccou, nn
 integer          nscacp, iscal
 double precision relxsp
-double precision omgnrm, ctheta, stheta
+double precision omgnrm, cosdto, sindto
 double precision ux, uy, uz
 
 !===============================================================================
@@ -140,8 +141,7 @@ if (nbmomt.gt.0) then
   enddo
 endif
 if (iale.eq.1) then
-  call pstdfm
-  !==========
+  call cs_post_set_deformable
   nn = 1
   if (iortvm.eq.1) nn = 3
   do ii = 1, nn
@@ -856,37 +856,37 @@ enddo
 !           a l'ordre 1 :
 !                  2  pour la pression
 !                  1  pour les autres variables
-!                  on initialise EPSRSM a 1.D-8
 !                  on initialise EPSILO a 1.D-8
+!                  on initialise EPSRSM a 10*EPSILO
 !           a l'ordre 2 :
 !                  5  pour la pression
 !                  10 pour les autres variables
-!                  on initialise EPSRSM a 1.D-5
 !                  on initialise EPSILO a 1.D-5
+!                  on initialise EPSRSM a 10*EPSILO
 !     Attention aux tests dans verini
 
 if (ischtp.eq.2) then
   ii = ipr
   if (nswrsm(ii).eq.-999) nswrsm(ii) = 5
-  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 1.d-5
   if (abs(epsilo(ii)+999.d0).lt.epzero) epsilo(ii) = 1.d-5
+  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 10.d0*epsilo(ii)
   ii = iu
   if (nswrsm(ii).eq.-999) nswrsm(ii) = 10
-  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 1.d-5
   if (abs(epsilo(ii)+999.d0).lt.epzero) epsilo(ii) = 1.d-5
+  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 10.d0*epsilo(ii)
   ii = iv
   if (nswrsm(ii).eq.-999) nswrsm(ii) = 10
-  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 1.d-5
   if (abs(epsilo(ii)+999.d0).lt.epzero) epsilo(ii) = 1.d-5
+  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 10.d0*epsilo(ii)
   ii = iw
   if (nswrsm(ii).eq.-999) nswrsm(ii) = 10
-  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 1.d-5
   if (abs(epsilo(ii)+999.d0).lt.epzero) epsilo(ii) = 1.d-5
+  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 10.d0*epsilo(ii)
   do jj = 1, nscal
     ii = isca(jj)
     if (nswrsm(ii).eq.-999) nswrsm(ii) = 10
-    if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 1.d-5
     if (abs(epsilo(ii)+999.d0).lt.epzero) epsilo(ii) = 1.d-5
+    if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 10.d0*epsilo(ii)
   enddo
 endif
 ii = ipr
@@ -894,8 +894,8 @@ if (nswrsm(ii).eq.-999) nswrsm(ii) = 2
 
 do ii = 1, nvarmx
   if (nswrsm(ii).eq.-999) nswrsm(ii) = 1
-  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 1.d-8
   if (abs(epsilo(ii)+999.d0).lt.epzero) epsilo(ii) = 1.d-8
+  if (abs(epsrsm(ii)+999.d0).lt.epzero) epsrsm(ii) = 10.d0*epsilo(ii)
 enddo
 
 ! ---> ANOMAX
@@ -913,13 +913,13 @@ endif
 !        On impose -1 avec gradrc (pas de limitation)
 !               et  1 avec gradmc (limitation)
 
-if (imrgra.eq.0.or.imrgra.eq.4) then
+if (imrgra.eq.0.or.imrgra.ge.4.or.imrgra.le.-4) then
   do ii = 1, nvarmx
     if (imligr(ii).eq.-999) then
       imligr(ii) = -1
     endif
   enddo
-elseif (imrgra.eq.1.or.imrgra.eq.2.or.imrgra.eq.3) then
+else
   do ii = 1, nvarmx
     if (imligr(ii).eq.-999) then
       imligr(ii) = 1
@@ -986,7 +986,7 @@ endif
 if (ideuch.eq.-999) then
   if (iturb.eq. 0.or.                                     &
       iturb.eq.10.or.                                     &
-      itytur.eq.4.or.                                     &
+      itytur.eq.4.or.itytur.eq.5.or.iturb.eq.32.or.       &
       iturb.eq.70) then
     ideuch = 0
   else
@@ -1160,11 +1160,11 @@ if ((iturb.eq.30.and.irijec.eq.1).or.              &
   ineedy = 1
 endif
 
-if (imrgra.eq.0 .or. imrgra.eq.4) then
+if (imrgra.eq.0 .or. imrgra.ge.4 .or. imrgra.le.-4) then
   if (imligy.eq.-999) then
     imligy = -1
   endif
-elseif (imrgra.eq.1.or.imrgra.eq.2.or.imrgra.eq.3) then
+else
   if (imligy.eq.-999) then
     imligy = 1
   endif
@@ -1203,16 +1203,21 @@ if (idtvar.lt.0) then
   enddo
 else
   if (ikecou.eq.0) then
-    if (itytur.eq.2 .or. itytur.eq.5) then
+    if (itytur.eq.5) then !FIXME
       if (abs(relaxv(ik)+999.d0).lt.epzero)              &
            relaxv(ik) = 0.7d0
       if (abs(relaxv(iep)+999.d0).lt.epzero)             &
            relaxv(iep) = 0.7d0
+    else if (itytur.eq.2) then
+      if (abs(relaxv(ik)+999.d0).lt.epzero)              &
+           relaxv(ik) = 1.d0
+      if (abs(relaxv(iep)+999.d0).lt.epzero)             &
+           relaxv(iep) = 1.d0
     else if (itytur.eq.6) then
       if (abs(relaxv(ik)+999.d0).lt.epzero)              &
-           relaxv(ik) = 0.7d0
+           relaxv(ik) = 1.d0
       if (abs(relaxv(iomg)+999.d0).lt.epzero)            &
-           relaxv(iomg) = 0.7d0
+           relaxv(iomg) = 1.d0
     endif
   endif
   if (iturb.eq.70) then
@@ -1238,7 +1243,7 @@ endif
 ! ---> INEEDF
 !     Si on a demande un posttraitement des efforts aux bords, on
 !     les calcule !
-if (mod(ipstdv,ipstfo).eq.0) then
+if (ipstdv(ipstfo).ne.0) then
   ineedf = 1
 endif
 !     Si on est en ALE, par defaut on calcule les efforts aux bords
@@ -1246,6 +1251,13 @@ endif
 !     tard)
 if (iale.eq.1) ineedf = 1
 
+! If no thermal variable is present, do not try to
+! postprocess boundary temperature or Nusselt
+if (iscalt.le.0) then
+  ipstdv(ipsttb) = 0
+  ipstdv(ipstnu) = 0
+endif
+
 !===============================================================================
 ! 4. TABLEAUX DE cstphy
 !===============================================================================
@@ -1274,10 +1286,21 @@ enddo
 
 
 ! ---> VISLS0 (IVISLS ont ete verifies dans varpos)
-!      Pour les variances de fluctuations, les valeurs du tableau
-!        precedent ne doivent pas avoir ete modifiees par l'utilisateur
-!        Elles sont prises egales aux valeurs correspondantes pour le
-!        scalaire associe.
+
+! For scalars which are not variances, define the default diffusivity
+
+! Pour les variances de fluctuations, les valeurs du tableau
+! precedent ne doivent pas avoir ete modifiees par l'utilisateur
+! Elles sont prises egales aux valeurs correspondantes pour le
+! scalaire associe.
+
+if (nscaus.gt.0) then
+  do jj = 1, nscaus
+    if (iscavr(jj).le.0 .and. visls0(jj).lt.-grand) then
+      visls0(jj) = viscl0
+    endif
+  enddo
+endif
 
 if (nscal.gt.0) then
   do ii = 1, nscal
@@ -1308,6 +1331,35 @@ do ii = 1, 3
   endif
 enddo
 
+! Turbulent fluxes constant for GGDH, AFM and DFM
+if (nscal.gt.0) then
+  do iscal = 1, nscal
+    if (iturt(iscal).eq.0) then
+      idften(isca(iscal)) = 1
+
+    ! AFM and GGDH on the scalar
+    elseif (ityturt(iscal).eq.1.or.ityturt(iscal).eq.2) then
+      idften(isca(iscal)) = 6
+      ctheta(iscal) = cthafm
+
+    ! DFM on the scalar
+    elseif (ityturt(iscal).eq.3) then
+      idifft(isca(iscal)) = 0
+      idften(isca(iscal)) = 1
+      ctheta(iscal) = cthdfm
+      ! GGDH on the thermal fluxes is automatically done
+
+      ! GGDH on the variance of the thermal scalar
+      do ii = 1, nscal
+        if (iscavr(ii).eq.iscal) then
+          idften(isca(ii)) = 6
+          ctheta(ii) = csrij
+        endif
+      enddo
+    endif
+  enddo
+endif
+
 ! Vecteur rotation et matrice(s) associees
 
 omgnrm = sqrt(omegax**2 + omegay**2 + omegaz**2)
@@ -1352,8 +1404,8 @@ if (omgnrm.ge.epzero) then
 
   ! Matrice de rotation
 
-  ctheta = cos(dtref*omgnrm)
-  stheta = sin(dtref*omgnrm)
+  cosdto = cos(dtref*omgnrm)
+  sindto = sin(dtref*omgnrm)
 
   do ii = 1, 3
     do jj = 1, 3
@@ -1364,8 +1416,8 @@ if (omgnrm.ge.epzero) then
 
   do ii = 1, 3
     do jj = 1, 3
-      rrot(ii,jj) = ctheta*irot(ii,jj) + (1.d0 - ctheta)*prot(ii,jj) &
-                                       +         stheta *qrot(ii,jj)
+      rrot(ii,jj) = cosdto*irot(ii,jj) + (1.d0 - cosdto)*prot(ii,jj) &
+                                       +         sindto *qrot(ii,jj)
     enddo
   enddo
 
@@ -1423,8 +1475,7 @@ if (nbrcpl.ge.1) then
     ! Maillage mobile
     if (icorio.eq.0) then
       imobil = 1
-      call pstdfm
-      !==========
+      call cs_post_set_deformable
     endif
   endif
 endif
