@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -26,7 +26,7 @@ subroutine navsto &
  ( nvar   , nscal  , iterns , icvrge ,                            &
    isostd ,                                                       &
    dt     , tpucou , rtp    , rtpa   , propce , propfa , propfb , &
-   tslagr , coefa  , coefb  , frcxt  ,                            &
+   tslagr , coefa  , coefb  , frcxt  , prhyd  ,                   &
    trava  , ximpa  , uvwk   )
 
 !===============================================================================
@@ -58,6 +58,7 @@ subroutine navsto &
 !  (nfabor, *)     !    !     !                                                !
 ! frcxt(ncelet,3)  ! tr ! <-- ! force exterieure generant la pression          !
 !                  !    !     !  hydrostatique                                 !
+! prhyd(ncelet)    ! tr ! <-- ! hydrostatic pressure predicted at cell centers !
 ! tslagr           ! tr ! <-- ! terme de couplage retour du                    !
 !(ncelet,*)        !    !     !     lagrangien                                 !
 ! trava,ximpa      ! tr ! <-- ! tableau de travail pour couplage               !
@@ -111,6 +112,7 @@ double precision propfa(nfac,*), propfb(ndimfb,*)
 double precision tslagr(ncelet,*)
 double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision frcxt(ncelet,3)
+double precision prhyd(ncelet)
 double precision trava(ncelet,ndim),ximpa(ncelet,ndim)
 double precision uvwk(ncelet,ndim)
 
@@ -149,6 +151,7 @@ double precision, allocatable, dimension(:) :: w7, w8, w9
 double precision, allocatable, dimension(:) :: w10
 double precision, allocatable, dimension(:,:) :: dfrcxt
 double precision, allocatable, dimension(:,:) :: frchy, dfrchy
+double precision, allocatable, dimension(:,:) :: grdphd
 double precision, allocatable, dimension(:) :: esflum, esflub
 double precision, allocatable, dimension(:) :: flint, flbrd
 double precision, allocatable, dimension(:) :: coefap
@@ -174,6 +177,7 @@ allocate(coefap(nfabor))
 !if (iphydr.eq.1) allocate(dfrcxt(ncelet,3))
 allocate(dfrcxt(ncelet,3))
 if (icalhy.eq.1) allocate(frchy(ncelet,ndim), dfrchy(ncelet,ndim))
+if (iphydr.eq.2) allocate(grdphd(ncelet,ndim))
 if (iescal(iestot).gt.0) allocate(esflum(nfac), esflub(nfabor))
 if (itytur.eq.3.and.irijnu.eq.1) then
   allocate(wvisfi(nfac), wvisbi(nfabor))
@@ -259,7 +263,8 @@ endif
 ! 1. Prediction of the mass flux in case of Low Mach compressible algorithm
 !===============================================================================
 
-if (idilat.eq.2.or.idilat.eq.3) then
+if ((idilat.eq.2.or.idilat.eq.3).and. &
+    (ntcabs.gt.1.or.isuite.gt.0)) then
 
   call predfl &
   !==========
@@ -272,7 +277,22 @@ if (idilat.eq.2.or.idilat.eq.3) then
 endif
 
 !===============================================================================
-! 2.  ETAPE DE PREDICTION DES VITESSES
+! 2. Hydrostatic pressure prediction in case of Low Mach compressible algorithm
+!===============================================================================
+
+if (iphydr.eq.2) then
+
+  call prehyd &
+  !==========
+  ( nvar   , nscal  ,                                     &
+    dt     , rtp    , rtpa   ,                            &
+    propce , propfa , propfb ,                            &
+    prhyd  , grdphd )
+
+endif
+
+!===============================================================================
+! 3.  ETAPE DE PREDICTION DES VITESSES
 !===============================================================================
 
 iappel = 1
@@ -288,7 +308,7 @@ call preduv &
   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
   propfa(1,iflmas), propfb(1,iflmab),                            &
   tslagr , coefa  , coefb  ,                                     &
-  ckupdc , smacel , frcxt ,                                      &
+  ckupdc , smacel , frcxt  , grdphd ,                            &
   trava  , ximpa  , uvwk   , dfrcxt , tpucou ,  trav  ,          &
   viscf  , viscb  , viscfi , viscbi ,                            &
   drtp   , smbr   , rovsdt ,                                     &
@@ -493,7 +513,7 @@ if ( iprco.le.0 ) then
 endif
 
 !===============================================================================
-! 3.  ETAPE DE PRESSION/CONTINUITE ( VITESSE/PRESSION )
+! 4.  ETAPE DE PRESSION/CONTINUITE ( VITESSE/PRESSION )
 !===============================================================================
 
 if (iwarni(iu).ge.1) then
@@ -520,7 +540,7 @@ call resolp &
 
 
 !===============================================================================
-! 4.  REACTUALISATION DU CHAMP DE VITESSE
+! 5.  REACTUALISATION DU CHAMP DE VITESSE
 !===============================================================================
 
 iclipr = iclrtp(ipr,icoef)
@@ -672,7 +692,7 @@ else
 
   call grdpot &
   !==========
- ( ipr , imrgra , inc    , iccocg , nswrgp , imligp , iphydr ,    &
+ ( ipr    , imrgra , inc    , iccocg , nswrgp , imligp , iphydr , &
    iwarnp , nfecra , epsrgp , climgp , extrap ,                   &
    rvoid  ,                                                       &
    dfrcxt(1,1),dfrcxt(1,2),dfrcxt(1,3),                           &
@@ -682,7 +702,7 @@ else
   !     REACTUALISATION DU CHAMP DE VITESSES
 
   thetap = thetav(ipr)
-  if (iphydr.eq.0) then
+  if (iphydr.eq.0.or.iphydr.eq.2) then
     if (idtsca.eq.0) then
       !$omp parallel do private(dtsrom)
       do iel = 1, ncel
@@ -898,7 +918,7 @@ endif
 
 
 !===============================================================================
-! 5.  CALCUL D'UN ESTIMATEUR D'ERREUR DE L'ETAPE DE CORRECTION ET TOTAL
+! 6.  CALCUL D'UN ESTIMATEUR D'ERREUR DE L'ETAPE DE CORRECTION ET TOTAL
 !===============================================================================
 
 
@@ -1035,7 +1055,7 @@ if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
    dt     , rtp    , rtp    , propce , propfa , propfb ,          &
    esflum , esflub ,                                              &
    tslagr , coefa  , coefb  ,                                     &
-   ckupdc , smacel , frcxt  ,                                     &
+   ckupdc , smacel , frcxt  , grdphd ,                            &
    trava  , ximpa  , uvwk   , dfrcxt , tpucou , trav   ,          &
    viscf  , viscb  , viscfi , viscbi ,                            &
    drtp   , smbr   , rovsdt ,                                     &
@@ -1046,7 +1066,7 @@ if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 endif
 
 !===============================================================================
-! 6.  TRAITEMENT DU POINT FIXE SUR LE SYSTEME VITESSE/PRESSION
+! 7.  TRAITEMENT DU POINT FIXE SUR LE SYSTEME VITESSE/PRESSION
 !===============================================================================
 
 if (nterup.gt.1) then
@@ -1116,7 +1136,7 @@ if (ippmod(icompf).lt.0) then
 endif
 
 !===============================================================================
-! 7.  IMPRESSIONS
+! 8.  IMPRESSIONS
 !===============================================================================
 
 iflmas = ipprof(ifluma(iu))
@@ -1248,6 +1268,7 @@ deallocate(drtp, smbr, rovsdt)
 deallocate(trav)
 if (allocated(dfrcxt)) deallocate(dfrcxt)
 if (allocated(frchy))  deallocate(frchy, dfrchy)
+if (allocated(grdphd)) deallocate(grdphd)
 if (allocated(esflum)) deallocate(esflum, esflub)
 if (allocated(wvisfi)) deallocate(wvisfi, wvisbi)
 deallocate(w1, w2, w3)
