@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -20,60 +20,56 @@
 
 !-------------------------------------------------------------------------------
 
-subroutine navstv &
-!================
+!===============================================================================
+! Function:
+! ---------
 
+!> \file navstv.f90
+!>
+!> \brief Solving of NS equations for incompressible or slightly compressible
+!> flows for one time step. Both convection-diffusion and continuity steps are
+!> performed.  The velocity components are solved together in once.
+!>
+!-------------------------------------------------------------------------------
+
+!-------------------------------------------------------------------------------
+! Arguments
+!______________________________________________________________________________.
+!  mode           name          role                                           !
+!______________________________________________________________________________!
+!> \param[in]     nvar          total number of variables
+!> \param[in]     nscal         total number of scalars
+!> \param[in]     iterns        index of the iteration on Navier-Stokes
+!> \param[in]     icvrge        indicator of convergence
+!> \param[in]     itrale        number of the current ALE iteration
+!> \param[in]     isostd        indicator of standar outlet
+!>                               +index of the reference face
+!> \param[in]     dt            time step (per cell)
+!> \param[in]     tpucou        velocity-pressure coupling (interleaved)
+!> \param[in,out] rtp, rtpa     calculated variables at cell centers
+!>                               (at current and previous time steps)
+!> \param[in]     propce        physical properties at cell centers
+!> \param[in]     propfa        physical properties at interior face centers
+!> \param[in]     propfb        physical properties at boundary face centers
+!> \param[in]     coefa, coefb  boundary conditions
+!> \param[in]     frcxt         external force generating the hydrostatic
+!>                              pressure
+!> \param[in]     prhyd         hydrostatic pressure predicted at cell centers
+!> \param[in]     tslagr        terme de couplage retour du
+!>                                  lagrangien
+!> \param[in]     trava         work array for pressure velocity coupling
+!> \param[in]     ximpa         work array for pressure velocity coupling
+!> \param[in]     uvwk          work array for pressure velocity coupling
+!_______________________________________________________________________________
+
+
+subroutine navstv &
  ( nvar   , nscal  , iterns , icvrge , itrale ,                   &
    isostd ,                                                       &
    dt     , tpucou , rtp    , rtpa   , propce , propfa , propfb , &
-   tslagr , coefa  , coefb  , frcxt  ,                            &
+   tslagr , coefa  , coefb  , frcxt  , prhyd  ,                   &
    trava  , ximpa  , uvwk   )
 
-!===============================================================================
-! FONCTION :
-! ----------
-
-! Solving of NS equations for incompressible or slightly compressible flows for
-! one time step. Both convection-diffusion and continuity steps are performed.
-! The velocity components are solved together in once.
-
-!-------------------------------------------------------------------------------
-!ARGU                             ARGUMENTS
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
-! iterns           ! e  ! <-- ! numero d'iteration sur navsto                  !
-! icvrge           ! e  ! <-- ! indicateur de convergence du pnt fix           !
-! isostd           ! te ! <-- ! indicateur de sortie standard                  !
-!    (nfabor+1)    !    !     !  +numero de la face de reference               !
-! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! tpucou(ncelet,3) ! ra ! <-- ! velocity-pressure coupling (interleaved)       !
-! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
-!  (ncelet, *)     !    !     !  (at current and previous time steps)          !
-! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
-! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
-! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
-! frcxt(ncelet,3)  ! tr ! <-- ! force exterieure generant la pression          !
-!                  !    !     !  hydrostatique                                 !
-! tslagr           ! tr ! <-- ! terme de couplage retour du                    !
-!(ncelet,*)        !    !     !     lagrangien                                 !
-! trava            ! tr ! <-- ! tableau de travail pour couplage               !
-!(3,ncelet)        !    !     ! vitesse pression par point fixe                !
-! ximpa            ! tr ! <-- ! tableau de travail pour couplage               !
-!(3,3,ncelet)      !    !     ! vitesse pression par point fixe                !
-! uvwk             ! tr ! <-- ! tableau de travail pour couplage u/p           !
-!(3,ncelet)        !    !     ! sert a stocker la vitesse de                   !
-!                  !    !     ! l'iteration precedente                         !
-!__________________!____!_____!________________________________________________!
-
-!     Type: i (integer), r (real), s (string), a (array), l (logical),
-!           and composite types (ex: ra real array)
-!     mode: <-- input, --> output, <-> modifies data, --- work array
-
 !===============================================================================
 
 !===============================================================================
@@ -113,12 +109,13 @@ double precision propfa(nfac,*), propfb(ndimfb,*)
 double precision tslagr(ncelet,*)
 double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision frcxt(ncelet,3)
+double precision prhyd(ncelet)
 double precision trava(ndim,ncelet),ximpa(ndim,ndim,ncelet)
 double precision uvwk(ndim,ncelet)
 
 ! Local variables
 
-integer          iccocg, inc, iel, iel1, iel2, ifac, imax
+integer          iccocg, inc, iel, iel1, iel2, ifac, imax, imaxt
 integer          ii    , inod, itypfl
 integer          isou, ivar, iitsm
 integer          iclipr, iclipf
@@ -126,10 +123,10 @@ integer          icliup, iclivp, icliwp, init
 integer          iflmas, iflmab, ipcrom, ipbrom
 integer          iflms1, iflmb1, iflmb0
 integer          nswrgp, imligp, iwarnp
-integer          nbrval, iappel, iescop, idtsca
-integer          ndircp, icpt  , iecrw
+integer          nbrval, iappel, iescop
+integer          ndircp, icpt
 integer          numcpl
-double precision rnorm , rnorma, rnormi, vitnor
+double precision rnorm , rnormt, rnorma, rnormi, vitnor
 double precision dtsrom, unsrom, surf  , rhom, rovolsdt
 double precision epsrgp, climgp, extrap, xyzmax(3)
 double precision thetap, xdu, xdv, xdw
@@ -149,6 +146,7 @@ double precision, allocatable, dimension(:) :: w7, w8, w9
 double precision, allocatable, dimension(:) :: w10
 double precision, allocatable, dimension(:,:) :: dfrcxt
 double precision, allocatable, dimension(:,:) :: frchy, dfrchy
+double precision, allocatable, dimension(:,:) :: grdphd
 double precision, allocatable, dimension(:) :: esflum, esflub
 double precision, allocatable, dimension(:) :: intflx, bouflx
 double precision, allocatable, dimension(:) :: secvif, secvib
@@ -159,7 +157,6 @@ double precision, dimension(:,:), allocatable :: gradp
 double precision, dimension(:,:), allocatable :: vel
 double precision, dimension(:,:), allocatable :: vela
 double precision, dimension(:,:), allocatable :: mshvel
-double precision, dimension(:,:), allocatable :: tpucov
 double precision, dimension(:), allocatable :: coefap
 
 !===============================================================================
@@ -174,9 +171,6 @@ allocate(drtp(ncelet))
 allocate(trav(3,ncelet))
 allocate(vela(3,ncelet))
 allocate(vel(3,ncelet))
-if (ipucou.eq.1 .or. ncpdct.gt.0) then
-  allocate(tpucov(3,ncelet))
-endif
 
 ! Allocate other arrays, depending on user options
 
@@ -186,6 +180,7 @@ allocate(coefap(nfabor))
 !if (iphydr.eq.1) allocate(dfrcxt(ncelet,3))!FIXME
 allocate(dfrcxt(ncelet,3))
 if (icalhy.eq.1) allocate(frchy(ncelet,ndim), dfrchy(ncelet,ndim))
+if (iphydr.eq.2) allocate(grdphd(ncelet,ndim))
 if (iescal(iestot).gt.0) allocate(esflum(nfac), esflub(nfabor))
 if (itytur.eq.3.and.irijnu.eq.1) then
   allocate(wvisfi(nfac), wvisbi(nfabor))
@@ -208,7 +203,7 @@ allocate(w1(ncelet))
 allocate(w7(ncelet), w8(ncelet), w9(ncelet))
 if (irnpnw.eq.1) allocate(w10(ncelet))
 
-! Interleaved value of vel and vela and tpucou
+! Interleaved value of vel and vela
 !$omp parallel do
 do iel = 1, ncelet
   vel (1,iel) = rtp (iel,iu)
@@ -286,7 +281,8 @@ endif
 ! 1. Prediction of the mass flux in case of Low Mach compressible algorithm
 !===============================================================================
 
-if (idilat.eq.2.or.idilat.eq.3) then
+if ((idilat.eq.2.or.idilat.eq.3).and. &
+    (ntcabs.gt.1.or.isuite.gt.0)) then
 
   call predfl &
   !==========
@@ -299,7 +295,22 @@ if (idilat.eq.2.or.idilat.eq.3) then
 endif
 
 !===============================================================================
-! 2.  ETAPE DE PREDICTION DES VITESSES
+! 2. Hydrostatic pressure prediction in case of Low Mach compressible algorithm
+!===============================================================================
+
+if (iphydr.eq.2) then
+
+  call prehyd &
+  !==========
+  ( nvar   , nscal  ,                                     &
+    dt     , rtp    , rtpa   ,                            &
+    propce , propfa , propfb ,                            &
+    prhyd  , grdphd )
+
+endif
+
+!===============================================================================
+! 3.  ETAPE DE PREDICTION DES VITESSES
 !===============================================================================
 
 iappel = 1
@@ -316,8 +327,8 @@ call predvv &
   propce , propfa , propfb ,                                     &
   propfa(1,iflmas), propfb(1,iflmab),                            &
   tslagr , coefa  , coefb  , coefau , coefbu , cofafu , cofbfu , &
-  ckupdc , smacel , frcxt ,                                      &
-  trava  , ximpa  , uvwk   , dfrcxt , tpucov ,  trav  ,          &
+  ckupdc , smacel , frcxt  , grdphd ,                            &
+  trava  , ximpa  , uvwk   , dfrcxt , dttens ,  trav  ,          &
   viscf  , viscb  , viscfi , viscbi , secvif , secvib ,          &
   w1     , w7     , w8     , w9     , w10    )
 
@@ -397,7 +408,7 @@ if (iprco.le.0) then
     epsrgp , climgp , extrap ,                                     &
     propce(1,ipcrom), propfb(1,ipbrom),                            &
     mshvel ,                                                       &
-    cfaale , cfbale ,                                              &
+    claale , clbale ,                                              &
     intflx , bouflx )
 
     ! Here we need of the opposite of the mesh velocity.
@@ -406,24 +417,24 @@ if (iprco.le.0) then
       propfb(ifac,iflmab) = propfb(ifac,iflmab) - bouflx(ifac)
     enddo
 
-    !$omp parallel do private(iecrw, ddepx, ddepy, ddepz, icpt, ii, inod, &
+    !$omp parallel do private(ddepx, ddepy, ddepz, icpt, ii, inod, &
     !$omp                     iel1, iel2, dtfac, rhofac)
     do ifac = 1, nfac
-      iecrw = 0
       ddepx = 0.d0
       ddepy = 0.d0
       ddepz = 0.d0
       icpt  = 0
       do ii = ipnfac(ifac),ipnfac(ifac+1)-1
         inod = nodfac(ii)
-        if (impale(inod).eq.0) iecrw = iecrw + 1
         icpt = icpt + 1
         ddepx = ddepx + disala(1,inod) + xyzno0(1,inod)-xyznod(1,inod)
         ddepy = ddepy + disala(2,inod) + xyzno0(2,inod)-xyznod(2,inod)
         ddepz = ddepz + disala(3,inod) + xyzno0(3,inod)-xyznod(3,inod)
       enddo
-      ! For inner vertices, the mass flux due to the mesh displacement is
-      !  recomputed from the nodes displacement
+      ! Compute the mass flux using the nodes displacement
+      if (iflxmw.eq.0) then
+        ! For inner vertices, the mass flux due to the mesh displacement is
+        !  recomputed from the nodes displacement
         iel1 = ifacel(1,ifac)
         iel2 = ifacel(2,ifac)
         dtfac = 0.5d0*(dt(iel1) + dt(iel2))
@@ -432,6 +443,9 @@ if (iprco.le.0) then
               ddepx*surfac(1,ifac)                                &
              +ddepy*surfac(2,ifac)                                &
              +ddepz*surfac(3,ifac) )/dtfac/icpt
+      else
+        propfa(ifac,iflmas) = propfa(ifac,iflmas) - intflx(ifac)
+      endif
     enddo
 
     ! Free memory
@@ -486,10 +500,11 @@ if (iprco.le.0) then
     rtpa(iel,iu) = vela(1,iel)
     rtpa(iel,iv) = vela(2,iel)
     rtpa(iel,iw) = vela(3,iel)
+    ! Store the diagonal part of dttens for postprocessing purpose
     if (ipucou.eq.1 .or. ncpdct.gt.0) then
-      tpucou(iel,1) = tpucov(1,iel)
-      tpucou(iel,2) = tpucov(2,iel)
-      tpucou(iel,3) = tpucov(3,iel)
+      tpucou(iel,1) = dttens(1,iel)
+      tpucou(iel,2) = dttens(2,iel)
+      tpucou(iel,3) = dttens(3,iel)
     endif
   enddo
 
@@ -498,41 +513,35 @@ if (iprco.le.0) then
   deallocate(vel)
   deallocate(vela)
   deallocate(coefap)
-  if (ipucou.eq.1 .or. ncpdct.gt.0) deallocate(tpucov)
 
   return
 
 endif
 
 !===============================================================================
-! 3.  ETAPE DE PRESSION/CONTINUITE ( VITESSE/PRESSION )
+! 4.  ETAPE DE PRESSION/CONTINUITE ( VITESSE/PRESSION )
 !===============================================================================
 
 if (iwarni(iu).ge.1) then
   write(nfecra,1200)
 endif
 
-! --- Pas de temps scalaire ou pas
-idtsca = 0
-if ((ipucou.eq.1).or.(ncpdct.gt.0)) idtsca = 1
-
 call resopv &
 !==========
  ( nvar   , nscal  ,                                              &
    ncepdc , ncetsm ,                                              &
-   icepdc , icetsm , itypsm ,                                     &
-   isostd , idtsca ,                                              &
+   icepdc , icetsm , itypsm , isostd ,                            &
    dt     , rtp    , rtpa   , vel    , vela   ,                   &
    propce , propfa , propfb ,                                     &
-   coefa  , coefb  , coefau , coefbu , coefap ,                   & !TODO
+   coefa  , coefb  , coefau , coefbu , coefap ,                   &
    ckupdc , smacel ,                                              &
-   frcxt  , dfrcxt , tpucov , trav   ,                            &
+   frcxt  , dfrcxt , dttens , trav   ,                            &
    viscf  , viscb  , viscfi , viscbi ,                            &
    drtp   , tslagr ,                                              &
    frchy  , dfrchy , trava  )
 
 !===============================================================================
-! 4.  RESOLUTION DE LA VITESSE DE MAILLAGE EN ALE
+! 5.  RESOLUTION DE LA VITESSE DE MAILLAGE EN ALE
 !===============================================================================
 
 if (iale.eq.1) then
@@ -550,7 +559,7 @@ if (iale.eq.1) then
 endif
 
 !===============================================================================
-! 5.  REACTUALISATION DU CHAMP DE VITESSE
+! 6.  REACTUALISATION DU CHAMP DE VITESSE
 !===============================================================================
 
 iclipr = iclrtp(ipr,icoef)
@@ -626,50 +635,52 @@ if (irevmc.eq.0) then
   !Free memory
   deallocate(gradp)
 
-  !     REACTUALISATION DU CHAMP DE VITESSES
-
+  ! Update the velocity field
+  !--------------------------
   thetap = thetav(ipr)
-  if (iphydr.eq.0) then
-    if (idtsca.eq.0) then
-      !$omp parallel do private(dtsrom, isou)
-      do iel = 1, ncel
-        dtsrom = -thetap*dt(iel)/propce(iel,ipcrom)
-        do isou = 1, 3
-          vel(isou,iel) = vel(isou,iel)+dtsrom*trav(isou,iel)
-        enddo
-      enddo
-    else
-      !$omp parallel do private(unsrom, isou)
-      do iel = 1, ncel
-        unsrom = -thetap/propce(iel,ipcrom)
-        ! tpucov is an interleaved array
-        do isou = 1, 3
-          vel(isou,iel) = vel(isou,iel) + unsrom*tpucov(isou,iel)*trav(isou,iel)
-        enddo
-      enddo
-    endif
-  else
-    if (idtsca.eq.0) then
+
+  ! Specific handling of hydrostatic pressure
+  !------------------------------------------
+  if (iphydr.eq.1) then
+
+    ! Scalar diffusion for the pressure
+    if (idften(ipr).eq.1) then
       !$omp parallel do private(dtsrom, isou)
       do iel = 1, ncel
         dtsrom = thetap*dt(iel)/propce(iel,ipcrom)
         do isou = 1, 3
-          vel(isou,iel) = vel(isou,iel)                           &
-             +dtsrom*(dfrcxt(iel,isou)-trav(isou,iel) )
+          vel(isou,iel) = vel(isou,iel)                            &
+                        + dtsrom*(dfrcxt(iel,isou)-trav(isou,iel))
         enddo
       enddo
-    else
-      !$omp parallel do private(unsrom, isou)
+
+    ! Tensorial diffusion for the pressure
+    else if (idften(ipr).eq.6) then
+      !$omp parallel do private(unsrom)
       do iel = 1, ncel
         unsrom = thetap/propce(iel,ipcrom)
-        ! tpucov is an interleaved array
-        do isou = 1, 3
-          vel(isou,iel) = vel(isou,iel)                         &
-               +unsrom*tpucov(isou,iel)                         &
-               *(dfrcxt(iel,isou)-trav(isou,iel))
-        enddo
+
+        vel(1, iel) = vel(1, iel)                                            &
+                    + unsrom*(                                               &
+                               dttens(1,iel)*(dfrcxt(iel,1)-trav(1,iel))     &
+                             + dttens(4,iel)*(dfrcxt(iel,2)-trav(2,iel))     &
+                             + dttens(6,iel)*(dfrcxt(iel,3)-trav(3,iel))     &
+                             )
+        vel(2, iel) = vel(2, iel)                                            &
+                    + unsrom*(                                               &
+                               dttens(4,iel)*(dfrcxt(iel,1)-trav(1,iel))     &
+                             + dttens(2,iel)*(dfrcxt(iel,2)-trav(2,iel))     &
+                             + dttens(5,iel)*(dfrcxt(iel,3)-trav(3,iel))     &
+                             )
+        vel(3, iel) = vel(3, iel)                                            &
+                    + unsrom*(                                               &
+                               dttens(6,iel)*(dfrcxt(iel,1)-trav(1,iel))     &
+                             + dttens(5,iel)*(dfrcxt(iel,2)-trav(2,iel))     &
+                             + dttens(3,iel)*(dfrcxt(iel,3)-trav(3,iel))     &
+                             )
       enddo
     endif
+
     ! Update external forces for the computation of the gradients
     !$omp parallel do
     do iel=1,ncel
@@ -690,6 +701,51 @@ if (irevmc.eq.0) then
         coefa(ifac,iclipr) = coefa(ifac,iclipr) + coefap(ifac)
       endif
     enddo
+
+
+  ! Standard handling of hydrostatic pressure
+  !------------------------------------------
+  else
+
+    ! Scalar diffusion for the pressure
+    if (idften(ipr).eq.1) then
+
+      !$omp parallel do private(dtsrom, isou)
+      do iel = 1, ncel
+        dtsrom = thetap*dt(iel)/propce(iel,ipcrom)
+        do isou = 1, 3
+          vel(isou,iel) = vel(isou,iel) - dtsrom*trav(isou,iel)
+        enddo
+      enddo
+
+    ! Tensorial diffusion for the pressure
+    else if (idften(ipr).eq.6) then
+
+      !$omp parallel do private(unsrom)
+      do iel = 1, ncel
+        unsrom = thetap/propce(iel,ipcrom)
+
+        vel(1, iel) = vel(1, iel)                              &
+                    - unsrom*(                                 &
+                               dttens(1,iel)*(trav(1,iel))     &
+                             + dttens(4,iel)*(trav(2,iel))     &
+                             + dttens(6,iel)*(trav(3,iel))     &
+                             )
+        vel(2, iel) = vel(2, iel)                              &
+                    - unsrom*(                                 &
+                               dttens(4,iel)*(trav(1,iel))     &
+                             + dttens(2,iel)*(trav(2,iel))     &
+                             + dttens(5,iel)*(trav(3,iel))     &
+                             )
+        vel(3, iel) = vel(3, iel)                              &
+                    - unsrom*(                                 &
+                               dttens(6,iel)*(trav(1,iel))     &
+                             + dttens(5,iel)*(trav(2,iel))     &
+                             + dttens(3,iel)*(trav(3,iel))     &
+                             )
+      enddo
+
+    endif
   endif
 endif
 
@@ -741,24 +797,24 @@ if (iale.eq.1) then
     propfb(ifac,iflmab) = propfb(ifac,iflmab) - bouflx(ifac)
   enddo
 
-  !$omp parallel do private(iecrw, ddepx, ddepy, ddepz, icpt, ii, inod, &
+  !$omp parallel do private(ddepx, ddepy, ddepz, icpt, ii, inod, &
   !$omp                     iel1, iel2, dtfac, rhofac)
   do ifac = 1, nfac
-    iecrw = 0
     ddepx = 0.d0
     ddepy = 0.d0
     ddepz = 0.d0
     icpt  = 0
     do ii = ipnfac(ifac),ipnfac(ifac+1)-1
       inod = nodfac(ii)
-      if (impale(inod).eq.0) iecrw = iecrw + 1
       icpt = icpt + 1
       ddepx = ddepx + disala(1,inod) + xyzno0(1,inod)-xyznod(1,inod)
       ddepy = ddepy + disala(2,inod) + xyzno0(2,inod)-xyznod(2,inod)
       ddepz = ddepz + disala(3,inod) + xyzno0(3,inod)-xyznod(3,inod)
     enddo
-    ! For inner vertices, the mass flux due to the mesh displacement is
-    !  recomputed from the nodes displacement
+    ! Compute the mass flux using the nodes displacement
+    if (iflxmw.eq.0) then
+      ! For inner vertices, the mass flux due to the mesh displacement is
+      !  recomputed from the nodes displacement
       iel1 = ifacel(1,ifac)
       iel2 = ifacel(2,ifac)
       dtfac = 0.5d0*(dt(iel1) + dt(iel2))
@@ -767,6 +823,9 @@ if (iale.eq.1) then
             ddepx*surfac(1,ifac)                                &
            +ddepy*surfac(2,ifac)                                &
            +ddepz*surfac(3,ifac) )/dtfac/icpt
+    else
+      propfa(ifac,iflmas) = propfa(ifac,iflmas) - intflx(ifac)
+    endif
   enddo
 
   ! Free memory
@@ -813,7 +872,7 @@ if (imobil.eq.1) then
 endif
 
 !===============================================================================
-! 5.  CALCUL D'UN ESTIMATEUR D'ERREUR DE L'ETAPE DE CORRECTION ET TOTAL
+! 7.  CALCUL D'UN ESTIMATEUR D'ERREUR DE L'ETAPE DE CORRECTION ET TOTAL
 !===============================================================================
 
 if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
@@ -944,8 +1003,8 @@ if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
    propce , propfa , propfb ,                                     &
    esflum , esflub ,                                              &
    tslagr , coefa  , coefb  , coefau , coefbu , cofafu , cofbfu , &
-   ckupdc , smacel , frcxt  ,                                     &
-   trava  , ximpa  , uvwk   , dfrcxt , tpucov , trav   ,          &
+   ckupdc , smacel , frcxt  , grdphd ,                            &
+   trava  , ximpa  , uvwk   , dfrcxt , dttens , trav   ,          &
    viscf  , viscb  , viscfi , viscbi , secvif , secvib ,          &
    w1     , w7     , w8     , w9     , w10    )
 
@@ -954,7 +1013,7 @@ if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 endif
 
 !===============================================================================
-! 6.  TRAITEMENT DU POINT FIXE SUR LE SYSTEME VITESSE/PRESSION
+! 8.  TRAITEMENT DU POINT FIXE SUR LE SYSTEME VITESSE/PRESSION
 !===============================================================================
 
 if (nterup.gt.1) then
@@ -1023,7 +1082,7 @@ if (ippmod(icompf).lt.0) then
 endif
 
 !===============================================================================
-! 7.  IMPRESSIONS
+! 9.  IMPRESSIONS
 !===============================================================================
 
 iflmas = ipprof(ifluma(iu))
@@ -1044,14 +1103,24 @@ if (iwarni(iu).ge.1) then
   write(nfecra,2100)rnorm
 
   rnorm = -1.d0
-  !$omp parallel do private(vitnor, rnorm, imax)
+  imax = 1
+  !$omp parallel private(vitnor, rnormt, imaxt)
+  rnormt = -1.d0
+  !$omp do
   do iel = 1, ncel
     vitnor = sqrt(vel(1,iel)**2+vel(2,iel)**2+vel(3,iel)**2)
-    if (vitnor.ge.rnorm) then
-      rnorm = vitnor
-      imax  = iel
+    if (vitnor.ge.rnormt) then
+      rnormt = vitnor
+      imaxt  = iel
     endif
   enddo
+  !$omp critical
+  if (rnormt .gt. rnorm) then
+    rnormt = rnorm
+    imax = imaxt
+  endif
+  !$omp end critical
+  !$omp end parallel
 
   xyzmax(1) = xyzcen(1,imax)
   xyzmax(2) = xyzcen(2,imax)
@@ -1142,6 +1211,7 @@ deallocate(drtp)
 deallocate(trav)
 if (allocated(dfrcxt)) deallocate(dfrcxt)
 if (allocated(frchy))  deallocate(frchy, dfrchy)
+if (allocated(grdphd)) deallocate(grdphd)
 if (allocated(esflum)) deallocate(esflum, esflub)
 if (allocated(wvisfi)) deallocate(wvisfi, wvisbi)
 deallocate(w1)
@@ -1160,10 +1230,12 @@ do iel = 1, ncelet
   rtpa(iel,iu) = vela(1,iel)
   rtpa(iel,iv) = vela(2,iel)
   rtpa(iel,iw) = vela(3,iel)
+
+  ! Store the diagonal part of dttens for postprocessing purpose
   if (ipucou.eq.1 .or. ncpdct.gt.0) then
-    tpucou(iel,1) = tpucov(1,iel)
-    tpucou(iel,2) = tpucov(2,iel)
-    tpucou(iel,3) = tpucov(3,iel)
+    tpucou(iel,1) = dttens(1,iel)
+    tpucou(iel,2) = dttens(2,iel)
+    tpucou(iel,3) = dttens(3,iel)
   endif
 enddo
 
@@ -1172,7 +1244,6 @@ enddo
 deallocate(vel)
 deallocate(vela)
 deallocate(coefap)
-if (ipucou.eq.1 .or. ncpdct.gt.0) deallocate(tpucov)
 
 !--------
 ! Formats
