@@ -828,9 +828,8 @@ module optcal
   !                       variables par l'utilisateur
   !          iusini = 1 passage dans usiniv ou ppiniv
   !                   0 pas de passage (ni iusini ni ppiniv)
-  !          iuscfp = 1 n'est plus utile et est ignore
 
-  integer, save :: iusini, iuscfp
+  integer, save :: iusini
 
   !> \}
 
@@ -987,6 +986,30 @@ module optcal
   !> ctheta : coefficient des modeles de flux turbulents GGDH et AFM
   double precision, save :: ctheta(nscamx)
 
+  !> flag for computing the drift mass flux:
+  !> (for coal classes for instance, only the first
+  !>  scalar of a class compute the drift flux of the class
+  !>  and the other scalars use it without recomputing it)
+  integer :: DRIFT_SCALAR_ADD_DRIFT_FLUX
+
+  !> flag for activating thermophoresis for drift scalars
+  integer :: DRIFT_SCALAR_THERMOPHORESIS
+
+  !> flag for activating turbophoresis for drift scalars
+  integer :: DRIFT_SCALAR_TURBOPHORESIS
+
+  ! flag for activating electrophoresis for drift scalars
+  integer :: DRIFT_SCALAR_ELECTROPHORESIS
+
+  !> flag for activating the centrifugal force for drift scalars
+  integer :: DRIFT_SCALAR_CENTRIFUGALFORCE
+
+  parameter (DRIFT_SCALAR_ADD_DRIFT_FLUX=1)
+  parameter (DRIFT_SCALAR_THERMOPHORESIS=2)
+  parameter (DRIFT_SCALAR_TURBOPHORESIS=3)
+  parameter (DRIFT_SCALAR_ELECTROPHORESIS=4)
+  parameter (DRIFT_SCALAR_CENTRIFUGALFORCE=5)
+
   !> \}
 
   !> \}
