@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -20,43 +20,43 @@
 
 !-------------------------------------------------------------------------------
 
-subroutine phyvar &
-!================
+!===============================================================================
+! Function:
+! ---------
 
+!> \file phyvar.f90
+!>
+!> \brief This subroutine fills physical properties which are variable in time
+!> (mainly the eddy viscosity).
+!>
+!> Some user subroutines are called which allows the setting of \f$ \rho \f$,
+!> \f$ \mu \f$, etc.
+!>
+!-------------------------------------------------------------------------------
+
+!-------------------------------------------------------------------------------
+! Arguments
+!______________________________________________________________________________.
+!  mode           name          role                                           !
+!______________________________________________________________________________!
+!> \param[in]     nvar          total number of variables
+!> \param[in]     nscal         total number of scalars
+!> \param[in]     dt            time step (per cell)
+!> \param[in,out] rtp, rtpa     calculated variables at cell centers
+!>                               (at current and previous time steps)
+!> \param[in]     propce        physical properties at cell centers
+!> \param[in,out] propfa        physical properties at interior face centers
+!> \param[in,out] propfb        physical properties at boundary face centers
+!> \param[in]     coefa, coefb  boundary conditions
+!_______________________________________________________________________________
+
+
+subroutine phyvar &
  ( nvar   , nscal  ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
    coefa  , coefb  )
 
 !===============================================================================
-! FONCTION :
-! --------
-
-! REMPLISSAGE DES GRANDEURS PHYSIQUES VARIABLES EN TEMPS
-!    ESSENTIELLEMENT LA VISCOSITE TURBULENTE.
-!    ON APPELLE UN SOUS PROGRAMME UTILISATEUR QUI PERMET DE
-!    SPECIFIER ROM, ROMB, VISCL, VISCLS ...
-
-! Arguments
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
-! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
-!  (ncelet, *)     !    !     !  (at current and previous time steps)          !
-! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
-! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
-! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
-!__________________!____!_____!________________________________________________!
-
-!     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
-!            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
-!     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
-!            --- tableau de travail
-!===============================================================================
 
 !===============================================================================
 ! Module files
@@ -110,11 +110,7 @@ double precision varmn(4), varmx(4), tt, ttmin, ttke, viscto, xrtp
 double precision alp3, xrij(3,3) , xnal(3)   , xnoral
 double precision xttke, xttkmg, xttdrb,epsrgp, climgp, extrap
 double precision alpha, ym, yk
-
-double precision, allocatable, dimension(:) :: vistot, viscf, viscb
-double precision, allocatable, dimension(:) :: coefap, coefbp
-double precision, allocatable, dimension(:) :: cofafp, cofbfp
-double precision, allocatable, dimension(:) :: whsad
+double precision trrij, csteps
 
 integer          ipass
 data             ipass /0/
@@ -123,22 +119,19 @@ save             ipass
 !===============================================================================
 
 !===============================================================================
-! 1.  INITIALISATIONS
+! 1. Initializations
 !===============================================================================
 
-
 ipass = ipass + 1
 
 !===============================================================================
-! 2.  PREPARATION DE LA PERIODICITE DE ROTATION
-!       CALCUL DE DUDXYZ ET DRDXYZ (gradients sur les halos avec prise
-!       en compte des periodicites pour exploitation dans pering, inimas)
+! 2. Preparing periodicity of rotation
 !===============================================================================
 
 if (iperot.gt.0) then
 
   if (ivelco.eq.0) then
-    call perinu                                                    &
+    call perinu &
     !==========
   ( nvar   , nscal  ,                                              &
     dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
@@ -148,7 +141,7 @@ if (iperot.gt.0) then
 
   if (itytur.eq.3) then
 
-    call perinr                                                   &
+    call perinr &
     !==========
  ( nvar   , nscal  ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
@@ -176,22 +169,11 @@ if (idilat.eq.4.and.ipass.gt.1) then
 endif
 
 !===============================================================================
-! 4.  ON REND LA MAIN A L'UTILISATEUR POUR LA PROGRAMMATION DES
-!      GRANDEURS PHYSIQUES VARIABLES QUI LUI SONT PROPRES
+! 4. User settings
 !===============================================================================
 
 ibrom = 0
 
-if (ippmod(iphpar).ge.1) then
-  call ppphyv                                                     &
-  !==========
- ( nvar   , nscal  ,                                              &
-   ibrom  ,                                                       &
-   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  )
-
-endif
-
 
 ! - Interface Code_Saturne
 !   ======================
@@ -202,7 +184,7 @@ if (iihmpr.eq.1) then
 ( ncel, ncelet, nscaus,                                         &
   irom, iviscl, icp,    ivisls, irovar, ivivar,                 &
   isca, iscalt, iscsth, iscavr, ipproc, iviscv, itempk,         &
-  p0  , t0    , ro0   , cp0   , viscl0, visls0,                 &
+  p0  , t0    , ro0   , cp0   , viscl0, visls0, viscv0,         &
   rtp,    propce)
 endif
 
@@ -211,11 +193,23 @@ call usphyv &
 ( nvar   , nscal  ,                                              &
   ibrom  ,                                                       &
   dt     , rtp    , rtpa   ,                                     &
-  propce , propfa , propfb ,                                     &
-  coefa  , coefb  )
+  propce , propfa , propfb )
+
+if (ippmod(iphpar).ge.1) then
+  call ppphyv &
+  !==========
+ ( nvar   , nscal  ,                                              &
+   ibrom  ,                                                       &
+   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
+   coefa  , coefb  )
+
+endif
+
+!===============================================================================
+! 5. Density defined by a perfect gas equation of state
+!    for the low-Mach algorithm
+!===============================================================================
 
-!  Density defined by a perfect gas equation of state
-!  for the low-Mach algorithm
 if (idilat.eq.3) then
 
   ! Works only with enthalpy
@@ -312,7 +306,7 @@ endif
 
 if (ntcabs.eq.ntpabs+1) then
 
-!     Masse volumique aux cellules et aux faces de bord
+  ! Masse volumique aux cellules et aux faces de bord
   iok1 = 0
   if (irovar.eq.0) then
     ipcrom = ipproc(irom)
@@ -332,7 +326,7 @@ if (ntcabs.eq.ntpabs+1) then
     write(nfecra,9001)
   endif
 
-!     Viscosite moleculaire aux cellules
+  ! Viscosite moleculaire aux cellules
   iok2 = 0
   if (ivivar.eq.0) then
     ipcvis = ipproc(iviscl)
@@ -357,13 +351,13 @@ if (ntcabs.eq.ntpabs+1) then
 endif
 
 !===============================================================================
-! 3.  CALCUL DE LA VISCOSITE TURBULENTE
+! 6. Compute the eddy viscosity
 !===============================================================================
 
 if     (iturb.eq. 0) then
 
-! 3.1 LAMINAIRE
-! ==============
+! 6.1 Laminar
+! ===========
 
   ipcvst = ipproc(ivisct)
 
@@ -373,8 +367,8 @@ if     (iturb.eq. 0) then
 
 elseif (iturb.eq.10) then
 
-! 3.2 LONGUEUR DE MELANGE
-! ========================
+! 6.2 Mixing length model
+! =======================
 
   call vislmg &
   !==========
@@ -386,8 +380,8 @@ elseif (iturb.eq.10) then
 
 elseif (itytur.eq.2) then
 
-! 3.3 K-EPSILON
-! ==============
+! 6.3 k-epsilon
+! =============
 
   ipcvst = ipproc(ivisct)
   ipcrom = ipproc(irom  )
@@ -400,8 +394,8 @@ elseif (itytur.eq.2) then
 
 elseif (itytur.eq.3) then
 
-! 3.4 Rij-EPSILON
-! ================
+! 6.4 Rij-epsilon
+! ===============
 
   ipcvst = ipproc(ivisct)
   ipcrom = ipproc(irom  )
@@ -414,10 +408,9 @@ elseif (itytur.eq.3) then
 
 elseif (iturb.eq.40) then
 
-! 3.5 LES Smagorinsky
+! 6.5 LES Smagorinsky
 ! ===================
 
-
   call vissma &
   !==========
  ( nvar   , nscal  ,                                              &
@@ -428,9 +421,8 @@ elseif (iturb.eq.40) then
 
 elseif (iturb.eq.41) then
 
-! 3.6 LES dynamique
-! =================
-
+! 6.6 LES dynamic
+! ===============
 
   call visdyn &
   !==========
@@ -443,10 +435,9 @@ elseif (iturb.eq.41) then
 
 elseif (iturb.eq.42) then
 
-! 3.7 LES WALE
+! 6.7 LES WALE
 ! ============
 
-
   call viswal &
   !==========
  ( nvar   , nscal  ,                                              &
@@ -457,7 +448,7 @@ elseif (iturb.eq.42) then
 
 elseif (itytur.eq.5) then
 
-! 3.8 v2f (phi-model and BL-v2/k)
+! 6.8 v2f (phi-model and BL-v2/k)
 ! ===============================
 
   if (iturb.eq.50) then
@@ -491,7 +482,7 @@ elseif (itytur.eq.5) then
 
 elseif (iturb.eq.60) then
 
-! 3.9 K-OMEGA SST
+! 6.9 k-omega SST
 ! ===============
 
   call vissst &
@@ -504,8 +495,8 @@ elseif (iturb.eq.60) then
 
 elseif (iturb.eq.70) then
 
-! 3.10 SPALART -ALLMARAS
-! ======================
+! 6.10 Spalart-Allmaras
+! =====================
 
   cv13 = csav1**3
 
@@ -524,7 +515,53 @@ elseif (iturb.eq.70) then
 endif
 
 !===============================================================================
-! 4.  MODIFICATION UTILISATEUR DE LA VISCOSITE TURBULENTE
+! 7. Symmetric tensor diffusivity
+!===============================================================================
+iok = 0
+do ivar = 1, nvar
+  if (ivar.ne.ipr) then
+    if (idften(ivar).eq.6) iok = 1
+  endif
+enddo
+
+do iscal = 1, nscal
+  if (ityturt(iscal).eq.3) iok = 1
+enddo
+
+if (iok.eq.1) then
+  if (itytur.eq.3) then
+
+    ipcrom = ipproc(irom)
+
+    do iel = 1, ncel
+      trrij = 0.5d0*(rtp(iel,ir11)+rtp(iel,ir22)+rtp(iel,ir33))
+      csteps  = propce(iel,ipcrom) * trrij / rtp(iel,iep)
+
+      visten(1,iel) = csteps*rtp(iel,ir11)
+      visten(2,iel) = csteps*rtp(iel,ir22)
+      visten(3,iel) = csteps*rtp(iel,ir33)
+      visten(4,iel) = csteps*rtp(iel,ir12)
+      visten(5,iel) = csteps*rtp(iel,ir13)
+      visten(6,iel) = csteps*rtp(iel,ir23)
+    enddo
+
+  else
+
+    do iel = 1, ncel
+      visten(1,iel) = 0.d0
+      visten(2,iel) = 0.d0
+      visten(3,iel) = 0.d0
+      visten(4,iel) = 0.d0
+      visten(5,iel) = 0.d0
+      visten(6,iel) = 0.d0
+    enddo
+
+  endif
+endif
+
+!===============================================================================
+! 8. User modification of the turbulent viscosity and symmetric tensor
+!    diffusivity
 !===============================================================================
 
 call usvist &
@@ -533,10 +570,10 @@ call usvist &
   ncepdc , ncetsm ,                                              &
   icepdc , icetsm , itypsm ,                                     &
   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-  coefa  , coefb  , ckupdc , smacel )
+  ckupdc , smacel )
 
 !===============================================================================
-! 5.  CLIPPING DE LA VISCOSITE TURBULENTE EN LES DYNAMIQUE
+! 9. Clipping of the turbulent viscosity in dynamic LES
 !===============================================================================
 
 ! Pour la LES en modele dynamique on clippe la viscosite turbulente de maniere
@@ -558,14 +595,13 @@ if (iturb.eq.41) then
   if (iwarni(iu).ge.1) then
     if (irangp.ge.0) then
       call parcpt(iclipc)
-      !==========
     endif
     write(nfecra,1000) iclipc
   endif
 endif
 
 !===============================================================================
-! 6.  MODIFICATION UTILISATEUR DE LA VISCOSITE DE MAILLAGE EN ALE
+! 10. User modification of the mesh viscosity in ALE
 !===============================================================================
 
 if (iale.eq.1.and.ntcabs.eq.0) then
@@ -575,7 +611,7 @@ if (iale.eq.1.and.ntcabs.eq.0) then
 
   if (iihmpr.eq.1) then
 
-    call uivima                       &
+    call uivima &
     !==========
   ( ncel,                             &
     propce(1,ipproc(ivisma(1))),      &
@@ -585,20 +621,19 @@ if (iale.eq.1.and.ntcabs.eq.0) then
 
   endif
 
-  call usvima                                                     &
+  call usvima &
   !==========
  ( nvar   , nscal  ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  , propce(1,ipproc(ivisma(1))) ,                &
+   propce(1,ipproc(ivisma(1))) ,                                  &
    propce(1,ipproc(ivisma(2))) , propce(1,ipproc(ivisma(3))) )
 
 endif
 
 !===============================================================================
-! 7.  IMPRESSIONS DE CONTROLE DES VALEURS ENTREES PAR L'UTILISATEUR
+! 11. Checcking of the user values
 !===============================================================================
 
-
 ! ---> Calcul des bornes des variables et impressions
 
 ! Indicateur d'erreur
@@ -635,9 +670,7 @@ do ii = 1, nn
     enddo
     if (irangp.ge.0) then
       call parmax (varmx(ii))
-      !==========
       call parmin (varmn(ii))
-      !==========
     endif
   endif
 enddo
@@ -651,12 +684,10 @@ do ifac = 1, nfabor
 enddo
 if (irangp.ge.0) then
   call parmax (varmx(ii))
-  !==========
   call parmin (varmn(ii))
-  !==========
 endif
 
-! Impressions
+! Writings
 iok1 = 0
 do ii = 1, nn
   if (ii.eq.1) chaine = nomvar(ipppro(ipproc(irom  )))
@@ -742,9 +773,7 @@ if (nscal.ge.1) then
       enddo
       if (irangp.ge.0) then
         call parmax (vismax(iscal))
-        !==========
         call parmin (vismin(iscal))
-        !==========
       endif
     else
       vismax(iscal) = visls0(iscal)
@@ -764,9 +793,9 @@ if (nscal.ge.1) then
   enddo
   if (iok1.eq.1) write(nfecra,3112)
 
-! Verifications de valeur physique
+  ! Verifications de valeur physique
 
-! IOK a deja ete initialise
+  ! IOK a deja ete initialise
 
   do iscal = 1, nscal
 
@@ -778,6 +807,13 @@ if (nscal.ge.1) then
       iok = iok + 1
     endif
 
+    if (iscal.eq.iscalt.and.irovar.eq.1.and.ityturt(iscal).eq.2) then
+      iok1 = 0
+      do iel = 1, ncel
+        if (propce(iel,ipproc(ibeta)).le.0.d0) iok1 = 1
+      enddo
+      if (iok1.eq.1) write(nfecra,9013)
+    endif
   enddo
 
 endif
@@ -792,7 +828,7 @@ if (iale.eq.1.and.ntcabs.eq.0) then
   do ii = 1, nn
     ipcvma = ipproc(ivisma(ii))
 
-! Min et max sur les cellules
+    ! Min et max sur les cellules
     varmx(1) = propce(1,ipcvma)
     varmn(1) = propce(1,ipcvma)
     do iel = 2, ncel
@@ -801,12 +837,10 @@ if (iale.eq.1.and.ntcabs.eq.0) then
     enddo
     if (irangp.ge.0) then
       call parmax (varmx(1))
-      !==========
       call parmin (varmn(1))
-      !==========
     endif
 
-! Impressions
+    ! Writings
     chaine = nomvar(ipppro(ipcvma))
     if (iwarni(iuma).ge.1.or.ipass.eq.1.or.varmn(1).lt.0.d0) then
       if (iok1.eq.0) then
@@ -816,9 +850,9 @@ if (iale.eq.1.and.ntcabs.eq.0) then
       write(nfecra,3211)chaine(1:16),varmn(1),varmx(1)
     endif
 
-! Verifications de valeur physique
+    ! Verifications de valeur physique
 
-! Viscosite de maillage definie
+    ! Viscosite de maillage definie
     chaine = nomvar(ipppro(ipcvma))
     if (varmn(1).le.0.d0) then
       write(nfecra,9211) varmn(1)
@@ -839,22 +873,20 @@ if (iok.ne.0) then
 endif
 
 !===============================================================================
-! 8.  ECHANGES
+! 12. Parallelism and periodicity
 !===============================================================================
 
 ! Pour navsto et vissec on a besoin de ROM dans le halo
 
-
 ipcrom = ipproc(irom)
 
 if (irangp.ge.0.or.iperio.eq.1) then
   call synsca(propce(1,ipcrom))
-  !==========
 endif
 
-!----
-! FORMATS
-!----
+!--------
+! Formats
+!--------
 
 #if defined(_CS_LANG_FR)
 
@@ -931,17 +963,17 @@ endif
 '@ @@ ATTENTION : ARRET LORS DU CALCUL DES GRANDEURS PHYSIQUES',/,&
 '@    =========',                                               /,&
 '@    MODULE COMPRESSIBLE',                                     /,&
-'@    INCOHERENCE ENTRE USCFPV ET USCFX1 POUR',                 /,&
+'@    INCOHERENCE ENTRE USCFPV ET USCFX2 POUR',                 /,&
 '@                                    LA VISCOSITE MOLECULAIRE',/,&
 '@',                                                            /,&
 '@  En compressible la viscosite moleculaire est constante par',/,&
 '@     defaut (IVIVAR=0) et la valeur de IVIVAR n''a',   /,&
-'@     pas ete modifiee dans uscfx1. Pourtant, on a modifie',   /,&
+'@     pas ete modifiee dans uscfx2. Pourtant, on a modifie',   /,&
 '@     les valeurs de la viscosite moleculaire dans uscfpv.',   /,&
 '@',                                                            /,&
 '@  Le calcul ne sera pas execute.',                            /,&
 '@',                                                            /,&
-'@  Verifier uscfx1 et uscfpv.',                                /,&
+'@  Verifier uscfx2 et uscfpv.',                                /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
@@ -995,6 +1027,25 @@ endif
 '@    dans usvist.',                                            /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /)
+ 9013  format(                                                    &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ ATTENTION : ARRET LORS DU CALCUL DES GRANDEURS PHYSIQUES',/,&
+'@    =========',                                               /,&
+'@    INCOHERENCE ENTRE LES PARAMETRES ET LE COEFFICIENT'      ,/,&
+'@    de dilatation volumique  Beta'                           ,/,&
+'@',                                                            /,&
+'@  On a indique que la masse volumique etait',                 /,&
+'@     variable (IROVAR=1) mais on n a pas modifie ',           /,&
+'@     la valeur de Beta dans l''interface ou dans usphyv',     /,&
+'@',                                                            /,&
+'@  Le calcul ne sera pas execute.',                            /,&
+'@',                                                            /,&
+'@  Verifier l''interface et usphyv.'                         , /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
 
  9111  format(                                                    &
@@ -1127,17 +1178,17 @@ endif
 '@',                                                            /,&
 '@ @@ WARNING: ABORT IN THE PHYSICAL QUANTITIES COMPUTATION',   /,&
 '@    ========',                                                /,&
-'@    INCOHERENCY BETWEEN USCFPV AND USCFX1 FOR',               /,&
+'@    INCOHERENCY BETWEEN USCFPV AND USCFX2 FOR',               /,&
 '@                                     THE MOLECULAR VISCOSITY',/,&
 '@',                                                            /,&
 '@  In the compressible module, the molecular viscosity is',    /,&
 '@     constant by default (IVIVAR=0) and the value',    /,&
-'@     of IVIVAR  has not been modified in uscfx1. Yet, its',   /,&
+'@     of IVIVAR  has not been modified in uscfx2. Yet, its',   /,&
 '@     value has been modified in uscfpv.',                     /,&
 '@',                                                            /,&
 '@  The calculation will not be run.',                          /,&
 '@',                                                            /,&
-'@  Verify uscfx1 and uscfpv.',                                 /,&
+'@  Verify uscfx2 and uscfpv.',                                 /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
@@ -1188,6 +1239,26 @@ endif
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
+ 9013  format( &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ WARNING : ABORT IN THE PHYSICAL QUANTITIES COMPUTATION',  /,&
+'@    =========',                                               /,&
+'@    INCOHERENCY BETWEEN PARAMETERS and the volumic thermal'  ,/,&
+'@    expansion coefficient Beta'                              ,/,&
+'@',                                                            /,&
+'@  The density has been declared variable (IROVAR=1) but',     /,&
+'@     the value of Beta has not been modified     ',           /,&
+'@     in GUI or usphyv',                                       /,&
+'@',                                                            /,&
+'@  The calculation will not be run',                           /,&
+'@',                                                            /,&
+'@  Check the interface or usphyv.'                           , /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@', /)
+
 
  9111  format(                                                    &
 '@',                                                            /,&
