@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -20,7 +20,8 @@
 
 !-------------------------------------------------------------------------------
 
-! Module for pointer variables
+!> \file pointe.f90
+!> Module for pointer variables
 
 module pointe
 
@@ -30,9 +31,45 @@ module pointe
 
   !=============================================================================
 
+
+  !> \defgroup fortan_pointer_containers Containers to Fortran array pointers.
+  !> An array of one of these these derived types can be used to manage a set of
+  !> pointers (Fortran not allow arrays of pointers directly, so this
+  !> technique is a classical workaround.
+
+  ! Note also that Fortran bounds remapping could in theory be used to
+  ! handle different pointer shapes with a single type, but this feature
+  ! of Fortran 2003 (extended in 2008) is supported only by very recent
+  ! compilers (2010 or later), and even recent compilers such as Intel 12
+  ! reportedly have bugs using this feature, so we will need to avoid
+  ! depending on it for a few years.
+
+  !> \ingroup fortan_pointer_containers
+  !> \brief container for rank 1 double precision array pointer.
+
+  type pmapper_double_r1
+    double precision, dimension(:),  pointer :: p !< rank 1 array pointer
+  end type pmapper_double_r1
+
+  !> \ingroup fortan_pointer_containers
+  !> \brief container for rank 2 double precision array pointer.
+
+  type pmapper_double_r2
+    double precision, dimension(:,:),  pointer :: p !< rank 2 array pointer
+  end type pmapper_double_r2
+
+  !> \ingroup fortan_pointer_containers
+  !> \brief container for rank 3 double precision array pointer.
+
+  type pmapper_double_r3
+    double precision, dimension(:,:,:),  pointer :: p !< rank 3 array pointer
+  end type pmapper_double_r3
+
+  !=============================================================================
+
   !... Auxiliaires
 
-  ! Array ! Dimension               ! Description
+  ! Array  ! Dimension               ! Description
 
   ! dispar ! ncelet                  ! distance a la face de type 5 (phase 1) la
   !                                    plus proche
@@ -93,8 +130,11 @@ module pointe
   ! s2kw   ! ncelet                  ! stockage de 2 Sij.Sij en k-omega
   ! divukw ! ncelet                  ! stockage de divu en k-omega (en meme
   !                                    temps que s2kw)
+  ! straio ! ncelet                  ! strain rate tensor at the
+  !                                    previous time step
 
   double precision, allocatable, dimension(:) :: s2kw , divukw
+  double precision, allocatable, dimension(:,:) :: straio
 
   !... Parametres du module thermique 1D
 
@@ -143,6 +183,12 @@ module pointe
   ! porosi ! ncelet                  ! value of the porosity
   double precision, allocatable, dimension(:) :: porosi
 
+  ! visten ! ncelet                  ! symmetric tensor cell visco
+  double precision, allocatable, dimension(:,:) :: visten
+
+  ! dttens ! ncelet                  ! diagonal tensor cell tensor for pressure
+  double precision, allocatable, dimension(:,:) :: dttens
+
 contains
 
   !=============================================================================
@@ -151,10 +197,10 @@ contains
 
   subroutine init_aux_arrays &
 
-( ncelet , ncel   , ncelbr , nfac  , nfabor , &
-  iverif )
+( ncelet , ncel   , ncelbr , nfac  , nfabor )
 
     use paramx
+    use numvar, only: ipr
     use parall
     use period
     use optcal
@@ -170,7 +216,9 @@ contains
     ! Arguments
 
     integer, intent(in) :: ncelet, ncel, ncelbr, nfac, nfabor
-    integer, intent(in) :: iverif
+
+    ! Local variables
+    integer                iok, ivar, iscal
 
     ! Boundary-face related arrays
 
@@ -209,6 +257,31 @@ contains
       allocate(porosi(ncelet))
     endif
 
+    ! Symmetric cell diffusivity when needed
+    iok = 0
+    do ivar = 1, nvarmx
+      if (idften(ivar).eq.6) iok = 1
+    enddo
+
+    do iscal = 1, nscamx
+      if (ityturt(iscal).eq.3) iok = 1
+    enddo
+
+    if (iok.eq.1) then
+      allocate(visten(6,ncelet))
+    endif
+
+    ! Diagonal cell tensor for the pressure solving when needed
+    if (ncpdct.gt.0.or.ipucou.eq.1) then
+      if (ivelco.eq.0) then
+        idften(ipr) = 3
+        allocate(dttens(3,ncelet))
+      else
+        idften(ipr) = 6
+        allocate(dttens(6,ncelet))
+      endif
+    endif
+
     ! Wall-distance calculation
 
     if (ineedy.eq.1 .and. abs(icdpar).eq.1) then
@@ -246,7 +319,7 @@ contains
 
     ! Non-dimensional distance to the wall (for post-processing)
 
-    if (mod(ipstdv,ipstyp).eq.0) then
+    if (ipstdv(ipstyp).ne.0) then
       allocate(yplbr(nfabor))
     endif
 
@@ -257,6 +330,14 @@ contains
       allocate(divukw(ncelet))
     endif
 
+   ! Strain rate tensor at the previous time step
+   ! if rotation curvature correction
+   if (irccor.eq.1) then
+      if (idtvar.ge.0) then
+        allocate(straio(ncelet,6))
+      endif
+    endif
+
     return
 
   end subroutine init_aux_arrays
@@ -276,6 +357,8 @@ contains
     if (allocated(izft1d)) deallocate(izft1d)
     if (allocated(coefau)) deallocate(coefau, cofafu, coefbu, cofbfu)
     if (allocated(porosi)) deallocate(porosi)
+    if (allocated(visten)) deallocate(visten)
+    if (allocated(dttens)) deallocate(dttens)
     if (allocated(cfaale)) deallocate(cfaale, cfbale, claale, clbale)
     if (allocated(dispar)) deallocate(dispar)
     if (allocated(yplpar)) deallocate(yplpar)
@@ -286,6 +369,7 @@ contains
     if (allocated(uetbor)) deallocate(uetbor)
     if (allocated(yplbr)) deallocate(yplbr)
     if (allocated(s2kw)) deallocate(s2kw, divukw)
+    if (allocated(straio))  deallocate(straio)
 
     return
 
