@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -108,17 +108,17 @@ implicit none
 
 integer          nvar   , nscal
 
-integer          icodcl(nfabor,nvar)
+integer          icodcl(nfabor,nvarcl)
 
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
 double precision coefa(nfabor,*), coefb(nfabor,*)
-double precision rcodcl(nfabor,nvar,3)
+double precision rcodcl(nfabor,nvarcl,3)
 
 ! Local variables
 
-integer          ifac, ivar
+integer          ifac, ivar, iscal, iut, ivt, iwt
 
 !===============================================================================
 !===============================================================================
@@ -151,6 +151,29 @@ do ivar = 1, nvar
   enddo
 enddo
 
+! Default value for turbulent fluxes
+do iscal = 1, nscal
+  if (ityturt(iscal).eq.3) then
+    iut = nvar + 3*(ifltur(iscal) - 1) + 1
+    ivt = nvar + 3*(ifltur(iscal) - 1) + 2
+    iwt = nvar + 3*(ifltur(iscal) - 1) + 3
+    do ifac = 1, nfabor
+      icodcl(ifac,iut)   = 0
+      rcodcl(ifac,iut,1) = rinfin
+      rcodcl(ifac,iut,2) = rinfin
+      rcodcl(ifac,iut,3) = 0.d0
+      icodcl(ifac,ivt)   = 0
+      rcodcl(ifac,ivt,1) = rinfin
+      rcodcl(ifac,ivt,2) = rinfin
+      rcodcl(ifac,ivt,3) = 0.d0
+      icodcl(ifac,iwt)   = 0
+      rcodcl(ifac,iwt,1) = rinfin
+      rcodcl(ifac,iwt,2) = rinfin
+      rcodcl(ifac,iwt,3) = 0.d0
+    enddo
+  endif
+enddo
+
 ! En ALE, on initialise aussi le tableau IALTYB
 if (iale.eq.1) then
   do ifac = 1, nfabor
