@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -64,8 +64,6 @@
 !_______________________________________________________________________________
 
 subroutine predfl &
-!================
-
  ( nvar   , nscal  , ncesmp ,                                     &
    icetsm ,                                                       &
    dt     , rtp    , rtpa   ,                                     &
@@ -126,9 +124,9 @@ integer          idiffp, iconvp, ndircp
 integer          nitmap, imgrp , ncymap, nitmgp
 integer          iinvpe
 integer          nagmax, npstmg
-integer          ibsize, iphydp
+integer          ibsize, iesize, iphydp
 integer          imucpp
-double precision residu, resold
+double precision residu
 double precision thetap
 double precision epsrgp, climgp, extrap, epsilp
 double precision drom  , tcrite, relaxp, rnorm, hint, qimp
@@ -175,6 +173,7 @@ endif
 
 ! Matrix block size
 ibsize = 1
+iesize = 1
 
 if (iresol(ipr).eq.-1) then
   ireslp = 0
@@ -309,8 +308,8 @@ if (imgr(ipr).gt.0) then
 
   call clmlga &
   !==========
- ( chaine(1:16) ,   lchain ,                                      &
-   isym   , ibsize , nagmax , npstmg , iwarnp ,                   &
+ ( chaine(1:16) ,    lchain ,                                     &
+   isym   , ibsize , iesize , nagmax , npstmg , iwarnp ,          &
    ngrmax , ncegrm ,                                              &
    rlxp1  ,                                                       &
    dam    , xam    )
@@ -336,14 +335,9 @@ enddo
 
 relaxp = relaxv(ipr)
 
-! Dynamic relaxation criterion
 ! (Test to modify if needed: must be scticter than
 ! the test in the conjugate gradient)
-if (swpdyn.eq.1) then
-  tcrite = 100.d0*epsilo(ipr)*rnorm
-else
-  tcrite = 10.d0*epsrsm(ipr)*rnorm
-endif
+tcrite = 10.d0*epsrsm(ipr)*rnorm
 
 ! Reconstruction loop (beginning)
 !--------------------------------
@@ -370,7 +364,7 @@ do while (isweep.le.nswmpr.and.residu.gt.tcrite)
 
   call invers &
   !==========
- ( chaine(1:16)    , isym   , ibsize ,                            &
+ ( chaine(1:16)    , isym   , ibsize , iesize ,                   &
    ipol   , ireslp , nitmap , imgrp  ,                            &
    ncymap , nitmgp ,                                              &
    iwarnp , nfecra , niterf , icycle , iinvpe ,                   &
@@ -406,11 +400,13 @@ do while (isweep.le.nswmpr.and.residu.gt.tcrite)
     epsrgp = epsrgr(ipr)
     climgp = climgr(ipr)
     extrap = extrag(ipr)
+    ! This option should be adapted to iphydr = 1
+    iphydp = 0
 
     call itrgrp &
     !==========
    ( nvar   , nscal  ,                                              &
-     init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
+     init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydp , &
      iwarnp , nfecra ,                                              &
      epsrgp , climgp , extrap ,                                     &
      rvoid  , rvoid  , rvoid  ,                                     &
@@ -428,18 +424,6 @@ do while (isweep.le.nswmpr.and.residu.gt.tcrite)
     ! --- Convergence test
     call prodsc(ncel, isqrt, rhs, rhs, residu)
 
-    ! Dynamic relaxation criterion
-    if (swpdyn.eq.1) then
-      if (isweep.gt.2) then
-
-        if ((residu + 0.001d0*residu).gt.resold) then
-          relaxv(ipr) = max(0.8d0*relaxp, 0.1d0)
-        endif
-
-      endif
-      resold = residu
-    endif
-
     if (iwarni(ipr).ge.2) then
       if (rnorm.ge.epzero) then
         write(nfecra,1440) chaine(1:16),isweep,residu/rnorm, relaxp
