@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -29,7 +29,7 @@ subroutine preduv &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
    flumas , flumab ,                                              &
    tslagr , coefa  , coefb  ,                                     &
-   ckupdc , smacel , frcxt  ,                                     &
+   ckupdc , smacel , frcxt  , grdphd ,                            &
    trava  , ximpa  , uvwk   , dfrcxt , tpucou , trav   ,          &
    viscf  , viscb  , viscfi , viscbi ,                            &
    drtp   , smbr   , rovsdt ,                                     &
@@ -90,6 +90,7 @@ subroutine preduv &
 !                  !    !     !  pour ivar=ipr, smacel=flux de masse           !
 ! frcxt(ncelet,3)  ! tr ! <-- ! force exterieure generant la pression          !
 !                  !    !     !  hydrostatique                                 !
+! grdphd(ncelet,3) ! tr ! <-- ! hydrostatic pressure gradient                  !
 ! trava,ximpa      ! tr ! <-- ! tableau de travail pour couplage               !
 ! uvwk             ! tr ! <-- ! tableau de travail pour couplage u/p           !
 !                  !    !     ! sert a stocker la vitesse de                   !
@@ -162,6 +163,7 @@ double precision tslagr(ncelet,*)
 double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision frcxt(ncelet,3), dfrcxt(ncelet,3)
+double precision grdphd(ncelet,3)
 double precision trava(ncelet,ndim)
 double precision ximpa(ncelet,ndim),uvwk(ncelet,ndim)
 double precision tpucou(ncelet,ndim), trav(ncelet,3)
@@ -188,10 +190,10 @@ integer          iesprp, iestop
 integer          iptsna
 integer          iflmb0, nswrp , imaspe, ipbrom, itypfl
 integer          idiaex, idtva0
-integer          imucpp
+integer          imucpp, idftnp, iswdyp
 
 double precision rnorm , vitnor
-double precision romvom, drom
+double precision romvom, rom, drom
 double precision epsrgp, climgp, extrap, relaxp, blencp, epsilp
 double precision epsrsp
 double precision vit1  , vit2  , vit3, xkb, pip, pfac, pfac1
@@ -290,8 +292,8 @@ if (iappel.eq.1.and.iphydr.eq.1) then
       cpdc22 = ckupdc(ielpdc,2)
       cpdc33 = ckupdc(ielpdc,3)
       cpdc12 = ckupdc(ielpdc,4)
-      cpdc13 = ckupdc(ielpdc,5)
-      cpdc23 = ckupdc(ielpdc,6)
+      cpdc23 = ckupdc(ielpdc,5)
+      cpdc13 = ckupdc(ielpdc,6)
       dfrcxt(iel,1) = dfrcxt(iel,1)                   &
            -propce(iel,ipcrom)*(                                  &
            cpdc11*vit1+cpdc12*vit2+cpdc13*vit3)
@@ -492,6 +494,15 @@ if(iappel.eq.1) then
       trav(iel,2) = (frcxt(iel,2) - grad(iel,2)) * volume(iel)
       trav(iel,3) = (frcxt(iel,3) - grad(iel,3)) * volume(iel)
     enddo
+
+  elseif(iphydr.eq.2) then
+    do iel = 1, ncel
+      rom = propce(iel,ipcrom)
+      trav(iel,1) = (rom*gx - grdphd(iel,1)) * volume(iel)
+      trav(iel,2) = (rom*gy - grdphd(iel,2)) * volume(iel)
+      trav(iel,3) = (rom*gz - grdphd(iel,3)) * volume(iel)
+    enddo
+
   else
     do iel = 1, ncel
       drom = (propce(iel,ipcrom)-ro0)
@@ -505,16 +516,25 @@ elseif(iappel.eq.2) then
 
   if (iphydr.eq.1) then
     do iel = 1, ncel
-      trav(iel,1) = trav(iel,1) + ( frcxt(iel,1) - grad(iel,1) )*volume(iel)
-      trav(iel,2) = trav(iel,2) + ( frcxt(iel,2) - grad(iel,2) )*volume(iel)
-      trav(iel,3) = trav(iel,3) + ( frcxt(iel,3) - grad(iel,3) )*volume(iel)
+      trav(iel,1) = trav(iel,1) + (frcxt(iel,1) - grad(iel,1))*volume(iel)
+      trav(iel,2) = trav(iel,2) + (frcxt(iel,2) - grad(iel,2))*volume(iel)
+      trav(iel,3) = trav(iel,3) + (frcxt(iel,3) - grad(iel,3))*volume(iel)
     enddo
+
+  elseif (iphydr.eq.2) then
+    do iel = 1, ncel
+      rom = propce(iel,ipcrom)
+      trav(iel,1) = trav(iel,1) + (rom*gx - grdphd(iel,1))*volume(iel)
+      trav(iel,2) = trav(iel,2) + (rom*gy - grdphd(iel,2))*volume(iel)
+      trav(iel,3) = trav(iel,3) + (rom*gz - grdphd(iel,3))*volume(iel)
+    enddo
+
   else
     do iel = 1, ncel
       drom = (propce(iel,ipcrom)-ro0)
-      trav(iel,1) =  trav(iel,1) + ( drom*gx - grad(iel,1) )*volume(iel)
-      trav(iel,2) =  trav(iel,2) + ( drom*gy - grad(iel,2) )*volume(iel)
-      trav(iel,3) =  trav(iel,3) + ( drom*gz - grad(iel,3) )*volume(iel)
+      trav(iel,1) = trav(iel,1) + (drom*gx - grad(iel,1))*volume(iel)
+      trav(iel,2) = trav(iel,2) + (drom*gy - grad(iel,2))*volume(iel)
+      trav(iel,3) = trav(iel,3) + (drom*gz - grad(iel,3))*volume(iel)
     enddo
   endif
 
@@ -789,14 +809,14 @@ if((ncepdp.gt.0).and.(iphydr.eq.0)) then
    rtpa   , propce , propfa , propfb ,                            &
    coefa  , coefb  , ckupdc , trav   )
 
-  ! With porosity
-  if (iporos.eq.1) then
-    do iel = 1, ncel
-      trav(iel,1) = trav(iel,1)*porosi(iel)
-      trav(iel,2) = trav(iel,2)*porosi(iel)
-      trav(iel,3) = trav(iel,3)*porosi(iel)
-    enddo
-  endif
+    ! With porosity
+    if (iporos.eq.1) then
+      do iel = 1, ncel
+        trav(iel,1) = trav(iel,1)*porosi(iel)
+        trav(iel,2) = trav(iel,2)*porosi(iel)
+        trav(iel,3) = trav(iel,3)*porosi(iel)
+      enddo
+    endif
 
 !     Si on itere sur navsto, on utilise TRAVA ; sinon TRAV
     if(nterup.gt.1) then
@@ -845,14 +865,14 @@ if((ncepdp.gt.0).and.(iphydr.eq.0)) then
    rtpa   , propce , propfa , propfb ,                            &
    coefa  , coefb  , ckupdc , trav   )
 
-  ! With porosity
-  if (iporos.eq.1) then
-    do iel = 1, ncel
-      trav(iel,1) = trav(iel,1)*porosi(iel)
-      trav(iel,2) = trav(iel,2)*porosi(iel)
-      trav(iel,3) = trav(iel,3)*porosi(iel)
-    enddo
-  endif
+    ! With porosity
+    if (iporos.eq.1) then
+      do iel = 1, ncel
+        trav(iel,1) = trav(iel,1)*porosi(iel)
+        trav(iel,2) = trav(iel,2)*porosi(iel)
+        trav(iel,3) = trav(iel,3)*porosi(iel)
+      enddo
+    endif
 
 !     Si on extrapole les termes source en temps :
 !       PROPCE recoit les termes extradiagonaux et
@@ -1139,13 +1159,13 @@ do isou = 1, 3
 ! FIXME with porosity
   if(iterns.eq.1) then
 
-    call ustsns                                                 &
+    call ustsns                                                    &
     !==========
   ( nvar   , nscal  , ncepdp , ncesmp ,                            &
     ivar   ,                                                       &
     icepdc , icetsm , itypsm ,                                     &
     dt     , rtpa   , propce , propfa , propfb ,                   &
-    coefa  , coefb  , ckupdc , smacel ,                            &
+    ckupdc , smacel ,                                              &
     w7     , drtp   )
 
     if (nbrcpl.gt.0) then
@@ -1422,6 +1442,8 @@ do isou = 1, 3
   ischcp = ischcv(ivar)
   isstpp = isstpc(ivar)
   imucpp = 0
+  idftnp = 1 !no tensorial diffusion avalaible for the velocity
+  iswdyp = iswdyn(ivar)
   imgrp  = imgr  (ivar)
   ncymxp = ncymax(ivar)
   nitmfp = nitmgf(ivar)
@@ -1450,15 +1472,16 @@ do isou = 1, 3
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
-                     coefa(1,iclvar) , coefb(1,iclvar) ,          &
-                     coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
-                     flumas , flumab ,                            &
-   viscfi , viscbi , viscf  , viscb  ,                            &
+   coefa(1,iclvar) , coefb(1,iclvar) ,                            &
+   coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
+   flumas , flumab ,                                              &
+   viscfi , viscbi , rvoid  , viscf  , viscb  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
    rvoid  , eswork )
 
@@ -1469,15 +1492,16 @@ do isou = 1, 3
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
    rtpa(1,ivar)    , uvwk(1,isou) ,                               &
-                     coefa(1,iclvar) , coefb(1,iclvar) ,          &
-                     coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
-                     flumas , flumab ,                            &
-   viscfi , viscbi , viscf  , viscb  ,                            &
+   coefa(1,iclvar) , coefb(1,iclvar) ,                            &
+   coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
+   flumas , flumab ,                                              &
+   viscfi , viscbi , rvoid  , viscf  , viscb  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
    rvoid  , eswork )
 
@@ -1520,15 +1544,16 @@ do isou = 1, 3
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ippt   , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
    tpucou(1,isou)  , tpucou(1,isou)  ,                            &
-                     coefa(1,iclvar) , coefb(1,iclvar) ,          &
-                     coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
-                     flumas , flumab ,                            &
-   viscfi , viscbi , viscf  , viscb  ,                            &
+   coefa(1,iclvar) , coefb(1,iclvar) ,                            &
+   coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
+   flumas , flumab ,                                              &
+   viscfi , viscbi , rvoid  , viscf  , viscb  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    rovsdt , smbr   , tpucou(1,isou)  , dpvar  ,                   &
    rvoid  , rvoid  )
 
@@ -1555,21 +1580,21 @@ do isou = 1, 3
 
     inc = 1
     iccocg = 1
-    imucpp = 0
 !     Pas de relaxation en stationnaire
     idtva0 = 0
 
-    call bilsc2                                                   &
+    call bilsca &
     !==========
  ( nvar   , nscal  ,                                              &
    idtva0 , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp ,                                     &
+   ipp    , iwarnp , imucpp , idftnp ,                            &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtp(1,ivar)     , rtp(1,ivar)     ,                            &
    coefa(1,iclvar) , coefb(1,iclvar) ,                            &
    coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
-   flumas , flumab , viscf  , viscb  , rvoid  ,                   &
+   flumas , flumab , viscf  , viscb  , rvoid  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    smbr   )
 
     iestop = ipproc(iestim(iestot))
