@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -20,8 +20,77 @@
 
 !-------------------------------------------------------------------------------
 
+!===============================================================================
+! Function:
+! ---------
+
+!> \file predvv.f90
+!>
+!> \brief This subroutine perform the velocity prediction step of the Navier
+!> Stokes equations for incompressible or slightly compressible flows for
+!> the coupled velocity components solver.
+!>
+!> - at the first call, the predicted velocities are computed and also
+!>   an estimator on the predicted velocity is computed.
+!>
+!> - at the second call, a global estimator on Navier Stokes is computed.
+!>   This second call is done after the correction step (\ref resopv).
+!>
+!-------------------------------------------------------------------------------
+
+!-------------------------------------------------------------------------------
+! Arguments
+!______________________________________________________________________________.
+!  mode           name          role                                           !
+!______________________________________________________________________________!
+!> \param[in]     iappel        call number (1 or 2)
+!> \param[in]     nvar          total number of variables
+!> \param[in]     nscal         total number of scalars
+!> \param[in]     iterns        index of the iteration on Navier-Stokes
+!> \param[in]     ncepdp        number of cells with head loss
+!> \param[in]     ncesmp        number of cells with mass source term
+!> \param[in]     icepdc        index of cells with head loss
+!> \param[in]     icetsm        index of cells with mass source term
+!> \param[in]     itypsm        type of mass source term for the variables
+!> \param[in]     dt            time step (per cell)
+!> \param[in,out] rtp, rtpa     calculated variables at cell centers
+!>                               (at current and previous time steps)
+!> \param[in]     propce        physical properties at cell centers
+!> \param[in,out] propfa        physical properties at interior face centers
+!> \param[in,out] propfb        physical properties at boundary face centers
+!> \param[in]     flumas        internal mass flux (depending on iappel)
+!> \param[in]     flumab        boundary mass flux (depending on iappel)
+!> \param[in]     coefa, coefb  boundary conditions
+!> \param[in]     ckupdc        work array for the head loss
+!> \param[in]     smacel        variable value associated to the mass source
+!>                               term (for ivar=ipr, smacel is the mass flux
+!>                               \f$ \Gamma^n \f$)
+!> \param[in]     frcxt         external forces making hydrostatic pressure
+!> \param[in]     trava         working array for the velocity-pressure coupling
+!> \param[in]     ximpa         idem
+!> \param[in]     uvwk          idem (stores the velocity at the previous iteration)*
+!> \param[in]     dfrcxt        variation of the external forces
+!> \param[in]                    making the hydrostatic pressure
+!> \param[in]     grdphd        hydrostatic pressure gradient to handle the imbalance
+!> \param[in]                   between the pressure gradient and gravity source term
+!> \param[in]     tpucou        non scalar time step in case of
+!>                               velocity pressure coupling
+!> \param[in]     trav          right hand side for the normalizing
+!>                               the residual
+!> \param[in]     viscf         visc*surface/dist aux faces internes
+!> \param[in]     viscb         visc*surface/dist aux faces de bord
+!> \param[in]     viscfi        idem viscf pour increments
+!> \param[in]     viscbi        idem viscb pour increments
+!> \param[in]     secvif        secondary viscosity at interior faces
+!> \param[in]     secvib        secondary viscosity at boundary faces
+!> \param[in]     w1            working array
+!> \param[in]     w7            working array
+!> \param[in]     w8            working array
+!> \param[in]     w9            working array
+!> \param[in]     xnormp        workig array for the norm of the pressure
+!_______________________________________________________________________________
+
 subroutine predvv &
-!================
  ( iappel ,                                                       &
    nvar   , nscal  , iterns , ncepdp , ncesmp ,                   &
    icepdc , icetsm , itypsm ,                                     &
@@ -29,97 +98,12 @@ subroutine predvv &
    propce , propfa , propfb ,                                     &
    flumas , flumab ,                                              &
    tslagr , coefa  , coefb  , coefav , coefbv , cofafv , cofbfv , &
-   ckupdc , smacel , frcxt  ,                                     &
+   ckupdc , smacel , frcxt  , grdphd ,                            &
    trava  , ximpa  , uvwk   , dfrcxt , tpucou , trav   ,          &
    viscf  , viscb  , viscfi , viscbi , secvif , secvib ,          &
    w1     , w7     , w8     , w9     , xnormp )
 
 !===============================================================================
-! FONCTION :
-! ----------
-
-! Solving of NS equations for incompressible or slightly compressible flows for
-! one time step. Both convection-diffusion and continuity steps are performed.
-! The velocity components are solved together in once.
-
-! AU PREMIER APPEL,  ON EFFECTUE LA PREDICITION DES VITESSES
-!               ET  ON CALCULE UN ESTIMATEUR SUR LA VITESSE PREDITE
-
-! AU DEUXIEME APPEL, ON CALCULE UN ESTIMATEUR GLOBAL
-!               POUR NAVIER-STOKES :
-!   ON UTILISE TRAV, SMBR ET LES TABLEAUX DE TRAVAIL
-!   ON APPELLE BILSC4 AU LIEU DE CODITV
-!   ON REMPLIT LE PROPCE ESTIMATEUR IESTOT
-!   CE DEUXIEME APPEL INTERVIENT DANS NAVSTV APRES RESOPV
-!   LORS DE CE DEUXIEME APPEL
-!     RTPA ET RTP SONT UN UNIQUE TABLEAU (= RTP)
-!     LE FLUX DE MASSE EST LE FLUX DE MASSE DEDUIT DE LA VITESSE
-!      AU CENTRE CONTENUE DANS RTP
-
-!-------------------------------------------------------------------------------
-!ARGU                             ARGUMENTS
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! iappel           ! e  ! <-- ! numero d'appel du sous programme               !
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
-! iterns           ! e  ! <-- ! numero d'iteration sur navsto                  !
-! ncepdp           ! i  ! <-- ! number of cells with head loss                 !
-! ncesmp           ! i  ! <-- ! number of cells with mass source term          !
-! icepdc(ncelet    ! te ! <-- ! numero des ncepdp cellules avec pdc            !
-! icetsm(ncesmp    ! te ! <-- ! numero des cellules a source de masse          !
-! itypsm           ! te ! <-- ! type de source de masse pour les               !
-! (ncesmp,nvar)    !    !     !  variables (cf. ustsma)                        !
-! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
-!  (ncelet, *)     !    !     !  (at current and previous time steps)          !
-! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
-! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
-! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! flumas           ! tr ! <-- ! flux de masse aux faces internes               !
-!  (nfac  )        !    !     !   (distinction iappel=1 ou 2)                  !
-! flumab           ! tr ! <-- ! flux de masse aux faces de bord                !
-!  (nfabor  )      !    !     !    (distinction iappel=1 ou 2)                 !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
-! ckupdc           ! tr ! <-- ! tableau de travail pour pdc                    !
-!  (ncepdp,6)      !    !     !                                                !
-! smacel           ! tr ! <-- ! valeur des variables associee a la             !
-! (ncesmp,*   )    !    !     !  source de masse                               !
-!                  !    !     !  pour ivar=ipr, smacel=flux de masse           !
-! frcxt(ncelet,3)  ! tr ! <-- ! force exterieure generant la pression          !
-!                  !    !     !  hydrostatique                                 !
-! trava            ! tr ! <-- ! tableau de travail pour couplage               !
-!(3,ncelet)        !    !     ! vitesse pression par point fixe                !
-! ximpa            ! tr ! <-- ! tableau de travail pour couplage               !
-!(3,3,ncelet)      !    !     ! vitesse pression par point fixe                !
-! uvwk             ! tr ! <-- ! tableau de travail pour couplage u/p           !
-!                  !    !     ! sert a stocker la vitesse de                   !
-!                  !    !     ! l'iteration precedente                         !
-!dfrcxt(ncelet,3)  ! tr ! --> ! variation de force exterieure                  !
-!                  !    !     !  generant la pression hydrostatique            !
-! tpucou           ! tr ! --> ! couplage vitesse pression                      !
-! (ndim,ncelel)    !    !     !                                                !
-! trav(3,ncelet)   ! tr ! --> ! smb qui servira pour normalisation             !
-!                  !    !     !  dans resolp                                   !
-! viscf(nfac)      ! tr ! --- ! visc*surface/dist aux faces internes           !
-! viscb(nfabor)    ! tr ! --- ! visc*surface/dist aux faces de bord            !
-! viscfi(nfac)     ! tr ! --- ! idem viscf pour increments                     !
-! viscbi(nfabor)   ! tr ! --- ! idem viscb pour increments                     !
-! secvif(nfac)     ! tr ! --- ! secondary viscosity at interior faces          !
-! secvib(nfabor)   ! tr ! --- ! secondary viscosity at boundary faces          !
-! w1...9(ncelet    ! tr ! --- ! tableau de travail                             !
-! xnormp(ncelet    ! tr ! <-- ! tableau reel pour norme resolp                 !
-! tslagr(ncelet    ! tr ! <-- ! terme de couplage retour du                    !
-!   ntersl)        !    !     !   lagrangien                                   !
-!__________________!____!_____!________________________________________________!
-
-!     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
-!            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
-!     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
-!            --- tableau de travail
-!===============================================================================
 
 !===============================================================================
 ! Module files
@@ -141,6 +125,7 @@ use ppppar
 use ppthch
 use ppincl
 use cplsat
+use ihmpre, only: iihmpr
 use mesh
 
 !===============================================================================
@@ -164,12 +149,13 @@ double precision tslagr(ncelet,*)
 double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision frcxt(ncelet,3), dfrcxt(ncelet,3)
+double precision grdphd(ncelet,3)
 double precision trava(ndim,ncelet)
 double precision ximpa(ndim,ndim,ncelet),uvwk(ndim,ncelet)
-double precision tpucou(ndim,ncelet)
+double precision tpucou(6, ncelet)
 double precision trav(3,ncelet)
-double precision viscf(nfac), viscb(nfabor)
-double precision viscfi(nfac), viscbi(nfabor)
+double precision viscf(*), viscb(nfabor)
+double precision viscfi(*), viscbi(nfabor)
 double precision secvif(nfac), secvib(nfabor)
 double precision w1(ncelet)
 double precision w7(ncelet), w8(ncelet), w9(ncelet)
@@ -187,6 +173,7 @@ double precision vela  (3  ,ncelet)
 integer          iel   , ielpdc, ifac  , ivar  , isou  , itypfl
 integer          iccocg, inc   , init  , ii    , isqrt
 integer          ireslp, nswrgp, imligp, iwarnp, ippt  , ipp
+integer          iswdyp, idftnp
 integer          iclipr
 integer          iclik
 integer          ipcrom, ipcroa, ipcroo, ipcrho, ipcvis, ipcvst
@@ -219,6 +206,7 @@ double precision, dimension(:,:,:), allocatable :: fimp
 double precision, dimension(:,:), allocatable :: gavinj
 double precision, dimension(:,:), allocatable :: tsexp
 double precision, dimension(:,:,:), allocatable :: tsimp
+double precision, dimension(:,:), allocatable :: vect
 
 !===============================================================================
 
@@ -307,8 +295,8 @@ if (iappel.eq.1.and.iphydr.eq.1) then
       cpdc22 = ckupdc(ielpdc,2)
       cpdc33 = ckupdc(ielpdc,3)
       cpdc12 = ckupdc(ielpdc,4)
-      cpdc13 = ckupdc(ielpdc,5)
-      cpdc23 = ckupdc(ielpdc,6)
+      cpdc23 = ckupdc(ielpdc,5)
+      cpdc13 = ckupdc(ielpdc,6)
       dfrcxt(iel,1) = dfrcxt(iel,1) &
                     - propce(iel,ipcrom)*(cpdc11*vit1+cpdc12*vit2+cpdc13*vit3)
       dfrcxt(iel,2) = dfrcxt(iel,2) &
@@ -504,6 +492,13 @@ if (iappel.eq.1) then
       trav(2,iel) = (frcxt(iel,2) - grad(iel,2)) * volume(iel)
       trav(3,iel) = (frcxt(iel,3) - grad(iel,3)) * volume(iel)
     enddo
+  elseif (iphydr.eq.2) then
+    do iel = 1, ncel
+      rom = propce(iel, ipcrom)
+      trav(1,iel) = (rom*gx - grdphd(iel,1)) * volume(iel)
+      trav(2,iel) = (rom*gy - grdphd(iel,2)) * volume(iel)
+      trav(3,iel) = (rom*gz - grdphd(iel,3)) * volume(iel)
+    enddo
   else
     do iel = 1, ncel
       drom = (propce(iel,ipcrom)-ro0)
@@ -517,9 +512,16 @@ elseif(iappel.eq.2) then
 
   if (iphydr.eq.1) then
     do iel = 1, ncel
-      trav(1,iel) = trav(1,iel) + ( frcxt(iel,1) - grad(iel,1) )*volume(iel)
-      trav(2,iel) = trav(2,iel) + ( frcxt(iel,2) - grad(iel,2) )*volume(iel)
-      trav(3,iel) = trav(3,iel) + ( frcxt(iel,3) - grad(iel,3) )*volume(iel)
+      trav(1,iel) = trav(1,iel) + ( frcxt(iel,1) - grad(iel,1) ) * volume(iel)
+      trav(2,iel) = trav(2,iel) + ( frcxt(iel,2) - grad(iel,2) ) * volume(iel)
+      trav(3,iel) = trav(3,iel) + ( frcxt(iel,3) - grad(iel,3) ) * volume(iel)
+    enddo
+  elseif (iphydr.eq.2) then
+    do iel = 1, ncel
+      rom = propce(iel,ipcrom)
+      trav(1,iel) = trav(1,iel) + (rom*gx - grdphd(iel,1)) * volume(iel)
+      trav(2,iel) = trav(2,iel) + (rom*gy - grdphd(iel,2)) * volume(iel)
+      trav(3,iel) = trav(3,iel) + (rom*gz - grdphd(iel,3)) * volume(iel)
     enddo
   else
     do iel = 1, ncel
@@ -704,7 +706,7 @@ endif
 !-------------------------------------------------------------------------------
 ! ---> TERMES DE GRADIENT TRANSPOSE
 
-!     These terms are taken into account in bilsc4.
+!     These terms are taken into account in bilscv.
 !     We only compute here the secondary viscosity.
 
 if (ivisse.eq.1) then
@@ -724,12 +726,12 @@ endif
 if((ncepdp.gt.0).and.(iphydr.eq.0)) then
 
   ! Les termes diagonaux sont places dans TRAV ou TRAVA,
-  !   La prise en compte de UVWK a partir de la seconde iteration
+  !   La prise en compte de uvwk a partir de la seconde iteration
   !   est faite directement dans coditv.
   if(iterns.eq.1) then
 
     ! On utilise temporairement TRAV comme tableau de travail.
-    ! Son contenu est stocke dans W7, W8 et W9 jusqu'apres tspdci
+    ! Son contenu est stocke dans W7, W8 et W9 jusqu'apres tspdcv
     do iel = 1,ncel
       w7(iel) = trav(1,iel)
       w8(iel) = trav(2,iel)
@@ -747,14 +749,14 @@ if((ncepdp.gt.0).and.(iphydr.eq.0)) then
    propce , propfa , propfb ,                                     &
    coefa  , coefb  , ckupdc , trav   )
 
-  ! With porosity
-  if (iporos.eq.1) then
-    do iel = 1, ncel
-      trav(iel,1) = trav(iel,1)*porosi(iel)
-      trav(iel,2) = trav(iel,2)*porosi(iel)
-      trav(iel,3) = trav(iel,3)*porosi(iel)
-    enddo
-  endif
+    ! With porosity
+    if (iporos.eq.1) then
+      do iel = 1, ncel
+        trav(iel,1) = trav(iel,1)*porosi(iel)
+        trav(iel,2) = trav(iel,2)*porosi(iel)
+        trav(iel,3) = trav(iel,3)*porosi(iel)
+      enddo
+    endif
     ! Si on itere sur navsto, on utilise TRAVA ; sinon TRAV
     if(nterup.gt.1) then
       do iel = 1, ncel
@@ -869,17 +871,10 @@ endif
 
 
 !-------------------------------------------------------------------------------
-! ---> "VITESSE" DE DIFFUSION FACETTE
-!      SI ON FAIT AUTRE CHOSE QUE DU K EPS, IL FAUDRA LA METTRE
-!        DANS LA BOUCLE
+! ---> Face diffusivity for the velocity
 
-if( idiff(iu).ge. 1 ) then
+if (idiff(iu).ge. 1) then
 
-! --- Si la vitesse doit etre diffusee, on calcule la viscosite
-!       pour le second membre (selon Rij ou non)
-
-  !FIXME we do NOT extrapolate the viscosity here, whereas we do extrapolate for
-  ! the second viscosity
   if (itytur.eq.3) then
     do iel = 1, ncel
       w1(iel) = propce(iel,ipcvis)
@@ -890,36 +885,31 @@ if( idiff(iu).ge. 1 ) then
     enddo
   endif
 
-  call viscfa                                                     &
+  call viscfa &
   !==========
  ( imvisf ,                                                       &
    w1     ,                                                       &
    viscf  , viscb  )
 
-!     Quand on n'est pas en Rij ou que irijnu = 0, les tableaux
-!       VISCFI, VISCBI se trouvent remplis par la meme occasion
-!       (ils sont confondus avec VISCF, VISCB)
-!     En Rij avec irijnu = 1, on calcule la viscosite increment
-!       de la matrice dans VISCFI, VISCBI
+  ! When using Rij-epsilon model with th option irijnu=1, the face
+  ! viscosity for the Matrix (viscfi and viscbi) is increased
 
   if(itytur.eq.3.and.irijnu.eq.1) then
+
     do iel = 1, ncel
-      w1(iel) = propce(iel,ipcvis)                                &
-                            + idifft(iu)*propce(iel,ipcvst)
+      w1(iel) = propce(iel,ipcvis) + idifft(iu)*propce(iel,ipcvst)
     enddo
-    call viscfa                                                   &
+
+    call viscfa &
     !==========
  ( imvisf ,                                                       &
    w1     ,                                                       &
    viscfi , viscbi )
   endif
 
+! --- If no dissusion, viscosity is set to 0.
 else
 
-! --- Si la vitesse n'a pas de diffusion, on annule la viscosite
-!      (matrice et second membre sont dans le meme tableau,
-!       sauf en Rij avec IRIJNU = 1)
-
   do ifac = 1, nfac
     viscf(ifac) = 0.d0
   enddo
@@ -984,14 +974,17 @@ ipp  = ipprtp(iu)
 ! FIXME with porosity
 if(iterns.eq.1) then
 
-  call ustsnv                                                     &
+  if (iihmpr.eq.1) then
+    call uitsnv (vel, tsexp, tsimp)
+  endif
+
+  call ustsnv &
   !==========
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
-   iu   ,                                                       &
+   iu   ,                                                         &
    icepdc , icetsm , itypsm ,                                     &
    dt     , rtpa   , propce , propfa , propfb ,                   &
-   coefa  , coefb  , ckupdc , smacel ,                            &
-   tsexp  , tsimp  )
+   ckupdc , smacel , tsexp  , tsimp  )
 
   ! Coupling between two Code_Saturne
   if (nbrcpl.gt.0) then
@@ -1178,8 +1171,8 @@ if(iappel.eq.1) then
       enddo
       ! Extra-diagonal part
       cpdc12 = ckupdc(ielpdc,4)
-      cpdc13 = ckupdc(ielpdc,5)
-      cpdc23 = ckupdc(ielpdc,6)
+      cpdc23 = ckupdc(ielpdc,5)
+      cpdc13 = ckupdc(ielpdc,6)
 
       fimp(1,2,iel) = fimp(1,2,iel) + romvom*cpdc12
       fimp(2,1,iel) = fimp(2,1,iel) + romvom*cpdc12
@@ -1378,6 +1371,8 @@ imligp = imligr(iu)
 ircflp = ircflu(iu)
 ischcp = ischcv(iu)
 isstpp = isstpc(iu)
+idftnp = idften(iu)
+iswdyp = iswdyn(iu)
 imgrp  = imgr  (iu)
 ncymxp = ncymax(iu)
 nitmfp = nitmgf(iu)
@@ -1390,7 +1385,6 @@ climgp = climgr(iu)
 extrap = extrag(iu)
 relaxp = relaxv(iu)
 thetap = thetav(iu)
-
 ippu   = ipprtp(iu)
 ippv   = ipprtp(iv)
 ippw   = ipprtp(iw)
@@ -1410,7 +1404,7 @@ if(iappel.eq.1) then
  ( nvar   , nscal  ,                                              &
    idtvar , iu     , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp , ivisse ,          &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , idftnp , iswdyp ,                   &
    imgrp  , ncymxp , nitmfp , ippu   , ippv   , ippw   , iwarnp , &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
@@ -1430,7 +1424,7 @@ if(iappel.eq.1) then
  ( nvar   , nscal  ,                                              &
    idtvar , iu     , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp , ivisse ,          &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , idftnp , iswdyp ,                   &
    imgrp  , ncymxp , nitmfp , ippu   , ippv   , ippw   , iwarnp , &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
@@ -1445,36 +1439,16 @@ if(iappel.eq.1) then
 
   endif
 
-
-!     DANS LE CAS DE PERTES DE CHARGE, ON UTILISE LES TABLEAUX
-!     TPUCOU POUR LA PHASE D'IMPLICITATION
-!     Attention, il faut regarder s'il y a des pdc sur un proc quelconque,
-!       pas uniquement en local.
-!TODO modify the tpucou array for the correction step
-! in case of Coriolis force or head loss
-  if((ncpdct.gt.0).and.(ipucou.eq.0)) then
-    do iel = 1,ncel
-      do isou=1,3
-        tpucou(isou,iel) = dt(iel)
-      enddo
-    enddo
-    do ielpdc = 1, ncepdp
-      iel=icepdc(ielpdc)
-      do isou = 1, 3
-        tpucou(isou,iel) = 1.d0/(1.d0/dt(iel)+ckupdc(ielpdc,isou))
-      enddo
-    enddo
-  endif
-
-!     COUPLAGE P/U RENFORCE : CALCUL DU VECTEUR T ENTRELACE, STOCKE DANS TPUCOU
-!       ON PASSE DANS CODITV, EN NE FAISANT QU'UN SEUL SWEEP, ET EN
-!       INITIALISANT TPUCOU A 0 POUR QUE LA PARTIE CV/DIFF AJOUTEE
-!       PAR BILSC4 SOIT NULLE
-!     NSWRSP = -1 INDIQUERA A CODITS QU'IL NE FAUT FAIRE QU'UN SWEEP
-!       ET QU'IL FAUT METTRE INC A 0 (POUR OTER LES DIRICHLETS DANS LES
-!       CL DES MATRICES POIDS)
-
+  ! Velocity-pression coupling: compute the vector T, stored in tpucou,
+  !  coditv is called, only one sweep is done, and tpucou is initialized
+  !  by 0. so that the advection/diffusion added by bilscv is 0.
+  !  nswrsp = -1 indicated that only one sweep is required and inc=0
+  !  for boundary contitions on the weight matrix.
   if (ipucou.eq.1) then
+
+    ! Allocate temporary arrays for the velocity-pressure resolution
+    allocate(vect(3,ncelet))
+
     nswrsp = -1
     do iel = 1, ncel
       do isou = 1, 3
@@ -1483,7 +1457,7 @@ if(iappel.eq.1) then
     enddo
     do iel = 1, ncelet
       do isou = 1, 3
-        tpucou(isou,iel) = 0.d0
+        vect(isou,iel) = 0.d0
       enddo
     enddo
     iescap = 0
@@ -1496,26 +1470,32 @@ if(iappel.eq.1) then
  ( nvar   , nscal  ,                                              &
    idtvar , iu     , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp , ivisep ,          &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , idftnp , iswdyp ,                   &
    imgrp  , ncymxp , nitmfp , ippu   , ippv   , ippw   , iwarnp , &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
-   tpucou , tpucou ,                                              &
+   vect   , vect   ,                                              &
    coefav , coefbv , cofafv , cofbfv ,                            &
    flumas , flumab ,                                              &
    viscfi , viscbi , viscf  , viscb  , secvif , secvib ,          &
    fimp   ,                                                       &
    smbr   ,                                                       &
-   tpucou ,                                                       &
+   vect   ,                                                       &
    rvoid  )
 
     do iel = 1, ncelet
       rom = propce(iel,ipcrom)
       do isou = 1, 3
-        tpucou(isou,iel) = rom*tpucou(isou,iel)
+        tpucou(isou,iel) = rom*vect(isou,iel)
+      enddo
+      do isou = 4, 6
+        tpucou(isou,iel) = 0.d0
       enddo
     enddo
 
+    ! Free memory
+    deallocate(vect)
+
   endif
 
 ! --->  ESTIMATEUR SUR LA VITESSE PREDITE : ON SOMME SUR LES COMPOSANTES
@@ -1543,12 +1523,12 @@ elseif(iappel.eq.2) then
   ippv  = ipprtp(iv)
   ippw  = ipprtp(iw)
 
-  call bilsc4 &
+  call bilscv &
   !==========
  ( nvar   , nscal  ,                                              &
    idtva0 , iu     , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , ivisep ,                   &
-   ippu   , ippv   , ippw   , iwarnp ,                            &
+   ippu   , ippv   , ippw   , iwarnp , idftnp ,                   &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    vel    , vel    ,                                              &
    coefav , coefbv , cofafv , cofbfv ,                            &
@@ -1674,7 +1654,7 @@ deallocate(fimp)
 deallocate(tsexp)
 deallocate(tsimp)
 !--------
-! FORMATS
+! Formats
 !--------
 #if defined(_CS_LANG_FR)
 
@@ -1689,7 +1669,7 @@ deallocate(tsimp)
 #endif
 
 !----
-! FIN
+! End
 !----
 
 return
