@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -109,7 +109,7 @@ use entsor
 use cstphy
 use cstnum
 use optcal
-use pointe, only: itypfb
+use pointe, only: itypfb, dttens
 use albase
 use parall
 use period
@@ -168,27 +168,27 @@ integer          iinvpe, imaspe, indhyd, itypfl
 integer          iesdep
 integer          idtsca
 integer          nagmax, npstmg
-integer          ibsize
+integer          ibsize, iesize
 integer          iescap, ircflp, ischcp, isstpp, ivar, ncymxp, nitmfp
 integer          nswrsp
-integer          imucpp
+integer          imucpp, idftnp, iswdyp
 
 double precision residu, phydr0
 double precision ardtsr, arsr  , unsara, thetap
 double precision dtsrom, unsvom, romro0
 double precision epsrgp, climgp, extrap, epsilp
 double precision drom  , dronm1
-double precision hint, qimp, pimpv(3), epsrsp, blencp, relaxp
+double precision hint, qimp, epsrsp, blencp, relaxp
 
 double precision rvoid(1)
 
-double precision, allocatable, dimension(:) :: dam
+double precision, allocatable, dimension(:)   :: dam
 double precision, allocatable, dimension(:,:) :: xam
-double precision, allocatable, dimension(:) :: w1, w7
+double precision, allocatable, dimension(:)   :: w1, w7
 double precision, allocatable, dimension(:,:) :: grad
-double precision, allocatable, dimension(:) :: cofafp, coefbp, cofbfp
-double precision, allocatable, dimension(:) :: velflx, velflb, dpvar
-double precision, allocatable, dimension(:,:) :: coefav, coefbv, cofafv, cofbfv
+double precision, allocatable, dimension(:)   :: cofafp, coefbp, cofbfp
+double precision, allocatable, dimension(:)   :: velflx, velflb, dpvar
+double precision, allocatable, dimension(:)   :: coefav, cofafv, coefbv, cofbfv
 
 !===============================================================================
 
@@ -203,8 +203,6 @@ allocate(w1(ncelet), w7(ncelet))
 ! Boundary conditions for delta P
 allocate(cofafp(nfabor), coefbp(nfabor), cofbfp(nfabor))
 
-! --- Weakly compressible algorithm: semi analytic scheme
-if (idilat.eq.4) allocate(velflx(nfac), velflb(nfabor))
 
 ! --- Memoire
 
@@ -238,6 +236,7 @@ endif
 
 ! Matrix block size
 ibsize = 1
+iesize = 1
 
 if (iresol(ipr).eq.-1) then
   ireslp = 0
@@ -410,7 +409,15 @@ if (iphydr.eq.1) then
       ! Neumann Boundary Conditions
       !----------------------------
 
-      hint = dt(iel)/distb(ifac)
+      if (idften(ipr).eq.1) then
+        hint = dt(iel)/distb(ifac)
+      else if (idften(ipr).eq.3) then
+        hint = ( dttens(1, iel)*surfbo(1,ifac)**2              &
+               + dttens(2, iel)*surfbo(2,ifac)**2              &
+               + dttens(3, iel)*surfbo(3,ifac)**2              &
+               ) / (surfbn(ifac)**2 * distb(ifac))
+      endif
+
       qimp = 0.d0
 
       call set_neumann_scalar &
@@ -614,6 +621,7 @@ endif
 
 init   = 1
 inc    = 1
+if (idilat.eq.4) inc = 0
 iccocg = 1
 iflmb0 = 1
 if (iale.eq.1.or.imobil.eq.1) iflmb0 = 0
@@ -630,14 +638,14 @@ itypfl = 1
 call inimas &
 !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe , itypfl ,                            &
+   iu     , iv     , iw     , imaspe , itypfl ,                   &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
    propce(1,ipcrom), propfb(1,ipbrom),                            &
-   grad(1,1) , grad(1,2) , grad(1,3) ,                            &
-   coefa(1,icliup), coefa(1,iclivp), coefa(1,icliwp),             &
-   coefb(1,icliup), coefb(1,iclivp), coefb(1,icliwp),             &
+   grad(1,1)       , grad(1,2)       , grad(1,3)       ,          &
+   coefa(1,icliup) , coefa(1,iclivp) , coefa(1,icliwp) ,          &
+   coefb(1,icliup) , coefb(1,iclivp) , coefb(1,icliwp) ,          &
    propfa(1,iflmas), propfb(1,iflmab) )
 
 ! --- Projection aux faces des forces exterieures
@@ -867,7 +875,14 @@ if (iphydr.eq.1) then
              +(cdgfbo(2,ifac)-xyzcen(2,iel))*dfrcxt(iel,2)  &
              +(cdgfbo(3,ifac)-xyzcen(3,iel))*dfrcxt(iel,3)  &
              - phydr0
-        hint = dt(iel)/distb(ifac)
+        if (idften(ipr).eq.1) then
+          hint = dt(iel)/distb(ifac)
+        else if (idften(ipr).eq.3) then
+          hint = ( dttens(1, iel)*surfbo(1,ifac)**2              &
+                 + dttens(2, iel)*surfbo(2,ifac)**2              &
+                 + dttens(3, iel)*surfbo(3,ifac)**2              &
+                 ) / (surfbn(ifac)**2 * distb(ifac))
+        endif
         cofafp(ifac) = - hint*coefap(ifac)
       endif
     enddo
@@ -891,8 +906,8 @@ if (imgr(ipr).gt.0) then
 
   call clmlga &
   !==========
- ( chaine(1:16) ,   lchain ,                                      &
-   isym   , ibsize , nagmax , npstmg , iwarnp ,                   &
+ ( chaine(1:16) ,    lchain ,                                     &
+   isym   , ibsize , iesize , nagmax , npstmg , iwarnp ,          &
    ngrmax , ncegrm ,                                              &
    rlxp1  ,                                                       &
    dam    , xam    )
@@ -916,7 +931,7 @@ do iel = 1,ncel
   smbr(iel) = 0.d0
 enddo
 
-! --- Initial divergence contains Rhie & Chow
+! --- Initial divergence
 init = 1
 
 call divmas &
@@ -927,9 +942,13 @@ call divmas &
 
 ! --- Weakly compressible algorithm: semi analytic scheme
 !     1. The RHS contains rho div(u*) and not div(rho u*)
-!     2. The mass flux is completed by rho u* . S
+!     2. Add dilatation source term to rhs
+!     3. The mass flux is completed by rho u* . S
 if (idilat.eq.4) then
 
+  allocate(velflx(nfac), velflb(nfabor))
+
+  ! 1. The RHS contains rho div(u*) and not div(rho u*)
   init   = 1
   inc    = 1
   iccocg = 1
@@ -948,14 +967,14 @@ if (idilat.eq.4) then
   call inimas &
   !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe , itypfl ,                            &
+   iu     , iv     , iw     , imaspe , itypfl ,                   &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
    propce(1,ipcrom), propfb(1,ipbrom),                            &
    rtp(1,iu)       , rtp(1,iv)       , rtp(1,iw)       ,          &
-   coefa(1,icliup), coefa(1,iclivp), coefa(1,icliwp),             &
-   coefb(1,icliup), coefb(1,iclivp), coefb(1,icliwp),             &
+   coefa(1,icliup) , coefa(1,iclivp) , coefa(1,icliwp) ,          &
+   coefb(1,icliup) , coefb(1,iclivp) , coefb(1,icliwp) ,          &
    velflx , velflb )
 
   call divmas &
@@ -968,7 +987,12 @@ if (idilat.eq.4) then
     w7(iel) = w7(iel) + w1(iel)*propce(iel,ipcrom)
   enddo
 
-  ! 2. The mass flux is completed by rho u* . S
+  ! 2. Add dilatation source term
+  do iel = 1, ncel
+    w7(iel) = w7(iel) + propce(iel,ipproc(iustdy(itsrho)))
+  enddo
+
+  ! 3. The mass flux is completed by rho u* . S
   init   = 0
   inc    = 1
   iccocg = 1
@@ -1003,21 +1027,13 @@ endif
 if (ncesmp.gt.0) then
   do ii = 1, ncesmp
     iel = icetsm(ii)
-    w7(iel) = w7(iel) -volume(iel)*smacel(ii,ipr)
+    w7(iel) = w7(iel) - volume(iel)*smacel(ii,ipr)
   enddo
 endif
 
-! --- Weakly compressible algorithm: semi analytic scheme
-if (idilat.eq.4) then
-
-  do iel = 1, ncel
-    w7(iel) = w7(iel) + propce(iel,ipproc(iustdy(itsrho)))
-  enddo
-
-endif
-
 ! --- Source term associated to the mass aggregation
-if (idilat.eq.2.or.idilat.eq.3) then
+if ((idilat.eq.2.or.idilat.eq.3).and. &
+    (ntcabs.gt.1).and.(isuite.gt.0)) then
   do iel = 1, ncel
     drom = propce(iel,ipcrom) - propce(iel,ipcroa)
     w7(iel) = w7(iel) + drom*volume(iel)/dt(iel)
@@ -1059,9 +1075,7 @@ do 100 isweep = 1, nswmpr
   endif
   if (isweep.eq.1) rnsmbr(ipp) = residu
 
-!  Test a modifier eventuellement
-! (il faut qu'il soit plus strict que celui de gradco)
-  if( residu .le. 10.d0*epsrsm(ipr)*rnormp ) then
+  if (residu .le. epsrsm(ipr)*rnormp ) then
 ! --- Si convergence, calcul de l'indicateur
 !                     mise a jour du flux de masse et sortie
 
@@ -1146,15 +1160,16 @@ do 100 isweep = 1, nswmpr
   iwarnp = iwarni(ipr)
   epsilp = epsilo(ipr)
   ibsize = 1
+  iesize = 1
 
 ! ---> TRAITEMENT PERIODICITE
 !     (La pression est un scalaire,
 !                 pas de pb pour la rotation: IINVPE=1)
- iinvpe = 1
+  iinvpe = 1
 
-  call invers                                                     &
+  call invers &
   !==========
- ( chaine(1:16)    , isym   , ibsize ,                            &
+ ( chaine(1:16)    , isym   , ibsize , iesize ,                   &
    ipol   , ireslp , nitmap , imgrp  ,                            &
    ncymap , nitmgp ,                                              &
    iwarnp , nfecra , niterf , icycle , iinvpe ,                   &
@@ -1222,9 +1237,8 @@ do 100 isweep = 1, nswmpr
    dt          , dt          , dt          ,                      &
    propfa(1,iflmas), propfb(1,iflmab))
 
-!     pour le dernier increment, on ne reconstruit pas, on n'appelle donc
-!     pas GRDCEL. La valeur des DFRCXT (qui doit normalement etre nul)
-!     est donc sans importance
+    ! The last increment is not reconstructed to fullfill exactly the continuity
+    ! equation (see theory guide). The value of dfrcxt has no importance.
     iccocg = 0
     nswrp = 0
     inc = 0
@@ -1259,9 +1273,8 @@ do 100 isweep = 1, nswmpr
    tpucou(1,1) , tpucou(1,2) , tpucou(1,3) ,                      &
    propfa(1,iflmas), propfb(1,iflmab))
 
-!     pour le dernier increment, on ne reconstruit pas, on n'appelle donc
-!     pas GRDCEL. La valeur des DFRCXT (qui doit normalement etre nul)
-!     est donc sans importance
+    ! The last increment is not reconstructed to fullfill exactly the continuity
+    ! equation (see theory guide). The value of dfrcxt has no importance.
     iccocg = 0
     nswrp = 0
     inc = 0
@@ -1381,8 +1394,8 @@ if (idilat.eq.4) then
 
   ! Allocate temporary arrays
   allocate(dpvar(ncelet))
-  allocate(coefav(nfabor,3), coefbv(nfabor,3))
-  allocate(cofafv(nfabor,3), cofbfv(nfabor,3))
+  allocate(coefav(nfabor), coefbv(nfabor))
+  allocate(cofafv(nfabor), cofbfv(nfabor))
 
   ! --- Convective flux: dt/rho grad(rho)
   inc = 1
@@ -1390,7 +1403,7 @@ if (idilat.eq.4) then
   ivar   = 0
   nswrgp = nswrgr(iu)
   imligp = imligr(iu)
-  iwarnp = iwarni(iu)
+  iwarnp = iwarni(ipr)
   epsrgp = epsrgr(iu)
   climgp = climgr(iu)
   extrap = extrag(iu)
@@ -1434,38 +1447,20 @@ if (idilat.eq.4) then
   imaspe = 1
   itypfl = 0
 
-  ! --- Viscosity
-  call viscfa (imvisf, dt, viscf, viscb)
-
+  ! Boundary Conditions for the convective flux
   do ifac = 1, nfabor
 
      iel = ifabor(ifac)
 
-     ! Dirichlet Boundary Condition
-     !-----------------------------
-
-     pimpv(1) = 0.d0
-     pimpv(2) = 0.d0
-     pimpv(3) = 0.d0
+     qimp = 0.d0
      hint = dt(iel)/distb(ifac)
 
-     call set_dirichlet_scalar &
-          !===================
-        ( coefav(ifac,1), cofafv(ifac,1),             &
-          coefbv(ifac,1), cofbfv(ifac,1),             &
-          pimpv(1)      , hint          , rinfin )
+     call set_neumann_scalar &
+          !=================
+        ( coefav(ifac), cofafv(ifac),             &
+          coefbv(ifac), cofbfv(ifac),             &
+          qimp        , hint        )
 
-     call set_dirichlet_scalar &
-          !===================
-        ( coefav(ifac,2), cofafv(ifac,2),             &
-          coefbv(ifac,2), cofbfv(ifac,2),             &
-          pimpv(2)      , hint          , rinfin )
-
-     call set_dirichlet_scalar &
-          !===================
-        ( coefav(ifac,3), cofafv(ifac,3),             &
-          coefbv(ifac,3), cofbfv(ifac,3),             &
-          pimpv(3)      , hint          , rinfin )
   enddo
 
   call inimas &
@@ -1477,33 +1472,65 @@ if (idilat.eq.4) then
      epsrgp , climgp , extrap ,                                     &
      propce(1,ipcrom), propfb(1,ipbrom),                            &
      grad(1,1)       , grad(1,2)   , grad(1,3)   ,                  &
-     coefav(1,1)     , coefav(1,2) , coefav(1,3) ,                  &
-     coefbv(1,1)     , coefbv(1,2) , coefbv(1,3) ,                  &
+     coefav          , coefav      , coefav      ,                  &
+     coefbv          , coefbv      , coefbv      ,                  &
      velflx , velflb )
 
-  ! Initialization of the variable to solve
-  do iel = 1, ncel
-    rovsdt(iel) = dt(iel)/9.d4 * volume(iel)
-    drtp(iel)   = 0.d0
-    smbr(iel)   = - w7(iel)
+  ! --- Viscosity
+  call viscfa (imvisf, dt, viscf, viscb)
+
+  ! --- Boundary condition for the pressure increment
+  do ifac = 1, nfabor
+   coefap(ifac) = 0.d0
+   cofafp(ifac) = 0.d0
   enddo
 
-  ! Neumann boundary condition for the pressure increment
-  !------------------------------------------------------
+  ! --- Convective source term
+  do iel = 1, ncel
+    smbr(iel) = 0.d0
+  enddo
 
-  do ifac = 1, nfabor
+  ivar   = ipr
+  iconvp = 1
+  idiffp = 0
+  nswrsp = 1
+  imligp = imligr(ivar)
+  ircflp = ircflu(ivar)
+  ischcp = ischcv(ivar)
+  isstpp = isstpc(ivar)
+  inc    = 1
+  iccocg = 1
+  ipp    = ipprtp(ivar)
+  iwarnp = iwarni(ivar)
+  imucpp = 0
+  idftnp = idften(ivar)
+  blencp = blencv(ivar)
+  epsrgp = epsrgr(ivar)
+  climgp = climgr(ivar)
+  extrap = extrag(ivar)
+  relaxp = relaxv(ivar)
+  thetap = 1.d0
 
-    iel = ifabor(ifac)
-
-    hint = dt(iel)/distb(ifac)
-    qimp = 0.d0
-
-    call set_neumann_scalar &
-         !=================
-       ( coefap(ifac), cofafp(ifac),             &
-         coefbp(ifac), cofbfp(ifac),             &
-         qimp        , hint )
+  call bilsca &
+  !==========
+ ( nvar   , nscal  ,                                              &
+   idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
+   ischcp , isstpp , inc    , imrgra , iccocg ,                   &
+   ipp    , iwarnp , imucpp , idftnp ,                            &
+   blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
+   rtp(1,ipr)      , rtp(1,ipr)      ,                            &
+   coefap , coefb(1,iclipr) ,                                     &
+   cofafp , coefb(1,iclipf) ,                                     &
+   velflx , velflb , viscf  , viscb  , rvoid  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
+   smbr   )
 
+  ! --- Initialization of the variable to solve
+  do iel = 1, ncel
+    rovsdt(iel) = 340.d0/dt(iel) * volume(iel)
+    drtp(iel)   = 0.d0
+    dpvar(iel)  = 0.d0
+    smbr(iel)   = - smbr(iel)
   enddo
 
   ! --- Solve the convection diffusion equation
@@ -1522,6 +1549,9 @@ if (idilat.eq.4) then
   ischcp = ischcv(ivar)
   isstpp = isstpc(ivar)
   iescap = 0
+  imucpp = 0
+  idftnp = idften(ivar)
+  iswdyp = iswdyn(ivar)
   imgrp  = 0
   ncymxp = ncymax(ivar)
   nitmfp = nitmgf(ivar)
@@ -1535,7 +1565,6 @@ if (idilat.eq.4) then
   extrap = extrag(ivar)
   relaxp = relaxv(ivar)
   thetap = thetav(ivar)
-  imucpp = 0
 
   ! --- Solve the convection diffusion equation
 
@@ -1544,15 +1573,16 @@ if (idilat.eq.4) then
    ( nvar   , nscal  ,                                              &
      idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
      imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-     ischcp , isstpp , iescap , imucpp ,                            &
+     ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
      imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
      blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
      relaxp , thetap ,                                              &
-     rtp(1,ipr)      , drtp   ,                                     &
-     coefap , coefbp ,                                              &
-     cofafp , cofbfp ,                                              &
+     drtp   , drtp   ,                                              &
+     coefap , coefb(1,iclipr) ,                                     &
+     cofafp , coefb(1,iclipf) ,                                     &
      velflx , velflb ,                                              &
-     viscf  , viscb  , viscf  , viscb  ,                            &
+     viscf  , viscb  , rvoid  , viscf  , viscb  , rvoid  ,          &
+     rvoid  , rvoid  ,                                              &
      rovsdt , smbr   , drtp   , dpvar  ,                            &
      rvoid  , rvoid  )
 
@@ -1569,14 +1599,12 @@ if (idilat.eq.4) then
   init   = 0
   inc    = 1
   iccocg = 1
-  iflmb0 = 1
-  if (iale.eq.1.or.imobil.eq.1) iflmb0 = 0
-  nswrgp = nswrgr(iu)
-  imligp = imligr(iu)
+  nswrgp = nswrgr(ipr)
+  imligp = imligr(ipr)
   iwarnp = iwarni(ipr)
-  epsrgp = epsrgr(iu)
-  climgp = climgr(iu)
-  extrap = extrag(iu)
+  epsrgp = epsrgr(ipr)
+  climgp = climgr(ipr)
+  extrap = extrag(ipr)
 
   if (idtsca.eq.0) then
     call itrmas &
@@ -1587,15 +1615,14 @@ if (idilat.eq.4) then
    epsrgp , climgp , extrap ,                                     &
    dfrcxt(1,1)     , dfrcxt(1,2)     , dfrcxt(1,3)     ,          &
    drtp   ,                                                       &
-   coefap , coefbp ,                                              &
-   cofafp , cofbfp ,                                              &
+   coefap , coefb(1,iclipr) ,                                     &
+   cofafp , coefb(1,iclipf) ,                                     &
    viscf  , viscb  ,                                              &
    dt     , dt     , dt     ,                                     &
    propfa(1,iflmas), propfb(1,iflmab))
 
-    ! pour le dernier increment, on ne reconstruit pas, on n'appelle donc
-    ! pas GRDCEL. La valeur des DFRCXT (qui doit normalement etre nul)
-    ! est donc sans importance
+    ! The last increment is not reconstructed to fullfill exactly the continuity
+    ! equation (see theory guide). The value of dfrcxt has no importance.
     iccocg = 0
     nswrp = 0
     inc = 0
@@ -1608,8 +1635,8 @@ if (idilat.eq.4) then
    epsrgp , climgp , extrap ,                                     &
    dfrcxt(1,1)     , dfrcxt(1,2)     , dfrcxt(1,3)     ,          &
    dpvar  ,                                                       &
-   coefap , coefbp ,                                              &
-   cofafp , cofbfp ,                                              &
+   coefap , coefb(1,iclipr) ,                                     &
+   cofafp , coefb(1,iclipf) ,                                     &
    viscf  , viscb  ,                                              &
    dt     , dt     , dt     ,                                     &
    propfa(1,iflmas), propfb(1,iflmab))
@@ -1624,15 +1651,14 @@ if (idilat.eq.4) then
    epsrgp , climgp , extrap ,                                     &
    dfrcxt(1,1)     , dfrcxt(1,2)     , dfrcxt(1,3)     ,          &
    drtp   ,                                                       &
-   coefap , coefbp ,                                              &
-   cofafp , cofbfp ,                                              &
+   coefap , coefb(1,iclipr) ,                                     &
+   cofafp , coefb(1,iclipf) ,                                     &
    viscf  , viscb  ,                                              &
    tpucou(1,1)     , tpucou(1,2)     , tpucou(1,3)     ,          &
    propfa(1,iflmas), propfb(1,iflmab))
 
-    ! pour le dernier increment, on ne reconstruit pas, on n'appelle donc
-    ! pas GRDCEL. La valeur des DFRCXT (qui doit normalement etre nul)
-    ! est donc sans importance
+    ! The last increment is not reconstructed to fullfill exactly the continuity
+    ! equation (see theory guide). The value of dfrcxt has no importance.
     iccocg = 0
     nswrp = 0
     inc = 0
@@ -1645,8 +1671,8 @@ if (idilat.eq.4) then
    epsrgp , climgp , extrap ,                                     &
    dfrcxt(1,1)     , dfrcxt(1,2)     , dfrcxt(1,3)     ,          &
    dpvar  ,                                                       &
-   coefap , coefbp ,                                              &
-   cofafp , cofbfp ,                                              &
+   coefap , coefb(1,iclipr) ,                                     &
+   cofafp , coefb(1,iclipf) ,                                     &
    viscf  , viscb  ,                                              &
    tpucou(1,1)     , tpucou(1,2)     , tpucou(1,3)     ,          &
    propfa(1,iflmas), propfb(1,iflmab))
@@ -1655,6 +1681,7 @@ if (idilat.eq.4) then
 
   ! Free memory
   deallocate(dpvar)
+  deallocate(velflx, velflb)
   deallocate(coefav, coefbv)
   deallocate(cofafv, cofbfv)
 
@@ -1674,13 +1701,11 @@ else
   enddo
 endif
 
-
 ! Free memory
 deallocate(grad)
 deallocate(dam, xam)
 deallocate(w1, w7)
 deallocate(cofafp, coefbp, cofbfp)
-if (idilat.eq.4) deallocate(velflx, velflb)
 
 !--------
 ! FORMATS
