@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -220,8 +220,7 @@ call ustssc                                                       &
    iscal  ,                                                       &
    icepdc , icetsm , itypsm ,                                     &
    dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
-   coefa  , coefb  , ckupdc , smacel ,                            &
-   smbrs  , rovsdt )
+   ckupdc , smacel , smbrs  , rovsdt )
 
 do iel = 1, ncel
   smbrs(iel) = smbrs(iel) + rovsdt(iel)*rtp(iel,ivar)
@@ -247,28 +246,12 @@ if (ncesmp.gt.0) then
                 smacel(1,ipr) , smbrs , rovsdt , w1    )
 endif
 
-!                                     __    n+1
-!     TERME D'ACCUMULATION DE MASSE : >  (Q    .n)  *S
-!     =============================   --   pr     ij  ij
-
-init = 1
-call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                  &
-               ifacel,ifabor,propfa(1,iflmas),propfb(1,iflmab),w1)
-
-!                                      __    n+1             n
-!     TERME INSTATIONNAIRE EXPLICITE : >  (Q    .n)  *S   * e
-!     ==============================   --   pr     ij  ij
+!                                      RHO*VOLUME
+!     TERME INSTATIONNAIRE IMPLICITE : ----------
+!     ==============================       DT
 
 do iel = 1, ncel
-  smbrs(iel) = smbrs(iel) + iconv(ivar)*w1(iel)*rtpa(iel,ivar)
-enddo
-
-!                                      RHO*VOLUME   __    n+1
-!     TERME INSTATIONNAIRE IMPLICITE : ---------- - >  (Q    .n)  *S
-!     ==============================       DT       --   pr     ij  ij
-
-do iel = 1, ncel
-  rovsdt(iel) = rovsdt(iel) - iconv(ivar)*w1(iel)                 &
+  rovsdt(iel) = rovsdt(iel)                                       &
            + istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel)
 enddo
 
@@ -496,13 +479,12 @@ if( idiff(ivar).ge. 1 ) then
 !     Terme complementaire au centre des cellules
   iccfth = 7
   imodif = 0
-  call uscfth                                                     &
+  call cfther                                                     &
   !==========
  ( nvar   , nscal  ,                                              &
    iccfth , imodif ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
-   w9     , wb     , w8     , w1     )
+   w9     , wb     , w8     , w4     )
 
 !     Calcul de la divergence avec reconstruction
 
@@ -593,7 +575,7 @@ enddo
 !     Pour les faces  flux impos ou temperature impose, tout est
 !       pris par le terme de diffusion de l'energie. On ne doit donc
 !       pas prendre en compte la contribution des termes en u2 et e-CvT
-!       quand IA(IIFBE+IFAC-1).NE.0
+!       quand ifbet(ifac).ne.0
 
   do ifac = 1, nfabor
 
@@ -601,13 +583,14 @@ enddo
 
       iel = ifabor(ifac)
 
-      flux = viscb(ifac)*( w9(iel) - wb(ifac)            &
+      flux = viscb(ifac)*(w1(iel)/distb(ifac))*            &
+            ( w9(iel) - wb(ifac)                           &
            + 0.5d0*( rtp(iel,iu)**2 -                      &
    ( coefa(ifac,iclrtp(iu,icoef))                          &
-   + coefb(ifac,iclrtp(iu,icoef))*rtp(iel,iu) )**2  &
+   + coefb(ifac,iclrtp(iu,icoef))*rtp(iel,iu) )**2         &
                    + rtp(iel,iv)**2 -                      &
    ( coefa(ifac,iclrtp(iv,icoef))                          &
-   + coefb(ifac,iclrtp(iv,icoef))*rtp(iel,iv) )**2  &
+   + coefb(ifac,iclrtp(iv,icoef))*rtp(iel,iv) )**2         &
                    + rtp(iel,iw)**2 -                      &
    ( coefa(ifac,iclrtp(iw,icoef))                          &
    + coefb(ifac,iclrtp(iw,icoef))*rtp(iel,iw) )**2))
@@ -661,7 +644,7 @@ iescap = 0
 call cfcdts                                                       &
 !==========
  ( nvar   , nscal  ,                                              &
-   iscal  , iconvp , idiffp , ireslp , ndircp , nitmap ,          &
+   ivar  , iconvp , idiffp , ireslp , ndircp , nitmap ,           &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
    ischcp , isstpp , iescap ,                                     &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
@@ -689,12 +672,11 @@ call clpsca                                                       &
 !       et actions correctives ventuelles.
   iccfth = -4
   imodif = 0
-  call uscfth                                                     &
+  call cfther                                                     &
   !==========
  ( nvar   , nscal  ,                                              &
    iccfth , imodif ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w6     , w7     , w8     , w9     )
 
 
@@ -721,12 +703,11 @@ endif
 ! --- Calcul de P et T au centre des cellules
   iccfth = 24
   imodif = 0
-  call uscfth                                                     &
+  call cfther                                                     &
   !==========
  ( nvar   , nscal  ,                                              &
    iccfth , imodif ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    rtp(1,ipr) , rtp(1,isca(itempk)) , w8     , w9 )
 
 !===============================================================================
