@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -59,6 +59,8 @@ use cstnum
 use ppppar
 use ppthch
 use ppincl
+!bug Ba
+use ihmpre
 
 !===============================================================================
 
@@ -138,6 +140,14 @@ enddo
 
 !         Upwind necessaire pour le schema utilise
 
+! --- Segregated or coupled solver for the velocity components:
+!       only the segregated one is possible with the compressible module.
+!       ivelco is imposed to 0.
+
+if (ivelco.ne.0) then
+  write(nfecra,6000) ivelco
+  ivelco = 0
+endif
 
 ! 1.3 Variable courante : nom, sortie chrono, suivi listing, sortie hist
 ! ======================================================================
@@ -200,10 +210,6 @@ if( (iescal(iespre).ne.0) .or.                            &
   write(nfecra,4000)
   call csexit (1)
 endif
-!       IESCAL(IESPRE) = 0
-!       IESCAL(IESDER) = 0
-!       IESCAL(IESCOR) = 0
-!       IESCAL(IESTOT) = 0
 
 !===============================================================================
 ! 3. OPTIONS DE CALCUL PAR DEFAUT
@@ -215,17 +221,18 @@ endif
 icfgrp = 1
 
 
-! ---> Masse volumique variable et viscosite constante (pour les suites)
+! ---> Masse volumique variable (pour les suites)
 irovar = 1
-ivivar = 0
 
 !===============================================================================
 ! 4. ON REDONNE LA MAIN A L'UTLISATEUR
 !===============================================================================
 
-call cscfgp(icfgrp)
+if (iihmpr.eq.1) then
+  call cscfgp(icfgrp)
+endif
 
-call uscfx1
+call uscfx2
 !==========
 
 !===============================================================================
@@ -248,7 +255,7 @@ iconv(isca(irho)) = 0
 ! --> Prise en compte de la pression predite pour resoudre Navier-Stokes
 !     (oui = 1 , non = 0)
 
-igrdpp = 0
+igrdpp = 1
 
 ! --> Prediction de pression par une equation d'evolution
 
@@ -276,6 +283,8 @@ endif
 ! FORMATS
 !--------
 
+#if defined(_CS_LANG_FR)
+
  1000 format(                                                     &
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
@@ -317,7 +326,6 @@ endif
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
-
  2000 format(                                                     &
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
@@ -338,7 +346,7 @@ endif
 '@  On peut modifier les bornes des variables rho et energie  ',/,&
 '@  dans uscfx1, mais ce n''est pas conseille.                ',/,&
 '@  Il est preferable de gerer les depassements ventuels     ',/,&
-'@  au moyen du sous programme uscfth (arret du calcul en fin ',/,&
+'@  au moyen du sous programme cfther (arret du calcul en fin ',/,&
 '@  de pas de temps en cas de depassement).                   ',/,&
 '@                                                            ',/,&
 '@  Le calcul ne sera pas execute.                            ',/,&
@@ -347,7 +355,6 @@ endif
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
-
  3000 format(                                                     &
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
@@ -374,7 +381,7 @@ endif
 '@    PHYSIQUE PARTICULIERE (COMPRESSIBLE) DEMANDEE           ',/,&
 '@                                                            ',/,&
 '@  Les estimateurs ne sont pas compatibles avec le module    ',/,&
-'@    compressible                                            ',/,&
+'@    compressible.                                           ',/,&
 '@                                                            ',/,&
 '@  Le calcul ne sera pas execute.                            ',/,&
 '@                                                            ',/,&
@@ -395,10 +402,178 @@ endif
 '@                                                            ',/,&
 '@  Le calcul ne sera pas execute.                            ',/,&
 '@                                                            ',/,&
-'@  Verifier uscfx1.                                          ',/,&
+'@  Verifier uscfx2.                                          ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
+6000 format(                                                      &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ ATTENTION :      A L''ENTREE DES DONNEES',                /,&
+'@    =========',                                               /,&
+'@   EN COMPRESSIBLE',                                          /,&
+'@   CONCERNANT LE COUPLAGE DES COMPOSANTES DE VITESSE',        /,&
+'@   LA SEULE VALEUR POSSIBLE POUR LE PARAMETRE IVELCO EST 0',  /,&
+'@' ,                                                           /,&
+'@   IVELCO A ETE IMPOSE ICI A', I10,                           /,&
+'@   IL EST DONC REMIS A 0',                                    /,&
+'@',                                                            /,&
+'@  Le calcul sera execute',                                    /,&
+'@',                                                            /,&
+'@  Il est conseille de verifier les parametres donnes via',    /,&
+'@  cs_user_parameters.f90.',                                   /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /)
+
+#else
+
+ 1000 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : STOP WHILE READING INPUT DATAS                ',/,&
+'@    =========                                               ',/,&
+'@    SPECIFIC PHYSICS MODULES (COMPRESSIBLE) SET             ',/,&
+'@                                                            ',/,&
+'@  The value of ISCALT is set automatically.                 ',/,&
+'@                                                            ',/,&
+'@  The user should not give a value for it, however          ',/,&
+'@    it has been given the following value:                  ',/,&
+'@    ISCALT = ',I10                                           ,/,&
+'@                                                            ',/,&
+'@  The calculation could NOT run.                            ',/,&
+'@                                                            ',/,&
+'@  Check parameters.                                         ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 1001 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : STOP WHILE READING INPUT DATAS                ',/,&
+'@    =========                                               ',/,&
+'@    SPECIFIC PHYSICS MODULES (COMPRESSIBLE) SET             ',/,&
+'@                                                            ',/,&
+'@  The values of ISCSTH are set automatically.               ',/,&
+'@                                                            ',/,&
+'@  The user should not set a value for them, however         ',/,&
+'@    for the scalar ',I10   ,' corresponding to the specific ',/,&
+'@    physics scalar ',I10   ,' we have                       ',/,&
+'@    ISCSTH(',I10   ,') = ',I10                               ,/,&
+'@                                                            ',/,&
+'@  The calculation could NOT run.                            ',/,&
+'@                                                            ',/,&
+'@  Check parameters.                                         ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 2000 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : STOP WHILE READING INPUT DATAS                ',/,&
+'@    =========                                               ',/,&
+'@    SPECIFIC PHYSICS MODULES (COMPRESSIBLE) SET             ',/,&
+'@                                                            ',/,&
+'@  The bounds of the variables density, energy or temperature',/,&
+'@    have been modified :                                    ',/,&
+'@                                                            ',/,&
+'@                      SCAMIN        SCAMAX                  ',/,&
+'@  density     ',2E14.5                                       ,/,&
+'@  energy      ',2E14.5                                       ,/,&
+'@  temperature ',2E14.5                                       ,/,&
+'@                                                            ',/,&
+'@  The bounds of these variables should not be modified.     ',/,&
+'@  It is possible to modify the bounds of the variables      ',/,&
+'@  density or energy in uscfx2, but it is not recommended.   ',/,&
+'@  It is advised to manage the possible overshoot by the     ',/,&
+'@  use of the subroutine cfther (stop of the calculation     ',/,&
+'@  at the end of the time step in case of an overshoot).     ',/,&
+'@                                                            ',/,&
+'@  The calculation could NOT run.                            ',/,&
+'@                                                            ',/,&
+'@  Check parameters.                                         ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 3000 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : STOP WHILE READING INPUT DATAS                ',/,&
+'@    =========                                               ',/,&
+'@    SPECIFIC PHYSICS MODULES (COMPRESSIBLE) SET             ',/,&
+'@                                                            ',/,&
+'@  The option IPUCOU = ',I10                                  ,/,&
+'@    is not compatible with the compressible module          ',/,&
+'@                                                            ',/,&
+'@  The calculation could NOT run.                            ',/,&
+'@                                                            ',/,&
+'@  Impose IPUCOU = 0.                                        ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 4000 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : STOP WHILE READING INPUT DATAS                ',/,&
+'@    =========                                               ',/,&
+'@    SPECIFIC PHYSICS MODULES (COMPRESSIBLE) SET             ',/,&
+'@                                                            ',/,&
+'@  The error estimators are not compatible with the          ',/,&
+'@    compressible module.                                    ',/,&
+'@                                                            ',/,&
+'@  The calculation could NOT run.                            ',/,&
+'@                                                            ',/,&
+'@  Impose IESCAL(.) = 0.                                     ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 5000 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING : STOP WHILE READING INPUT DATAS                ',/,&
+'@    =========                                               ',/,&
+'@    SPECIFIC PHYSICS MODULES (COMPRESSIBLE) SET             ',/,&
+'@                                                            ',/,&
+'@    ',A6,' MUST BE AN INTEGER EGAL TO 0 OR 1                ',/,&
+'@    IT HAS VALUE',I10                                        ,/,&
+'@                                                            ',/,&
+'@  The calculation could NOT run.                            ',/,&
+'@                                                            ',/,&
+'@  Check uscfx2.                                             ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 6000 format(                                                     &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@   WARNING :      WHEN READING INPUT DATA',                /,&
+'@    =========',                                               /,&
+'@   FOR COMPRESSIBLE MODEL',                                   /,&
+'@   AND THE CHOICE FOR VELOCITY COMPONENTS COUPLING',          /,&
+'@   THE ONLY POSSIBLE VALUE FOR THE PARAMETER IVELCO IS 0',    /,&
+'@' ,                                                           /,&
+'@   IVELCO IS IMPOSED HERE AS', I10,                           /,&
+'@   IT IS THEN REPLACED BY 0',                                 /,&
+'@',                                                            /,&
+'@  computation will go on',                                    /,&
+'@',                                                            /,&
+'@ Check the input data given in cs_user_parameters.f90.',      /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /)
+
+#endif
 
 return
 end subroutine
+
+
+
