@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -131,7 +131,7 @@ double precision sclnor
 
 integer          iccfth, imodif
 integer          iij
-integer          imucpp
+integer          imucpp, idftnp, iswdyp
 double precision dijpfx, dijpfy, dijpfz, pnd
 double precision diipfx, diipfy, diipfz, djjpfx, djjpfy, djjpfz
 double precision diipbx, diipby, diipbz
@@ -420,6 +420,8 @@ ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
 imucpp = 0
+idftnp = idften(ivar)
+iswdyp = iswdyn(ivar)
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
@@ -439,15 +441,16 @@ call codits &
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetv  ,                                              &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
    coefa(1,iclvar) , coefb(1,iclvar) ,                            &
-                     coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
-                     wflmas          , wflmab          ,          &
-   viscf  , viscb  , viscf  , viscb  ,                            &
+   coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
+   wflmas          , wflmab          ,                            &
+   viscf  , viscb  , rvoid  , viscf  , viscb  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    rovsdt , smbrs  , rtp(1,ivar)     , dpvar  ,                   &
    rvoid  , rvoid  )
 
@@ -470,12 +473,11 @@ call clpsca                                                       &
 !       et actions correctives ventuelles.
   iccfth = -2
   imodif = 0
-  call uscfth                                                     &
+  call cfther                                                     &
   !==========
  ( nvar   , nscal  ,                                              &
    iccfth , imodif ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w7     , w8     , w9     , w10    )
 
 
@@ -558,12 +560,11 @@ if(igrdpp.gt.0) then
 
   iccfth = 24
   imodif = 0
-  call uscfth                                                     &
+  call cfther                                                     &
   !==========
  ( nvar   , nscal  ,                                              &
    iccfth , imodif ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    rtp(1,ipr)        , w8     , w9     , w10    )
 
 !===============================================================================
