@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -248,8 +248,8 @@ if (iphydr.eq.1) then
       cpdc22 = ckupdc(ielpdc,2)
       cpdc33 = ckupdc(ielpdc,3)
       cpdc12 = ckupdc(ielpdc,4)
-      cpdc13 = ckupdc(ielpdc,5)
-      cpdc23 = ckupdc(ielpdc,6)
+      cpdc23 = ckupdc(ielpdc,5)
+      cpdc13 = ckupdc(ielpdc,6)
       dfrcxt(iel,1) = dfrcxt(iel,1)                   &
  -rtp(iel,isca(irho))*(cpdc11*vit1+cpdc12*vit2+cpdc13*vit3)
       dfrcxt(iel,2) = dfrcxt(iel,2)                   &
@@ -620,34 +620,22 @@ do isou = 1, 3
    ivar   ,                                                       &
    icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , propce , propfa , propfb ,                   &
-   coefa  , coefb  , ckupdc , smacel ,                            &
-   smbr   , drtp   )
+   ckupdc , smacel , smbr   , drtp   )
 
   do iel = 1, ncel
     rovsdt(iel) = max(-drtp(iel),zero)
     smbr  (iel) = smbr(iel) + drtp(iel) * rtp(iel,ivar)
   enddo
 
-
-! ---> TERME D'ACCUMULATION DE MASSE -(dRO/dt)*Volume
-
-  init = 1
-  call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                &
-                           ifacel,ifabor,flumas,flumab,w1)
-
-
-
 ! ---> AJOUT DANS LE TERME SOURCE ET DANS LE TERME INSTATIONNAIRE
 
   do iel = 1, ncel
-    smbr(iel) = smbr  (iel) +                                     &
-         trav(iel,isou)+iconv(ivar)*w1(iel)*rtpa(iel,ivar)
+    smbr(iel) = smbr(iel) + trav(iel,isou)
   enddo
 
   do iel = 1, ncel
     rovsdt(iel) = rovsdt(iel) +                                   &
-         istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel)     &
-         -iconv(ivar)*w1(iel)
+         istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel)
   enddo
 
 
@@ -673,8 +661,6 @@ do isou = 1, 3
                   smacel(1,ipr) , smbr , rovsdt , w1)
   endif
 
-
-
 ! ---> PARAMETRES POUR LA RESOLUTION DU SYSTEME
 
   iconvp = iconv (ivar)
