@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -111,7 +111,7 @@ implicit none
 
 integer          nvar   , nscal
 
-integer          icodcl(nfabor,nvar)
+integer          icodcl(nfabor,nvarcl)
 integer          itrifb(nfabor), itypfb(nfabor)
 integer          izfppp(nfabor)
 
@@ -119,7 +119,7 @@ double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
 double precision coefa(nfabor,*), coefb(nfabor,*)
-double precision rcodcl(nfabor,nvar,3)
+double precision rcodcl(nfabor,nvarcl,3)
 
 ! Local variables
 
@@ -182,7 +182,7 @@ nvarcf    = 7
 !       Il est calcul aux cellules W5 et aux faces de bord COEFU.
 !       On n'en a besoin ici qu'aux cellules de bord : s'il est
 !         ncessaire de gagner de la mmoire, on pourra modifier
-!         uscfth.
+!         cfther.
 
 icalep = 0
 do ifac = 1, nfabor
@@ -193,12 +193,11 @@ enddo
 if(icalep.ne.0) then
   iccfth = 7
   imodif = 0
-  call uscfth                                                   &
+  call cfther                                                   &
   !==========
 ( nvar   , nscal  ,                                              &
   iccfth , imodif ,                                              &
   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-  coefa  , coefb  ,                                              &
   w5     , w7     , w3     , w4     )
 endif
 
@@ -218,12 +217,11 @@ enddo
 if(icalgm.ne.0) then
   iccfth = 1
   imodif = 0
-  call uscfth                                                   &
+  call cfther                                                   &
   !==========
 ( nvar   , nscal  ,                                              &
   iccfth , imodif ,                                              &
   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-  coefa  , coefb  ,                                              &
   w1     , w2     , w6     , w4     )
 
   if(ieos.eq.1) then
@@ -291,12 +289,11 @@ do ifac = 1, nfabor
 
       iccfth = 91
 
-      call uscfth                                               &
+      call cfther                                               &
       !==========
  ( nvar   , nscal  ,                                              &
    iccfth , ifac   ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w1     , w2     , w3     , w4     )
 
 !       En outre, il faut appliquer une pre-correction pour compenser
@@ -420,12 +417,11 @@ do ifac = 1, nfabor
 
     iccfth = 90
 
-    call uscfth                                                 &
+    call cfther                                                 &
     !==========
  ( nvar   , nscal  ,                                              &
    iccfth , ifac   ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w1     , w2     , w3     , w4     )
 
 
@@ -500,12 +496,11 @@ do ifac = 1, nfabor
       coefa(ifac,iclrtp(ivar,icoef)) = rcodcl(ifac,ivar,1)
     enddo
 
-    call uscfth                                                 &
+    call cfther                                                 &
     !==========
  ( nvar   , nscal  ,                                              &
    iccfth , ifac   ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w1     , w2     , w3     , w4     )
 
 
@@ -555,12 +550,11 @@ do ifac = 1, nfabor
       coefa(ifac,iclrtp(ivar,icoef)) = rcodcl(ifac,ivar,1)
     enddo
 
-    call uscfth                                                 &
+    call cfther                                                 &
     !==========
  ( nvar   , nscal  ,                                              &
    iccfth , ifac   ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w1     , w2     , w3     , w4     )
 
 !               flux de masse et type de conditions aux limites :
@@ -609,12 +603,11 @@ do ifac = 1, nfabor
       coefa(ifac,iclrtp(ivar,icoef)) = rcodcl(ifac,ivar,1)
     enddo
 
-    call uscfth                                                 &
+    call cfther                                                 &
     !==========
  ( nvar   , nscal  ,                                              &
    iccfth , ifac   ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w1     , w2     , w3     , w4     )
 
 !     Rusanov, flux de masse et type de conditions aux limites :
@@ -663,12 +656,11 @@ do ifac = 1, nfabor
       coefa(ifac,iclrtp(ivar,icoef)) = rcodcl(ifac,ivar,1)
     enddo
 
-    call uscfth                                                 &
+    call cfther                                                 &
     !==========
  ( nvar   , nscal  ,                                              &
    iccfth , ifac   ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    w1     , w2     , w3     , w4     )
 
 !     Rusanov, flux de masse et type de conditions aux limites :
@@ -1094,7 +1086,7 @@ deallocate(w7)
 '@                                                            ',/,&
 '@  Le calcul ne sera pas execute.                            ',/,&
 '@                                                            ',/,&
-'@  Verifier IEOS dans uscfth.                                ',/,&
+'@  Verifier IEOS dans cfther.                                ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
