@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -20,49 +20,42 @@
 
 !-------------------------------------------------------------------------------
 
-subroutine d3pphy &
-!================
+!===============================================================================
+! Function:
+! ---------
 
+!> \file d3pphy.f90
+!>
+!> \brief Specific physic subroutine: diffusion flame.
+!>
+!> Calculation of mean density
+!-------------------------------------------------------------------------------
+
+!-------------------------------------------------------------------------------
+! Arguments
+!______________________________________________________________________________.
+!  mode           name          role                                           !
+!______________________________________________________________________________!
+!> \param[in]     nvar          total number of variables
+!> \param[in]     nscal         total number of scalars
+!> \param[in]     ibrom         indicator of boundary density array filling
+!> \param[in]     izfppp        boundary zone index for specific physic
+!> \param[in]     dt            time step (per cell)
+!> \param[in]     rtp, rtpa     calculated variables at cell centers
+!>                               (at current and previous time steps)
+!> \param[in,out] propce        physical properties at cell centers
+!> \param[in]     propfa        physical properties at interior face centers
+!> \param[in,out] propfb        physical properties at boundary face centers
+!> \param[in]     coefa, coefb  boundary conditions
+!_______________________________________________________________________________
+
+subroutine d3pphy &
  ( nvar   , nscal  ,                                              &
    ibrom  , izfppp ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
    coefa  , coefb  )
 
 !===============================================================================
-! FONCTION :
-! --------
-
-! ROUTINE PHYSIQUE PARTICULIERE : FLAMME DE DIFFUSION
-! Calcul de RHO mutualise pour chimie 3 points
-!  adiabatique ou permeatique (transport de H)
-
-
-! Arguments
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
-! ibrom            ! te ! <-- ! indicateur de remplissage de romb              !
-!        !    !     !                                                !
-! izfppp           ! te ! --> ! numero de zone de la face de bord              !
-! (nfabor)         !    !     !  pour le module phys. part.                    !
-! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
-!  (ncelet, *)     !    !     !  (at current and previous time steps)          !
-! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
-! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
-! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
-! rpp              ! tr ! --- ! macro tableau reel pp                          !
-!__________________!____!_____!________________________________________________!
-
-!     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
-!            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
-!     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
-!            --- tableau de travail
-!===============================================================================
 
 !===============================================================================
 ! Module files
@@ -111,7 +104,7 @@ integer, allocatable, dimension(:) :: indpdf
 
 double precision, allocatable, dimension(:) :: dirmin, dirmax
 double precision, allocatable, dimension(:) :: fdeb, ffin
-double precision, allocatable, dimension(:) :: hrec
+double precision, allocatable, dimension(:) :: hrec, tpdf
 double precision, allocatable, dimension(:) :: w1, w2
 
 integer       ipass
@@ -132,7 +125,7 @@ ipass = ipass + 1
 ! Allocate temporary arrays
 allocate(dirmin(ncelet), dirmax(ncelet))
 allocate(fdeb(ncelet), ffin(ncelet))
-allocate(hrec(ncelet))
+allocate(hrec(ncelet), tpdf(ncelet))
 
 ! Allocate temporary arrays
 allocate(w1(ncelet), w2(ncelet))
@@ -260,10 +253,11 @@ enddo
 
 call pppdfr &
 !==========
- ( ncelet, ncel, indpdf ,                                         &
-   rtp(1,isca(ifm)), rtp(1,isca(ifp2m)),                          &
-   w1, w2,                                                        &
-   dirmin, dirmax, fdeb, ffin, hrec )
+ ( ncelet, ncel  , indpdf,                                 &
+   tpdf  ,                                                 &
+   rtp(1,isca(ifm))      , rtp(1,isca(ifp2m)),             &
+   w1    , w2    ,                                         &
+   dirmin, dirmax, fdeb  , ffin, hrec )
 
 
 
@@ -276,27 +270,11 @@ call pppdfr &
 !    Ces variables d'etat sont dans PROPCE
 !===============================================================================
 
-if ( ippmod(icod3p).eq.1 ) then
-
-  call d3pint &
-  !==========
- ( ncelet , ncel , indpdf ,                                       &
-   dirmin,dirmax,fdeb,ffin,hrec,                                  &
-   rtp(1,isca(ifm)),rtp(1,isca(ihm)),rtp(1,ipr),                  &
-   propce,                                                        &
-   w1 )
-
-else
-
-  call d3pint &
-  !==========
- ( ncelet , ncel , indpdf ,                                       &
-   dirmin,dirmax,fdeb,ffin,hrec,                                  &
-   rtp(1,isca(ifm)),w2,rtp(1,ipr),                                &
-   propce,                                                        &
-   w1 )
-
-endif
+call d3pint &
+!==========
+ ( indpdf ,                                                       &
+   dirmin , dirmax , fdeb   , ffin , hrec , tpdf ,                &
+   rtp    , propce , w1 )
 
 ! Free memory
 deallocate(indpdf)
@@ -369,7 +347,7 @@ endif
 ! Free memory
 deallocate(dirmin, dirmax)
 deallocate(fdeb, ffin)
-deallocate(hrec)
+deallocate(hrec, tpdf)
 deallocate(w1, w2)
 
 !===============================================================================
