@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -156,6 +156,7 @@ double precision , dimension ( : )     , allocatable :: x2,cx1m,cx2m,wmchx1,wmch
 double precision , dimension ( : , : ) , allocatable :: af1    , af2
 double precision , dimension ( : )     , allocatable :: fs3no  , fs4no
 double precision , dimension ( : , : ) , allocatable :: yfs4no
+double precision, allocatable, dimension(:) :: tpdf
 !
 integer          ipass
 data ipass / 0 /
@@ -232,14 +233,20 @@ do iel = 1, ncel
 ! Somme de F1+F2
   ffuel(iel)=f1m(iel)+f2m(iel)
 enddo
-!
-call pppdfr                                                       &
+
+allocate(tpdf(ncelet))
+
+call pppdfr &
 !==========
- ( ncelet,ncel,                                                   &
-   intpdf ,                                                       &
-   ffuel  , fvp2m , fmini , fmaxi ,                               &
+ ( ncelet , ncel  , intpdf ,                                      &
+   tpdf   ,                                                       &
+   ffuel  , fvp2m ,                                               &
+   fmini  , fmaxi ,                                               &
    doxyd  , dfuel , pdfm1 , pdfm2 , hrec )
 
+! Free memory
+deallocate(tpdf)
+
 !===============================================================================
 ! 2.CALCUL DES CONCENTRATIONS MOYENNES
 !===============================================================================
