@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -65,6 +65,7 @@ implicit none
 ! Local variables
 
 integer ii, jj, isc, ipp
+double precision cpa,cpe,cpv,hv0,rhoe,visc,conduc
 
 !===============================================================================
 
@@ -129,6 +130,19 @@ ihisvr(ipp,1)= -1
 
 ichrze = 1
 
+! Air properties
+
+cpa    = 1006.0d0
+cpv    = 1831.0d0
+cpe    = 4179.0d0
+hv0    = 2501600.0d0
+rhoe   = 997.85615d0
+visc   = 1.765d-5
+conduc = 0.02493d0
+
+call ctprof(cpa, cpv, cpe, hv0, rhoe, visc, conduc, gx, gy, gz)
+!==========
+
 !===============================================================================
 ! 2. Define user settings
 !===============================================================================
