@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -20,7 +20,8 @@
 
 !-------------------------------------------------------------------------------
 
-! Module for electric arcs
+!> \file elincl.f90
+!> Module for electric arcs
 
 module elincl
 
@@ -125,8 +126,16 @@ module elincl
   !     DPOT   : Delta du potentiel electrique entre l'Anode et la cathode
   !              (arc et Joule)
   !     COEJOU : coefficient de correction pour version Joule
+  !     MODREC : modele de recalage de l'arc
+  !              1 : modele cas general
+  !              2 : modele avec un plan
+  !     IZRECA : definition du plan de recalage
+  !     IDRECA : defnition de la compsante a recaler
+  !     CRIT_RECA : define criteria for recal
 
-  integer, save ::           ielcor
+  double precision, save :: crit_reca(5)
+  integer, save ::           ielcor, modrec, idreca
+  integer, allocatable, dimension(:) :: izreca
 
   double precision, save ::  couimp , dpot , puisim , coejou, elcou
 
@@ -141,4 +150,30 @@ module elincl
 
   !=============================================================================
 
+contains
+
+  !=============================================================================
+
+subroutine init_elec
+
+  use mesh
+  implicit none
+  integer iel
+  allocate(izreca(nfac))
+
+  do iel = 1, nfac
+    izreca(iel) = 0
+  enddo
+
+end subroutine init_elec
+
+  !=============================================================================
+
+subroutine finalize_elec
+
+  implicit none
+  deallocate(izreca)
+
+end subroutine finalize_elec
+
 end module elincl
