@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -59,6 +59,7 @@ use ppppar
 use ppthch
 use ppincl
 use elincl
+use ihmpre
 
 !===============================================================================
 
@@ -123,6 +124,15 @@ if ( ngazg .gt. 1 ) then
   enddo
 endif
 
+!   - Interface Code_Saturne
+!     ======================
+!     Construction de l'indirection entre la numerotation du noyau et XML
+
+if (iihmpr.eq.1) then
+   call uielsc(ippmod, ieljou, ielarc, ngazg, ihm,               &
+               ipotr, iycoel, ipoti, ipotva)
+endif
+
 
 !===============================================================================
 ! 2. PROPRIETES PHYSIQUES
