@@ -21,7 +21,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -256,6 +256,19 @@ fvm_io_num_create_from_scan(size_t  n_entities);
 fvm_io_num_t *
 fvm_io_num_destroy(fvm_io_num_t  * this_io_num);
 
+/*----------------------------------------------------------------------------
+ * Transfer ownership of global numbering array from IO numbering structure.
+ *
+ * parameters:
+ *   this_io_num <-> pointer to structure transferring array ownership.
+ *
+ * returns:
+ *   pointer to transferred array
+ *----------------------------------------------------------------------------*/
+
+cs_gnum_t *
+fvm_io_num_transfer_global_num(fvm_io_num_t  * this_io_num);
+
 /*----------------------------------------------------------------------------
  * Return local number of entities associated with an I/O numbering
  * structure.
