@@ -488,6 +488,25 @@ void CS_PROCF(uitssc, UITSSC)(const int                  *iscal,
                               cs_real_t         *restrict tsimp);
 
 
+/*----------------------------------------------------------------------------
+ * Thermal scalar source terms.
+ *
+ * Fortran Interface:
+ *
+ * subroutine uitsth (iscal, pvar, tsexp, tsimp)
+ * *****************
+ *
+ * integer          iscal    --> index of the corresponding scalar
+ * double precision pvar     -->  scalar
+ * double precision tsexp    <--  explicit source terms
+ * double precision tsimp    <--  implicit source terms
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF(uitsth, UITSTH)(const int                  *iscal,
+                              const cs_real_t   *restrict pvar,
+                              cs_real_t         *restrict tsexp,
+                              cs_real_t         *restrict tsimp);
+
 /*----------------------------------------------------------------------------
  * Variables and user scalars initialization.
  *
@@ -629,6 +648,8 @@ void CS_PROCF(uikpdc, UIKPDC)(const int*   iappel,
  * INTEGER          NTMABS   -->  max iterations numbers
  * INTEGER          NTCABS   -->  current iteration number
  * DOUBLE PRECISION TTCABS   -->  current physical time
+ * DOUBLE PRECISION TTMABS   -->  max physical time
+ * DOUBLE PRECISION TTPABS   -->  physical time at calculation beginning
  * DOUBLE PRECISION XYZCEN   -->  cell's gravity center
  * DOUBLE PRECISION RTP      -->  variables and scalars array
  * DOUBLE PRECISION PROPCE   -->  property array
@@ -639,6 +660,8 @@ void CS_PROCF (uiprof, UIPROF)(const int    *const ncelet,
                                const int    *const ntmabs,
                                const int    *const ntcabs,
                                const double *const ttcabs,
+                               const double *const ttmabs,
+                               const double *const ttpabs,
                                const double *const xyzcen,
                                const double *const rtp,
                                const double *const propce);
