@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -317,22 +317,23 @@ _get_periodicity_mixed(int     number,
 }
 
 /*============================================================================
- * Public Fortran function definitions
+ * Public function definitions
  *============================================================================*/
 
 /*-----------------------------------------------------------------------------
  * Determine whether warped faces should be cut.
- *
- * subroutine uicwf
- * *****************
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (uicwf, UICWF) (void)
+void
+cs_gui_mesh_warping(void)
 {
   char  *path = NULL;
   int cut_warped_faces = 0;
   double max_warp_angle = -1;
 
+  if (!cs_gui_file_is_loaded())
+    return;
+
   path = cs_xpath_init_path();
   cs_xpath_add_elements(&path, 2, "solution_domain", "faces_cutting");
   cs_xpath_add_attribute(&path, "status");
@@ -370,10 +371,6 @@ void CS_PROCF (uicwf, UICWF) (void)
     cs_mesh_warping_set_defaults(max_warp_angle, 0);
 }
 
-/*============================================================================
- * Public function definitions
- *============================================================================*/
-
 /*-----------------------------------------------------------------------------
  * Define joinings using a GUI-produced XML file.
  *----------------------------------------------------------------------------*/
