@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -41,13 +41,6 @@ BEGIN_C_DECLS
  * Type definitions
  *============================================================================*/
 
-/*=============================================================================
- * Public function prototypes
- *============================================================================*/
-
-void cs_gui_postprocess_writers(void);
-void cs_gui_postprocess_meshes(void);
-
 /*============================================================================
  * Public function prototypes for Fortran API
  *============================================================================*/
@@ -57,36 +50,54 @@ void cs_gui_postprocess_meshes(void);
  *
  * Fortran Interface:
  *
- * SUBROUTINE uinpst (ttcabs, ntcabs)
+ * subroutine uinpst (ttcabs, ntcabs)
  * *****************
  *
- * INTEGER          UREF   <--   reference velocity
- * DOUBLE          ALMAX  <--   reference length
+ * integer          uref  <-- reference velocity
+ * double          almax  <-- reference length
  *----------------------------------------------------------------------------*/
 
 void CS_PROCF (uinpst, UINPST) (const cs_int_t  *ntcabs,
                                 const cs_real_t *ttcabs);
 
 
-void CS_PROCF (csenso, CSENSO) (const    int *const nvppmx,
-                                         int *const ncapt,
-                                         int *const nthist,
-                                      double *const frhist,
-                                         int *const ntlist,
-                                         int *const iecaux,
-                                         int *const ipstdv,
-                                         int *const ipstyp,
-                                         int *const ipstcl,
-                                         int *const ipstft,
-                                         int *const ipstfo,
-                                         int *const ichrvr,
-                                         int *const ilisvr,
-                                         int *const ihisvr,
-                                         int *const tplfmt,
-                                const    int *const isca,
-                                const    int *const iscapp,
-                                const    int *const ipprtp,
-                                      double *const xyzcap);
+/*----------------------------------------------------------------------------
+ * Determine output options
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (csenso, CSENSO) (const cs_int_t  *nvppmx,
+                                cs_int_t        *ncapt,
+                                cs_int_t        *nthist,
+                                cs_real_t       *frhist,
+                                cs_int_t        *ntlist,
+                                cs_int_t        *iecaux,
+                                cs_int_t        *ipstdv,
+                                cs_int_t        *ichrvr,
+                                cs_int_t        *ilisvr,
+                                cs_int_t        *ihisvr,
+                                cs_int_t        *tplfmt,
+                                const cs_int_t  *isca,
+                                const cs_int_t  *iscapp,
+                                const cs_int_t  *ipprtp,
+                                cs_real_t       *xyzcap);
+
+/*============================================================================
+ * Public function prototypes
+ *============================================================================*/
+
+/*----------------------------------------------------------------------------
+ * Define postprocessing meshes using an XML file.
+ *----------------------------------------------------------------------------*/
+
+void
+cs_gui_postprocess_meshes(void);
+
+/*----------------------------------------------------------------------------
+ * Define postprocessing writers using an XML file.
+ *----------------------------------------------------------------------------*/
+
+void
+cs_gui_postprocess_writers(void);
 
 /*----------------------------------------------------------------------------*/
 
