@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -90,7 +90,6 @@ void CS_PROCF (uippmo, UIPPMO) (int *const ippmod,
                                 int *const icompf,
                                 int *const iatmos,
                                 int *const iaeros,
-                                int *const indjon,
                                 int *const ieos,
                                 int *const ieqco2);
 
@@ -200,6 +199,40 @@ void CS_PROCF (uicfsc, UICFSC) (const int *const irho,
                                 const int *const ienerg,
                                 const int *const itempk);
 
+/*-----------------------------------------------------------------------------
+ * Indirection between the solver numbering and the XML one
+ * for physical properties of the activated specific physics (electrical model)
+ *----------------------------------------------------------------------------*/
+void CS_PROCF (uielpr, UIELPR) (const int *const nsalpp,
+                                const int *const ippmod,
+                                const int *const ipppro,
+                                const int *const ipproc,
+                                const int *const ieljou,
+                                const int *const ielarc,
+                                const int *const itemp,
+                                const int *const iefjou,
+                                const int *const idjr,
+                                const int *const idji,
+                                const int *const ilapla,
+                                const int *const idrad,
+                                const int *const ivisls,
+                                const int *const ipotr,
+                                const int *const ixkabe);
+
+/*------------------------------------------------------------------------------
+ * Indirection between the solver numbering and the XML one
+ * for the model scalar (electrical model)
+ *----------------------------------------------------------------------------*/
+void CS_PROCF (uielsc, UIELSC) (const int *const ippmod,
+                                const int *const ieljou,
+                                const int *const ielarc,
+                                const int *const ngazg,
+                                const int *const ihm,
+                                const int *const ipotr,
+                                const int *const iycoel,
+                                const int *const ipoti,
+                                const int *const ipotva);
+
 /*-----------------------------------------------------------------------------
  * Indirection between the solver numbering and the XML one
  * for physical properties of the activated specific physics (gaz combustion)
@@ -246,6 +279,49 @@ void CS_PROCF (uicosc, UICOSC) (const int *const ippmod,
                                 const int *const iyfp2m,
                                 const int *const icoyfp);
 
+/*----------------------------------------------------------------------------
+ * Electrical model : read parameters
+ *
+ * Fortran Interface:
+ *
+ * subroutine uieli1
+ * *****************
+ * integer         ieljou    -->   joule model
+ * integer         ielarc    -->   arc model
+ * integer         ielcor    <--   scaling electrical variables
+ * double          couimp    <--   imposed current intensity
+ * double          puisim    <--   imposed power
+ * integer         modrec    <--   scaling type for electric arc
+ * integer         idrecal   <--   current density component used to scaling
+ *                                 (modrec ==2)
+ * char            crit_reca <--   define criteria for plane used to scaling (modrec ==2)
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (uieli1, UIELI1) (const int    *const ncelet,
+                                const int    *const ieljou,
+                                const int    *const ielarc,
+                                      int    *const ielcor,
+                                      double *const couimp,
+                                      double *const puisim,
+                                      int    *const modrec,
+                                      int    *const idreca,
+                                      double *const crit_reca);
+
+/*----------------------------------------------------------------------------
+ * Electrical model : define plane for elreca
+ *
+ * Fortran Interface:
+ *
+ * subroutine uielrc
+ * *****************
+ * integer         izreca    <--   define plane used to scaling (modrec ==2)
+ * char            crit_reca <--   define criteria for plane used to scaling (modrec ==2)
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (uielrc, UIELRC) (const int    *const ncelet,
+                                      int    *const izreca,
+                                      double *const crit_reca);
+
 /*----------------------------------------------------------------------------
  * Atmospheric flows: read of meteorological file of data
  *
@@ -254,9 +330,14 @@ void CS_PROCF (uicosc, UICOSC) (const int *const ippmod,
  * subroutine uiati1
  * *****************
  * integer         imeteo   <--   on/off index
+ * char(*)         fmeteo   <--   meteo file name
+ * int             len      <--   meteo file name destination string length
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (uiati1, UIATI1) (int *const imeteo);
+void CS_PROCF (uiati1, UIATI1) (int           *imeteo,
+                                char          *fmeteo,
+                                int           *len
+                                CS_ARGF_SUPP_CHAINE);
 
 /*----------------------------------------------------------------------------
  * Atmospheric flows: indirection between the solver numbering and the XML one
@@ -373,6 +454,14 @@ void CS_PROCF (uisofu, UISOFU) (const int    *const iirayo,
                                       double *const oxyh2o,
                                       double *const oxyco2);
 
+/*----------------------------------------------------------------------------
+ * Copy name of thermophysical data file from C to Fortran
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF(cfnmtd, CFNMTD) (char          *fstr,    /* --> Fortran string */
+                               int           *len      /* --> String Length  */
+                               CS_ARGF_SUPP_CHAINE);
+
 /*=============================================================================
  * Public function prototypes
  *============================================================================*/
