@@ -1,5 +1,5 @@
 /*============================================================================
- * Utilitarian functions for the diphasic lagrangian module
+ * Utility functions for the diphasic lagrangian module
  *============================================================================*/
 
 /*
@@ -34,16 +34,12 @@
 #include <stdlib.h>
 #include <math.h>
 
-/*----------------------------------------------------------------------------
- * BFT library headers
- *----------------------------------------------------------------------------*/
-
-#include <bft_error.h>
-
 /*----------------------------------------------------------------------------
  *  Local headers
  *----------------------------------------------------------------------------*/
 
+#include "bft_error.h"
+
 #include "cs_base.h"
 
 /*----------------------------------------------------------------------------
@@ -52,7 +48,6 @@
 
 #include "cs_lagr_utils.h"
 
-
 /*----------------------------------------------------------------------------*/
 
 BEGIN_C_DECLS
@@ -79,16 +74,16 @@ BEGIN_C_DECLS
  * two vertices are identical.
  *
  * parameters:
- *   p             --> X, Y, Z coordinates of the vertex P
- *   q             --> X, Y, Z coordinates of the vertex Q
+ *   p             <-- X, Y, Z coordinates of the vertex P
+ *   q             <-- X, Y, Z coordinates of the vertex Q
  *
  * Returns:
- *  1 if the two vertices are identical otherwise 0
+ *   1 if the two vertices are identical otherwise 0
  *----------------------------------------------------------------------------*/
 
 int
-cs_lagrang_check_colocalization(cs_real_t p[3],
-                                cs_real_t q[3])
+cs_lagrang_check_colocalization(const cs_real_t p[3],
+                                const cs_real_t q[3])
 {
   int  sign = -1;
 
@@ -109,22 +104,22 @@ cs_lagrang_check_colocalization(cs_real_t p[3],
  * faces.
  *
  * parameters:
- *  p1            --> X, Y, Z coordinate of the first vertex
- *  p2            --> X, Y, Z coordinate of the second vertex
- *  p3            --> X, Y, Z coordinate of the third vertex
- *  p4            --> X, Y, Z coordinate of the fourth vertex
- *  perturbation  <-> an indicator if perturbation is used (1: true, 0: false)
+ *   p1            <-- X, Y, Z coordinate of the first vertex
+ *   p2            <-- X, Y, Z coordinate of the second vertex
+ *   p3            <-- X, Y, Z coordinate of the third vertex
+ *   p4            <-- X, Y, Z coordinate of the fourth vertex
+ *   perturbation  <-- an indicator if perturbation is used (1: true, 0: false)
  *
- *Returns:
+ * returns:
  *  an indicator on the orientation of the tetrahedron [p1, p2, p3, p4]
  *----------------------------------------------------------------------------*/
 
 int
-cs_lagrang_tetra_orientation(cs_real_t   p1[3],
-                             cs_real_t   p2[3],
-                             cs_real_t   p3[3],
-                             cs_real_t   p4[3],
-                             int         perturbation)
+cs_lagrang_tetra_orientation(const cs_real_t  p1[3],
+                             const cs_real_t  p2[3],
+                             const cs_real_t  p3[3],
+                             const cs_real_t  p4[3],
+                             int              perturbation)
 {
   int  returned_sign = -2; /* initialize to an incoherent value */
 
@@ -144,7 +139,6 @@ cs_lagrang_tetra_orientation(cs_real_t   p1[3],
   cs_real_t H = p4[1] - p1[1];
   cs_real_t I = p4[2] - p1[2];
 
-
   /* minors computation */
 
   /*  M1 = D*H - E*G  */
@@ -155,7 +149,6 @@ cs_lagrang_tetra_orientation(cs_real_t   p1[3],
   cs_real_t M2 = A*H - B*G;
   cs_real_t M3 = A*E - B*D;
 
-
   /* determinant computation */
 
   /*  det = (C*M1 - F*M2) + I*M3  */
