@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -275,10 +275,10 @@ if (ltsdyn.eq.1) then
 
     do iel = 1,ncel
 
-      tslag(iel,itske) = tslag(iel,itske)                         &
-                       - ettp(npt,juf) * tslag(iel,itsvx)         &
-                       - ettp(npt,jvf) * tslag(iel,itsvy)         &
-                       - ettp(npt,jwf) * tslag(iel,itsvz)
+      tslag(iel,itske) = tslag(iel,itske)                       &
+                       - rtp(iel,iu) * tslag(iel,itsvx)         &
+                       - rtp(iel,iv) * tslag(iel,itsvy)         &
+                       - rtp(iel,iw) * tslag(iel,itsvz)
 
     enddo
 
