@@ -27,7 +27,7 @@ subroutine lagent &
    nvar   , nscal  ,                                              &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   itycel , icocel ,                                              &
+   itycel , icocel , dlgeo  ,                                     &
    itypfb , itrifb , ifrlag , itepa  ,                            &
    dt     , rtpa   , propce , propfa , propfb ,                   &
    ettp   , tepa   , vagaus , auxl   , w1     , w2     , w3     )
@@ -67,6 +67,8 @@ subroutine lagent &
 ! ntersl           ! e  ! <-- ! nbr termes sources de couplage retour          !
 ! nvlsta           ! e  ! <-- ! nombre de var statistiques lagrangien          !
 ! nvisbr           ! e  ! <-- ! nombre de statistiques aux frontieres          !
+! dlgeo            ! tr ! --> ! tableau contenant les donnees geometriques     !
+! (nfabor,ngeol)   !    !     ! pour le sous-modele de depot                   !
 ! icocel           ! te ! <-- ! connectivite cellules -> faces                 !
 ! (lndnod)         !    !     !    face de bord si numero negatif              !
 ! itycel           ! te ! <-- ! connectivite cellules -> faces                 !
@@ -144,6 +146,7 @@ double precision ettp(nbpmax,nvp) , tepa(nbpmax,nvep)
 double precision vagaus(nbpmax,*)
 double precision auxl(nbpmax,3)
 double precision w1(ncelet) ,  w2(ncelet) ,  w3(ncelet)
+double precision dlgeo(nfabor,ngeol)
 
 ! Local variables
 
@@ -171,7 +174,6 @@ integer, allocatable, dimension(:) :: ilftot
 
 double precision unif(1), offset, rapsurf
 integer irp, ipart, jj, kk, nfrtot, nlocnew, nbpartall
-integer, save :: counter
 integer          ipass
 data             ipass /0/
 save             ipass
@@ -215,7 +217,7 @@ if (iihmpr.eq.1) then
   !==========
  ( nfabor, nozppm, nbclst,                                        &
    ientrl, isortl, idepo1, idepo2,                                &
-   idepfa, iencrl, irebol, iphyla,                                &
+   idepfa, iencrl, irebol, isymtl, iphyla,                        &
    ijnbp,  ijfre,  iclst,  ijuvw,  iuno,   iupt,   ivpt,   iwpt,  &
    ijprpd, ipoit,  idebt,  ijprdp, idpt,   ivdpt,                 &
    iropt,  ijprtp, itpt,   icpt,   iepsi,                         &
@@ -408,7 +410,7 @@ do ii = 1,nfrlag
   nb = ilflag(ii)
   if ( iusclb(nb).ne.ientrl .and. iusclb(nb).ne.isortl .and.      &
        iusclb(nb).ne.irebol .and. iusclb(nb).ne.idepo1 .and.      &
-       iusclb(nb).ne.idepo2 .and.                                 &
+       iusclb(nb).ne.idepo2 .and. iusclb(nb).ne.isymtl .and.      &
        iusclb(nb).ne.iencrl .and. iusclb(nb).ne.jbord1 .and.      &
        iusclb(nb).ne.jbord2 .and. iusclb(nb).ne.jbord3 .and.      &
        iusclb(nb).ne.jbord4 .and. iusclb(nb).ne.jbord5 .and.      &
@@ -975,7 +977,7 @@ do ii = 1,nfrtot
 
             endif
 
-            if ( ippmod(icp3pl).ge.0 .or.                         &
+            if ( ippmod(iccoal).ge.0 .or.                         &
                  ippmod(icpl3c).ge.0 .or.                         &
                  ippmod(icfuel).ge.0      ) then
 
@@ -1180,12 +1182,12 @@ npar2 = nbpart+ nlocnew
 
 call lagipn                                                       &
 !==========
-  ( ncelet , ncel   ,                                             &
-    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                  &
+  ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                  &
     npar1  , npar2  ,                                             &
     itepa  ,                                                      &
     rtpa   ,                                                      &
-    ettp   , tepa   , vagaus )
+    ettp   , tepa   , vagaus ,                                    &
+    icocel , lndnod , itycel , dlgeo  , propce , ifrlag )
 
 !===============================================================================
 ! 7. MODIFICATION DES TABLEAUX DE DONNEES PARTICULAIRES
@@ -1199,22 +1201,16 @@ call uslain                                                       &
    nlocnew ,                                                      &
    itypfb , itrifb , itepa  , ifrlag , iwork  ,                   &
    dt     , rtpa   , propce , propfa , propfb ,                   &
-   ettp   , tepa   , vagaus , ncmax  , nzmax  , iusloc )
+   ettp   , tepa   , vagaus , icocel , lndnod , itycel , dlgeo,   &
+   ncmax  , nzmax  , iusloc )
+
 
 !===============================================================================
-! 7bis. NUMEROTATION GLOBALE
+! 7bis. Random id associated with particles (to be initialized later)
 !===============================================================================
-ipass = ipass + 1
-
-if (ipass .eq. 1) counter = 1
 
 do npt = npar1,npar2
-  if (irangp.lt.0) then
-    itepa(npt,jgnum) = counter
-  else
-    itepa(npt,jgnum) = nbpmax * irangp + counter
-  endif
-    counter = counter + 1
+  call random_number(tepa(npt,jrval))
 enddo
 
 !   reinitialisation du compteur de nouvelles particules
@@ -1346,43 +1342,7 @@ do ii = 1,nfrlag
 enddo
 
 !===============================================================================
-! 10. IMPRESSIONS POUR POST-PROCESSING EN MODE TRAJECTOIRES
-!===============================================================================
-
-if ( iensi1.eq.1 ) then
-
-  nfin = 0
-
-!   reinitialisation du compteur de nouvelles particules
-  npt = nbpart
-
-!       pour chaque zone de bord :
-  do ii = 1, nfrlag
-    nb = ilflag(ii)
-
-!         pour chaque classe :
-    do nc = 1, iusncl(nb)
-
-!           si de nouvelles particules doivent entrer :
-      if (mod(ntcabs,iuslag(nc,nb,ijfre)).eq.0) then
-
-        do ip = npt+1 , npt+iusloc(nc,nb,ijnbp)
-          call enslag                                             &
-          !==========
-           ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,         &
-             nfin   , ip     ,                                    &
-             itepa  ,                                             &
-             ettp   , tepa   )
-        enddo
-        npt = npt + iusloc(nc,nb,ijfre)
-
-      endif
-    enddo
-  enddo
-endif
-
-!===============================================================================
-! 11. NOUVEAU NOMBRE DE PARTICULES TOTAL
+! 10. NOUVEAU NOMBRE DE PARTICULES TOTAL
 !===============================================================================
 
 !     NBPART : NOMBRE DE PARTICULES PRESENTES DANS LE DOMAINE
@@ -1568,6 +1528,7 @@ endif
 '@   = IENTRL  zone d''injection de particules                ',/,&
 '@   = ISORTL  sortie du domaine                              ',/,&
 '@   = IREBOL  rebond des particules                          ',/,&
+'@   = ISYMTL  flux nul pour les particules  (symetrie)       ',/,&
 '@   = IDEPO1  deposition definitive                          ',/,&
 '@   = IDEPO2  deposition definitive mais la particule reste  ',/,&
 '@             en memoire                                     ',/,&
