@@ -23,12 +23,12 @@
 subroutine lagipn &
 !================
 
- ( ncelet , ncel   ,                                              &
-   nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
+ ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    npar1  , npar2  ,                                              &
    itepa  ,                                                       &
    rtp    ,                                                       &
-   ettp   , tepa   , vagaus )
+   ettp   , tepa   , vagaus ,                                     &
+   icocel , lndnod , itycel , dlgeo  , propce , ifrlag  )
 
 !===============================================================================
 ! FONCTION :
@@ -45,8 +45,6 @@ subroutine lagipn &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
 ! nbpmax           ! e  ! <-- ! nombre max de particulies autorise             !
 ! nvp              ! e  ! <-- ! nombre de variables particulaires              !
 ! nvp1             ! e  ! <-- ! nvp sans position, vfluide, vpart              !
@@ -58,12 +56,22 @@ subroutine lagipn &
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
 ! rtp              ! tr ! <-- ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules (instant courant ou prec)          !
+!  dlgeo           ! tr ! <-- ! tableau contenant les donnees geometriques     !
+!(nfabor,ngeol)    !    !     !                                                !
 ! ettp             ! tr ! <-- ! tableaux des variables liees                   !
 !  (nbpmax,nvp)    !    !     !   aux particules etape courante                !
 ! tepa             ! tr ! <-- ! info particulaires (reels)                     !
 ! (nbpmax,nvep)    !    !     !   (poids statistiques,...)                     !
 ! vagaus           ! tr ! --> ! variables aleatoires gaussiennes               !
 !(nbpmax,nvgaus    !    !     !                                                !
+! icocel           ! te ! <-- ! connectivite cellules -> faces                 !
+!   (lndnod)       !    !     !    face de bord si numero negatif              !
+! lndnod           ! e  ! <-- ! dim. connectivite cellules->faces              !
+!  itycel          ! te ! <-- ! connectivite cellules -> faces                 !
+! (ncelet+1)       !    !     !    pointeur du tableau icocel                  !
+! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
+!   ifrlag         ! te ! <-- ! numero de zone de la face de bord              !
+!   (nfabor)       !    !     !  pour le module lagrangien                     !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -87,6 +95,8 @@ use parall
 use period
 use lagpar
 use lagran
+use ppincl
+use mesh
 
 !===============================================================================
 
@@ -94,22 +104,31 @@ implicit none
 
 ! Arguments
 
-integer          ncelet , ncel
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          npar1 , npar2
 integer          itepa(nbpmax,nivep)
+integer          lndnod
 
 double precision rtp(ncelet,*)
+double precision dlgeo(nfabor,ngeol)
+double precision propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , tepa(nbpmax,nvep)
 double precision vagaus(nbpmax,*)
-
+integer          icocel(lndnod) ,  itycel(ncelet+1)
+integer          ifrlag(nfabor)
 ! Local variables
 
-integer          iel , npt , nomb
+integer          iel , npt , nomb , nbfac , ifac , iromf , il , izone ,i
 double precision tu , d2s3
 
 double precision, allocatable, dimension(:) :: w1
 
+double precision  lvisq, ypp
+double precision  d3 , vpart, vvue
+double precision  px , py , pz , distp , d1
+double precision  dismin,dismax, ustar, visccf,depint , romf
+double precision  unif1(1)
+
 !===============================================================================
 
 !===============================================================================
@@ -181,6 +200,112 @@ do npt = npar1,npar2
 
 enddo
 
+!Calcul de la fluctuation de vitesse si le modèle de dépôt est activé
+
+if (idepst.eq.1) then
+
+   do npt = npar1,npar2
+      iel = itepa(npt,jisor)
+      !Calculation of the normalized wall-normal particle distance (y^+)
+
+      dismin = 1.d+20
+      dismax = -1.d+20
+
+      distp = 1.0d+20
+      tepa(npt,jryplu) = 1.0d3
+      nbfac = 0
+
+      do il = itycel(iel)+1,itycel(iel+1)
+         ifac = icocel(il)
+         if (ifac.lt.0) then
+            ifac = -ifac
+            izone = ifrlag(ifac)
+
+            !          Test if the particle is located in a boundary cell
+
+            if ( iusclb(izone) .eq. idepo1 .or.                   &
+                 iusclb(izone) .eq. idepo2 .or.                   &
+                 iusclb(izone) .eq. idepfa .or.                   &
+                 iusclb(izone) .eq. irebol     ) then
+
+
+               !              Calculation of the wall units
+
+               if ( ippmod(iccoal).ge.0 .and. ippmod(icfuel).ge.0 ) then
+                  iromf = ipproc(irom1)
+               else
+                  iromf = ipproc(irom)
+               endif
+               romf = propce(iel,iromf)
+               visccf = propce(iel,ipproc(iviscl)) / romf
+
+               ustar = uetbor(ifac)
+               lvisq = visccf / ustar
+
+               px = ettp(npt,jxp)
+               py = ettp(npt,jyp)
+               pz = ettp(npt,jzp)
+
+               d1 = abs(px*dlgeo(ifac,1)+py*dlgeo(ifac,2)         &
+                    +pz*dlgeo(ifac,3)+dlgeo(ifac,4))           &
+                    /sqrt( dlgeo(ifac,1)*dlgeo(ifac,1)            &
+                    +dlgeo(ifac,2)*dlgeo(ifac,2)               &
+                    +dlgeo(ifac,3)*dlgeo(ifac,3))
+
+               if (d1.lt.distp) then
+                  distp = d1
+                  tepa(npt,jryplu) = distp/lvisq
+                  itepa(npt,jdfac) = ifac
+               endif
+            endif
+         endif
+      enddo
+
+      if (tepa(npt,jryplu).lt.tepa(npt,jrinpf)) then
+         itepa(npt,jimark) = 10
+      elseif (tepa(npt,jryplu).gt.100.d0) then
+         itepa(npt,jimark) = -1
+      else
+
+         call zufall(1, unif1(1))
+         !==========
+         if (unif1(1).lt.0.25d0) then
+            itepa(npt,jimark) = 12
+         elseif (unif1(1).gt.0.625d0) then
+            itepa(npt,jimark) = 1
+         elseif ((unif1(1).gt.0.25d0).and.(unif1(1).lt.0.625d0)) then
+            itepa(npt,jimark) = 3
+         endif
+      endif
+
+      if (tepa(npt,jryplu).le.tepa(npt,jrinpf)) then
+         ettp(npt,juf) = rtp(iel,iu)
+         ettp(npt,jvf) = rtp(iel,iv)
+         ettp(npt,jwf) = rtp(iel,iw)
+      endif
+
+      ! No deposited particles at the injection
+      itepa(npt,jdepo) = 0
+
+   enddo
+
+   ! Initialization of the additional "pointers"
+   ! for the resuspension model
+
+   if (ireent.gt.0) then
+
+      tepa(npt,jfadh) = 0.d0
+      tepa(npt,jmfadh) = 0.d0
+
+      itepa(npt,jnbasg) = 0
+      itepa(npt,jnbasp) = 0
+
+      tepa(npt,jndisp) = 0.d0
+
+   endif
+
+endif
+
 ! Free memory
 deallocate(w1)
 
