@@ -251,11 +251,6 @@ if(ierror.ne.0) then
   call csexit (1)
 endif
 
-if (ivers.lt.112 .and. irangp.ge.0) then
-  write(nfecra,9021) ficsui
-  call csexit (1)
-endif
-
 !  ---> Tests
 
 iok = 0
@@ -279,15 +274,8 @@ itysup = 0
 nbval  = 1
 irtyp  = 1
 
-if (ivers.lt.112) then
-  ipasup = 0
-  rubriq = 'nombre_courant_particules'
-  call lecsui(impaml,rubriq,len(rubriq),itysup,nbval,irtyp,       &
-              nbpart,ierror)
-else
-  rubriq = 'particles'
-  call lipsui(impaml,rubriq,len(rubriq),nbpart,ipasup)
-endif
+rubriq = 'particles'
+call lipsui(impaml,rubriq,len(rubriq),nbpart,ipasup)
 
 if(ierror.ne.0) then
   write(nfecra,9040) ficsui,                                      &
@@ -452,8 +440,6 @@ endif
 
 nberro = 0
 
-nomite(jgnum) = 'glob_num_'
-
 if (nbclst.gt.0) then
   nomite(jclst) = 'numero_groupe_statistiques'
 endif
@@ -469,77 +455,54 @@ if (idepst.eq.1) then
   nomite(jtraj) = 'traj_particules'
   nomite(jptdet) = 'ptdet_particules'
   nomite(jinjst) = 'indic_stat'
+  nomite(jdepo) = 'part_depo'
 endif
 
-if (ivers.lt.112) then
+if (ireent.eq.1) then
+   nomite(jnbasg) = 'nb_ls_aspe'
+   nomite(jnbasp) = 'nb_sms_aspe'
+endif
 
-  ! Read legacy file (non-parallel compatible)
+itysup = ipasup
+nbval  = 1
 
-  itysup = 0
-  nbval = nbpart
+allocate(coopar(3,nbpart))
 
-  irtyp  = 1
-  rubriq = 'numero_cellule_particules'
-  call lecsui(impaml,rubriq,len(rubriq),itysup,nbval,irtyp,       &
-              itepa(1,jisor),ierror)
-  nberro = nberro+ierror
+call lepsui(impaml,itepa(1,jisor),coopar,itysup,ierror)
 
-  irtyp  = 2
-  nomnvl(jxp) = 'variable_positionX_particule'
-  nomnvl(jyp) = 'variable_positionY_particule'
-  nomnvl(jzp) = 'variable_positionZ_particule'
-  do ivar = jxp, jzp
-    rubriq = nomnvl(ivar)
-    call lecsui(impaml,rubriq,len(rubriq),itysup,nbval,irtyp,       &
-                ettp(1,ivar),ierror)
-    nberro = nberro+ierror
+nberro = nberro+ierror
+
+if (ierror.eq.0) then
+  do ii = 1, nbpart
+    ettp(ii,jxp) = coopar(1,ii)
+    ettp(ii,jyp) = coopar(2,ii)
+    ettp(ii,jzp) = coopar(3,ii)
   enddo
-
-else
-
-  ! Read current file (parallel-compatible)
-
-  itysup = ipasup
-  nbval  = 1
-
-  allocate(coopar(3,nbpart))
-
-  call lepsui(impaml,itepa(1,jisor),coopar,itysup,ierror)
-
-  nberro = nberro+ierror
-
-  if (ierror.eq.0) then
-    do ii = 1, nbpart
-      ettp(ii,jxp) = coopar(1,ii)
-      ettp(ii,jyp) = coopar(2,ii)
-      ettp(ii,jzp) = coopar(3,ii)
-    enddo
-  endif
-
-  deallocate(coopar)
-
-  allocate(iflpar(nbpart))
-
-  irtyp  = 1
-  rubriq = 'particle_status_flag'
-  call lecsui(impaml,rubriq,len(rubriq),itysup,nbval,irtyp,       &
-              iflpar,ierror)
-  nberro = nberro+ierror
-
-  if (ierror.eq.0) then
-    do ii = 1, nbpart
-      if (iand(iflpar(ii), 1) .eq. 1) itepa(ii,jisor) = -itepa(ii,jisor)
-    enddo
-  endif
-
-  deallocate(iflpar)
-
 endif
 
+deallocate(coopar)
+
+allocate(iflpar(nbpart))
+
+irtyp  = 1
+
+rubriq = 'particle_status_flag'
+call lecsui(impaml,rubriq,len(rubriq),itysup,nbval,irtyp,       &
+            iflpar,ierror)
+nberro = nberro+ierror
+
+if (ierror.eq.0) then
+  do ii = 1, nbpart
+    if (iand(iflpar(ii), 1) .eq. 1) itepa(ii,jisor) = -itepa(ii,jisor)
+  enddo
+endif
+
+deallocate(iflpar)
+
 irtyp  = 1
 
 do ivar = 1, nivep
-  if (ivar.ne.jisor .or. ivers.lt.112) then
+  if (ivar.ne.jisor) then
     rubriq = nomite(ivar)
     if (ivar.eq.jdfac) then
       idbase = 1
@@ -549,11 +512,6 @@ do ivar = 1, nivep
     else
       call lecsui(impaml,rubriq,len(rubriq),itysup,nbval,irtyp,     &
                   itepa(1,ivar),ierror)
-
-      if ((ivar.eq.jgnum) .and. (ierror.eq.-6)) then
-      ! jgnum not necessary to perform a particle restart
-         ierror = 0
-      endif
     endif
     nberro = nberro+ierror
   endif
@@ -561,6 +519,7 @@ enddo
 
 ! --> Caracteristiques et infos particulaires (REELS)
 
+nomrte(jrval) = 'random_value'
 nomrte(jrtsp) = 'temps_sejour_particules'
 nomrte(jrpoi) = 'poids_statistiques_particules'
 if (iphyla.eq.1 .and. itpvar.eq.1 .and. iirayo.gt.0) then
@@ -570,6 +529,7 @@ if (iphyla.eq.2) then
   nomrte(jrdck) = 'diametre_coeur_retrecissant_charbon'
   nomrte(jrd0p) = 'diametre_initial_charbon'
   nomrte(jrr0p) = 'masse_volumique_initial_charbon'
+  nomrte(jrhock) ='masse_volumique_coke'
 endif
 
 ! Deposition submodel
@@ -578,12 +538,23 @@ if (idepst.eq.1) then
   nomrte(jrinpf) = 'dx_particules'
 endif
 
+if (ireent.eq.1) then
+   nomrte(jfadh) = 'force_adhesion'
+   nomrte(jmfadh) = 'moment_adhesion'
+   nomrte(jndisp) = 'disp_norm'
+endif
+
 irtyp  = 2
 
 do ivar = 1, nvep
   rubriq = nomrte(ivar)
   call lecsui(impaml,rubriq,len(rubriq),itysup,nbval,irtyp,       &
               tepa(1,ivar),ierror)
+  if (ivar.eq.jrval .and. ierror.ne.0) then
+    do ii = 1, nbpart
+      call random_number(tepa(ii,jrval))
+    enddo
+  endif
   nberro = nberro+ierror
 enddo
 
@@ -639,7 +610,7 @@ if (iphyla.eq.1 .and. itpvar.eq.1) then
       iel = itepa(ip,jisor)
       ettp(ip,jtp) = tpart
       ettp(ip,jcp) = cppart
-      if ( ippmod(icp3pl).ge.0 .or.                               &
+      if ( ippmod(iccoal).ge.0 .or.                               &
            ippmod(icpl3c).ge.0 .or.                               &
            ippmod(icfuel).ge.0      ) then
          ettp(ip,jtf) = propce(iel,ipproc(itemp1)) -tkelvi
@@ -1296,26 +1267,6 @@ write(nfecra,2000)
 '@        a un fichier suite Lagrangien.                      ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@                                                            ',/)
-
- 9021 format(                                                     &
-'@                                                            ',/,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@                                                            ',/,&
-'@ @@ ATTENTION : ARRET A LA LECTURE DU FICHIER SUITE         ',/,&
-'@    =========     LAGRANGIEN ',A13                           ,/,&
-'@      VERSION DE FICHIER OBSOLETE                           ',/,&
-'@                                                            ',/,&
-'@    Ce fichier pourra etre lu en mode serie, mais pas       ',/,&
-'@      en parallele.                                         ',/,&
-'@                                                            ',/,&
-'@    Le calcul ne peut etre execute.                         ',/,&
-'@                                                            ',/,&
-'@    Relancer le calcul en mode serie sur au moins 1         ',/,&
-'@        iteration pour generer un fichier suite lagrangien  ',/,&
-'@        utilisable en parallele.                            ',/,&
-'@                                                            ',/,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
 
  9030 format(                                                           &
