@@ -155,7 +155,7 @@ character        nomite(nvplmx)*64 , nomrte(nvplmx)*64
 character        ficsui*32
 integer          ierror , nbval, itysup , irtyp  , irfsup, idbase
 integer          ivers  , ilecec
-integer          nfin   , iforce , icha   , ii
+integer          icha   , ii
 integer          itrav1
 integer          ipas   , jj
 integer          impavl , impvls, inmcoo, ipasup
@@ -330,8 +330,6 @@ enddo
 
 nomite(jisor) = 'indicateur_'
 
-nomite(jgnum) = 'glob_num_'
-
 if (iphyla.eq.2) then
   nomite(jinch) = 'numero_charbon'
 endif
@@ -345,6 +343,12 @@ if (idepst.eq.1) then
   nomite(jtraj) = 'traj_particules'
   nomite(jptdet) = 'ptdet_particules'
   nomite(jinjst) = 'indic_stat'
+  nomite(jdepo) = 'part_depo'
+endif
+
+if (ireent.eq.1) then
+   nomite(jnbasg) = 'nb_ls_aspe'
+   nomite(jnbasp) = 'nb_sms_aspe'
 endif
 
 itysup = ipasup
@@ -390,6 +394,7 @@ endif
 
 ! Caracteristiques et infos particulaires (REELS)
 
+nomrte(jrval) = 'random_value'
 nomrte(jrtsp) = 'temps_sejour_particules'
 nomrte(jrpoi) = 'poids_statistiques_particules'
 if (iphyla.eq.1 .and. itpvar.eq.1 .and.iirayo.gt.0) then
@@ -399,6 +404,7 @@ if (iphyla.eq.2) then
   nomrte(jrdck) = 'diametre_coeur_retrecissant_charbon'
   nomrte(jrd0p) = 'diametre_initial_charbon'
   nomrte(jrr0p) = 'masse_volumique_initial_charbon'
+  nomrte(jrhock) = 'masse_volumique_coke'
 endif
 
 ! Deposition submodel
@@ -407,6 +413,12 @@ if (idepst.eq.1) then
   nomrte(jrinpf) = 'dx_particules'
 endif
 
+if (ireent.eq.1) then
+   nomrte(jfadh) = 'force_adhesion'
+   nomrte(jmfadh) = 'moment_adhesion'
+   nomrte(jndisp) = 'disp_norm'
+endif
+
 itysup = ipasup
 nbval  = 1
 irtyp  = 2
@@ -697,41 +709,6 @@ if ( (istala.eq.1 .and. iplas.ge.idstnt) .or.                     &
 
 endif
 
-!===============================================================================
-! Visualization
-!===============================================================================
-
-if (irangp.ge.0 .or. ntcabs.lt.ntmabs) return
-
-nfin = 1
-
-!-->Stockage des trajectoires au format Ensight Gold
-
-if (iensi1.eq.1) then
-
-  iforce = 0
-  call enslag                                                     &
-  !==========
-   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                 &
-     nfin   , iforce ,                                            &
-     itepa  ,                                                     &
-     ettp   , tepa   )
-
-endif
-
-!-->Stockage des deplacements au format Ensight Gold
-
-if (iensi2.eq.1) then
-
-  call enswaf                                                     &
-  !==========
-   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                 &
-     nfin   ,                                                     &
-     itepa  ,                                                     &
-     ettp   , tepa   )
-
-endif
-
 !===============================================================================
 ! End
 !===============================================================================
