@@ -37,7 +37,7 @@ module lagpar
   !     NCHARM2 : NOMBRE MAXIMAL DE CLASSES DE CHARBON (voir cpincl.f90)
 
   integer         ncharm2
-  parameter      (ncharm2 = 3)
+  parameter      (ncharm2 = 5)
 
   !     NCLSTM : NOMBRE MAXIMUM DE STATISTIQUES VOLUMIQUE PAR GROUPE
 
@@ -111,29 +111,19 @@ module lagpar
   parameter      (nvplmx = 50)
 
   !=============================================================================
-  ! 8. Visualisation particulaires
-
-  !     NLISTE : Nombre maximum de particules visualisable
-
-  integer         nliste
-  parameter      (nliste = 100000)
-
-  !=============================================================================
-  ! 9. Types d'interaction au bord
-
-  !     NLISTE : Nombre maximum de particules visualisable
+  ! 8. Types d'interaction au bord
 
   integer         ientrl     , isortl     , irebol
   integer         idepo1     , idepo2
   integer         iencrl     , jbord1     , jbord2
   integer         jbord3     , jbord4     , jbord5
-  integer         idepfa
+  integer         idepfa     , isymtl
 
   parameter      (ientrl =  1, isortl =  2, irebol =  3)
   parameter      (idepo1 =  4, idepo2 =  5)
   parameter      (iencrl =  7, jbord1 =  8, jbord2 =  9)
   parameter      (jbord3 = 10, jbord4 = 11, jbord5 = 12)
-  parameter      (idepfa = 13)
+  parameter      (idepfa = 13, isymtl = 14)
 
   !=============================================================================
 
