@@ -61,6 +61,8 @@ module lagran
 
   !     NBPDEP/DNBDEP : NOMBRE DE PARTICULES DEPOSEES
 
+  !     NBPRES/DNBRES : NOMBRE DE PARTICULES RESUSPENDUES
+
   !     NBPERT : NOMBRE DE PARTICULES ELIMINEES EN ERREUR DANS
   !                LE CALCUL DEPUIS LE DEBUT, SUITES COMPRISES
 
@@ -82,8 +84,9 @@ module lagran
 
 
   integer, save ::           nbpart , nbpnew , nbperr , nbptot , nbpout ,   &
-                             nbpert , ndepot , nbpdep
-  double precision, save ::  dnbpar , dnbpnw , dnbper , dnbpou, dnbdep
+                             nbpert , ndepot , nbpdep , nbpres
+  double precision, save ::  dnbpar , dnbpnw , dnbper , dnbpou, dnbdep,     &
+                             dnbres
 
   integer, save ::           npclon , npkill , npcsup
   double precision, save ::  dnpclo , dnpkil , dnpcsu
@@ -106,7 +109,10 @@ module lagran
 
   double precision, save ::  tpart , cppart
 
-  ! 4.1 Particules deposition submodel (Guingo & Minier, 2008)
+
+
+
+  ! 4.1 Particules deposition submodel
   !==================================
 
 
@@ -115,6 +121,11 @@ module lagran
 
   integer, save ::     idepst
 
+  !     IDLVO  = 0 : no DLVO conditions
+  !            = 1 : DLVO conditions
+
+  integer, save ::         idlvo
+
   !     NGEOL : geometric parameters stored
 
   integer ngeol
@@ -126,6 +137,24 @@ module lagran
   integer, save ::   jimark , jdiel  , jdfac , jdifel , jtraj , jptdet , jinjst
   integer, save ::   jryplu , jrinpf
 
+  ! 4.2 Resuspension model
+  !=======================
+
+  !     IREENT = 0 : no resuspension model
+  !            = 1 : resuspension model
+
+  integer, save ::         ireent
+
+  ! Additional pointers in the ITEPA and TEPA array
+  ! ITEPA contains the particule state
+
+  integer, save ::   jroll , jnbasg , jnbasp , jdepo
+  integer, save ::   jfadh , jmfadh , jndisp
+
+  ! Parameters of the particle resuspension model
+
+   double precision, save :: espasg , denasp, modyeq , rayasp, rayasg
+
   !=============================================================================
   ! 5. Pas de temps Lagrangien
 
@@ -175,17 +204,20 @@ module lagran
   !   Tableau TEPA
   !   ^^^^^^^^^^^^
 
-  !     JRTSP       : TEMPS DE SEJOUR DES PARTICULES
-  !     JRPOI       : POIDS DES PARTICULES
-  !     JREPS       : EMISSIVITE DES PARTICULES
+  !     jrval       : random number associated with a particle
+  !     jrtsp       : temps de sejour des particules
+  !     jrpoi       : poids des particules
+  !     jreps       : emissivite des particules
 
   !   Charbon
   !   -------
-  !     JRDCK       : DIAMETRE DU COEUR RETRECISSANT
-  !     JRD0P       : DIAMETRE INITIAL DES PARTICULES
-  !     JRR0P       : MASSE VOLUMIQUE INITIALE DES PARTICULES
+  !     jrdck       : diametre du coeur retrecissant
+  !     jrd0p       : diametre initial des particules
+  !     jrr0p       : masse volumique initiale des particules
+  !     jrhock      : masse volumique du coke
 
-  integer, save ::           jrtsp, jrpoi, jreps, jrd0p, jrr0p, jrdck
+
+  integer, save :: jrval, jrtsp, jrpoi, jreps, jrd0p, jrr0p, jrdck, jrhock
 
   !   Tableau ITEPA
   !   ^^^^^^^^^^^^^
@@ -201,7 +233,7 @@ module lagran
   !   -------
   !     JINCH       : NUMERO DU CHARBON DE LA PARTICULE
 
-  integer, save ::           jisor, jinch , jclst , jgnum
+  integer, save ::           jisor, jinch , jclst
 
   !    NVLS         : NOMBRE DE VARIABLES UTILISATEUR SUPPLEMENTAIRES
   !                   (DEJA CONTENU DANS NVP et NVP1)
@@ -440,7 +472,6 @@ module lagran
   double precision cstfar
   parameter(cstfar = 9.648d4)
 
-
 !    Vacuum permittivity (F/m):
 
   double precision epsvid
@@ -451,6 +482,16 @@ module lagran
   double precision kboltz
   parameter(kboltz = 1.38d-23)
 
+!    Cut-off distance for adhesion forces (assumed to be the Born distance) (m)
+
+  double precision dcutof
+  parameter(dcutof = 1.65d-10)
+
+!    Characteristic retardation wavelength (m) for Hamaker constant
+
+  double precision lambwl
+  parameter(lambwl = 1000.d-9)
+
   !=============================================================================
   ! 13. Mouvement brownien
 
@@ -526,37 +567,17 @@ module lagran
   !=============================================================================
   ! 16. Visu
 
-  !... NBVIS  : nombre de particules a visualiser a l instant t
-  !    LISTE  : numero des particules a visualiser
-  !    LIST0  : sauvegarde de LISTE pour post-processing trajectoires
-  !    NPLIST : nombre d enregistrement par particule
-  !    NVISLA : periode d aquisition
-
-  integer, save ::           nbvis, liste(nliste), list0(nliste),            &
-                             nplist(nliste), nvisla
-
   !... Type de visualisation :
-  !    IENSI1 : trajectoires
-  !    IENSI2 : deplacements
   !    IENSI3 : interaction particules/frontieres
 
-  integer, save ::           iensi1 , iensi2 , iensi3
+  integer, save ::           iensi3
 
-  !... Contenu des flichiers resultats
+  !... Contenu des fichiers resultats
 
 
   integer, save ::           ivisv1 , ivisv2 , ivistp ,                      &
                              ivisdm , iviste , ivismp ,                      &
-                             ivishp , ivisch , ivisck , ivisdk
-
-  !... visualisation de type deplacement
-  !    ITLAG : nombre d enregistrement
-  !    TIMLAG : temps physiques lagrangien pour la visualisation
-
-
-  integer, save ::           itlag
-  double precision, save ::  timlag(9999)
-
+                             ivisch , ivisck , ivisdk
 
   !=============================================================================
 
@@ -782,4 +803,30 @@ contains
 
   !=============================================================================
 
+  !> \brief Return Lagrangian model status.
+
+  !> \param[out]   model     0 without Lagrangian, 1 or 2 with Lagrangian
+  !> \param[out]   restart   1 for Lagrangian restart, 0 otherwise
+  !> \param[out]   frozen    1 for frozen Eulerian flow, 0 otherwise
+
+  subroutine lagr_status(model, restart, frozen)  &
+    bind(C, name='cs_lagr_status')
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Arguments
+
+    integer(c_int), intent(out) :: model, restart, frozen
+
+    model = iilagr
+    restart = isuila
+    frozen = isttio
+
+    return
+
+  end subroutine lagr_status
+
+  !=============================================================================
+
 end module lagran
