@@ -149,9 +149,9 @@ double precision dlgeo(nfabor,ngeol)
 ! Local variables
 
 integer          ip     , npt    , iok
-integer          nfin   , npars  , iel    , ivf
+integer          npars  , iel    , ivf
 integer          npar1  , npar2
-integer          iforce , iitslg
+integer          iitslg
 integer          modntl , iromf
 
 double precision dnpars
@@ -183,6 +183,8 @@ double precision, allocatable, dimension(:,:) :: tslag
 
 double precision, allocatable, save, dimension(:) :: vislen
 
+double precision, allocatable, dimension(:):: energt
+
 
 integer nrangpp, ii
 integer nbpartall, nbpper
@@ -194,7 +196,6 @@ data             ipass /0/
 save             ipass
 
 
-
 !===============================================================================
 !===============================================================================
 ! 0.  GESTION MEMOIRE ET COMPTEUR DE PASSAGE
@@ -239,15 +240,22 @@ endif
 if (nordre.eq.2) then
   allocate(auxl2(nbpmax,7))
 endif
-
+if (idlvo.eq.1) then
+  allocate(energt(nfabor))
+endif
 
 ipass = ipass + 1
 
 if ((idepst.eq.1).and.(ipass.eq.1)) then
    allocate(vislen(nfabor))
+   do ifac = 1, nfabor
+     vislen(ifac) = grand
+   enddo
 endif
 
 
+
+
 !===============================================================================
 ! 1.  INITIALISATIONS
 !===============================================================================
@@ -263,6 +271,7 @@ npencr = 0
 nbpout = 0
 nbperr = 0
 nbpdep = 0
+nbpres = 0
 
 dnbpnw = 0.d0
 dnpcsu = 0.d0
@@ -272,6 +281,8 @@ dnpenc = 0.d0
 dnbpou = 0.d0
 dnbper = 0.d0
 dnbdep = 0.d0
+dnbres = 0.d0
+
 
 !-->Sur Champ fige Lagrangien : RTPA = RTP
 !   Rem : cette boucle pourrait etre faite au 1er passage
@@ -293,11 +304,17 @@ if (iplar.eq.1) then
 
   call lagbeg                                                     &
   !==========
- ( nbpmax , iphyla , nvls, nbclst)
+ ( nbpmax , iphyla , idepst , ireent ,                            &
+   nvls   , nbclst , icocel , itycel ,                            &
+   jisor  , jrval  , jrpoi  , jrtsp  , jdp    , jmp    ,          &
+   jxp    , jyp    , jzp    , jup    , jvp    , jwp    ,          &
+   juf    , jvf    , jwf    , jtaux  , jryplu ,                   &
+   jrinpf , jdfac  , jimark ,                                     &
+   jtp    , jhp    , jtf    , jmch   , jmck   , jcp    ,          &
+   jrdck  , jrd0p  , jrr0p  , jinch  , jrhock , jreps  ,          &
+   jdepo  , jnbasg , jnbasp , jfadh  , jmfadh , jndisp)
 
-!
 ! --> if the deposition model is activated
-!
 
   if (idepst.ge.1) then
 
@@ -323,7 +340,7 @@ if (iplar.eq.1) then
 
            ! the density pointer according to the flow location
 
-           if ( ippmod(icp3pl).ge.0 .or. ippmod(icfuel).ge.0 ) then
+           if ( ippmod(iccoal).ge.0 .or. ippmod(icfuel).ge.0 ) then
               iromf = ipproc(irom1)
            else
               iromf = ipproc(irom)
@@ -369,7 +386,7 @@ if ( ntcabs.eq.1 ) then
    nvar   , nscal  ,                                              &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   itycel , icocel ,                                              &
+   itycel , icocel , dlgeo  ,                                             &
    itypfb , itrifb , ifrlag , itepa  ,                            &
    dt     , rtp    , propce , propfa , propfb ,                   &
    ettp   , tepa   , vagaus , auxl   , w1     , w2     , w3     )
@@ -382,7 +399,7 @@ else
    nvar   , nscal  ,                                              &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   itycel , icocel ,                                              &
+   itycel , icocel , dlgeo  ,                                             &
    itypfb , itrifb , ifrlag , itepa  ,                            &
    dt     , rtpa   , propce , propfa , propfb ,                   &
    ettp   , tepa   , vagaus , auxl   , w1     , w2     , w3     )
@@ -643,32 +660,44 @@ if (iilagr.eq.2 .and. nor.eq.nordre) then
 endif
 
 !===============================================================================
-! 7.  Reperage des particules - Traitement des conditions aux limites
+! 7.  Calcul de la barrière d'énergie dans le cas DLVO
+!===============================================================================
+
+if (idlvo.eq.1) then
+
+   call lagbar                                                    &
+   !==========
+  ( rtp , energt )
+
+endif
+
+!===============================================================================
+! 8.  Reperage des particules - Traitement des conditions aux limites
 !     pour la position des particules
 !===============================================================================
 
 if (nor.eq.1) then
 
-!--> Si on est en instationnaire, RAZ des statistiques aux frontieres
+  !--> Si on est en instationnaire, RAZ des statistiques aux frontieres
 
-if (iensi3.eq.1) then
+  if (iensi3.eq.1) then
 
-  if (isttio.eq.0 .or. (isttio.eq.1 .and. iplas.le.nstbor)) then
-    tstatp = 0.d0
-    npstf = 0
-    do ii = 1,nvisbr
-      do ifac = 1,nfabor
-        parbor(ifac,ii) = 0.d0
+    if (isttio.eq.0 .or. (isttio.eq.1 .and. iplas.le.nstbor)) then
+      tstatp = 0.d0
+      npstf = 0
+      do ii = 1,nvisbr
+        do ifac = 1,nfabor
+          parbor(ifac,ii) = 0.d0
+        enddo
       enddo
-    enddo
+    endif
+
+    tstatp = tstatp + dtp
+    npstf  = npstf  + 1
+    npstft = npstft + 1
+
   endif
 
-  tstatp = tstatp + dtp
-  npstf  = npstf  + 1
-  npstft = npstft + 1
-
-endif
-
   call getbdy                                                     &
   !==========
  ( nflagm , nfrlag , injcon , ilflag , iusncl ,                   &
@@ -677,37 +706,25 @@ endif
 
   call prtget                                                     &
   !==========
- ( nbpmax , nbpart , dnbpar , liste  , nbvis  ,                   &
+ ( nbpmax , nbpart ,                                              &
    ettp   , ettpa  , itepa  , tepa   ,                            &
-   ibord  , indep  ,                                              &
-   jisor  , jgnum  , jrpoi  , jrtsp  , jdp    , jmp    ,          &
-   jxp    , jyp    , jzp    ,                                     &
-   jup    , jvp    , jwp    ,                                     &
-   juf    , jvf    , jwf    , jtaux  , jryplu,                    &
-   jrinpf , jdfac  ,                                              &
-   jimark , idepst)
-
+   ibord  , indep  )
 
   call dplprt                                                     &
   !==========
  ( nbpart , dnbpar, nordre, parbor, iensi3,                       &
-   nvisbr , inbr  , inbrbd,                                       &
+   inbr   , inbrbd,                                               &
    iflm   , iflmbd, iang  , iangbd, ivit  ,  ivitbd,              &
    nusbor , iusb,   vislen,  dlgeo , rtp , iu    ,                &
-   iv     , iw  ,   idepst)
-
+   iv     , iw  ,   energt)
 
   call prtput                                                     &
   !==========
  ( nbpmax , nbpart , dnbpar , nbpout , dnbpou , nbperr , dnbper,  &
    nbpdep , dnbdep ,                                              &
-   liste  , nbvis,                                                &
    ettp   , ettpa  , itepa  , tepa   ,                            &
-   ibord  ,                                                       &
-   jisor  , jgnum  , jrpoi  , jrtsp  , jdp    ,                   &
-   jmp    , jxp    , jyp    , jzp    ,                            &
-   jup    , jvp    , jwp    , juf    , jvf    , jwf , jtaux,      &
-   jryplu , jrinpf , jdfac  , jimark , idepst )
+   ibord  )
+
 
   if (ierr.eq.1) then
     ntmabs = ntcabs
@@ -732,6 +749,23 @@ if (nor.eq.nordre) then
 
 endif
 
+!===============================================================================
+! 11.  CALCUL DE L'ADHESION SI MODELE DE REENTRAINEMENT
+!===============================================================================
+
+if (ireent.gt.0) then
+
+  call lagres                                                     &
+  !==========
+ ( nvar   , nscal  ,                                              &
+   nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
+   ntersl , nvlsta , nvisbr ,                                     &
+   itepa  ,                                                       &
+   dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
+   ettp   , ettpa  , tepa )
+
+endif
+
 !===============================================================================
 ! 11.  CALCUL STATISTIQUES
 !===============================================================================
@@ -789,12 +823,12 @@ if ( nor.eq.nordre .and. iroule.ge.1 ) then
 
     call lagipn                                                   &
     !==========
-    ( ncelet , ncel   ,                                           &
-      nbpmax , nvp    , nvp1   , nvep   , nivep  ,                &
+    ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                &
       npar1  , npar2  ,                                           &
       itepa  ,                                                    &
       rtp    ,                                                    &
-      ettp   , tepa   , vagaus )
+      ettp   , tepa   , vagaus ,                                  &
+      icocel , lndnod , itycel , dlgeo  , propce , ifrlag )
 
   endif
 
@@ -827,30 +861,11 @@ call uslast                                                       &
 
  20   continue
 
-nfin = 0
-
-!-->Stockage des trajectoires au format Ensight Gold
-
-if (iensi1.eq.1) then
-
-  iforce = 0
-
-  call enslag                                                     &
-  !==========
-   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                 &
-     nfin   , iforce ,                                            &
-     itepa  ,                                                     &
-     ettp   , tepa   )
-endif
-
-if (iensi2.eq.1) then
-  call enswaf                                                     &
-  !==========
-   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                 &
-     nfin   ,                                                     &
-     itepa  ,                                                     &
-     ettp   , tepa   )
-endif
+call ucdprt                                                        &
+!==========
+ ( nbpmax , nbpart , dnbpar , nbpout , dnbpou , nbperr ,           &
+   dnbper , nbpdep , dnbdep,                                       &
+   ettp   , ettpa  , itepa  , tepa   , ibord  , indep  )
 
 !===============================================================================
 ! 17. NOMBRE DE PARITICULES PERDUES (SUITES COMPRISES)
@@ -895,6 +910,7 @@ if (modntl.eq.0) then
 endif
 
 ! Free memory
+
 deallocate(indep, ibord)
 deallocate(auxl)
 deallocate(taup)
@@ -935,6 +951,9 @@ endif
 if ((idepst.eq.1).and.(ntcabs.eq.ntmabs)) then
    deallocate(vislen)
 endif
+if (idlvo.eq.1) then
+   deallocate(energt)
+endif
 
 !===============================================================================
 
