@@ -10,7 +10,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -130,7 +130,7 @@ cs_join_merge_vertices(cs_join_param_t        param,
 
 void
 cs_join_merge_update_struct(cs_join_param_t          param,
-                            cs_int_t                 n_iwm_vertices,
+                            cs_lnum_t                n_iwm_vertices,
                             const cs_gnum_t          iwm_vtx_gnum[],
                             cs_gnum_t                init_max_vtx_gnum,
                             const cs_gnum_t          rank_face_gnum_index[],
