@@ -42,6 +42,7 @@
 
 #include "fvm_io_num.h"
 
+#include "cs_block_dist.h"
 #include "cs_join_util.h"
 #include "cs_order.h"
 #include "cs_search.h"
@@ -382,6 +383,8 @@ void
 cs_join_eset_check_size(cs_lnum_t         request_size,
                         cs_join_eset_t  **equiv_set)
 {
+  assert(equiv_set != NULL);
+
   cs_join_eset_t  *eset = *equiv_set;
 
   if (eset == NULL)
@@ -431,6 +434,8 @@ cs_join_eset_destroy(cs_join_eset_t  **equiv_set)
 void
 cs_join_eset_clean(cs_join_eset_t  **eset)
 {
+  assert(eset != NULL);
+
   int  i;
   cs_lnum_t  prev, current;
 
@@ -706,7 +711,7 @@ cs_join_gset_create_from_tag(cs_lnum_t        n_elts,
  *   init_array <-- initial values of set->g_list
  *
  * returns:
- *   a new allocated cs_join_gset_t structure
+ *   a new allocated cs_join_gset_t structure, or NULL if it would be empty
  *---------------------------------------------------------------------------*/
 
 cs_join_gset_t *
@@ -1544,17 +1549,20 @@ cs_join_gset_t *
 cs_join_gset_robin_sync(cs_join_gset_t  *loc_set,
                         MPI_Comm         comm)
 {
-  int  i, j, shift, elt_id;
-  int  rank, local_rank, n_ranks, n_recv_elts, n_sub_elts;
-  cs_gnum_t  gnum;
+  int  shift, rank, local_rank, n_ranks, n_recv_elts;
+  cs_lnum_t i, j, elt_id, n_sub_elts;
+  cs_gnum_t g_ent_num, _n_ranks;
 
   cs_lnum_t  *send_count = NULL, *recv_count = NULL;
   cs_lnum_t  *send_shift = NULL, *recv_shift = NULL;
   cs_gnum_t  *send_buffer = NULL, *recv_buffer = NULL;
   cs_join_gset_t  *sync_set = NULL;
 
+  assert(loc_set != NULL);
+
   MPI_Comm_rank(comm, &local_rank);
   MPI_Comm_size(comm, &n_ranks);
+  _n_ranks = n_ranks;
 
   /* Allocate parameters for MPI functions */
 
@@ -1571,7 +1579,7 @@ cs_join_gset_robin_sync(cs_join_gset_t  *loc_set,
   /* Synchronize list definition for each global element */
 
   for (i = 0; i < loc_set->n_elts; i++) {
-    rank = (loc_set->g_elts[i] - 1) % n_ranks;
+    rank = (loc_set->g_elts[i] - 1) % _n_ranks;
     send_count[rank] += 1;
   }
 
@@ -1599,7 +1607,7 @@ cs_join_gset_robin_sync(cs_join_gset_t  *loc_set,
 
   for (i = 0; i < loc_set->n_elts; i++) {
 
-    rank = (loc_set->g_elts[i] - 1) % (cs_gnum_t)n_ranks;
+    rank = (loc_set->g_elts[i] - 1) % _n_ranks;
     n_sub_elts = loc_set->index[i+1] - loc_set->index[i];
     send_count[rank] += 2 + n_sub_elts;
 
@@ -1625,16 +1633,16 @@ cs_join_gset_robin_sync(cs_join_gset_t  *loc_set,
 
   for (i = 0; i < loc_set->n_elts; i++) {
 
-    gnum = loc_set->g_elts[i];
-    rank = (gnum - 1) % (cs_gnum_t)n_ranks;
+    g_ent_num = loc_set->g_elts[i];
+    rank = (g_ent_num - 1) % _n_ranks;
     shift = send_shift[rank] + send_count[rank];
     n_sub_elts = loc_set->index[i+1] - loc_set->index[i];
 
-    send_buffer[shift++] = gnum;
+    send_buffer[shift++] = g_ent_num;
     send_buffer[shift++] = n_sub_elts;
 
     for (j = 0; j < n_sub_elts; j++)
-      send_buffer[shift + j] = loc_set->g_list[loc_set->index[i] + j];
+      send_buffer[shift + j] = loc_set->g_list[loc_set->index[i] + (cs_gnum_t)j];
 
     send_count[rank] += 2 + n_sub_elts;
 
@@ -1723,9 +1731,9 @@ cs_join_gset_robin_update(const cs_join_gset_t  *sync_set,
                           cs_join_gset_t        *loc_set,
                           MPI_Comm               comm)
 {
-  int  i, j, k, shift, elt_id, start, end;
-  int  rank, local_rank, n_ranks, n_sub_elts, n_recv_elts;
-  cs_gnum_t  gnum, _n_ranks;
+  int  rank, local_rank, n_ranks, n_sub_elts, n_recv_elts, shift;
+  cs_lnum_t  i, j, k, elt_id, start, end;
+  cs_gnum_t  g_ent_num, _n_ranks;
 
   cs_lnum_t  *send_count = NULL, *recv_count = NULL;
   cs_lnum_t  *send_shift = NULL, *recv_shift = NULL, *wanted_rank_index = NULL;
@@ -1734,6 +1742,7 @@ cs_join_gset_robin_update(const cs_join_gset_t  *sync_set,
   /* Sanity checks */
 
   assert(sync_set != NULL);
+  assert(loc_set != NULL);
 
   /* Build a cs_join_block_info_t structure */
 
@@ -1781,11 +1790,11 @@ cs_join_gset_robin_update(const cs_join_gset_t  *sync_set,
 
   for (i = 0; i < loc_set->n_elts; i++) {
 
-    gnum = loc_set->g_elts[i];
-    rank = (gnum - 1) % _n_ranks;
+    g_ent_num = loc_set->g_elts[i];
+    rank = (g_ent_num - 1) % _n_ranks;
     shift = send_shift[rank] + send_count[rank];
 
-    send_buffer[shift] = gnum;
+    send_buffer[shift] = g_ent_num;
     send_count[rank] += 1;
 
   }
@@ -1889,10 +1898,9 @@ cs_join_gset_robin_update(const cs_join_gset_t  *sync_set,
 
   while (i < n_recv_elts) {
 
-    gnum = recv_buffer[i++];
-
-    assert(loc_set->g_elts[j] = gnum);
+    assert(loc_set->g_elts[j] = recv_buffer[i]);
 
+    i++;
     n_sub_elts = recv_buffer[i++];
     loc_set->index[j+1] = n_sub_elts;
 
@@ -1913,10 +1921,10 @@ cs_join_gset_robin_update(const cs_join_gset_t  *sync_set,
 
   while (i < n_recv_elts) {
 
-    gnum = recv_buffer[i++];
-    n_sub_elts = recv_buffer[i++];
+    assert(loc_set->g_elts[j] = recv_buffer[i]);
 
-    assert(loc_set->g_elts[j] = gnum);
+    i++;
+    n_sub_elts = recv_buffer[i++];
 
     for (k = 0; k < n_sub_elts; k++)
       loc_set->g_list[loc_set->index[j] + k] = recv_buffer[i + k];
@@ -1950,23 +1958,36 @@ cs_join_gset_block_sync(cs_gnum_t        max_gnum,
                         cs_join_gset_t  *loc_set,
                         MPI_Comm         comm)
 {
-  int  i, j, shift, block_id;
-  int  rank, local_rank, n_ranks, n_recv_elts, n_sub_elts;
-  cs_gnum_t  gnum;
-  cs_join_block_info_t  block_info;
+  int  block_id;
+  int  rank, local_rank, n_ranks, n_recv_elts, shift;
+  cs_lnum_t i, j, n_sub_elts;
+  cs_gnum_t g_ent_num, _n_ranks;
+  cs_block_dist_info_t  bi;
+
+  cs_lnum_t block_size = 0;
 
   cs_lnum_t  *send_count = NULL, *recv_count = NULL, *counter = NULL;
   cs_lnum_t  *send_shift = NULL, *recv_shift = NULL;
   cs_gnum_t  *send_buffer = NULL, *recv_buffer = NULL;
   cs_join_gset_t  *sync_set = NULL;
 
+  assert(loc_set != NULL);
+
   if (max_gnum == 0)
     return  sync_set;
 
   MPI_Comm_rank(comm, &local_rank);
   MPI_Comm_size(comm, &n_ranks);
+  _n_ranks = n_ranks;
 
-  block_info = cs_join_get_block_info(max_gnum, n_ranks, local_rank);
+  bi = cs_block_dist_compute_sizes(local_rank,
+                                   n_ranks,
+                                   1,
+                                   0,
+                                   max_gnum);
+
+  if (bi.gnum_range[1] > bi.gnum_range[0])
+    block_size = bi.gnum_range[1] - bi.gnum_range[0];
 
   /* Allocate parameters for MPI functions */
 
@@ -1984,7 +2005,7 @@ cs_join_gset_block_sync(cs_gnum_t        max_gnum,
 
   for (i = 0; i < loc_set->n_elts; i++) {
 
-    rank = (loc_set->g_elts[i] - 1)/block_info.size;
+    rank = (loc_set->g_elts[i] - 1)/bi.block_size;
     n_sub_elts = loc_set->index[i+1] - loc_set->index[i];
     send_count[rank] += 2 + n_sub_elts;
 
@@ -2010,12 +2031,12 @@ cs_join_gset_block_sync(cs_gnum_t        max_gnum,
 
   for (i = 0; i < loc_set->n_elts; i++) {
 
-    gnum = loc_set->g_elts[i];
-    rank = (gnum - 1)/(cs_gnum_t)(block_info.size);
+    g_ent_num = loc_set->g_elts[i];
+    rank = (g_ent_num - 1)/(cs_gnum_t)(bi.block_size);
     shift = send_shift[rank] + send_count[rank];
     n_sub_elts = loc_set->index[i+1] - loc_set->index[i];
 
-    send_buffer[shift++] = gnum;
+    send_buffer[shift++] = g_ent_num;
     send_buffer[shift++] = n_sub_elts;
 
     for (j = 0; j < n_sub_elts; j++)
@@ -2042,10 +2063,12 @@ cs_join_gset_block_sync(cs_gnum_t        max_gnum,
   /* Define sync_set: a distributed cs_join_gset_t structure which
      synchronize data over the ranks */
 
-  sync_set = cs_join_gset_create(block_info.local_size);
+  sync_set = cs_join_gset_create(block_size);
 
-  for (i = 0; i < sync_set->n_elts; i++)
-    sync_set->g_elts[i] = block_info.first_gnum + i;
+  for (i = 0; i < sync_set->n_elts; i++) {
+    cs_gnum_t g_id = i;
+    sync_set->g_elts[i] = bi.gnum_range[0] + g_id;
+  }
 
   /* Fill sync_set->index and define a new recv_count for the next comm. */
 
@@ -2053,7 +2076,7 @@ cs_join_gset_block_sync(cs_gnum_t        max_gnum,
 
   while (i < n_recv_elts) {
 
-    block_id = recv_buffer[i++] - block_info.first_gnum;
+    block_id = recv_buffer[i++] - bi.gnum_range[0];
 
     assert(sync_set->g_elts[block_id] == recv_buffer[i-1]);
 
@@ -2083,7 +2106,7 @@ cs_join_gset_block_sync(cs_gnum_t        max_gnum,
 
   while (i < n_recv_elts) {
 
-    block_id = recv_buffer[i++] - block_info.first_gnum;
+    block_id = recv_buffer[i++] - bi.gnum_range[0];
     shift = sync_set->index[block_id] + counter[block_id];
 
     n_sub_elts = recv_buffer[i++];
@@ -2124,10 +2147,11 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
                           cs_join_gset_t        *loc_set,
                           MPI_Comm               comm)
 {
-  int  i, j, k, shift, block_id, start, end;
+  int  shift, block_id;
   int  rank, local_rank, n_ranks, n_sub_elts, n_recv_elts;
-  cs_gnum_t  gnum;
-  cs_join_block_info_t  block_info;
+  cs_lnum_t i, j, k, start, end;
+  cs_gnum_t g_ent_num, _n_ranks;
+  cs_block_dist_info_t  bi;
 
   cs_lnum_t  *send_count = NULL, *recv_count = NULL;
   cs_lnum_t  *send_shift = NULL, *recv_shift = NULL, *wanted_rank_index = NULL;
@@ -2138,14 +2162,20 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
 
   /* Sanity checks */
 
+  assert(loc_set != NULL);
   assert(sync_set != NULL);
 
   /* Build a cs_join_block_info_t structure */
 
   MPI_Comm_rank(comm, &local_rank);
   MPI_Comm_size(comm, &n_ranks);
+  _n_ranks = n_ranks;
 
-  block_info = cs_join_get_block_info(max_gnum, n_ranks, local_rank);
+  bi = cs_block_dist_compute_sizes(local_rank,
+                                   n_ranks,
+                                   1,
+                                   0,
+                                   max_gnum);
 
   /* Allocate parameters for MPI functions */
 
@@ -2163,7 +2193,7 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
   /* Get a synchronized list definition for each global element */
 
   for (i = 0; i < loc_set->n_elts; i++) {
-    rank = (loc_set->g_elts[i] - 1)/block_info.size;
+    rank = (loc_set->g_elts[i] - 1)/(cs_gnum_t)bi.block_size;
     send_count[rank] += 1;
   }
 
@@ -2187,11 +2217,11 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
 
   for (i = 0; i < loc_set->n_elts; i++) {
 
-    gnum = loc_set->g_elts[i];
-    rank = (gnum - 1)/block_info.size;
+    g_ent_num = loc_set->g_elts[i];
+    rank = (g_ent_num - 1) / (cs_gnum_t)bi.block_size;
     shift = send_shift[rank] + send_count[rank];
 
-    send_buffer[shift] = gnum;
+    send_buffer[shift] = g_ent_num;
     send_count[rank] += 1;
 
   }
@@ -2210,7 +2240,7 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
 
     for (i = wanted_rank_index[rank]; i < wanted_rank_index[rank+1]; i++) {
 
-      block_id = wanted_elts[i] - block_info.first_gnum;
+      block_id = wanted_elts[i] - bi.gnum_range[0];
       n_sub_elts = sync_set->index[block_id+1] - sync_set->index[block_id];
 
       send_count[rank] +=  2 + n_sub_elts; /* glob. num,
@@ -2242,7 +2272,7 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
     for (i = wanted_rank_index[rank]; i < wanted_rank_index[rank+1]; i++) {
 
       shift = send_shift[rank] + send_count[rank];
-      block_id = wanted_elts[i] - block_info.first_gnum;
+      block_id = wanted_elts[i] - bi.gnum_range[0];
 
       start = sync_set->index[block_id];
       end = sync_set->index[block_id+1];
@@ -2290,10 +2320,9 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
 
   while (i < n_recv_elts) {
 
-    gnum = recv_buffer[i++];
-
-    assert(loc_set->g_elts[j] = gnum);
+    assert(loc_set->g_elts[j] = recv_buffer[i]);
 
+    i++;
     n_sub_elts = recv_buffer[i++];
     loc_set->index[j+1] = n_sub_elts;
 
@@ -2314,10 +2343,10 @@ cs_join_gset_block_update(cs_gnum_t              max_gnum,
 
   while (i < n_recv_elts) {
 
-    gnum = recv_buffer[i++];
-    n_sub_elts = recv_buffer[i++];
+    assert(loc_set->g_elts[j] = recv_buffer[i]);
 
-    assert(loc_set->g_elts[j] = gnum);
+    i++;
+    n_sub_elts = recv_buffer[i++];
 
     for (k = 0; k < n_sub_elts; k++)
       loc_set->g_list[loc_set->index[j] + k] = recv_buffer[i + k];
