@@ -249,6 +249,9 @@ _destroy_join_sync(cs_join_sync_t   **sync)
 {
   cs_join_sync_t  *_sync = *sync;
 
+  if (_sync == NULL)
+    return;
+
   if (_sync->array != NULL)
     BFT_FREE(_sync->array);
   if (_sync->ranks != NULL)
@@ -1332,6 +1335,7 @@ _add_coupled_edges(cs_interface_set_t   *ifs,
   const int  n_interfaces = cs_interface_set_size(ifs);
   const cs_interface_t  *interface = NULL;
 
+  assert(s_edges != NULL);
   assert(c_edges != NULL);
 
   /* Exchange number of single edges */
@@ -1592,6 +1596,8 @@ _filter_edge_element(cs_join_select_t   *selection,
   const int  loc_rank = CS_MAX(cs_glob_rank_id, 0);
 
   assert(cs_glob_n_ranks > 1);
+  assert(c_edges != NULL);
+  assert(s_edges != NULL);
 
   /* Allocate MPI buffers used for exchanging data */
 
@@ -1752,6 +1758,9 @@ _get_missing_edges(cs_lnum_t            b_f2v_idx[],
 
   cs_lnum_t  *sel_v2v_idx = NULL, *sel_v2v_lst = NULL;
 
+  assert(ifs != NULL);
+  assert(selection != NULL);
+
   /* Define single edge element */
 
   _get_select_v2v_connect(n_vertices,
@@ -2301,66 +2310,6 @@ cs_join_select_create(const char  *selection_criteria,
   return  selection;
 }
 
-/*----------------------------------------------------------------------------
- * Define a set of parameters to control a contiguous distribution by block.
- *
- * parameters:
- *   n_g_elts   <-- global number of elements to treat
- *   n_ranks    <-- number of ranks in the MPI communicator related to the
- *                  cs_join_block_info_t structure to create
- *   local_rank <-- rank in the MPI communicator related to the
- *                  cs_join_block_info_t structure to create
- *
- * returns:
- *   a new defined cs_join_block_info_t structure
- *---------------------------------------------------------------------------*/
-
-cs_join_block_info_t
-cs_join_get_block_info(cs_gnum_t  n_g_elts,
-                       int        n_ranks,
-                       int        local_rank)
-{
-  size_t  block_size, n_treat_elts;
-  cs_gnum_t  first_glob_num, last_glob_num;
-  cs_gnum_t  _local_rank, _block_size;
-
-  cs_join_block_info_t  block_info;
-
-  /* Compute block_size */
-
-  block_size = n_g_elts/n_ranks;
-  if (n_g_elts % n_ranks > 0)
-    block_size++;
-
-  _local_rank = local_rank; /* Help ensure 64-bit arithmetic for long gnum */
-  _block_size = block_size;
-
-  first_glob_num = _local_rank * block_size + 1;
-  last_glob_num = first_glob_num + _block_size;
-
-  if (last_glob_num > n_g_elts) {
-
-    if (first_glob_num > n_g_elts) /* n_ranks > n_g_elts */
-      n_treat_elts = 0;
-    else
-      n_treat_elts = n_g_elts - first_glob_num + 1;
-
-  }
-  else
-    n_treat_elts = block_size;
-
-  block_info.n_g_elts = n_g_elts;
-  block_info.first_gnum = first_glob_num;
-
-  block_info.size = block_size;
-  block_info.local_size = n_treat_elts;
-
-  block_info.n_ranks = n_ranks;
-  block_info.local_rank = local_rank;
-
-  return  block_info;
-}
-
 /*----------------------------------------------------------------------------
  * Extract vertices from a selection of faces.
  *
