@@ -186,31 +186,6 @@ extern cs_mesh_t *cs_glob_mesh; /* Pointer to main mesh structure */
  *  Public function prototypes for Fortran API
  *============================================================================*/
 
-/*----------------------------------------------------------------------------
- * Return the group number corresponding to a given name. If the group exists,
- * the number corresponds to the group rank (starting from 1) in the list of
- * the meshe's groups, multiplied by -1. This numbering is that used in
- * family (group class) description array IPRFML(NFML, NPRFML).
- *
- * If the group of the given name is not found, 9999 is returned.
- *
- * Fortran interface:
- *
- * FUNCTION NUMGRP (NAME, LEN)
- * ***************
- *
- * CHARACTER*       NAME        : <-- : Name of the group
- * INTEGER          LEN         : <-- : Group name length
- *----------------------------------------------------------------------------*/
-
-cs_int_t CS_PROCF (numgrp, NUMGRP)
-(
- const char       *name,    /* <-- Group name */
- const cs_int_t   *len      /* <-- Name length */
- CS_ARGF_SUPP_CHAINE        /*     (possible 'length' arguments added
-                                   by many Fortran compilers) */
-);
-
 /*----------------------------------------------------------------------------
  * Update a scalar array in case of parallelism and/or periodicity.
  *
@@ -465,18 +440,6 @@ cs_mesh_free_rebuildable(cs_mesh_t  *mesh,
 void
 cs_mesh_discard_free_faces(cs_mesh_t  *mesh);
 
-/*----------------------------------------------------------------------------
- * Renumber vertices.
- *
- * Ensure: if i < j then mesh->global_vtx_num[i] < mesh->global_vtx_num[j]
- *
- * parameters:
- *   mesh  <->  pointer to mesh structure
- *----------------------------------------------------------------------------*/
-
-void
-cs_mesh_order_vertices(cs_mesh_t  *mesh);
-
 /*----------------------------------------------------------------------------
  * Compute or update mesh structure members the depend on other members,
  * but whose results may be reused, such as global number of elements
@@ -689,17 +652,6 @@ cs_mesh_sync_var_sym_tens(cs_real_t  *var);
 void
 cs_mesh_clean_families(cs_mesh_t  *mesh);
 
-/*----------------------------------------------------------------------------
- * Add colors to group class descriptions for group names which are
- * convertible to integers.
- *
- * parameters
- *   mesh <-> pointer to mesh structure
- *----------------------------------------------------------------------------*/
-
-void
-cs_mesh_build_colors(cs_mesh_t  *mesh);
-
 /*----------------------------------------------------------------------------
  * Define group classes for a mesh based on its family definitions.
  *
