@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -2024,6 +2024,7 @@ cs_mesh_quantities_compute(const cs_mesh_t       *mesh,
                    "volume.\n"));
     }
 }
+
 /*----------------------------------------------------------------------------
  * Compute mesh quantities -> vectors II' and JJ'
  *
@@ -2226,6 +2227,23 @@ cs_mesh_quantities_check_vol(const cs_mesh_t             *mesh,
   }
 }
 
+/*----------------------------------------------------------------------------
+ * Update mesh quantities relative to extended ghost cells when the
+ * neighborhood is reduced.
+ *
+ * parameters:
+ *   mesh            <-- pointer to a cs_mesh_t structure
+ *   mesh_quantities <-> pointer to a cs_mesh_quantities_t structure
+ *----------------------------------------------------------------------------*/
+
+void
+cs_mesh_quantities_reduce_extended(const cs_mesh_t       *mesh,
+                                   cs_mesh_quantities_t  *mesh_quantities)
+{
+  if (cs_glob_mesh_quantities_compute_cocg_lsq == 1)
+    _compute_cell_cocg_lsq(mesh, mesh_quantities);
+}
+
 /*----------------------------------------------------------------------------
  * Dump a cs_mesh_quantities_t structure
  *
