@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2012 EDF S.A.
+  Copyright (C) 1998-2013 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -319,6 +319,19 @@ cs_mesh_quantities_check_vol(const cs_mesh_t             *mesh,
                              const cs_mesh_quantities_t  *mesh_quantities,
                              int                          allow_error);
 
+/*----------------------------------------------------------------------------
+ * Update mesh quantities relative to extended ghost cells when the
+ * neighborhood is reduced.
+ *
+ * parameters:
+ *   mesh            <-- pointer to a cs_mesh_t structure
+ *   mesh_quantities <-> pointer to a cs_mesh_quantities_t structure
+ *----------------------------------------------------------------------------*/
+
+void
+cs_mesh_quantities_reduce_extended(const cs_mesh_t       *mesh,
+                                   cs_mesh_quantities_t  *mesh_quantities);
+
 /*----------------------------------------------------------------------------
  * Dump a cs_mesh_quantities_t structure
  *
