@@ -87,10 +87,18 @@ module radiat
 
   integer, save ::           idiver
 
-  !--> parametre sur le nombre de directions de discretisation angulaire
+  !--> index of the quadrature and number of directions for a single octant
 
-  integer     ndirs8
-  parameter ( ndirs8 = 16 )
+  integer, save ::           i_quadrature, ndirs
+
+  !--> parameter assiociated to the Tn
+
+  integer, save :: ndirec
+
+  !--> directions of angular values of the quadrature sx, sy, sz
+  !    and weight of the solid angle associated
+
+  double precision, dimension(:), allocatable :: sx, sy, sz, angsol
 
   !--> suite de calcul (0 : non, 1 : oui)
 
@@ -100,14 +108,6 @@ module radiat
 
   integer, save ::           nfreqr
 
-  !--> nombre de bandes spectrales
-
-  integer, save :: nbande
-
-  !--> nombre de directions de discretisation angulaire
-
-  integer, save :: ndirec
-
   !--> Informations sur les zones frontieres
 
   ! NBZRDM Nombre max. de  zones frontieres
@@ -152,4 +152,71 @@ module radiat
 
   !=============================================================================
 
+contains
+
+  !=============================================================================
+
+  ! Allocate arrays
+
+  subroutine init_quadrature(ndirs)
+
+    ! Arguments
+
+    integer, intent(in) :: ndirs
+
+    ! Local variables
+
+    integer :: err = 0
+
+    if (.not.allocated(sx)) then
+      allocate(sx(ndirs), stat=err)
+    endif
+
+    if (.not.allocated(sy)) then
+      allocate(sy(ndirs), stat=err)
+    endif
+
+    if (.not.allocated(sz)) then
+      allocate(sz(ndirs), stat=err)
+    endif
+
+    if (.not.allocated(angsol)) then
+      allocate(angsol(ndirs), stat=err)
+    endif
+
+    if (err /= 0) then
+      write (*, *) "Error allocating array."
+      call csexit(err)
+    endif
+
+    return
+
+  end subroutine init_quadrature
+
+  !=============================================================================
+
+  ! Free related arrays
+
+  subroutine finalize_quadrature
+
+    if (allocated(sx)) then
+      deallocate(sx)
+    endif
+
+    if (allocated(sy)) then
+      deallocate(sy)
+    endif
+
+    if (allocated(sz)) then
+      deallocate(sz)
+    endif
+
+    if (allocated(angsol)) then
+      deallocate(angsol)
+    endif
+
+  end subroutine finalize_quadrature
+
+  !=============================================================================
+
 end module radiat
