@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -207,13 +207,13 @@ endif
 
 #if defined(_CS_LANG_FR)
 
- 1000 format('ATTENTION VARIABLE PHI'                             &
+ 1000 format('ATTENTION VARIABLE PHI',                            &
      'VALEUR MAXIMALE PHYSIQUE DE 2 DEPASSEE SUR ',I10,           &
      ' CELLULES')
 
 #else
 
- 1000 format('WARNING VARIABLE PHI'                               &
+ 1000 format('WARNING VARIABLE PHI',                              &
      'MAXIMUM PHYSICAL VALUE OF 2 EXCEEDED FOR ',I10,             &
      ' CELLS')
 
