@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -29,7 +29,7 @@ subroutine resrij &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
    coefa  , coefb  , produc , gradro ,                            &
    ckupdc , smcelp , gamma  ,                                     &
-   viscf  , viscb  , coefax ,                                     &
+   viscf  , viscb  ,                                              &
    tslage , tslagi ,                                              &
    smbr   , rovsdt )
 
@@ -76,9 +76,6 @@ subroutine resrij &
 ! gamma(ncesmp)    ! tr ! <-- ! valeur du flux de masse                        !
 ! viscf(nfac)      ! tr ! --- ! visc*surface/dist aux faces internes           !
 ! viscb(nfabor     ! tr ! --- ! visc*surface/dist aux faces de bord            !
-! coefax(nfabor    ! tr ! --- ! tab de trav pour cond.lim. paroi               !
-!                  ! tr ! --- !   attention : uniquement avec echo             !
-!                  ! tr ! --- !   de paroi et abs(icdpar) = 1                  !
 ! tslage(ncelet    ! tr ! <-- ! ts explicite couplage retour lagr.             !
 ! tslagi(ncelet    ! tr ! <-- ! ts implicite couplage retour lagr.             !
 ! smbr(ncelet      ! tr ! --- ! tableau de travail pour sec mem                !
@@ -128,14 +125,14 @@ double precision produc(6,ncelet)
 double precision gradro(ncelet,3)
 double precision ckupdc(ncepdp,6)
 double precision smcelp(ncesmp), gamma(ncesmp)
-double precision viscf(nfac), viscb(nfabor), coefax(nfabor)
+double precision viscf(nfac), viscb(nfabor)
 double precision tslage(ncelet),tslagi(ncelet)
 double precision smbr(ncelet), rovsdt(ncelet)
 
 ! Local variables
 
 integer          init  , ifac  , iel   , inc   , iccocg
-integer          ii    , jj    , iiun
+integer          ii    , jj    , kk    , iiun
 integer          ipcrom, ipcvis, iflmas, iflmab, ipcroo
 integer          iclvar, iclvaf
 integer          nswrgp, imligp, iwarnp
@@ -144,7 +141,8 @@ integer          nitmap, nswrsp, ircflp, ischcp, isstpp, iescap
 integer          imgrp , ncymxp, nitmfp
 integer          iptsta
 integer          isoluc
-integer          imucpp
+integer          imucpp, idftnp, iswdyp
+integer          indrey(3,3)
 
 double precision blencp, epsilp, epsrgp, climgp, extrap, relaxp
 double precision epsrsp
@@ -154,6 +152,7 @@ double precision surfn2
 double precision tuexpr, thets , thetv , thetp1
 double precision d1s3  , d2s3
 double precision hint
+double precision matrot(3,3)
 
 double precision rvoid(1)
 
@@ -226,7 +225,7 @@ call ustsri                                                       &
    ivar   ,                                                       &
    icepdc , icetsm , itpsmp ,                                     &
    dt     , rtpa   , propce , propfa , propfb ,                   &
-   coefa  , coefb  , ckupdc , smcelp , gamma  , produc , produc , &
+   ckupdc , smcelp , gamma  , produc , produc ,                   &
    smbr   , rovsdt )
 
 !     Si on extrapole les T.S.
@@ -426,11 +425,91 @@ else
 
 endif
 
+!===============================================================================
+! 5-bis. Coriolis terms in the Phi1 and production
+!===============================================================================
+
+if (icorio.eq.1) then
+
+  do iel = 1, ncel
+    w7(iel) = 0.d0
+  enddo
+
+  ! Rotation matrix: dual antisymmetric matrix of the rotation vector omega
+  matrot(1,2) = -omegaz
+  matrot(1,3) =  omegay
+  matrot(2,3) = -omegax
+
+  do ii = 1, 3
+    matrot(ii,ii) = 0.d0
+    do jj = ii+1, 3
+      matrot(jj,ii) = -matrot(ii,jj)
+    enddo
+  enddo
+
+  ! Index Connectivity
+  indrey(1,1) = ir11
+  indrey(2,2) = ir22
+  indrey(3,3) = ir33
+  indrey(1,2) = ir12
+  indrey(1,3) = ir13
+  indrey(2,3) = ir23
+  indrey(2,1) = indrey(1,2)
+  indrey(3,1) = indrey(1,3)
+  indrey(3,2) = indrey(2,3)
+
+  if (isou.eq.1) then
+    ii = 1
+    jj = 1
+  elseif (isou.eq.2) then
+    ii = 2
+    jj = 2
+  elseif (isou.eq.3) then
+    ii = 3
+    jj = 3
+  elseif (isou.eq.4) then
+    ii = 1
+    jj = 2
+  elseif (isou.eq.5) then
+    ii = 1
+    jj = 3
+  elseif (isou.eq.6) then
+    ii = 2
+    jj = 3
+  endif
+
+  do iel = 1, ncel
+    ! Compute Gij: (i,j) component of the Coriolis production
+    do kk = 1, 3
+      w7(iel) = w7(iel) - 2.d0*( matrot(ii,kk)*rtpa(iel,indrey(jj,kk)) &
+                               + matrot(jj,kk)*rtpa(iel,indrey(ii,kk)) )
+    enddo
+    ! Coriolis contribution in the Phi1 term:
+    ! (1-C2/2)Gij
+    w7(iel) = propce(iel,ipcrom) * volume(iel) *                  &
+         (1.d0 - 0.5d0*crij2)*w7(iel)
+  enddo
+
+  ! If source terms are extrapolated
+  if(isto2t.gt.0) then
+    do iel = 1, ncel
+      propce(iel,iptsta+isou-1) =                                 &
+      propce(iel,iptsta+isou-1) + w7(iel)
+    enddo
+  ! Otherwise, directly in smbr
+  else
+    do iel = 1, ncel
+      smbr(iel) = smbr(iel) + w7(iel)
+    enddo
+  endif
+
+endif
+
 !===============================================================================
 ! 6. TERMES D'ECHO DE PAROI
 !===============================================================================
 
-if(irijec.eq.1) then
+if (irijec.eq.1) then
 
   do iel = 1, ncel
     w7(iel) = 0.d0
@@ -441,21 +520,20 @@ if(irijec.eq.1) then
  ( nvar   , nscal  ,                                              &
    ivar   , isou   , ipp    ,                                     &
    rtp    , rtpa   , propce , propfa , propfb ,                   &
-   coefa  , coefb  , produc , w7   ,                              &
-   coefax , viscb  )
+   coefa  , coefb  , produc , w7     )
 
-!     Si on extrapole les T.S. : PROPCE
-if(isto2t.gt.0) then
-  do iel = 1, ncel
-     propce(iel,iptsta+isou-1) =                                  &
-     propce(iel,iptsta+isou-1) + w7(iel)
-   enddo
-!     Sinon SMBR
- else
-   do iel = 1, ncel
-     smbr(iel) = smbr(iel) + w7(iel)
-   enddo
- endif
+  ! Si on extrapole les T.S. : PROPCE
+  if(isto2t.gt.0) then
+    do iel = 1, ncel
+       propce(iel,iptsta+isou-1) =                                  &
+       propce(iel,iptsta+isou-1) + w7(iel)
+     enddo
+  ! Sinon SMBR
+  else
+    do iel = 1, ncel
+      smbr(iel) = smbr(iel) + w7(iel)
+    enddo
+  endif
 
 endif
 
@@ -588,10 +666,7 @@ if (idifre.eq.1) then
 !        (il reste des doutes sur la periodicite)
 
   if (irangp.ge.0.or.iperio.eq.1) then
-    call synvec(grad(1,1), grad(1,2), grad(1,3))
-    !==========
     call syndia(w4, w5, w6)
-    !==========
   endif
 
 
@@ -718,6 +793,8 @@ ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
 imucpp = 0
+idftnp = idften(ivar)
+iswdyp = iswdyn(ivar)
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
@@ -735,15 +812,16 @@ call codits &
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetv  ,                                              &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
-                     coefa(1,iclvar) , coefb(1,iclvar) ,          &
-                     coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
-                     propfa(1,iflmas), propfb(1,iflmab),          &
-   viscf  , viscb  , viscf  , viscb  ,                            &
+   coefa(1,iclvar) , coefb(1,iclvar) ,                            &
+   coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
+   propfa(1,iflmas), propfb(1,iflmab),                            &
+   viscf  , viscb  , rvoid  , viscf  , viscb  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
    rvoid  , rvoid  )
 
