@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -29,7 +29,7 @@ subroutine resssg &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
    coefa  , coefb  , grdvit , gradro ,                            &
    ckupdc , smcelp , gamma  ,                                     &
-   viscf  , viscb  , coefax ,                                     &
+   viscf  , viscb  ,                                              &
    tslage , tslagi ,                                              &
    smbr   , rovsdt )
 
@@ -77,9 +77,6 @@ subroutine resssg &
 ! gamma(ncesmp)    ! tr ! <-- ! valeur du flux de masse                        !
 ! viscf(nfac)      ! tr ! --- ! visc*surface/dist aux faces internes           !
 ! viscb(nfabor     ! tr ! --- ! visc*surface/dist aux faces de bord            !
-! coefax(nfabor    ! tr ! --- ! tab de trav pour cond.lim. paroi               !
-!                  ! tr ! --- !   attention : uniquement avec echo             !
-!                  ! tr ! --- !   de paroi et abs(icdpar) = 1                  !
 ! tslage(ncelet    ! tr ! <-- ! ts explicite couplage retour lagr.             !
 ! tslagi(ncelet    ! tr ! <-- ! ts implicite couplage retour lagr.             !
 ! smbr(ncelet      ! tr ! --- ! tableau de travail pour sec mem                !
@@ -129,7 +126,7 @@ double precision grdvit(ncelet,3,3)
 double precision gradro(ncelet,3)
 double precision ckupdc(ncepdp,6)
 double precision smcelp(ncesmp), gamma(ncesmp)
-double precision viscf(nfac), viscb(nfabor), coefax(nfabor)
+double precision viscf(nfac), viscb(nfabor)
 double precision tslage(ncelet),tslagi(ncelet)
 double precision smbr(ncelet), rovsdt(ncelet)
 
@@ -147,13 +144,15 @@ integer          iptsta
 integer          inc, iccocg, iphydp, ll, kkk
 integer          ipcvlo
 integer          idimte, itenso
-integer          imucpp
+integer          imucpp, idftnp, iswdyp
+integer          indrey(3,3)
+
 double precision blencp, epsilp, epsrgp, climgp, extrap, relaxp
 double precision epsrsp
 double precision trprod, trrij , rctse , deltij
 double precision tuexpr, thets , thetv , thetp1
 double precision aiksjk, aikrjk, aii ,aklskl, aikakj
-double precision xaniso(3,3), xstrai(3,3), xrotac(3,3), xprod(3,3)
+double precision xaniso(3,3), xstrai(3,3), xrotac(3,3), xprod(3,3), matrot(3,3)
 double precision xrij(3,3), xnal(3), xnoral, xnnd, xnu
 double precision d1s2, d1s3, d2s3, thetap
 double precision alpha3
@@ -182,6 +181,7 @@ allocate(dpvar(ncelet))
 
 ! Initialize variables to avoid compiler warnings
 
+iclal = 0
 iii = 0
 jjj = 0
 
@@ -250,7 +250,7 @@ call ustsri                                                       &
    ivar   ,                                                       &
    icepdc , icetsm , itpsmp ,                                     &
    dt     , rtpa   , propce , propfa , propfb ,                   &
-   coefa  , coefb  , ckupdc , smcelp , gamma  , grdvit , grdvit , &
+   ckupdc , smcelp , gamma  , grdvit , grdvit ,                   &
    smbr   , rovsdt )
 
 !     Si on extrapole les T.S.
@@ -389,6 +389,39 @@ if (iturb.eq.32) then
 
 endif
 
+if (icorio.eq.1) then
+
+  ! Compute the rotation matrix (dual antisymmetric matrix of the rotation vector)
+  matrot(1,2) = -omegaz
+  matrot(1,3) =  omegay
+  matrot(2,3) = -omegax
+
+  do ii = 1, 3
+    matrot(ii,ii) = 0.d0
+    do jj = ii+1, 3
+      matrot(jj,ii) = -matrot(ii,jj)
+    enddo
+  enddo
+
+else
+  do ii = 1, 3
+    do jj = 1, 3
+      matrot(ii,jj) = 0.d0
+    enddo
+  enddo
+endif
+
+! Index of the Reynolds stress variables in rtpa array
+indrey(1,1) = ir11
+indrey(2,2) = ir22
+indrey(3,3) = ir33
+indrey(1,2) = ir12
+indrey(1,3) = ir13
+indrey(2,3) = ir23
+indrey(2,1) = indrey(1,2)
+indrey(3,1) = indrey(1,3)
+indrey(3,2) = indrey(2,3)
+
 do iel=1,ncel
 
   ! EBRSM
@@ -439,6 +472,19 @@ do iel=1,ncel
                        rtpa(iel,ir23)*grdvit(iel,2,3) +         &
                        rtpa(iel,ir33)*grdvit(iel,3,3) )
 
+  ! Rotating frame of reference => "Coriolis production" term
+  if (icorio.eq.1) then
+    do ii = 1, 3
+      do jj = ii, 3
+        do kk = 1, 3
+          xprod(ii,jj) = xprod(ii,jj)                                   &
+                       - 2.d0*( matrot(ii,kk)*rtpa(iel,indrey(jj,kk))   &
+                              + matrot(jj,kk)*rtpa(iel,indrey(ii,kk)) )
+        enddo
+      enddo
+    enddo
+  endif
+
   xprod(2,1) = xprod(1,2)
   xprod(3,1) = xprod(1,3)
   xprod(3,2) = xprod(2,3)
@@ -482,6 +528,15 @@ do iel=1,ncel
   xrotac(3,2) = -xrotac(2,3)
   xrotac(3,3) = 0.d0
 
+  ! Rotating frame of reference => "absolute" vorticity
+  if (icorio.eq.1) then
+    do ii = 1, 3
+      do jj = 1, 3
+        xrotac(ii,jj) = xrotac(ii,jj) + matrot(ii,jj)
+      enddo
+    enddo
+  endif
+
   do ii=1,3
     do jj = 1,3
       ! aii = aij.aij
@@ -956,6 +1011,8 @@ ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
 imucpp = 0
+idftnp = idften(ivar)
+iswdyp = iswdyn(ivar)
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
@@ -973,15 +1030,16 @@ call codits &
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetv  ,                                              &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
-                     coefa(1,iclvar) , coefb(1,iclvar) ,          &
-                     coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
-                     propfa(1,iflmas), propfb(1,iflmab),          &
-   viscf  , viscb  , viscf  , viscb  ,                            &
+   coefa(1,iclvar) , coefb(1,iclvar) ,                            &
+   coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
+   propfa(1,iflmas), propfb(1,iflmab),                            &
+   viscf  , viscb  , rvoid  , viscf  , viscb  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
    rvoid  , rvoid  )
 
