@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -123,7 +123,7 @@ integer          iwarnp, ipp
 integer          iptsta
 integer          ipcroo, ipbroo, ipcvto, ipcvlo
 integer          ipatrg
-integer          imucpp
+integer          imucpp, idftnp, iswdyp
 
 logical          ilved
 
@@ -149,6 +149,7 @@ double precision, allocatable, dimension(:) :: w1
 double precision, allocatable, dimension(:) :: trgrdn, vort
 double precision, allocatable, dimension(:) :: tsexp
 double precision, allocatable, dimension(:) :: dpvar
+double precision, allocatable, dimension(:) :: csab1r, rotfct
 
 !===============================================================================
 
@@ -322,20 +323,20 @@ deallocate(grad)
 ! (and then give it the appropriate roughness value)
 
 ipatrg = 0
-dsa0   = -999.d0
+dsa0 = -999.d0
+hssa = -999.d0
 
 iclvar = iclrtp(inusa,icoef)
 do ifac = 1, nfabor
-  if ( itypfb(ifac).eq.iparug ) then
+  if (itypfb(ifac).eq.iparug) then
     ipatrg = 1
     cofbnu = coefb(ifac,iclvar)
     ! Roughness of the wall
     dsa0   = distb(ifac) *cofbnu/(1.d0-cofbnu)
     hssa   = exp(8.5d0*xkappa)*dsa0
   endif
-  if(ipatrg.ne.0) goto 100
+  if (ipatrg.ne.0) exit
 enddo
- 100    continue
 
 if(irangp.ge.0) then
   call parcpt(ipatrg)
@@ -345,6 +346,34 @@ if(irangp.ge.0) then
   endif
 endif
 
+! Take into account the Spalart-Shur rotation/curvature correction, if necessary
+! => variable production term coefficient (csab1)
+allocate(csab1r(ncel))
+
+if (irccor.eq.1) then
+
+  ! Allocate temporary array for rotation function
+  allocate(rotfct(ncel))
+
+  ! Compute the rotation function (w1 array not used)
+  call rotcor &
+  !==========
+( dt     , rtpa   , propce , coefa , coefb , &
+  rotfct , w1     )
+
+  do iel = 1, ncel
+    csab1r(iel) = csab1*rotfct(iel)
+  enddo
+
+  ! Free memory
+  deallocate(rotfct)
+
+else
+  do iel = 1, ncel
+    csab1r(iel) = csab1
+  enddo
+endif
+
 ! If source terms are extrapolated, rho is rho^n
 !                                 visct is visct^n
 do iel = 1, ncel
@@ -389,15 +418,18 @@ do iel = 1, ncel
   fw    = gsa*( (1.d0+csaw3**6)/(gsa**6+csaw3**6))**(1.d0/6.d0)
 
   rhssa(iel) = volume(iel)*rom*(                                 &
-     dsigma * csab2*trgrdn(iel)+csab1*taussa*nusa-csaw1*fw*(nusa/distbf)**2)
+     dsigma * csab2*trgrdn(iel)+csab1r(iel)*taussa*nusa-csaw1*fw*(nusa/distbf)**2)
 
   ! Implicitation of the negative source terms of the SA equation.
   ! NB : this term could be negative, and if so, then we explicit it.
-  tinssa(iel) = (max(csaw1*fw*nusa/distbf**2-csab1*taussa,0.d0)         &
+  tinssa(iel) = (max(csaw1*fw*nusa/distbf**2-csab1r(iel)*taussa,0.d0)         &
                       )*rom*volume(iel)
 
 enddo
 
+! Free memory
+deallocate(csab1r)
+
 !===============================================================================
 ! 5. Take user source terms into account
 
@@ -416,7 +448,7 @@ call ustssa                                                       &
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    icepdc , icetsm , itypsm ,                                     &
    dt     , rtpa   , propce , propfa , propfb ,                   &
-   coefa  , coefb  , ckupdc , smacel , vort   , trgrdu ,          &
+   ckupdc , smacel , vort   , trgrdu ,                            &
    tsexp  , tsimp )
 
 !===============================================================================
@@ -610,6 +642,8 @@ ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
 imucpp = 0
+idftnp = idften(ivar)
+iswdyp = iswdyn(ivar)
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
@@ -628,15 +662,16 @@ call codits &
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , imucpp ,                            &
+   ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
-                     coefa(1,iclvar) , coefb(1,iclvar) ,          &
-                     coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
-                     propfa(1,iflmas), propfb(1,iflmab),          &
-   viscf  , viscb  , viscf  , viscb  ,                            &
+   coefa(1,iclvar) , coefb(1,iclvar) ,                            &
+   coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
+   propfa(1,iflmas), propfb(1,iflmab),                            &
+   viscf  , viscb  , rvoid  , viscf  , viscb  , rvoid  ,          &
+   rvoid  , rvoid  ,                                              &
    tinssa , rhssa  , rtp(1,ivar)     , dpvar ,                    &
    rvoid  , rvoid  )
 
