@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -228,6 +228,7 @@ enddo
 
 do iel = 1, ncel
 
+  ! gradv(iel, xyz, uvw)
   s11   = gradv(iel,1,1)
   s22   = gradv(iel,2,2)
   s33   = gradv(iel,3,3)
@@ -442,7 +443,7 @@ call ussmag                                                       &
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  , ckupdc , smacel ,                            &
+   ckupdc , smacel ,                                              &
    smagor , w1     , w2     )
 
 iclipc = 0
