@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -268,7 +268,7 @@ endif
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
 
-end subroutine
+end subroutine usray3
 
 
 !===============================================================================
@@ -281,7 +281,6 @@ subroutine usray4 &
    mode   ,                                                       &
    itypfb ,                                                       &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
    tparop , hparop , tempk  )
 
 !===============================================================================
@@ -314,8 +313,6 @@ subroutine usray4 &
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
 ! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
 ! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
 ! tparop(nfabor)   ! i  ! <-- ! temperature in kelvin for wall boundary faces  !
 ! hparop(nfabor)   ! i  ! --> ! enthalpy for wall boundary faces               !
 ! tempk(ncelet)    ! i  ! --> ! temperature in kelvin                          !
@@ -360,7 +357,6 @@ integer          itypfb(nfabor)
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
-double precision coefa(nfabor,*), coefb(nfabor,*)
 
 double precision tempk(ncelet)
 double precision tparop(nfabor), hparop(nfabor)
@@ -423,7 +419,7 @@ endif
 !----
 
 return
-end subroutine
+end subroutine usray4
 
 !===============================================================================
 
@@ -630,4 +626,4 @@ endif
 ! End
 !----
 
-end subroutine
+end subroutine usray5
