@@ -568,32 +568,40 @@ if (modcpl.gt.0) idirla = 1
 !===============================================================================
 ! 10. Options concerning the treatment of specific forces
 !===============================================================================
+!         IDLVO = 0
+!               = 1   DLVO deposition conditions are activated for the
+!                     wall with appropriate conditions idepfa (see uslag2.f90)
+
+idlvo = 0
+
+if (idlvo.eq.1) then
 
 !-->  Constants for the van der Waals forces
 !     --------------------------------------
 !    Hamaker constant for the particle/fluid/substrate system:
 
-cstham = 6.d-20
+  cstham = 6.d-20
 
 !-->  Constants for the elecstrostatic forces
 !    ----------------------------------------
 
 !    Dielectric constant of the fluid (example: water at 293 K)
 
-epseau = 80.10d0
+  epseau = 80.10d0
 
 !    Electrokinetic potential of the first solid (Volt)
 
-phi1 = 50.d-3
+  phi1 = 50.d-3
 
 !    Electrokinetic potential of the second solid (Volt)
 
-phi2 = -50.d-3
+  phi2 = -50.d-3
 
 !    Ionic force (mol/l)
 
-fion = 1.d-2
+  fion = 1.d-2
 
+endif
 
 !===============================================================================
 ! 11. Activation of Brownian motion
@@ -622,122 +630,70 @@ lamvbr = 0
 
 idepst = 0
 
+
+
 !===============================================================================
-! 13. Post-processing
+! 12bis. Activation of resuspension model
 !===============================================================================
 
-! 13.1 Post-processing of the trajectories and particle displacements
+!--> Activation of the resuspension model
+
+!    (default off: 0 ; on: 1)
+
+!     CAUTION: OPTION FOR DEVELOPERS ONLY
+!     =========
+
+ireent = 0
+
+!--> Parameters of the particle resuspension model
+
+espasg = 20.d-6
+
+denasp = 6.36d13
+
+modyeq = 266.d9
+
+rayasp = 5.d-9
+
+rayasg = 2.d-6
 
 
-!     CAUTION: COMPUTATIONALLY EXPENSIVE
-!     ^^^^^^^^^^
-
-!   13.1.1 Generic parameters
-!   ~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-!     Trajectory mode
-!     (default off: 0 ; on: 1)
-
-iensi1 = 0
-
-!     Particle-displacement mode
-!     (default off: 0 ; on: 1)
-
-iensi2 = 0
-
-
-!     Maximal number of particles to visualize = nliste
-!     (default nbvis=nliste)
-!     Be careful, nbvis must not be greater than nbpmax nor nliste
-
-nbvis = nliste
-
-!     Acquisition period of the data to visualize
-!     (default nvisla = 1)
-
-nvisla = 1
-
-!     The liste array contains the numbers of particles that we want to
-!     visualize (by default liste(...) = -1, no particle to visualize)
-!     Be careful, if the number is negative, there is no visualization)
+!===============================================================================
+! 13. Variables to visualize on the trajectories or the particles
 !
-!     Example 1: the user wants to track the first nbvis
+!     See also cs_user_postprocess_mesh in cs_user_postprocess.c to define
+!     the associated visualization particle or trajectory segment meshes.
+!===============================================================================
 
-do ii = 1, nbvis
-  liste(ii) = ii
-enddo
-
-!   > Example 2:
-!     I want to track 3 5 67 23 1 76 35 36 ...etc..
-
-!     liste(1) = 3
-!     liste(2) = 5
-!     liste(3) = 67
-!     liste(4) = 23
-!     liste(5) = 1
-!     liste(6) = 76
-!     liste(7) = 35
-!     liste(8) = 36
-!     ...etc...
-
-!   > Remark: the holes, the repetitions of the liste array will be deleted,
-!             and the numbers will be sorted in increasing order
-!
-!
-
-!   13.1.2 Variables to visualize on the trajectories or the particles
-!   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-!     Variable: velocity of the flow seen
-!     (default off: 0 ; on: 1)
+! For all the following variables, a value of 0 means "off", and 1 means "on"
 
+! velocity of the flow seen
 ivisv1  = 0
 
-!     Variable: particle velocity
-!     (default off: 0 ; on: 1)
-
+! particle velocity
 ivisv2  = 0
 
-!     Variable: residence time
-!     (default off: 0 ; on: 1)
-
+! residence time
 ivistp  = 0
 
-!     Variable: diameter
-!     (default off: 0 ; on: 1)
-
+! diameter
 ivisdm  = 0
 
-!     Variable: temperature
-!     (default off: 0 ; on: 1)
+! temperature
 if (iphyla.eq.1 .and. itpvar.eq.1) iviste  = 0
 
-!     Variable: mass
-!     (default off: 0 ; on: 1)
-
+! mass
 ivismp  = 0
 
-
 if (iphyla.eq.2) then
 
-!       Variable coal: temperature in Celsius degrees
-!       (default off: 0 ; on: 1)
-
-  ivishp = 0
-
-!       Variable coal: diameter of the shrinking core
-!       (default off: 0 ; on: 1)
-
+  ! coal: diameter of the shrinking core
   ivisdk  = 0
 
-!       Variable coal: mass of reactive coal
-!       (default off: 0 ; on: 1)
-
+  ! coal: mass of reactive coal
   ivisch  = 0
 
-!       Variable coal: mass of coke
-!       (default off: 0 ; on: 1)
-
+  ! coal: mass of coke
   ivisck  = 0
 
 endif
