@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -28,7 +28,7 @@ subroutine cs_user_boundary_conditions &
  ( nvar   , nscal  ,                                              &
    icodcl , itrifb , itypfb , izfppp ,                            &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  , rcodcl )
+   rcodcl )
 
 !===============================================================================
 ! Purpose:
@@ -387,8 +387,6 @@ subroutine cs_user_boundary_conditions &
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
 ! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
 ! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
 ! rcodcl           ! ra ! --> ! boundary condition values                      !
 !  (nfabor,nvar,3) !    !     ! rcodcl(1) = Dirichlet value                    !
 !                  !    !     ! rcodcl(2) = exterior exchange coefficient      !
@@ -439,15 +437,14 @@ implicit none
 
 integer          nvar   , nscal
 
-integer          icodcl(nfabor,nvar)
+integer          icodcl(nfabor,nvarcl)
 integer          itrifb(nfabor), itypfb(nfabor)
 integer          izfppp(nfabor)
 
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
-double precision coefa(nfabor,*), coefb(nfabor,*)
-double precision rcodcl(nfabor,nvar,3)
+double precision rcodcl(nfabor,nvarcl,3)
 
 ! Local variables
 
@@ -490,8 +487,9 @@ rugt=0.1d0
 !===============================================================================
 
 ! --- For boundary faces of color 11,
-!       assign an inlet boundary condition for all phases prescribed from the meteo profile
-!       with automatic choice between inlet/ outlet according to the meteo profile
+!       assign an inlet boundary condition for all phases prescribed from the
+!       meteo profile with automatic choice between inlet/ outlet according to
+!       the meteo profile
 
 call getfbr('11',nlelt,lstelt)
 !==========
@@ -502,17 +500,21 @@ do ilelt = 1, nlelt
 
   ifac = lstelt(ilelt)
 
-!     - Zone to which the face belongs
+  ! - Zone to which the face belongs
   izfppp(ifac) = izone
 
-!     - Boundary conditions are prescribed from the meteo profile
+  ! - CAUTION: do not assign boundary condition type (itypfb(ifac))
+  !            as it is automatically set by the code.
+
+  ! - Boundary conditions are prescribed from the meteo profile
   iprofm(izone) = 1
 
 enddo
 
 
 ! ---For boundary faces of color 21,
-!     assign an inlet boundary condition for all phases prescribed from the meteo profile
+!     assign an inlet boundary condition for all phases prescribed from the
+!     meteo profile
 
 call getfbr('21',nlelt,lstelt)
 !==========
@@ -523,13 +525,13 @@ do ilelt = 1, nlelt
 
   ifac = lstelt(ilelt)
 
-!     - Zone to which the face belongs
+  ! - Zone to which the face belongs
   izfppp(ifac) = izone
 
-!     - Boundary conditions are prescribed from the meteo profile
+  ! - Boundary conditions are prescribed from the meteo profile
   iprofm(izone) = 1
 
-!     - Assign inlet boundary conditions
+  ! - Assign inlet boundary conditions
   itypfb(ifac) = ientre
 
 enddo
@@ -549,13 +551,13 @@ do ilelt = 1, nlelt
 
   ifac = lstelt(ilelt)
 
-!     - Zone to which the face belongs
+  ! - Zone to which the face belongs
   izfppp(ifac) = izone
 
-!     - Boundary conditions are prescribed from the meteo profile
+  ! - Boundary conditions are prescribed from the meteo profile
   iprofm(izone) = 1
 
-!     - Dynamical variables are prescribed with a rough log law
+  ! - Dynamical variables are prescribed with a rough log law
   zent=cdgfbo(3,ifac)
 
   ustar=xkappa*xuref/log((zref+rugd)/rugd)
@@ -617,7 +619,7 @@ do ilelt = 1, nlelt
 
   ifac = lstelt(ilelt)
 
-!     - Zone to which the zone belongs
+  ! - Zone to which the zone belongs
   izfppp(ifac) = izone
 
   ! Outlet: zero flux for velocity and temperature, prescribed pressure
@@ -643,16 +645,16 @@ do ilelt = 1, nlelt
   !       rough friction for velocities (+ turbulent variables)
   !       zero flux for scalars
 
-!     - Zone to which the zone belongs
+  ! - Zone to which the zone belongs
   izfppp(ifac) = izone
 
   itypfb(ifac)   = iparug
 
-  !     Roughness for velocity: rugd
+  ! Roughness for velocity: rugd
   rcodcl(ifac,iu,3) = rugd
 
-  !     Roughness for scalars (if required):
-  !   rcodcl(ifac,iv,3) = rugd
+  ! Roughness for scalars (if required):
+  ! rcodcl(ifac,iv,3) = rugd
 
 
   if(iscalt.ne.-1) then
@@ -682,7 +684,7 @@ do ilelt = 1, nlelt
 
   ifac = lstelt(ilelt)
 
-!     - Zone to which the zone belongs
+  ! - Zone to which the zone belongs
   izfppp(ifac) = izone
 
   itypfb(ifac)   = isymet
@@ -700,4 +702,4 @@ enddo
 deallocate(lstelt)  ! temporary array for boundary faces selection
 
 return
-end subroutine
+end subroutine cs_user_boundary_conditions
