@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2012 EDF S.A.
+! Copyright (C) 1998-2013 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -22,66 +22,57 @@
 
 !-------------------------------------------------------------------------------
 
-subroutine cs_user_extra_operations &
-!==================================
-
- ( nvar   , nscal  ,                                              &
-   nbpmax , nvp    , nvep   , nivep  , ntersl , nvlsta , nvisbr , &
-   itepa  ,                                                       &
-   dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
-   ettp   , ettpa  , tepa   , statis , stativ , tslagr , parbor )
-
 !===============================================================================
 ! Purpose:
 ! -------
 
-!    User subroutine.
+! This is an example of cs_user_extra_operations.f90 which
+! performs an energy balance.
 
-!    Called at end of each time step, very general purpose
-!    (i.e. anything that does not have another dedicated user subroutine)
+!-------------------------------------------------------------------------------
 
 !-------------------------------------------------------------------------------
 ! Arguments
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
-! nbpmax           ! i  ! <-- ! max. number of particles allowed               !
-! nvp              ! i  ! <-- ! number of particle-defined variables           !
-! nvep             ! i  ! <-- ! number of real particle properties             !
-! nivep            ! i  ! <-- ! number of integer particle properties          !
-! ntersl           ! i  ! <-- ! number of return coupling source terms         !
-! nvlsta           ! i  ! <-- ! number of Lagrangian statistical variables     !
-! nvisbr           ! i  ! <-- ! number of boundary statistics                  !
-! itepa            ! ia ! <-- ! integer particle attributes                    !
-!  (nbpmax, nivep) !    !     !   (containing cell, ...)                       !
-! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
-!  (ncelet, *)     !    !     !  (at current and previous time steps)          !
-! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
-! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
-! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
-! ettp, ettpa      ! ra ! <-- ! particle-defined variables                     !
-!  (nbpmax, nvp)   !    !     !  (at current and previous time steps)          !
-! tepa             ! ra ! <-- ! real particle properties                       !
-!  (nbpmax, nvep)  !    !     !  (statistical weight, ...                      !
-! statis           ! ra ! <-- ! statistic means                                !
-!  (ncelet, nvlsta)!    !     !                                                !
-! stativ(ncelet,   ! ra ! <-- ! accumulator for variance of volume statisitics !
-!        nvlsta -1)!    !     !                                                !
-! tslagr           ! ra ! <-- ! Lagrangian return coupling term                !
-!  (ncelet, ntersl)!    !     !  on carrier phase                              !
-! parbor           ! ra ! <-- ! particle interaction properties                !
-!  (nfabor, nvisbr)!    !     !  on boundary faces                             !
-!__________________!____!_____!________________________________________________!
+!______________________________________________________________________________.
+!  mode           name          role                                           !
+!______________________________________________________________________________!
+!> \param[in]     nvar          total number of variables
+!> \param[in]     nscal         total number of scalars
+!> \param[in]     nbpmax        max. number of particles allowed
+!> \param[in]     nvp           number of particle-defined variables
+!> \param[in]     nvep          number of real particle properties
+!> \param[in]     nivep         number of integer particle properties
+!> \param[in]     ntersl        number of return coupling source terms
+!> \param[in]     nvlsta        number of Lagrangian statistical variables
+!> \param[in]     nvisbr        number of boundary statistics
+!> \param[in]     itepa         integer particle attributes
+!>                                (containing cell, ...)
+!> \param[in]     dt            time step (per cell)
+!> \param[in]     rtp, rtpa     calculated variables at cell centers
+!>                               (at current and previous time steps)
+!> \param[in]     propce        physical properties at cell centers
+!> \param[in]     propfa        physical properties at interior face centers
+!> \param[in]     propfb        physical properties at boundary face centers
+!> \param[in]     ettp, ettpa   particle-defined variables
+!> \param[in]                    (at current and previous time steps)
+!> \param[in]     tepa          real particle properties
+!> \param[in]                    (statistical weight, ...
+!> \param[in]     statis        statistic means
+!> \param[in]     stativ        accumulator for variance of volume statisitics
+!> \param[in]     tslagr        Lagrangian return coupling term
+!> \param[in]                    on carrier phase
+!> \param[in]     parbor        particle interaction properties
+!> \param[in]                    on boundary faces
+!_______________________________________________________________________________
+
+
+subroutine cs_user_extra_operations &
+ ( nvar   , nscal  ,                                              &
+   nbpmax , nvp    , nvep   , nivep  , ntersl , nvlsta , nvisbr , &
+   itepa  ,                                                       &
+   dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
+   ettp   , ettpa  , tepa   , statis , stativ , tslagr , parbor )
 
-!     Type: i (integer), r (real), s (string), a (array), l (logical),
-!           and composite types (ex: ra real array)
-!     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
 !===============================================================================
@@ -104,6 +95,7 @@ use ppppar
 use ppthch
 use ppincl
 use mesh
+use field
 
 !===============================================================================
 
@@ -120,7 +112,6 @@ integer          itepa(nbpmax,nivep)
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(ndimfb,*)
-double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
 double precision statis(ncelet,nvlsta), stativ(ncelet,nvlsta-1)
@@ -130,12 +121,12 @@ double precision parbor(nfabor,nvisbr)
 
 ! Local variables
 
+!< [loc_var_dec]
 integer          iel    , ifac   , ivar
 integer          iel1   , iel2   , ieltsm
 integer          iortho
 integer          inc    , iccocg
 integer          nswrgp , imligp , iwarnp
-integer          iclvar , iclvaf
 integer          ipcrom , ipcvst , iflmas , iflmab , ipccp, ipcvsl
 integer          iscal
 integer          ncesmp
@@ -152,121 +143,24 @@ double precision visct, flumab , xcp , xvsl, ctb1, ctb2
 
 integer, allocatable, dimension(:) :: lstelt
 
+double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: treco
+!< [loc_var_dec]
 
 !===============================================================================
 ! Initialization
 !===============================================================================
 
+!< [init]
 ! Allocate a temporary array for cells or interior/boundary faces selection
 allocate(lstelt(max(ncel,nfac,nfabor)))
-
-!===============================================================================
-! Example: compute energy balance relative to temperature
-! -------------------------------------------------------
-
-! We assume that we want to compute balances  (convective and diffusive)
-! at the boundaries of the calculation domain represented below
-! (with boundaries marked by colors).
-
-! The scalar considered if the temperature. We will also use the
-! specific heat (to obtain balances in Joules)
-
-
-! Domain and associated boundary colors
-! -------------------------------------
-!                  6
-!      --------------------------
-!      |                        |
-!      |                        |
-!   7  |           1            | 5
-!      |     ^                  |
-!      |     |                  |
-!      --------------------------
-
-!         2  3             4
-
-! 2, 4, 7 : adiabatic walls
-! 6       : wall with fixed temperature
-! 3       : inlet
-! 5       : outlet
-! 1       : symmetry
-
-!-------------------------------------------------------------------------------
-
-! To ensure calculations have physical meaning, it is best to use
-! a spatially uniform time step (idtvar = 0 or 1).
-! In addition, when restarting a calculation, the balance is
-! incorrect if inpdt0 = 1 (visct not initialized and t(n-1) not known)
-
-!-------------------------------------------------------------------------------
-
-! Temperature variable: ivar = isca(iscalt) (use rtp(iel, ivar))
-
-!-------------------------------------------------------------------------------
-
-! The balance at time step n is equal to:
-
-!        n        iel=ncelet           n-1
-! balance  =   sum { volume(iel)*cp*rom(iel)*(rtpa(iel,ivar)-rtp(iel,ivar)) }
-!                 iel=1
-
-!                 ifac=nfabor
-!            + sum {
-!                 ifac=1
-
-!                     surfbn(ifac)*dt(ifabor(ifac))*cp
-!                   * [  coefa(ifac,iclvaf)
-!                      + coefb(ifac,iclvaf)*rtp(ifabor(ifac,ivar))]
-!                  }
-
-!                 ifac=nfabor
-!            + sum {
-!                 ifac=1
-!                     dt(ifabor(ifac))*cp
-!                   * rtp(ifabor(ifac,ivar))*(-flumab(ifac))
-!                  }
-
-! The first term is negative if the amount of energy in the volume
-! has decreased (it is 0 in a steady regime).
-
-! The other terms (convection, diffusion) are positive if the amount
-! of energy in the volume has increased due to boundary conditions.
-
-! In a steady regime, a positive balance thus indicates an energy gain.
-
-!-------------------------------------------------------------------------------
-
-! With 'rom' calculated using the density law from the usphyv subroutine,
-! for example:
-
-!    n-1
-! rom(iel) = p0 / [rr * (rtpa(iel,ivar) + tkelv)]
-
-!-------------------------------------------------------------------------------
-
-! Cp and lambda/Cp may be variable
-
-!-------------------------------------------------------------------------------
-
-! Adaptation to an arbitrary scalar
-! ---------------------------------
-
-! The approach may be used for the balance of any other scalar (but the
-! balances are not in Joules and the specific heat is not used)
-
-! In this case:
-
-! - replace iscalt by the number iscal of the required scalar,
-!   iscal having an allowed range of 1 to nscal.
-
-! - set ipccp to 0 independently of the value of icp and use 1 instead of cp0
+!< [init]
 
 !===============================================================================
 
+!< [example_1]
 ! The balance is not valid if inpdt0=1
-
 if (inpdt0.eq.0) then
 
   ! 2.1 Initialization
@@ -298,9 +192,7 @@ if (inpdt0.eq.0) then
   xbilan = 0.d0
 
   iscal = iscalt         ! temperature scalar number
-  ivar =  isca(iscal)           ! temperature variable number
-  iclvar = iclrtp(ivar,icoef)   ! boundary condition number for gradients and advection
-  iclvaf = iclrtp(ivar,icoeff)  ! boundary condition number for diffusion
+  ivar =  isca(iscal)    ! temperature variable number
 
   ! Physical quantity numbers
   ipcrom = ipproc(irom)
@@ -325,6 +217,16 @@ if (inpdt0.eq.0) then
     ipcvsl = 0
   endif
 
+  ! Boundary condition pointers for gradients and advection
+
+  call field_get_coefa_s(ivarfl(ivar), coefap)
+  call field_get_coefb_s(ivarfl(ivar), coefbp)
+
+  ! Boundary condition pointers for diffusion
+
+  call field_get_coefaf_s(ivarfl(ivar), cofafp)
+  call field_get_coefbf_s(ivarfl(ivar), cofbfp)
+
   ! --> Synchronization of Cp and Dt
   !     ----------------------------
 
@@ -426,7 +328,7 @@ if (inpdt0.eq.0) then
       ( ivar   , imrgra , inc    , iccocg , nswrgp , imligp ,          &
         iwarnp , nfecra ,                                              &
         epsrgp , climgp , extrap ,                                     &
-        rtp(1,ivar) , coefa(1,iclvar) , coefb(1,iclvar) ,              &
+        rtp(1,ivar) , coefap , coefbp ,                                &
         grad   )
 
     ! - Compute reconstructed value in boundary cells
@@ -612,10 +514,10 @@ if (inpdt0.eq.0) then
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = surfbn(ifac) * dt(iel) * xcp                             &
-             * (coefa(ifac,iclvaf) + coefb(ifac,iclvaf)*treco(ifac))  &
-           - flumab * dt(iel) * xcp                                   &
-             * (coefa(ifac,iclvar) + coefb(ifac,iclvar)*treco(ifac))
+    xfluxf = surfbn(ifac) * dt(iel) * xcp                   &
+             * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
+           - flumab * dt(iel) * xcp                         &
+             * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilpa = xbilpa + xfluxf
 
@@ -656,10 +558,10 @@ if (inpdt0.eq.0) then
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = surfbn(ifac) * dt(iel) * xcp                            &
-             * (coefa(ifac,iclvaf) + coefb(ifac,iclvaf)*treco(ifac)) &
-           - flumab * dt(iel) * xcp                                  &
-             * (coefa(ifac,iclvar) + coefb(ifac,iclvar)*treco(ifac))
+    xfluxf = surfbn(ifac) * dt(iel) * xcp                   &
+             * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
+           - flumab * dt(iel) * xcp                         &
+             * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilpt = xbilpt + xfluxf
 
@@ -699,10 +601,10 @@ if (inpdt0.eq.0) then
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = surfbn(ifac) * dt(iel) * xcp                             &
-             * (coefa(ifac,iclvaf) + coefb(ifac,iclvaf)*treco(ifac))  &
-           - flumab * dt(iel) * xcp                                   &
-             * (coefa(ifac,iclvar) + coefb(ifac,iclvar)*treco(ifac))
+    xfluxf = surfbn(ifac) * dt(iel) * xcp                   &
+             * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
+           - flumab * dt(iel) * xcp                         &
+             * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilsy = xbilsy + xfluxf
 
@@ -742,10 +644,10 @@ if (inpdt0.eq.0) then
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = surfbn(ifac) * dt(iel) * xcp                             &
-             * (coefa(ifac,iclvaf) + coefb(ifac,iclvaf)*treco(ifac))  &
-           - flumab * dt(iel) * xcp                                   &
-             * (coefa(ifac,iclvar) + coefb(ifac,iclvar)*treco(ifac))
+    xfluxf = surfbn(ifac) * dt(iel) * xcp                   &
+             * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
+           - flumab * dt(iel) * xcp                         &
+             * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilen = xbilen + xfluxf
 
@@ -785,10 +687,10 @@ if (inpdt0.eq.0) then
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = surfbn(ifac) * dt(iel) * xcp                             &
-             * (coefa(ifac,iclvaf) + coefb(ifac,iclvaf)*treco(ifac))  &
-           - flumab * dt(iel) * xcp                                   &
-             * (coefa(ifac,iclvar) + coefb(ifac,iclvar)*treco(ifac))
+    xfluxf = surfbn(ifac) * dt(iel) * xcp                   &
+             * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
+           - flumab * dt(iel) * xcp                         &
+             * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilso = xbilso + xfluxf
 
@@ -878,9 +780,12 @@ if (inpdt0.eq.0) then
    '------------------------------------------------------------')
 
 endif ! End of test on inpdt0
+!< [example_1]
 
+!< [finalize]
 ! Deallocate the temporary array
 deallocate(lstelt)
+!< [finalize]
 
 return
-end subroutine
+end subroutine cs_user_extra_operations
