@@ -637,14 +637,6 @@ if (.false.) then
       ichrvr(ipp)  = 1
       ilisvr(ipp)  = 1
       ihisvr(ipp,1)= -1
-
-      ! - Water mass fraction (in class ICLA)
-      if (ippmod(icp3pl) .eq. 1) then
-        ipp = ipprtp(isca(ixwt(icla)))
-        ichrvr(ipp)  = 1
-        ilisvr(ipp)  = 1
-        ihisvr(ipp,1)= -1
-      endif
     enddo
 
   endif
@@ -676,14 +668,6 @@ if (.false.) then
         ichrvr(ipp)  = 1
         ilisvr(ipp)  = 1
         ihisvr(ipp,1)= -1
-
-        !  Water mass fraction (in class ICLA)
-        if (ippmod(icp3pl) .eq. 1) then
-          ipp = ipprtp(isca(ixwt(icla)))
-          ichrvr(ipp)  = 1
-          ilisvr(ipp)  = 1
-          ihisvr(ipp,1)= -1
-        endif
       enddo
 
     endif
@@ -1037,15 +1021,6 @@ if (.false.) then
       ihisvr(ipp,1) = -1
     endif
 
-    ! - Rate of drying (s-1) < 0
-    !   (from class ICLA)
-    if (ippmod(icp3pl) .eq. 1) then
-      ipp = ipppro(ipproc(igmsec(icla)))
-      ichrvr(ipp)   = 0
-      ilisvr(ipp)   = 0
-      ihisvr(ipp,1) = -1
-    endif
-
     ! - Mass fraction (of class ICLA) in mix
     ipp = ipppro(ipproc(ix2(icla)))
     ichrvr(ipp)   = 1
